#!/usr/bin/env python2

'''
This module contains utilities for working with multiple instances of services
'''

import re

def instance_hostname(host_hostname, instance_id=2, multiplier=10000):
    """Return the instance hostname associated with a given host hostname

    If more than one instance is used, a instance_number may be provided.

    >>> instance_hostname("ics1.pop.llnw.net")
    'ics20001.pop.llnw.net'

    >>> instance_hostname("ics10.pop.llnw.net")
    'ics20010.pop.llnw.net'

    >>> instance_hostname("ics1.lga.llnw.net")
    'ics20001.lga.llnw.net'

    >>> instance_hostname("ics1.lga.llnw.net", 3)
    'ics30001.lga.llnw.net'

    >>> instance_hostname("ics10.lax.llnw.net")
    'ics20010.lax.llnw.net'

    >>> instance_hostname("ics123.phx7.llnw.net")
    'ics20123.phx7.llnw.net'

    >>> instance_hostname("sae-ics-menglish.saltdev.llnw.net")
    'sae-ics-menglish20001.saltdev.llnw.net'

    >>> instance_hostname("malformed.hostname.limelight.com")
    Traceback (most recent call last):
    ...
    Exception: Could not parse hostname 'malformed.hostname.limelight.com'

    >>> instance_hostname("icstest-1.qa.llnw.net")
    'icstest-20001.qa.llnw.net'

    >>> instance_hostname("icstest-6.phx7.qa.llnw.net")
    Traceback (most recent call last):
    ...
    Exception: Could not parse hostname 'icstest-6.phx7.qa.llnw.net'

    """

    # host_hostname pattern: "{host_type}{host_number}.{host_pop}.llnw.net"
    # instance_hostname pattern: "{host_type}{base + host_number}.{host_pop}.llnw.net"
    m = re.search('^([^\d.]+)(\d*)\.(\w+)\.llnw\.net$', host_hostname)

    if m:
        host_type = m.group(1)
        host_number = m.group(2) if m.group(2) else '1'
        host_pop = m.group(3)

        n = instance_id * multiplier
        instance_hostnumber = int(n) + int(host_number)

        instance_hostname = "%s%d.%s.llnw.net" % (host_type, instance_hostnumber, host_pop)
        return instance_hostname
    else:
        raise Exception("Could not parse hostname '{0}'".format(host_hostname))

    return instance_hostname

if __name__ == "__main__":
    # Run tests with `python ./mproc.py -v`
    import doctest
    doctest.testmod()
