#!jinja|pyobjects

''' Manages salt repositories.

    Depends:
        - ghe module
        - ghe.conf configuration file (under minion.d)

    1. Ensure repository listed in teams.yml exists in configured org
    2. Ensure 'automation' user (jenkins) has admin rights on the repo
    3. Manage hooks
'''

include('leck.ghe')

{% import_yaml 'leck/hooks.yml' as hooks %}
{% import_yaml 'teams.yml' as teams %}

hooks = {{ hooks }}
teams = {{ teams }}
team = 'automation'  # team with user that leck uses.


def hooks_manage(repo):
    existing_hooks_by_url = {hook_obj['config']['url']: hook_obj
                             for hook_obj in salt.ghe.hook_list(repo)}

    for hook_obj in hooks.values():
        msg = 'hook {0} on {1}'.format(hook_obj['config']['url'], repo)

        if hook_obj['config']['url'] in existing_hooks_by_url.keys():
            existing_hook = existing_hooks_by_url[hook_obj['config']['url']]
            existing_hook.pop('id', None) # remove id before comparing

            if hook_obj != existing_hook:

                # The hook needs to be updated:
                if salt.ghe.hook_update(repo,
                                        hook_obj['config']['url'],
                                        hook_obj):
                    Test.succeed_with_changes('Updated {0}'.format(msg))
                else:
                    Test.fail_without_changes('Failed to update {0}'.format(
                        msg))
        else:
            res = salt.ghe.hook_create(repo, hook_obj)

            if res.startswith('Success'):
                Test.succeed_with_changes('Created {0}'.format(msg))
            else:
                Test.fail_without_changes('Failed to create {0}'.format(msg))


for repo in teams.keys():
    Test.nop('Managing configuration for repository {0}'.format(repo))

    if salt.ghe.repo_exists(repo):

        if not salt.ghe.team_admins_repo(repo, team, add=True):
            Test.fail_without_changes(
                'Failed to modify admin on {0}'.format(repo))
        hooks_manage(repo)
    else:
        # We do not create repos from salt, just notifying.
        # In order to create repos, the account used has to have
        # admin over an org.
        Test.fail_without_changes('Repo {0} is missing.'.format(repo))
