# vim: sts=2 ts=2 sw=2 et ai

# teams.yml from the salt-state repo 
{%- import_yaml "teams.yml" as salt_teams %}
{%- import_yaml "leck/disabled_repos.yml" as disabled_repos %}

{% set base_url = 'http://repo.llnw.net/llnw/ubuntu/testing/python-modules' %}
{% set ghe_key = pillar['secrets']['sae']['github_key'] %}

sae|leck|pkg:
  pkgrepo.managed:
    - name: deb {{ base_url }} precise/
    - file: /etc/apt/sources.list.d/llnw.python-modules.test.list
    - refresh_db: false
  pkg.installed:
    - skip_verify: True  # necessary for internal unsigned debs
    - names:
      - python-github3.py
      - python-web.py
      - python-leck
      - git
    - require:
      - pkgrepo: sae|leck|pkg

sae|leck|config_file:
  file.managed:
    - name: /etc/leck/config.ini
    - template: jinja
    - backup: False
    - mode: 660
    - user: jenkins
    - source: salt://leck/templates/config.jinja
    - makedirs: True
    - defaults:
        github_key: {{ ghe_key }}

sae|leck|run_file:
  file.managed:
    - name: /srv/leck/run_leck.py
    - backup: False
    - mode: 755
    - user: jenkins
    - source: salt://leck/files/run_leck.py
    - makedirs: True

# Include repos of each salt-{team} in list of managed repositories
{% set repos = salt_teams %}
# Add to list of managed repositories:
{% do repos.update({
    'salt-pillar': {},
    'repo-mirrorer-apt': {},
}) %}

{%- for repo in repos.keys() %}
{%-   if repo not in disabled_repos %}
# https://github.com/blog/1270-easier-builds-and-deployments-using-git-over-https-and-oauth
sae|leck|git-{{ ghe_key }}-{{ repo }}:
  git.latest:
    - rev: master
    - user: jenkins
    - force_reset: True
    - name: https://{{ ghe_key }}@github.llnw.net/llnw/{{ repo }}.git
    - target: /tmp/Salt/llnw/{{ repo }}
{%   endif %}
{% endfor %}
