{% from slspath ~ "/map.jinja" import atp_accounts_json, atp_conf, atp_config, atp_etcdir, atp_version, atp_version_suffix, atp_url, atp_newsyslog_conf with context %}

{% set device_class = salt['grains.get']('cornerstone:device_class_name','') %}
include:
  - syslog-conf
  - resolver.anycachestatic
{% if device_class == 'mmd-token' %}
  - .dedicated-atp-hosts
  - .dedicated-firewall
  - .healthcheck
{% endif %}

sae|atp|v|logdir:
  file.directory:
    - name: /logs/atp
    - makedirs: True
    - mode: '0755'
    - owner: root
    - group: wheel

sae|atp|v|pkg-remove:
  cmd.run:
    - name: 'pkg delete -fy $(pkg info -a | grep authtokenprovider | cut -d- -f1)'
    - shell: /bin/bash
    - onlyif: 'pkg info -a | grep authtokenprovider'
    - unless: 'pkg info -D "authtokenprovider{{ atp_version_suffix }}={{ atp_version }}"'

sae|atp|v|pkg:
  pkg.installed:
    - sources:
      - authtokenprovider{{ atp_version_suffix }}: {{ atp_url }}
    - require:
      - sae|atp|v|pkg-remove
      - sae|atp|v|logdir

{% if device_class != 'mmd-token' %}
sae|atp|v|limited-mode-cleanup:
  file.absent:
    - name: {{ atp_accounts_json }}
    - require_in:
      - sae|atp|v|service
{% endif %}

sae|atp|v|config:
  file.managed:
    - name: {{ atp_conf }}
    - contents: '{{ atp_config|json }}'
    - mode: '0755'
    - owner: root
    - group: wheel

sae|atp|v|service:
  service.running:
    - name: authtokenprovider
    - enable: True
    - require:
        - sae|atp|v|logdir
        - sae|atp|v|pkg
    - watch:
        - sae|atp|v|pkg
        - sae|atp|v|config

sae|atp|v|newsyslog:
  file.managed:
    - name: {{ atp_newsyslog_conf }}
    - source: salt://{{ slspath }}/files/authtokenprovider.conf
    - mode: 644
    - makedirs: True
    - require:
      - service: core|syslog-ng|service
