{% set eqagent_core_path = "eq-agent/v6" %}

{% import_yaml slspath ~ "/properties.yaml" as properties %}
{% from eqagent_core_path ~ "/map.jinja" import eqagent_core %}

# ===============================================
# Checkpoint file path migration rollback part starts here
{% set checkpoint_old_dir = "/var/run" %}
{% set checkpoint_new_dir = "/var/edgequery/run" %}
{% set checkpoint_files   = ['edgequery-billing.checkpoint', 'edgequery.checkpoint'] %}

{# Stop eqbilling #}
eq|{{ sls }}|stop_eqbilling:
  service.dead:
    - name: eqbilling
    - enable: False
    - unless: ls -laF {{ checkpoint_old_dir }}/edgequery-billing.checkpoint
    - onlyif: ls -laF {{ checkpoint_new_dir }}/edgequery-billing.checkpoint

{# Stop edgequeryd #}
eq|{{ sls }}|stop_edgequeryd:
  service.dead:
    - name: edgequeryd
    - enable: False
    - unless: ls -laF {{ checkpoint_old_dir }}/edgequery.checkpoint
    - onlyif: ls -laF {{ checkpoint_new_dir }}/edgequery.checkpoint

{# Copy checkpoint files to new location #}
{% for file in checkpoint_files %}
eq|{{ sls }}|copy_checkpoint_{{ file }}_to new_dir:
  file.copy:
    - name: {{ checkpoint_old_dir }}/{{ file }}
    - source: {{ checkpoint_new_dir }}/{{ file }}
    - preserve: True
    - require:
      - service: eq|{{ sls }}|stop_eqbilling
      - service: eq|{{ sls }}|stop_edgequeryd
    - unless: ls -laF {{ checkpoint_old_dir }}/{{ file }}
    - onlyif: ls -laF {{ checkpoint_new_dir }}/{{ file }}
{% endfor %}
# Checkpoint file path migration rollback part ends here
# =============================================

# EQ Agent deployment starts here
{{ eqagent_core(properties, slspath, eqagent_core_path) }}
# EQ Agent deployment ends here

# ============================================
# New checkpoint file cleanup on rollback part starts here
eq|{{ sls }}|validate|ports|eqbilling:
  llnw_validate.ports_listening:
    - name: webstatus-eqbilling
    - ports: 30510

eq|{{ sls }}|validate|process|eqbilling:
  llnw_validate.proc_running:
    - name: process-eqbilling
    - search: "--system-service-name=eqbilling"

eq|{{ sls }}|validate|ports|edgequeryd:
  llnw_validate.ports_listening:
    - name: webstatus-edgequeryd
    - ports: 30520

eq|{{ sls }}|validate|process|edgequeryd:
  llnw_validate.proc_running:
    - name: process-edgequeryd
    - search: "--system-service-name=edgequeryd"

eq|{{ sls }}|remove_old_checkpoint|eqbilling:
  file.absent:
    - name: {{ checkpoint_new_dir }}/edgequery-billing.checkpoint
    - require:
      - llnw_validate: eq|{{ sls }}|validate|ports|eqbilling
      - llnw_validate: eq|{{ sls }}|validate|process|eqbilling

eq|{{ sls }}|remove_old_checkpoint|edgequeryd:
  file.absent:
    - name: {{ checkpoint_new_dir }}/edgequery.checkpoint
    - require:
      - llnw_validate: eq|{{ sls }}|validate|ports|edgequeryd
      - llnw_validate: eq|{{ sls }}|validate|process|edgequeryd
# New checkpoint file cleanup part ends here
# ==========================================

eq-agent|v6|remove_rldp_agent|remove_init_and_config:
  file.absent:
    - names:
      - '/usr/local/etc/rc.d/eqrldp'
      - '/usr/local/etc/edgequery-rldp.conf'

{#Without this state is invisible#}
eq-agent|component-eq-agent|dummy-state:
 test.nop:
   - name: This dummy state succeded!
