#
{# Reporting EQ Agent Multi instance items #}
{% set reporting_instances = [1, 2] %}

# ============================================================
# EQ Agent file  migrations to multi-instance part starts here
{% set checkpoint_dir = "/var/edgequery/run" %}
{% set cache_dir      = "/logs/edgequery" %}
{% set snap_dir       = "/var/run" %}

{# Stop edgequeryd multi instances #}
{% for rep_inst_num in reporting_instances %}
eq|{{ sls }}|stop_edgequeryd-{{ rep_inst_num }}_on_rollback:
  service.dead:
    - name: edgequeryd{{ rep_inst_num }}
    - enable: False
{% endfor %}

{# Deploy merge checkpoint script #}
eq|{{ sls }}|deploy_merge_chkp_script:
  file.managed:
    - name: /usr/local/etc/merge_checkpoints.py
    - source: salt://sae-cds/eq-agent/v370/files/merge_checkpoints.py
    - mode: 644
    - user: root

{# Merge Checkpoints to 1 file #}
eq|{{ sls }}|merge_multi_instance_checkpoints:
  cmd.run:
    - name: python /usr/local/etc/merge_checkpoints.py {{ checkpoint_dir }}/edgequery-1.checkpoint {{ checkpoint_dir }}/edgequery-2.checkpoint > {{ checkpoint_dir }}/edgequery.checkpoint
    - require:
      - file: eq|{{ sls }}|deploy_merge_chkp_script
    {% for rep_inst_num in reporting_instances %}
      - service: eq|{{ sls }}|stop_edgequeryd-{{ rep_inst_num }}_on_rollback
    {% endfor %}
    - onchanges:
    {% for rep_inst_num in reporting_instances %}
      - service: eq|{{ sls }}|stop_edgequeryd-{{ rep_inst_num }}_on_rollback
    {% endfor %} 

{# Deploy pick bigger snap file script #}
eq|{{ sls }}|deploy_pick_snap_script:
  file.managed:
    - name: /usr/local/etc/eq_pick_bigger_snap_file.sh
    - source: salt://sae-cds/eq-agent/v370/files/eq_pick_bigger_snap_file.sh
    - mode: 644
    - user: root

{# pick bigger snap file among 2 instances #}
eq|{{ sls }}|pick_multi_instance_snap:
  cmd.run:
    - name: bash /usr/local/etc/eq_pick_bigger_snap_file.sh
    - require:
      - file: eq|{{ sls }}|deploy_pick_snap_script
    {% for rep_inst_num in reporting_instances %}
      - service: eq|{{ sls }}|stop_edgequeryd-{{ rep_inst_num }}_on_rollback
    {% endfor %}
    - onchanges:
    {% for rep_inst_num in reporting_instances %}
      - service: eq|{{ sls }}|stop_edgequeryd-{{ rep_inst_num }}_on_rollback
    {% endfor %} 

{# remove multi instance checkpoints #}
eq|{{ sls }}|remove_multi_instance_checkpoints:
  file.absent:
    - names: 
      - {{ checkpoint_dir }}/edgequery-1.checkpoint
      - {{ checkpoint_dir }}/edgequery-2.checkpoint
    - onchanges:
      - cmd: eq|{{ sls }}|merge_multi_instance_checkpoints

{# remove multi instance snap files #}
eq|{{ sls }}|remove_multi_instance_snaps:
  file.absent:
    - names: 
      - {{ snap_dir }}/edgequery-1.snap
      - {{ snap_dir }}/edgequery-2.snap
    - onchanges:
      - cmd: eq|{{ sls }}|pick_multi_instance_snap
