{% set eqagent_core_path = "eq-agent/v6" %}

{% import_yaml slspath ~ "/properties.yaml" as properties %}
{% from eqagent_core_path ~ "/map.jinja" import eqagent_core %}

{# General Dirs items #}
{% set checkpoint_dir = "/var/edgequery/run" %}
{% set cache_dir      = "/logs/edgequery" %}
{% set snap_dir       = "/var/run" %}

{# Multi instance items #}
# Will create following Reporting EQ Agent instances items
{% set reporting_instances = [1, 2] %}

eq|{{ sls }}|create_checkpoint_dir:
  file.directory:
    - name: {{ checkpoint_dir }}
    - makedirs: True
    - replace: False
    - mode: 644
    - unless: ls -laF {{ checkpoint_dir }}


# ============================================================
# EQ Agent file  migrations to multi-instance part starts here

{# Create new  cache dir #}
{% for rep_inst_num in reporting_instances %}
eq|{{ sls }}|create_reporting_agent{{ rep_inst_num }}_cache_new_dir:
  file.directory:
    - name: {{ cache_dir }}-{{ rep_inst_num }}
    - makedirs: True
    - replace: False
    - mode: 644
{% endfor %}

{# Stop edgequeryd single instance #}
eq|{{ sls }}|stop_edgequeryd:
  service.dead:
    - name: edgequeryd
    - enable: False

{# Spread checkpoint files to 2 new clones #}
{% for rep_inst_num in reporting_instances %}
eq|{{ sls }}|copy_checkpoint_to new_dir_for_instance_{{ rep_inst_num }}:
  file.copy:
    - name:   {{ checkpoint_dir }}/edgequery-{{ rep_inst_num }}.checkpoint
    - source: {{ checkpoint_dir }}/edgequery.checkpoint
    - preserve: True
    - require:
      - service: eq|{{ sls }}|stop_edgequeryd
{% for rep_inst_num in reporting_instances %}
    - unless: ls -laF {{ checkpoint_dir }}/edgequery-{{ rep_inst_num }}.checkpoint
{% endfor %}
    - onlyif: ls -laF {{ checkpoint_dir }}/edgequery.checkpoint
{% endfor %}

{# Copy cache directory for multi-instance-1 #}
eq|{{ sls }}|copy_cache_to new_dir_for_instance_1:
  cmd.run:
    - name: cp -R {{ cache_dir }}/ {{ cache_dir }}-1/
    - require:
      - service: eq|{{ sls }}|stop_edgequeryd
    - onlyif: ls -laF {{ cache_dir }}

{# Copy snapshot file for multi-instance-1 #}
eq|{{ sls }}|copy_snapshot_to new_file_for_instance_1:
  file.copy:
    - name:   {{ snap_dir }}/edgequery-1.snap
    - source: {{ snap_dir }}/edgequery.snap
    - preserve: True
    - require:
      - service: eq|{{ sls }}|stop_edgequeryd
    - unless: ls -laF { snap_dir }}/edgequery-1.snap
    - onlyif: ls -laF {{ snap_dir }}/edgequery.snap
# EQ Agent file  migrations to multi-instance part ends here
# ==========================================================

# EQ Agent deployment starts here
{{ eqagent_core(properties, slspath, eqagent_core_path) }}
# EQ Agent deployment ends here

# =============================================
# Single instance post-cleanup part starts here
eq|{{ sls }}|validate|ports|edgequeryd_1:
  llnw_validate.ports_listening:
    - name: webstatus-edgequeryd_1
    - ports: 30521

eq|{{ sls }}|validate|ports|edgequeryd_2:
  llnw_validate.ports_listening:
    - name: webstatus-edgequeryd_2
    - ports: 30522

{% for rep_inst_num in reporting_instances %}
eq|{{ sls }}|validate|process|edgequeryd_{{ rep_inst_num }}:
  llnw_validate.proc_running:
    - name: process-edgequeryd_{{ rep_inst_num }}
    - search: "--system-service-name=edgequeryd{{ rep_inst_num }}"
{% endfor %}


{# remove single instance checkpoint #}
eq|{{ sls }}|remove_old_single_checkpoint|edgequeryd:
  file.absent:
    - name: {{ checkpoint_dir }}/edgequery.checkpoint
    - require:
    {% for rep_inst_num in reporting_instances %}
      - llnw_validate: eq|{{ sls }}|validate|ports|edgequeryd_{{ rep_inst_num }}
      - llnw_validate: eq|{{ sls }}|validate|process|edgequeryd_{{ rep_inst_num }}
    {% endfor %}

{# remove single instance snap file #}
eq|{{ sls }}|remove_old_single_snapshot|edgequeryd:
  file.absent:
    - name: {{ snap_dir }}/edgequery.snap
    - require:
    {% for rep_inst_num in reporting_instances %}
      - llnw_validate: eq|{{ sls }}|validate|ports|edgequeryd_{{ rep_inst_num }}
      - llnw_validate: eq|{{ sls }}|validate|process|edgequeryd_{{ rep_inst_num }}
    {% endfor %}

{# remove single instance cache dir #}
eq|{{ sls }}|remove_old_single_cache_dir|edgequeryd:
  file.absent:
    - name: {{ cache_dir }}
    - require:
    {% for rep_inst_num in reporting_instances %}
      - llnw_validate: eq|{{ sls }}|validate|ports|edgequeryd_{{ rep_inst_num }}
      - llnw_validate: eq|{{ sls }}|validate|process|edgequeryd_{{ rep_inst_num }}
    {% endfor %}

{# remove single instance config and init script #}
eq|{{ sls }}|remove_old_config_startup|edgequeryd:
  file.absent:
    - names:
      - /usr/local/etc/edgequery.conf
    - require:
    {% for rep_inst_num in reporting_instances %}
      - llnw_validate: eq|{{ sls }}|validate|ports|edgequeryd_{{ rep_inst_num }}
      - llnw_validate: eq|{{ sls }}|validate|process|edgequeryd_{{ rep_inst_num }}
    {% endfor %}
      - service: eq|{{ sls }}|stop_edgequeryd
# Single instance post-cleanup part ends here
# ===========================================

{#Without this state is invisible#}
eq-agent|component-eq-agent|dummy-state:
 test.nop:
   - name: This dummy state succeded!
