#!/bin/bash

if [ $UID -ne 0 ]; then
  echo "Must be root to run the script"
  exit 0
fi

usage(){
    echo "usage: $0 [options]"
    echo "Options:"
    echo "  -d     dryrun output instead of sending to TSDB  "
    echo "  -i     Run immediately instead of waiting for splay"
    echo "Example:"
    echo "  $0 -d -i"
    exit 1
}

while getopts "di" opt; do
  case ${opt} in
      d)
        dryrun=1
        ;;
      i)
        immediate=1
        ;;
      *)
        usage
        ;;
    esac
done

if [ -z "${immediate}" ]; then
  box_number=$(uname -n | grep -Eo '[0-9]+')
  sleep $((box_number % 60))
fi

# TSDB settings
tsdb_server="tsdb-data.lldns.net"
tsdb_port="4242"
tsdb_data=""

# Values and metadata
now=$(date +%s)
now_aligned=$(( $now - $now % 300 ))
time_file="/etc/salt.completedTime"
fqdn=$(uname -n)
pop=$(echo "$fqdn" | cut -d '.' -f 2)

# Check if we have the an old file if
# not to not report in data
if [ ! -f "$time_file" ]; then
    exit
fi

# Get last run time
last_completed_time=$(cat "$time_file")

# Build TSDB data
tsdb_data+="put app.salt.timeSinceLastRun ${now_aligned} $((now-last_completed_time)) fqdn=${fqdn} pop=${pop}\n"

# Send to TSDB
if [ -n "${dryrun}" ]; then
    echo -ne "$tsdb_data"
else
    echo -ne "$tsdb_data" | nc -N $tsdb_server $tsdb_port
fi
