# vim: sts=2 ts=2 sw=2 et ai

{%- set fqdn = salt['grains.get']('fqdn')|lower %}

{% if grains['singel'] is defined %}
{%   macro sysctlcds(name, sysctl, value) %}
sae-cds|sysctl|sysctlconf-{{ name }}:
  file.append:
    - name: /etc/sysctl.conf
    - text: {{ sysctl }}={{ value }}
{%-   endmacro %}
{% else %}
{%   macro sysctlcds(name, sysctl, value) %}
sae-cds|sysctl|sysctl-{{ name }}:
  sysctl.present:
    - name: {{ sysctl }}
    - value: {{ value }}
    - config: /etc/sysctl.conf
{%-   endmacro %}
{% endif %}

{{ sysctlcds('vfs-read-max', 'vfs.read_max', 32) }}
{{ sysctlcds('kern-sugid-coredump', 'kern.sugid_coredump', 1) }}
{{ sysctlcds('net-inet-tcp-recvbuf-auto', 'net.inet.tcp.recvbuf_auto', 1) }}
{{ sysctlcds('net-inet-tcp-sendbuf-auto', 'net.inet.tcp.sendbuf_auto', 1) }}
{{ sysctlcds('net-inet-tcp-sendbuf-max', 'net.inet.tcp.sendbuf_max', 10485760) }}
{{ sysctlcds('net-inet-tcp-recvbuf-max', 'net.inet.tcp.recvbuf_max', 10485760) }}
{{ sysctlcds('net-inet-tcp-sockopt-sndbuf-max', 'net.inet.tcp.sockopt_sndbuf_max', 10485760) }}
{{ sysctlcds('kern-ipc-maxsockbuf', 'kern.ipc.maxsockbuf', 157286400) }}
{{ sysctlcds('net-inet-tcp-sendspace', 'net.inet.tcp.sendspace', 200000) }}
{{ sysctlcds('net-inet-tcp-recvspace', 'net.inet.tcp.recvspace', 200000) }}
{{ sysctlcds('net-inet-tcp-delayed-ack', 'net.inet.tcp.delayed_ack', 0) }}
{{ sysctlcds('net-inet-tcp-keepidle', 'net.inet.tcp.keepidle', 75000) }}
{{ sysctlcds('kern-cam-da-retry-count', 'kern.cam.da.retry_count', 2) }}
{{ sysctlcds('net-inet-tcp-rfc3390', 'net.inet.tcp.rfc3390', 0) }}
{{ sysctlcds('hw-intr-storm-threshold', 'hw.intr_storm_threshold', 30000) }}
{{ sysctlcds('net-local-stream-recvspace', 'net.local.stream.recvspace', 200000) }}
{{ sysctlcds('net-local-stream-sendspace', 'net.local.stream.sendspace', 200000) }}
{{ sysctlcds('net-local-dgram-recvspace', 'net.local.dgram.recvspace', 42080) }}

{%- if 'cds-tcp-increase' in salt['grains.get']('cornerstone:tags', {}) %}
{{ sysctlcds('net-inet-tcp-bbr-def-cwndgain', 'net.inet.tcp.bbr.def_cwndgain', 1024) }}
{{ sysctlcds('net-inet-tcp-bbr-def-startgain', 'net.inet.tcp.bbr.def_startgain', 1478) }}
{{ sysctlcds('net-inet-tcp-bbr-def-gaincycle', 'net.inet.tcp.bbr.def_gaincycle', 640) }}
{{ sysctlcds('net-inet-tcp-bbr-def-draingain', 'net.inet.tcp.bbr.def_draingain', 176) }}
{{ sysctlcds('net-inet-tcp-bbr-loss-exit-gain', 'net.inet.tcp.bbr.loss_exit_gain', 0) }}
{{ sysctlcds('net-inet-tcp-bbr-no-limit', 'net.inet.tcp.bbr.no_limit', 1) }}
{{ sysctlcds('net-inet-tcp-bbr-initwin', 'net.inet.tcp.bbr.initwin', 30) }}
{%- elif 'cds-tcp-increase-reset' in salt['grains.get']('cornerstone:tags', {}) %}
{{ sysctlcds('net-inet-tcp-bbr-def-cwndgain', 'net.inet.tcp.bbr.def_cwndgain', 512) }}
{{ sysctlcds('net-inet-tcp-bbr-def-startgain', 'net.inet.tcp.bbr.def_startgain', 739) }}
{{ sysctlcds('net-inet-tcp-bbr-def-gaincycle', 'net.inet.tcp.bbr.def_gaincycle', 320) }}
{{ sysctlcds('net-inet-tcp-bbr-def-draingain', 'net.inet.tcp.bbr.def_draingain', 88) }}
{{ sysctlcds('net-inet-tcp-bbr-loss-exit-gain', 'net.inet.tcp.bbr.loss_exit_gain', 1) }}
{{ sysctlcds('net-inet-tcp-bbr-no-limit', 'net.inet.tcp.bbr.no_limit', 0) }}
{{ sysctlcds('net-inet-tcp-bbr-initwin', 'net.inet.tcp.bbr.initwin', 10) }}
{%- else %}
{{ sysctlcds('net-inet-tcp-bbr-initwin', 'net.inet.tcp.bbr.initwin', 10) }}
{%- endif %}

{% if 'role-sae-cds-midtier.sm-x10' in salt['grains.get']('cornerstone:tags', {}) %}
{{ sysctlcds('kern-ipc-shmmax', 'kern.ipc.shmmax', 1073741824) }}
{{ sysctlcds('kern-ipc-shmall', 'kern.ipc.shmall', 262144) }}
{% endif %}
{% if grains.get('cachepool') == 'midtier' %}
{{ sysctlcds('tcp-fast-rtt-thresh', 'tcp_fast.rtt_thresh', 1) }}
{% endif %}

{% if grains.get('cachepool') == 'enterprise' %}
{{ sysctlcds('net-inet-tcp-bbr-filter-algo', 'net.inet.tcp.bbr.filter_algo', 4) }}
{{ sysctlcds('net-inet-tcp-bbr-bw-trusted', 'net.inet.tcp.bbr.bw_trusted', 146000) }}
{% endif %}

{{ sysctlcds('net.inet.tcp.initcwnd_segments', 'net.inet.tcp.initcwnd_segments', 30) }}
