# vim: sts=2 ts=2 sw=2 et ai

{% from 'apache2/map.jinja' import apache %}
{% from slspath~"/map.jinja" import cs with context %}
{% from 'certs/map.jinja' import cert_path with context %}
{%- from slspath~"/macros.jinja" import local_salt_path with context %}
{% set salt_path = local_salt_path() %} 

include:
  - apache2
  - apache2.acl
  - apache2.prefork
  - apache2.ssl
  - base_repos
  - certs
  - firewall
  - firewall.standard
  - firewall.web
  - .sudoers
  - sysctl.ipv6_disable

{% if cs.get('external_netblocks', []) %}
sae|cornerstone|firewall|external_netblocks:
  firewall.accept:
    - tcp:
      - [443, {{ cs.external_netblocks }}]
    - require_in:
      - firewall: core|firewall|final-reject
{% endif %}

sae|cornerstone|repo:
  pkgrepo.managed:
    - name: deb http://repo.llnw.net/llnw/ubuntu/{{ cs.repo_env }}/cornerstone/ {{ salt['grains.get']('oscodename') }}/
    - file: /etc/apt/sources.list.d/llnw.cornerstone.{{ salt['grains.get']('oscodename') }}.list
    - clean_file: True

# things that are not dependencies, but nice to have around
sae|cornerstone|other-pkgs:
  pkg.latest:
    - names:
      - mysql-client

# TODO allow for version 'latest'
sae|cornerstone|pkg:
  pkg.installed:
    - pkgs:
      - libnet-rabbitmq-perl: {{ cs.libnet_rabbitmq_perl_version }}
      - cornerstone: {{ cs.cornerstone_version }}
    - skip_verify: True
    - require:
      - pkgrepo: sae|cornerstone|repo
    - watch_in:
      - service: core|apache2|service

sae|cornerstone|conf:
  file.managed:
    - name: /etc/cornerstone/cornerstone.conf
    - template: jinja
    - source: {{ salt_path~"templates/cornerstone.conf.jinja" }}
    - require:
      - pkg: sae|cornerstone|pkg
    - context:
        cs: {{ cs }}
    - defaults:
        db_pass: {{ salt['pillar.get']('secrets:sae-cornerstone:db_pass') }}
        edgeinfo_db_pass: {{ salt['pillar.get']('secrets:sae-cornerstone:config_db_password_ro') }}
        session_secret: {{ salt['pillar.get']('secrets:sae-cornerstone:session_secret') }}
        amqp_pass: {{ salt['pillar.get']('secrets:sae-cornerstone:amqp_pass') }}
        api_password: {{ salt['pillar.get']('secrets:sae-cornerstone:api_password') }}
        zabbix_password: {{ salt['pillar.get']('secrets:sae-cornerstone:zabbix_password') }}
        rtpass: {{ salt['pillar.get']('secrets:sae-cornerstone:rtpass') }}
        squelch_key: {{ salt['pillar.get']('secrets:sae-cornerstone:squelch_key') }}
        tenable_pass: {{ salt['pillar.get']('secrets:sae-cornerstone:cs_tenable_api_passwd') }}
        source_of_truth_pass: {{ salt['pillar.get']('secrets:sae-cornerstone:cornerstone_api_source_of_truth_passwd') }}

sae|cornerstone|cornerstone-apache:
  file.managed:
    - name: {{ apache['confdir'] }}/sites-available/cornerstone.conf
    - source: {{ salt_path~"templates/apache_cornerstone.conf.jinja" }}
    - require:
      - pkg: sae|cornerstone|pkg
    - template: jinja
    - defaults:
        vhost_cs: {{ cs.vhost_cs }}
        cert: {{ cert_path['certdir'] }}/{{ cert_path['certname'] }}.crt
        key: {{ cert_path['keydir'] }}/{{ cert_path['certname'] }}.key
        intermediate: {{ cert_path['certdir'] }}/{{ cert_path['certname'] }}.crt
    - watch_in:
      - service: core|apache2|service

sae|cornerstone|csapi-apache:
  file.managed:
    - name: {{ apache['confdir'] }}/sites-available/csapi.conf
    - source: {{ salt_path~"templates/apache_csapi.conf.jinja" }}
    - require:
      - pkg: sae|cornerstone|pkg
    - template: jinja
    - defaults:
        vhost_csapi: {{ cs.vhost_csapi }}
        cert: {{ cert_path['certdir'] }}/{{ cert_path['certname'] }}.crt
        key: {{ cert_path['keydir'] }}/{{ cert_path['certname'] }}.key
        intermediate: {{ cert_path['certdir'] }}/{{ cert_path['certname'] }}.crt
        external_netblocks: {{ cs.get('external_netblocks', []) }}
    - watch_in:
      - service: core|apache2|service

sae|cornerstone|a2ensite-cornerstone:
  cmd.run:
    - name: "a2ensite cornerstone"
    - unless: test -L {{ apache['confdir'] }}/sites-enabled/cornerstone.conf
    - watch:
      - file: sae|cornerstone|cornerstone-apache
    - watch_in:
      - service: core|apache2|service

sae|cornerstone|a2ensite-csapi:
  cmd.run:
    - name: "a2ensite csapi"
    - unless: test -L {{ apache['confdir'] }}/sites-enabled/csapi.conf
    - watch:
      - file: sae|cornerstone|csapi-apache
    - watch_in:
      - service: core|apache2|service

sae|cornerstone|limits-conf:
  file.managed:
    - name: /etc/security/limits.d/cornerstone.conf
    - source: {{ salt_path~"files/limits.conf" }}

