{% from "pepper/map.jinja"  import defaults, netblocks with context %}
{% from "sudoers/map.jinja" import sudo_map with context %}

{% set environment = salt['grains.get']('team_env', 'staging') %}

{% if environment == 'dynamic' %}
{%     set environment = 'testing' %}
{% endif %}

{% import_yaml "sae-czsync/map.yml" as czsync_map %}
{% set env_map = czsync_map[environment] %}

include:
  - sudoers.setup
  - splunkforwarder
  - sae-czsync.lastrites.MMR-838-remove-precise-repo
  - sae-zabbix-infra.repo

sae|czsync|core-sudo:
  file.managed:
    - name: {{ sudo_map.includedir }}/czsync
    - user: root
    - group: {{ defaults.root_group }}
    - mode: 440
    - contents: |
        %posix-czsync-admin ALL=(ALL) ALL
        %posix-zabbix-admins ALL=(ALL) ALL
        %ops-sysops ALL=(root) /usr/local/bin/czsync
        %ops-opseng ALL=(root) /usr/local/bin/czsync
        %sre-bizservices ALL=(root) /usr/local/bin/czsync
        %sre-delivery ALL=(root) /usr/local/bin/czsync
        %sre-storage ALL=(root) /usr/local/bin/czsync
        %sre-video ALL=(root) /usr/local/bin/czsync
        %sre-dns ALL=(root) /usr/local/bin/czsync
    - require:
      - file: core|sudoers|includedir

sae|czsync|packages:
  pkg.installed:
    - skip_verify: True
    - refresh: False
    - require_in:
      - file: sae|czsync|cz_sync.yml
    - require:
      - pkgrepo: sae|zabbix-infra|repo
    - pkgs:
      - czsync-cli: {{ env_map['czsync_package_version'] }}
      - libfile-which-perl: 1.19-1

sae|czsync|conf_dir:
  file.directory:
    - name: /usr/local/etc/zabbix
    - makedirs: True
    - user: root
    - group: {{ defaults.root_group }}
    - mode: 755

sae|czsync|cz_sync.yml:
  file.managed:
    - require:
      - file: sae|czsync|conf_dir
    - name: /usr/local/etc/zabbix/cz_sync.yml
    - user: root
    - group: {{ defaults.root_group }}
    - mode: 644
    - source: salt://sae-czsync/templates/cz_sync.yml.jinja
    - template: jinja
    - context:
        czsync:
          zabbix:
            user: {{ env_map['zabbix_user'] }}
            password: {{ salt['pillar.get']('secrets:sae-czsync:zabbix_password') }}
            url:  {{ env_map['zabbix_url'] }}
            default_proxy:  {{ env_map['zabbix_default_proxy'] }}
            unlink_templates:  {{ env_map['zabbix_unlink_templates'] }}
          cornerstone:
            user:  {{ env_map['cornerstone_user'] }}
            password:  {{ salt['pillar.get']('secrets:sae-czsync:cornerstone_password') }}
            url:   http://csapi.llnw.net
            load_hosts:   "{{ env_map['cornerstone_load_hosts'] }}"
            cs_full_url_path_override: {{ env_map['cs_full_url_path_override'] }}
            vpnip_regex: {{ env_map['vpnip_regex'] }}
          notify_list:    {{ env_map['notify_list'] }}
          dancer_api_key:     {{ salt['pillar.get']('secrets:sae-czsync:dancer_api_key') }}

sae|czsync|czsync_cron:
  file.managed:
    - name: /etc/cron.d/czsync
    - user: root
    - group: root
    - mode: 644
    - template: jinja
    - source: salt://sae-czsync/templates/czsync.cron.jinja
    - require:
      - pkg: sae|czsync|packages
    - context:
      {% if 'production' in environment %}
        czsync_minute: '0'
        czsync_hour: '08'
      {% else %}
        czsync_minute: '0'
        czsync_hour: '*/6'
      {% endif %}


sae|czsync|cz_sync_ht_map.json:
  file.managed:
    - name: /usr/local/etc/zabbix/cz_sync_ht_map.json
    - user: root
    - group: {{ defaults.root_group }}
    - mode: 644
    - source: salt://sae-czsync/files/cz_sync_ht_map.{{ environment }}.json
    - require:
      - file: sae|czsync|conf_dir

sae|czsync|cz_proxy_map.json:
  file.managed:
    - name: /usr/local/etc/zabbix/cz_proxy_map.json
    - user: root
    - group: {{ defaults.root_group }}
    - mode: 644
    - source: salt://sae-czsync/files/cz_proxy_map.json
    - require:
      - file: sae|czsync|conf_dir

sae|czsync|cz_sync_logging.conf:
  file.managed:
    - name: /usr/local/etc/zabbix/cz_sync_logging.conf
    - user: root
    - group: {{ defaults.root_group }}
    - mode: 644
    - source: salt://sae-czsync/files/cz_sync_logging.conf
    - require:
      - file: sae|czsync|conf_dir

sae|czsync|symlink_cz_sync_logging.conf:
   file.symlink:
     - name: /etc/zabbix/cz_sync_logging.conf
     - target: /usr/local/etc/zabbix/cz_sync_logging.conf
     - require:
        - file: sae|czsync|cz_sync_logging.conf

sae|czsync|www_dir:
  file.directory:
    - name: /var/www/cz_sync
    - makedirs: True
    - user: zabbix
    - group: {{ defaults.root_group }}
    - mode: 755

sae|czsync|Colorful.pm:
  file.managed:
    - name: /usr/share/perl5/Log/Dispatch/Colorful.pm
    - user: root
    - group: {{ defaults.root_group }}
    - mode: 644
    - source: salt://sae-czsync/files/Colorful.pm

sae|czsync|libyaml_perl:
  pkg.installed:
    - name: libyaml-perl
    - skip_verify: True
    - refresh: True
    - require_in:
      - pkg: sae|czsync|packages

sae|czsync|dispatch:
  pkg.installed:
    - name: liblog-dispatch-filerotate-perl
    - skip_verify: True
    - refresh: True
    - require_in:
      - pkg: sae|czsync|packages

sae|czsync|proxymap.get.sh:
  file.managed:
    - name: /usr/local/bin/proxymap.get.sh
    - user: root
    - group: {{ defaults.root_group }}
    - mode: 755
    - source: salt://sae-czsync/templates/proxymap.get.sh.jinja
    - template: jinja
    - context:
        api_url: {{ env_map['llnw_api'] }}

sae|czsync|cron--full-summary.sh:
  file.managed:
    - name: /usr/local/bin/cron--full-summary.sh
    - user: root
    - group: {{ defaults.root_group }}
    - mode: 755
    - source: salt://sae-czsync/templates/cron--full-summary.sh.jinja
    - template: jinja
    - context:
        proxymap_api_key: {{ salt['pillar.get']('secrets:sae-czsync:proxymap_api_key') }}
