#!/usr/bin/perl -w

use strict;

use DBI;
use POSIX;
use Sys::Hostname;
use Fcntl qw(:flock);

my $uid = $<;
my $hostname = hostname();
$hostname =~ /\.(\w+)\.llnw\.net$/;
my $localsite = $1;
my $nfsd_stopped = 0;
my ($os,undef,undef,$rel) = uname;

if($os eq 'Linux') {
  if(open(LSB,"/etc/lsb-release")) {
    while(<LSB>) {
      $rel = $1 if(/^DISTRIB_ID=(.*)$/);
    }
    close(LSB);
  }
}

if( ! -t STDIN ) {
  my $opt_e = '';
  my $mailer = 'Mail';
  $mailer = 'bsd-mailx' if($rel =~ /Ubuntu/i);

  $opt_e = '-E' if($os eq 'FreeBSD' || $rel =~ /Ubuntu/i);
  $opt_e = '-e' if($os eq 'Linux');
  open(STDOUT, "|$mailer $opt_e -s '$hostname: Log nfs problems' log-ops\@llnw.com") || die "Unable to run Mail: $!";
}
open(STDERR, ">&STDOUT") || die "Can't dup STDOUT: $!";

#&getlock('/var/run/checknfs.lock') if($uid == 0);

my $dbh = DBI->connect("DBI:mysql:logfile:lux-db-logfile.llnw.com", "nfscheck", "t9Og3R)8k(V-4\@#5i3dWA", {"RaiseError" => 1, "mysql_client_found_rows" => 1});

my(@row);
my $lock_sth = $dbh->prepare("select get_lock('checknfs', 3600)");
$lock_sth->execute();
@row = $lock_sth->fetchrow_array();
if (!$row[0]) {
    print STDERR "Unable to get checknfs lock\n";
    exit;
}
my $sth = $dbh->prepare("select distinct directory,hostname,mount_type from logvolume");
$sth->execute();

my(%mount);
my($mntp);
my(%mounted);

my %validType = (mount => 1, hold => 1, unmount => 1);
while(@row = $sth->fetchrow_array()) {
  $mount{host}{$row[0]} = $row[1];
  # assume remote mountpoint is /log*
  my $tmp = $row[0];
  $tmp =~ s/^\/rlog/\/log/;
  $mount{dir}{$row[0]} = $tmp;
  $mount{type}{$row[0]} = $row[2];
  if(!defined $validType{$mount{type}{$row[0]}}) {
    print STDERR "Unknown mount type '$mount{type}{$row[0]}'\n";
  }
}
$sth->finish;

open(MOUNT,"mount|") || die "cannot run mount: $!";
while(<MOUNT>) {
  chop;
  my($mntfrom,undef,$mounted,$option) = split(' ',$_,4);
  if($option =~ /nfs/) {
    $mounted{$mounted} = $mntfrom;
  }
}
close(MOUNT);

for $mntp (sort keys %{$mount{host}}) {

  if($mount{host}{$mntp} eq $hostname) {
    # local
    if(! -l $mntp) {
      print STDERR "$mntp should be a symlink to $mount{dir}{$mntp}, trying to fix\n";
      if( ! -e $mntp ) {
        if($uid == 0) {
          print STDERR "$mntp doesn't exist, creating\n";
          symlink($mount{dir}{$mntp},$mntp) ||
                warn "symlink($mount{dir}{$mntp},$mntp): $!";
        } else {
          print STDERR "$mntp doesn't exist\n";
        }
      } else {
        print STDERR "$mntp exists, not fixing\n";
      }
    } else {
      # link exists, check to make sure it points to the correct place
      my $link = readlink($mntp);
      if($link ne $mount{dir}{$mntp} &&
         '/'.$link ne $mount{dir}{$mntp}) {
        print STDERR "$mntp points to the wrong directory: $link, please fix\n";
      }
    }
  } else {
    # remote
    next if($mount{type}{$mntp} eq 'hold');
    if(defined $mounted{$mntp}) {
      my($hostfrom,$mntfrom) = split(':',$mounted{$mntp});
  
      my $shorthost = $mount{host}{$mntp};
      $shorthost =~ s/\.llnw\.net$//;
      if(($hostfrom ne 'private.'.$mount{host}{$mntp} && 
         $hostfrom ne 'private.'.$shorthost &&
         $hostfrom ne $mount{host}{$mntp} &&
         $hostfrom ne $shorthost ) ||
         $mntfrom ne $mount{dir}{$mntp}) {
          print STDERR "$mntp incorrectly mounted from $hostfrom:$mntfrom\n";
      } else {
	      if($mount{type}{$mntp} eq 'unmount') {
	        # correctly mounted and also requested to be unmounted
          if($uid == 0) {
            &stopNfsd;
	          print STDERR "umount requested for $hostfrom:$mntfrom on $mntp\n";
	          system("umount $mntp");
          } else {
            print STDERR "umount needed for $hostfrom:$mntfrom on $mntp\n";
          }
	      }
      }
    } else {
      next if($mount{type}{$mntp} ne 'mount');
      print STDERR "$mntp: not mounted\n";
      if($uid == 0) {
        &stopNfsd;
        print STDERR "Adding mount: $mount{host}{$mntp}:$mount{dir}{$mntp} on $mntp\n";
        if( ! -e $mntp ) {
          print STDERR "$mntp doesn't exist, creating\n";
          mkdir($mntp,0755) || warn "mkdir($mntp,0755): $!";
        }
        if( -d $mntp ) {
          my $shorthost = $mount{host}{$mntp}; $shorthost =~ s/\.llnw\.net$//;
          $mount{host}{$mntp} =~ /\.(\w+)\.llnw\.net$/;
          my $site = $1;
          my $mntopt = '';
          $mntopt = '-o ro' if($hostname =~ /^logproc/);
          $mntopt = '-o ro' if($hostname =~ /^sky/);
          $mntopt = '-o ro' if($hostname =~ /^daily-logs/);
          $mntopt .= ' -o udp,nfsvers=3' if($os eq 'Linux');
          if(($site eq 'phx3') && ($localsite eq $site)) {
            $shorthost = "private.".$shorthost;
          }
          system("mount -t nfs -o intr $mntopt $shorthost:$mount{dir}{$mntp} $mntp");
        } else {
          print STDERR "$mntp is an invalid mount point\n";
        }
      }
    }
  }
}

if($os eq 'FreeBSD' && $nfsd_stopped) {
  system("/etc/rc.d/nfsd start");
}

sub stopNfsd {
  if($os eq 'FreeBSD' && !$nfsd_stopped) {
    system("/etc/rc.d/nfsd stop");
    $nfsd_stopped = 1;
  }
}

sub getlock {
  my($lockfile) = @_;

  open(LOCK, ">$lockfile") or die "can't write to $lockfile: $!";
  flock(LOCK, LOCK_EX|LOCK_NB) ||
    die "$0: can't lock $lockfile ($!), am i already running?";
}
