include:
  - jenkins.slave

{% set ghe_key = pillar['secrets']['sae']['github_key'] %}
{% set opennebula_token = pillar['secrets']['sae-singel']['opennebula_salt_testing_token'] %}
{% set opennebula_password = pillar['secrets']['sae-singel']['opennebula_salt_testing'] %}

sae|devops-salt-testing|jenkins-config-file:
  file.managed:
    - name: /etc/VagrantTests/config.ini
    - template: jinja
    - backup: False
    - mode: 664
    - source: salt://sae-devops-salt-testing/templates/config.jinja
    - makedirs: True
    - defaults:
        github_key: {{ ghe_key }}

sae|devops-salt-testing|repo-github3:
  pkgrepo.managed:
    - names:
      - deb http://llnwsae.vo.llnwd.net/v1/packages/llnw/github3/ubuntu/{{ grains['osrelease'] }} ./
    - file:  /etc/apt/sources.list.d/github3.{{ grains['oscodename'] }}.list

sae|devops-salt-testing|github3:
  pkg.installed:
    - name: python-github3.py
    - require:
      - pkgrepo: sae|devops-salt-testing|repo-github3

sae|devops-salt-testing|uritemplate-ppa:
  pkgrepo.managed:
    - architectures: amd64
    - name: deb http://llnwsae.vo.llnwd.net/v1/packages/mirrors/daily-update/debian/ppa.launchpad.net/dennis/python/ubuntu {{ grains['oscodename'] }} main
    - file: /etc/apt/sources.list.d/dennis-ppa.list
    - key_url: http://llnwsae.vo.llnwd.net/v1/packages/mirrors/daily-update/debian/ppa.launchpad.net/dennis/python/0xF3FA6A64F50B4114.key

sae|devops-salt-testing|python-pkgs:
  pkg.installed:
    - pkgs:
      - python-psutil
      - python-uritemplate.py
      - python-pathlib
      - python-yaml
    - require:
      - pkgrepo: sae|devops-salt-testing|uritemplate-ppa

sae|devops-salt-testing|opennebula-salt-testing-config-file:
  file.managed:
    - name: /etc/VagrantTests/openNebulaTestingConfig.json
    - template: jinja
    - backup: False
    - mode: 664
    - source: salt://sae-devops-salt-testing/templates/openNebulaTestingConfig.jinja
    - makedirs: True
    - defaults:
        opennebula_password: {{ opennebula_password }}
        opennebula_token: {{ opennebula_token }}

sae|devops-salt-testing|opennebula-salt-testing-ssh-key:
  file.managed:
    - name: /home/opennebula-salt-testing/.ssh/id_rsa
    - contents_pillar: "secrets:sae-singel:opennebula-salt-testing-private-key"
    - user: opennebula-salt-testing
    - mode: 600
    - makedirs: True

sae|devops-salt-testing|opennebula-salt-testing-ssh-config:
  file.managed:
    - name: /home/opennebula-salt-testing/.ssh/config
    - source: salt://sae-devops-salt-testing/files/opennebula_ssh_config
    - user: opennebula-salt-testing
    - mode: 644
    - makedirs: True

sae|devops-salt-testing|opennebula-manager:
  file.managed:
    - name: /usr/local/bin/opennebulaManager
    - source: http://llnwsae.vo.llnwd.net/v1/devops/opennebula-manager/opennebula-manager
    - mode: 755
    - skip_verify: True
