#!/usr/bin/perl
# use strict;

my @cli_list = ("tw_cli", "storcli");

# figure out which raid controller we're running
foreach my $i (@cli_list) {
   if ($c = controllerCheck($i)) {
      $type = $i;
      $cli  = $c;
      last;
   }
}
if (!$type) {
	print "No controller found\n";
	exit;
}

# get drive data from raid controller cli
$pfile = "/var/tmp/drvinfo.tmp";
open(OUT, ">$pfile");

if ($type eq "tw_cli") {
   ($sn_href, $status_href, $model_href, $firm_href, $portuse_href) = drv3ware($cli);
   print OUT build($type, $sn_href, $status_href, $model_href, $firm_href, $portuse_href);

}
elsif ($type eq "storcli") {
   ($sn_href, $status_href, $model_href, $firm_href, $deviceid_href) = drvLsi($cli);
   print OUT build($type, $sn_href, $status_href, $model_href, $firm_href, $deviceid_href);
}

close(OUT);

exit;

sub build {

   $type        = $_[0];
   $sn_href     = $_[1];
   $status_href = $_[2];
   $model_href  = $_[3];
   $firm_href   = $_[4];

   if ($type eq "tw_cli") {
      #$unitmem_href = $_[5];
      #$units_href  = $_[6];
      $portuse_href = $_[5];
      $raidtype = "3ware";
      %pu = %$portuse_href;
   }
   elsif ($type eq "storcli") {
      $deviceid_href = $_[5];
      $raidtype = "LSI";
   }
   
   foreach $s (keys %sn) {
      if ($type eq "tw_cli") {
         #if ($units{$unitmem{$s}}) {
         #   $use = $units{$unitmem{$s}};
         #}
         #else {
         #   $use = "-";
         #}
         if ($pu{$s}) {
            $use = $pu{$s};
         }
         else {
            $use = "-";
         }
      }
      if ($type eq "storcli") {
         if ($status{$s} =~ /^Online/) {
            $use = "Raid";
         }
         elsif ($status{$s} =~ /^Hotspare/) {
            $use = "Hotspare";
         }
         else {
            $use = "-";
         }
      }

	$return .= "raid:$raidtype ident:$s usage:$use serial:$sn{$s} status:$status{$s} model:$model{$s} firm:$firm{$s}\n";
   }

	return $return;
}

sub drv3ware {
   $cli = $_[0];
   $o = `$c info`;
   @output = split(/\n/, $o);
   foreach $i (@output) {
      if ($i =~ /^(c\d+)\s/) {
         $ctrl_id = $1; 
         $o = `$cli info $ctrl_id`;
         @info = split(/\n/, $o);
         foreach $x (@info) {
            if ($x =~ /^(u\d+)\s+([\w\d\-]+)\s+/) {
               $unit_type{$1} = $2;
            }
            if ($x =~ /^(p\d+)\s/) {
               push(@drv_ids, $1);
            }
         }
         foreach $u (keys(%unit_type)) {
            $o = `$cli /$ctrl_id/$u show`;
            @unit_info = split(/\n/, $o);
            foreach $w (@unit_info) {
               if ($w =~ /\s(p\d+)\s/) {
                  $ds = "/$ctrl_id/$1";
                  $port_use{$ds} = $unit_type{$u};
               }
            }
         }
         foreach $d (@drv_ids) {
            $v = `$cli show ver`;
            if ($v =~ /2\.00\.09\.012/) {
               $o  = `$cli /$ctrl_id/$d show status`;
               $o .= `$cli /$ctrl_id/$d show model`;
               $o .= `$cli /$ctrl_id/$d show firmware`;
               $o .= `$cli /$ctrl_id/$d show serial`;
               $o .= `$cli /$ctrl_id/$d show model`;
               #print "Got ver.\n";
            }
            else {
               $o = `$cli /$ctrl_id/$d show all`;
            }
            @drv_data = split(/\n/, $o);
            $ds = "/$ctrl_id/$d";
            foreach $a (@drv_data) {
               if ($a =~ /$d\s+Status\s+\=\s+(.*)/) {
                  $status{$ds} = $1;
               }
               if ($a =~ /$d\s+Model\s+\=\s+(.*)/) {
                  $model{$ds} = $1;
               }
               if ($a =~ /$d\s+Firmware\sVersion\s+\=\s+(.*)/) {
                  $firm{$ds} = $1;
               }
               if ($a =~ /$d\s+Serial\s+\=\s+(.*)/) {
                  $sn{$ds} = $1;
               }
               if ($a =~ /$d\s+Belongs\sto\sUnit\s+\=\s+(.*)/) {
                  $belong{$ds} = $1;
               }
            }
         }
      }
   }
   if (!%sn) {
      return 0;
   }
   else {
      return (\%sn, \%status, \%model, \%firm, \%port_use); #\%belong, \%unit_type);
   }

}

sub drvLsi {
   $cli = $_[0];

   $o = `$cli -PDList -a0`;
   @pdlist = split(/\n/, $o);

   foreach $p (@pdlist) {
      if ($p =~ /^Enclosure Device ID:\s(\d+)/) {
         $encId = $1;
      }
      if ($p =~ /^Slot Number:\s+(\d+)/) {
         $slotNum = $1;
      }

      $ds = "$encId:$slotNum";

      $i=$p;

      # Inquiry Data:      WD-WCAVY1091564WDC WD2002FYPS-01U1B1                   04.05G05
      # Inquiry Data:             9WM0C9Z9ST32000644NS                            SN11
      if ($i =~ /^Inquiry Data:\s+([\w\d\-]+)\s+([\w\d\-]+)\s+([\w\d\.]+)/) {
         $sn{$ds} = $1;
         $model{$ds} = $2;
         $firm{$ds} = $3;
      }
      elsif ($i =~ /^Inquiry Data:\s+([\w\d]+)\s+([\w\d]+)/) {
         $sn{$ds} = $1;
         $model{$ds} = $1;
         $firm{$ds} = $2;
      }
      if ($i =~ /^Firmware state:\s+(.*)/) {
         $status{$ds} = $1;
      }
      if ($i =~ /^Device Id:\s(\d+)/) {
         $deviceid{$ds} = $1;
      }
   }

   if (!%sn) {
      return 0;
   }
   else {
      return (\%sn, \%status, \%model, \%firm, \%deviceid);
   }

}

sub controllerCheck {
   my $i = $_[0];
   my $p = `which $i`;
   if ($i eq "storcli") {
      $p = "/usr/local/bin/storcli";
   }
   chomp($p);
   if (-x $p) {
      if ($i eq "tw_cli") {
         my $o = `$p info`;
         if ($o =~ /No controller found/) {
            return 0;
         }
         elsif ($o =~ /Ctl/) {
            return $p;
         }
         else {
            return 0;
         }
      }
      elsif ($i eq "storcli") {
         my $o = `$p -AdpAllInfo -a0`;
         if ($o =~ /Failed to get CpController object/) {
            return 0;
         }
         elsif ($o =~ /Adapter/) {
            return $p;
         }
         else {
            return 0;
         }
      }
      else {
         return 0;
      }
   }
   else {
      return 0;
   }
}

sub get_timestamp {
   ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime(time);
   if ($mon < 10) { $mon = "0$mon"; }
   if ($hour < 10) { $hour = "0$hour"; }
   if ($min < 10) { $min = "0$min"; }
   if ($sec < 10) { $sec = "0$sec"; }
   $year=$year+1900;

   return $year . '-' . $mon . '-' . $mday . '_' . $hour . '-' . $min . '-' . $sec;
}

