# vim: sts=2 ts=2 sw=2 et ai

{% from "pepper/map.jinja" import defaults with context %}
{% from "tcpwrappers/map.jinja" import extend_hosts with context %}

include:
  - apache2
  - apache2.acl

sae|discrete-origin|llnwcontent-conf:
  file.managed:
    - name: /etc/apache2/conf-available/llnwcontent.conf
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 644
    - contents: |
        <Directory /content/>
                Options Indexes FollowSymLinks
                AllowOverride None
                Require all granted
        </Directory>
sae|discrete-origin|customer-confs:
  file.recurse:
    - name: /etc/apache2/sites-available
    - source: salt://sae-discrete-origin/xenial/custconfs
    - template: jinja
    - user: root
    - group: {{ defaults['root_group'] }}
    - file_mode: 644
    - clean: True
    - require:
      - pkg: core|apache2|pkg

sae|discrete-origin|healthcheck-dir:
  file.directory:
    - name: /content/hc/healthcheck/content
    - makedirs: True
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755

sae|discrete-origin|healthcheck-file:
  file.managed:
    - name: /content/hc/healthcheck/content/healthcheck.txt
    - contents: 'Hi. I am serving content correctly.'
    - require:
      - file: sae|discrete-origin|healthcheck-dir

sae|discrete-origin|apache-logs-dir:
  file.directory:
    - name: /logs/apache/old
    - makedirs: True
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755

sae|discrete-origin|apache-symlink:
  file.symlink:
    - name: /usr/local/apache2
    - target: /etc/apache2
    - require:
      - pkg: core|apache2|pkg

sae|discrete-origin|apache-logformat:
  file.comment:
    - name: /etc/apache2/apache2.conf
    - regex: ^LogFormat
    - listen_in:
      - service: core|apache2|service

sae|discrete-origin|apache-logging-conf:
  file.managed:
    - name: /etc/apache2/conf-available/logging.conf
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 644
    - contents: |
        LogFormat "%h %l %u %t \"%m http://%v%U %H\" %>s %O \"%{Referer}i\" \"%{User-Agent}i\" %T %f" combinedfullurl
        CustomLog "|/usr/local/sbin/cronolog --symlink=/logs/access_log --period=1hour /logs/apache/access_log_%y%m%d-%H.log" combinedfullurl
        ErrorLog /logs/error_log
        LogLevel warn

# Site, Configuration, and Module enabling

sae|discrete-origin|a2ensite-healthcheck:
  apache_site.enabled:
    - name: healthcheck
    - require:
      - file: sae|discrete-origin|customer-confs

sae|discrete-origin|a2enconf-logging:
  apache_conf.enabled:
    - name: logging
    - require:
      - file: sae|discrete-origin|apache-logging-conf
    - listen_in:
      - service: core|apache2|service

sae|discrete-origin|a2enconf-llnwcontent:
  apache_conf.enabled:
    - name: llnwcontent
    - require:
      - file: sae|discrete-origin|llnwcontent-conf
    - listen_in:
      - service: core|apache2|service

{% set a2enmod = ['auth_basic','filter','expires','deflate','include','headers','authn_core','negotiation','env','status','dir','proxy','mime','authz_groupfile','proxy_http','authz_host','proxy_balancer','proxy_ajp','autoindex','alias','mpm_event','access_compat','authn_file','slotmem_shm','authz_user','proxy_connect','setenvif','authz_core','rewrite','proxy_ftp'] %}

{% for mod in a2enmod %}
sae|discrete-origin|a2enmod-{{ mod }}:
  apache_module.enabled:
    - name: {{ mod }}
    - listen_in:
      - service: core|apache2|service
{% endfor %}
