#!/bin/sh
PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin'
HOSTNAME=`hostname | cut -d "." -f 1`
RHOSTNAME=`hostname`
RSYNC=`which rsync`
LOGGER=`which logger`
egrep=`which egrep`
df=`which df`
host=`which host`
mail=`which mail`;
date=`which date`;
wget=`which wget`
header='healthcheck-noexist.llnw.net'
file='healthcheck.txt'

DATE=`date`;

# if this is a shared origin we have to manipulate the filename more
echo $RHOSTNAME | $egrep "origin.+\."
RCODE=$?
if [ "$RCODE" = "0" ]; then
  # we're a shared origin
  HOSTNAME=`echo $HOSTNAME | awk '{print substr($0, 2, 10) ".llnw.net"}'`
else
  # we're a dedicated!
  HOSTNAME="`hostname | sed 's/\.bocs\./\.ocs\./'`"
fi

$LOGGER -p daemon.info "newsync.sh starting run at $DATE"

# Are we on backup and someone's just retarded?
ORIGIN=`$host $HOSTNAME`
echo $ORIGIN | $egrep "borigin|bocs"
RCODE=$?
if [ "$RCODE" = "0" ]; then 
  $LOGGER -p daemon.err -t ORIGIN_SYNC "$RHOSTNAME failed because $HOSTNAME is pointed to the backup - exiting"
  echo "Someone tried to start newsync on $RHOSTNAME while it's acting as primary" | $mail -s "RSYNC ERROR" opseng@llnw.com
  exit 253
fi

# Are we on backup and want SYNCs not enabled
if [ -e "/etc/NOSYNC" ]; then
  # disable sync
  $LOGGER -p daemon.err -t ORIGIN_SYNC "$RHOSTNAME has sync disabled due to /etc/NOSYNC file"
  exit 254
fi

if [ -e "/var/run/proftpd.pid" ]; then
  $LOGGER -p daemon.error -t ORIGIN_SYNC "$RHOSTNAME has a proftpd.pd file, assuming proftpd is running - exiting"
  echo "$RHOSTNAME has proftpd.pid, is proftpd running? exiting newsync" | $mail -s "RSYNC ERROR" opseng@llnw.com
  exit 252
fi

# see if we're already running
#NEWSYNCPID=`pgrep -f newsync`
NEWSYNCPID=`pgrep -f "/bin/sh /usr/local/bin/newsync.sh"`
if [ "X$NEWSYNCPID" != "X" ]; then
  if [ "$NEWSYNCPID" != "$$" ]; then
    # we're already running, make a note and exit
    $LOGGER -p daemon.err -t ORIGIN_SYNC "$RHOSTNAME already running newsync.sh with pid $NEWSYNCPID - exiting"
    exit 0
  fi
fi

# make sure /content is mounted
mounted=`$df | $egrep '/content$'`
if [ "x$mounted" = "x" ]; then
  $LOGGER -p daemon.err -t ORIGIN_SYNC "$RHOSTNAME failed sync because /content is not mounted"
  exit 255
fi

# now lets make sure the primary is functioning
wget -O /dev/null --timeout=10 --header="Host: $header" http://$HOSTNAME/$file
RCODE=$?
if [ $RCODE != "0" ]; then
  $LOGGPER -p daemon.err -t ORIGIN_SYNC "$HOSTNAME sync error: primary /content offline?"
  exit 255
fi

# touch our lockfile
touch /var/run/newsync.running

# run our syncs

# cycle the standard syncs

for type in ht; do
  echo -e "Syncing $type\n"
  $RSYNC -vrtogpulH --delete-during --ignore-errors --bwlimit=90000 $HOSTNAME::$type/digicata/content/ /content/$type/digicata/content/
  RCODE=$?
  if [ $RCODE != "0" ]; then
    if [ $RCODE = "1" ]; then
      $LOGGER -p daemon.err -t ORIGIN_SYNC "$RHOSTNAME sync error: syntax error - $type"
    elif [ $RCODE = "2" ]; then
      $LOGGER -p daemon.err -t ORIGIN_SYNC "$RHOSTNAME sync error: protocol error - $type"
    elif [ $RCODE = "10" ]; then
      $LOGGER -p daemon.err -t ORIGIN_SYNC "$RHOSTNAME failed to sync from primary: fatal connection error - exiting"
      rm /var/run/newsync.running
      exit 255
    elif [ $RCODE = "11" ]; then
      $LOGGER -p daemon.err -t ORIGIN_SYNC "$RHOSTNAME failed to sync from primary: fatal I/O error - exiting"
      rm /var/run/newsync.running
      exit 255
    elif [ $RCODE = "12" ]; then
      $LOGGER -p daemon.err -t ORIGIN_SYNC "$RHOSTNAME sync error: datastream error - $type"
    elif [ $RCODE = "22" ]; then
      $LOGGER -p daemon.err -t ORIGIN_SYNC "$RHOSTNAME sync error: memory error - $type"
    elif [ $RCODE = "23" ]; then
      $LOGGER -p daemon.err -t ORIGIN_SYNC "$RHOSTNAME sync error: partial content - $type"
    elif [ $RCODE = "24" ]; then
      $LOGGER -p daemon.err -t ORIGIN_SYNC "$RHOSTNAME sync error: source vanished - $type"
    elif [ $RCODE = "30" ]; then
      $LOGGER -p daemon.err -t ORIGIN_SYNC "$RHOSTNAME sync error: data timeout - $type"
    elif [ $RCODE = "35" ]; then
      $LOGGER -p daemon.err -t ORIGIN_SYNC "$RHOSTNAME sync error: connection timeout - $type"
    elif [ $RCODE = "5" ]; then
      # do nothing, it's semi-intentional - it means there's nothing there to sync
    echo "do nothing"
    else 
      $LOGGER -p daemon.err -t ORIGIN_SYNC "$RHOSTNAME sync error: unknown code $RCODE - $type"
    fi
  else 
      $LOGGER -p daemon.info -t ORIGIN_SYNC "$RHOSTNAME sync completed for $type"
  fi
done

# notify we're all done
$LOGGER -p daemon.info "newsync.sh finished run at $DATE"

# lets not forget to remove our lock file
rm /var/run/newsync.running
