# vim: sts=2 ts=2 sw=2 et ai

{% from "pepper/map.jinja" import defaults with context %}
{% from "tcpwrappers/map.jinja" import extend_hosts with context %}

{{ extend_hosts('sshd', '/etc/hosts.discrete', 'IP address whitelist for discrete origin primary/backup', 'allow') }}

include:
  - raid
  - sae-xfer
  - openssh
  - tcpwrappers
  - sae-sudoers.OpsEngGroup
  - sae-sudoers.ops-noc
  - .executables
  - .logpusher
  - .dirs
  - .apache2
  - .cust
  - .chroot
  - .mlocate
  - .hosts-allow

sae|discrete-origin|pkgs:
  pkg.installed:
    - names:
      - cronolog
      - lsyncd
      - mon
      - bacula-fd
      - libpam-mount

sae|discrete-origin|cronolog-symlink:
  file.symlink:
    - name: /usr/local/sbin/cronolog
    - target: /usr/bin/cronolog
    - require:
      - pkg: sae|discrete-origin|pkgs

sae|discrete-origin|dugather-conf:
  file.managed:
    - name: /etc/dugather.conf
    - source: salt://sae-discrete-origin/xenial/files/dugather.conf
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 644

sae|discrete-origin|rsyncd-conf:
  file.managed:
    - name: /etc/rsyncd.conf
    - source: salt://sae-discrete-origin/xenial/files/rsyncd.conf
    - replace: False
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 644

sae|discrete-origin|rclocal:
  file.managed:
    - name: /etc/rc.local
    - source: salt://sae-discrete-origin/xenial/files/rc.local
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755

sae|discrete-origin|rsync_exclude:
  file.managed:
    - name: /home/xfer/exclude.file
    - source: salt://sae-discrete-origin/xenial/files/exclude.file
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 644

# this needs to be done because of the number of sshd_config changes
# pulls a different sshd_config files rather than the default one
extend:
  core|openssh|sshd-config:
    file.managed:
      - name: /etc/ssh/sshd_config
      - source: salt://sae-discrete-origin/xenial/files/sshd_config

sae|discrete-origin|sudoers:
  file.managed:
    - name: /etc/sudoers.d/raidutils
    - content: |
        %users ALL = NOPASSWD: /usr/local/bin/storcli
        %users ALL = NOPASSWD: /usr/local/bin/tw_cli

sae|discrete-origin|bacula-filelist-exclude:
  file.managed:
    - name: /etc/bacula.filelist.exclude
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 644

sae|discrete-origin|bacula-filelist-include:
  file.managed:
    - name: /etc/bacula.filelist
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 644
    - contents:
      - /etc
      - /srv
      - /home/xfer
      - /usr/local/etc
      - /usr/local/apache2/conf

sae|discrete-origin|crontab:
  file.append:
    - name: /etc/crontab
    - text:
      - 0 0 * * * root find /logs/*/old -mtime +30 | xargs rm
      - 0 3 * * * root /usr/local/bin/driveInfoBasic.pl
      - 30 * * * * root /usr/local/bin/originParity.pl -silent
      - 30 5 * * * root sleep `/usr/bin/od -An -N1 -i /dev/urandom`; df -k /content | grep -v "^File" | awk '{ print "type=origin_space filesystem=" $1 " total_space=" $2 " used_space=" $3 " avail_space=" $4; }' | logger

sae|discrete-origin|pam_mount-conf:
  file.managed:
    - name: /etc/security/pam_mount.conf.xml
    - source: salt://sae-discrete-origin/xenial/files/pam_mount.conf.xml
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 644

sae|discrete-origin|del_lama-repo:
  file.absent:
    - name: /etc/apt/sources.list.d/llnw.lama.trusy.list

sae|discrete-origin|install_proftpd-basic:
  pkg.installed:
    - name: proftpd-basic
    - version: 1.3.5d-3-gd11723e
    - require:
      - pkgrepo: sae|discrete-origin|repo_proftpd

sae|discrete-origin|repo_proftpd:
  pkgrepo.managed:
    - names:
      - deb http://llnwsae.vo.llnwd.net/v1/packages/llnw/proftpd/ubuntu/{{ grains['osrelease'] }} ./
    - file: /etc/apt/sources.list.d/llnw.proftpd.{{ grains['oscodename'] }}.list
    - require:
      - file: sae|discrete-origin|del_lama-repo

sae|discrete-origin|defaultroot-proftpd-conf:
  file.managed:
    - name: /etc/proftpd/conf.d/defaultroot.conf
    - source: salt://sae-discrete-origin/xenial/files/proftpd-default.conf
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 644
    - require:
      - pkg: sae|discrete-origin|install_proftpd-basic

# see https://bugs.launchpad.net/ubuntu/+source/proftpd-dfsg/+bug/1246245
sae|discrete-origin|proftpd-init.conf:
  file.replace:
    - name: /etc/init.d/proftpd
    - pattern: |
        start-stop-daemon --stop --signal \$SIGNAL --quiet --pidfile "\$PIDFILE"
    - repl: |
        start-stop-daemon --stop --signal $SIGNAL --retry 1 --quiet --pidfile "$PIDFILE"
    - require:
      - pkg: sae|discrete-origin|install_proftpd-basic
