# vim: sts=2 ts=2 sw=2 et ai

{% from "pepper/map.jinja" import defaults with context %}

{% set geo_ver = '1.3.24' %}
{% set healthd_ver = '1.2.21' %}

{% macro dns100rcfile(name, command) %}
sae|dns100|rcfile|{{ name }}:
  file.managed:
    - name: /etc/rc.d/{{ name }}
    - source: salt://sae-dns100/templates/rc.d.jinja
    - user: root
    - group: {{ defaults['root_group'] }}
    - template: jinja
    - mode: 755
    - defaults:
        name: {{ name }}
        command: {{ command }}
{%- endmacro %}

{% macro dns100exec(file, path) %}
sae|dns100|exec|{{ file }}:
  file.managed:
    - name: {{ path }}/{{ file }} 
    - source: salt://sae-dns100/files/{{ file }}
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755
{%- endmacro %}

{{ dns100exec('dns_ipfw.pl', '/usr/local/bin') }}
{{ dns100exec('dnsdisk.pl', '/usr/local/bin') }}
{{ dns100exec('mknamedconf.pl', '/usr/local/bin') }}

sae|dns100|exec|check-reconfig:
  file.managed:
    - name: /usr/local/bin/check-reconfig
    - source: salt://sae-dns100/templates/check-reconfig.jinja
    - user: root
    - group: {{ defaults['root_group'] }}
    - template: jinja
    - mode: 755
    - makedirs: True
    - dir_mode: 755
    - defaults:
        check_reconfig_zebra: {{ salt['pillar.get']('secrets:sae-dns100:check_reconfig_zebra') }}

sae|dns100|custom-named-bin:
  file.managed:
    - name: /usr/local/sbin/named
    - source: http://test.vo.llnwd.net/o1/fbsd/All/named-dns100
    - source_hash: md5=f78186af8b0337334512398e59ffbbe2
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755

sae|dns100|dep-pkgs:
  pkg.installed:
    - sources:
      - quagga: http://test.vo.llnwd.net/o1/fbsd/amd64/10/quagga-1.0.20160315.txz

sae|dns100|geo-pkg:
  cmd.run:
    - name: pkg delete -fy llnw-geod geo; pkg add http://images.llnw.net/fbsd/amd64/10/geo-{{ geo_ver }}.txz
    - unless: pkg info -e "geo=={{ geo_ver }}"

sae|dns100|healthd-pkg:
  cmd.run:
    - name: pkg delete -fy llnw-healthd healthd; pkg add http://images.llnw.net/fbsd/amd64/10/healthd-{{ healthd_ver }}.txz
    - unless: pkg info -e "healthd=={{ healthd_ver }}"

{{ dns100rcfile('named', '/usr/local/sbin/named -c /home/dns/anycast/named.conf') }}
{{ dns100rcfile('geod', '/usr/local/bin/geod') }}
{{ dns100rcfile('healthd', '/usr/local/bin/healthd') }}
{{ dns100rcfile('logpusher', '/usr/local/bin/logpusher') }}
