#!/usr/bin/perl

$cdinodes  = 3_000_000;
$pcdinodes = 1_000_000;

$cmd = 'sysctl -n kern.disks';
open( IN, "$cmd|" ) or die "can't run $cmd: $!";
while (<IN>) {
    @tdisks = split;
    foreach $disk ( reverse @tdisks ) {
        if ( $disk =~ /^(a|vtb)?da?0$/ ) {
            push( @disks, $disk );
        }
        if ( $disk =~ /^twed(\d+)/ ) {
            if ( $1 > 0 ) {
                push( @disks, $disk );
            }
        }
    }
}
close IN;

foreach $disk (@disks) {
    $slice = $disk . 's1';
    my $cmd;
    &readslice($slice);
    $found = join( ' ', @parts );
    print "found partitions on $slice: $found\n";
    if ( $disk =~ /^(a|vtb)?da?0$/ ) {
        $is_pcds = 1;
        $expect  = "a b c d e";
        if ( $found eq $expect ) {
            &checkfs( $slice . 'd', 1_000_000, $sectors{'d'} );    # local
            &checkfs( $slice . 'e', 100_000,   $sectors{'e'} );    # logs
        }
        elsif ( $found eq "a b c e" ) {
            fixslice("$slice");
            readslice($slice);
            &checkfs( $slice . 'd', 1_000_000, $sectors{'d'} );    # local
            &checkfs( $slice . 'e', 100_000,   $sectors{'e'} );    # logs
        }
        else {

            print "$slice: '$found' differs from '$expect'\n";
        }
    }
}

sub readslice {
    my ($slice) = @_;
    $cmd = "disklabel $slice";
    open( IN, "$cmd 2>&1 |" ) or die "can't run $cmd: $!";
    @parts   = ();
    $inparts = 0;
    %type    = ();
    %sectors = ();
    while (<IN>) {
        next if (/super block size/);
        if ($inparts) {
            next if (/^#/);
            ( $part, $sectors, $start, $type ) = split;
            $part =~ tr/://d;
            push( @parts, $part );
            $type{$part}    = $type;
            $sectors{$part} = $sectors;
        }
        elsif (/partitions:/) {
            $inparts = 1;
        }
    }
    close IN;
}

sub fdisk_label_entire {
    my ($disk) = @_;
    my ( $slice, $cmd, $newlabel );

    $slice = $disk . 's1';
    $cmd   = "dd if=/dev/zero of=/dev/$disk bs=512 count=32";
    system($cmd);
    $cmd = "fdisk -BI $disk";
    system($cmd);
    $cmd = "dd if=/dev/zero of=/dev/$slice bs=512 count=32";
    system($cmd);
    $cmd = "disklabel -B -w -r $slice auto";
    system($cmd);
    $cmd = "disklabel $slice";
    open( IN, "$cmd|" );

    while (<IN>) {
        if (/^\s+c: /) {
            ( undef, $size, $offset ) = split;
            $newlabel .= $_;
            $newlabel .= sprintf "  e: %d 16 unused 0 0\n", $size - 16;
        }
        elsif (/^\s+a: /) {

            # skip!
        }
        else {
            $newlabel .= $_;
        }
    }
    close IN;
    $file = "/tmp/label.$slice.$$";
    print "$newlabel\n";
    open( OUT, ">$file" ) or die "can't write $file: $!";
    print OUT $newlabel;
    close OUT;
    $cmd = "disklabel -R $slice $file";
    system($cmd);

    #unlink($file);
}

sub fixslice {
    my $slice = shift;
    system("disklabel $slice");
    system("gpart show");

    print "slices are incorrect for $slice";
    $cmd = "gpart delete -i 5 $slice";
    system("disklabel $slice");
    system("gpart show");
    $res = &yesno("run $cmd");
    if ($res) {
        system($cmd);
    }

    $cmd = "gpart add -a 4k -s 10G -t freebsd-ufs $slice";
    $res = &yesno("run $cmd");
    if ($res) {
        system($cmd);
    }

    $cmd = "gpart add -a 4k -t freebsd-ufs $slice";

    $res = &yesno("run $cmd");
    if ($res) {
        system($cmd);
    }
}

sub checkfs {
    my ( $part, $inodes, $sectors ) = @_;
    my ( $need_newfs, $cmd );
    $cmd = "tunefs -p $part";
    open( IN, "$cmd 2>&1 |" ) or die "can't run $cmd: $!";
    while (<IN>) {
        if (/Device not configured/) {
            print "$cmd error:\n";
            print;
            exit;
        }
        elsif (/bad magic number/) {
            print "$part needs newfs\n";
            $need_newfs = 1;
        }
        elsif (/could not read superblock to fill out disk/) {
            print "$part needs newfs\n";
            $need_newfs = 1;
        }
        else {
            #print;
        }
    }
    close IN;
    if ($need_newfs) {
        print "$part $sectors $inodes\n";

        #$cmd = sprintf("newfs -U -i %d -b 32768 -f 4096 %s",
        $cmd = sprintf( "newfs -U -i %d %s", $sectors * 512 / $inodes, $part );
        $res = &yesno("run $cmd");
        if ($res) {
            system($cmd);
        }
    }
}

sub yesno {
    ($str) = @_;
    my ($ans);
    $| = 1;
    while (1) {
        print "\r$str? ";
        $ans = <STDIN>;
        if ( $ans =~ /^y/i ) {
            return (1);
        }
        if ( $ans =~ /^n/i ) {
            return (0);
        }
    }
    print "\n";
}
