#!/usr/bin/env bash
PATH="/sbin:/bin:/usr/bin:/usr/sbin:/usr/local/sbin:/usr/local/bin"
shopt -s nocaseglob
shopt -s nocasematch

host=`hostname`
host_name=( ${host//./ } )
pop=${host_name[1]}
site_file="/tftpboot/${pop}.flb"

error_exit(){
  echo "${0}: ${1:-""}" 1>&2
  exit 1
}

error_check(){
  lockfile="/tmp/gen_pbslb.lock"
  tmp_file="/tmp/gen_pbslb.dat"

  #If vtysh is not found and executable exit out
  if [ ! -x vtysh ]; then
    exit 0
  fi

  if [ -f ${lockfile} ]; then
    old_lock=`find ${lockfile} -mmin +60`
    if [ ${old_lock} ]; then
      rm -f ${old_lock} || error_exit "Could not remove old lockfile ${lockfile}, try manually removing"
    else
      exit 0
    fi
  fi

  touch ${lockfile} || error_exit "Could not create lock file ${lockfile}, line: $LINENO"
  touch ${tmp_file} || error_exit "Could not create tmp file ${tmp_file}, line: $LINENO"
  trap "rm -f ${lockfile} ${tmp_file}; exit" TERM INT EXIT
}

get_community(){
  case $pop in
    "gru") bgp_comm="64555:100"
           ;;
    "hhp") bgp_comm="64555:100"
           ;;
    *) exit 0
           ;;
  esac
}

get_bgp_routes(){
  vtysh -c "show ip bgp community ${bgp_comm}" > ${lockfile} || error_exit "Could not grab bgp routes"

  #If the file is empty just exit out
  if [ ! -s ${lockfile} ]; then
    exit 0
  fi

  while read line cidr rest; do 
    if [[ $cidr =~ ^[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\/[0-9]{1,2}$ ]]; then
      echo "${cidr} 1" >> $tmp_file || error_exit "Could not write to $tmp_file"
    elif [[ $cidr =~ ^[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3} ]]; then
      echo "${cidr}/24 1" >> $tmp_file || error_exit "Could not write to $tmp_file"
    fi
  done < $lockfile || error_exit "Failed to open file $tmp_file"
}

move_file(){
  if [ -s $tmp_file ]; then
    mv $tmp_file $site_file || error_exit "Failed to move $tmp_file to $site_file"
  fi
}

error_check
get_community
get_bgp_routes
move_file
