#!/usr/bin/perl -w

$conffile = "/home/dns/anycast/named.conf";
#$conffile = "/tmp/named.conf";
$domaindir = "/local/geo/llnwd/anycastdns";

my $debug = 0;

use POSIX;
use Socket;

@un = uname;
$hostname = $un[1];
if ($hostname !~ /^dns.*.llnw.net/) {
    die "cannot parse localhostname: $!";
}
if ($hostname =~ /^dns2[0-9][0-9]\./) {
    $llnwd_zone = "llnwd-int.net";
} else {
    $llnwd_zone = "llnwd.net";
}
$addr = inet_aton($hostname);
if (!$addr) {
    die "cannot lookup local hostname $hostname";
}
$ipaddr = inet_ntoa($addr);

open(CONF, ">$conffile.new") || die "$conffile.new: $!";
print CONF qq{
acl trusted {
	68.142.97.0/24;
	127.0.0.1;
	208.48.140.0/24;
	69.164.61.32/28;
	69.28.133.0/24;
	208.111.136.22;
	68.142.66.68;
};

options {
	directory "/home/dns/anycast";
	pid-file "named.pid";
	allow-transfer { trusted; };
	allow-query { trusted; };
	listen-on-v6 { none; };
	listen-on {
	   $ipaddr;
	   69.28.143.11;
	   69.28.143.12;
	   69.28.143.13;
	   69.28.143.14;
	   69.28.143.34;
	   69.28.143.35;
	   69.28.143.36;
	   69.28.143.37;
	   69.28.143.21;
	   69.28.143.22;
	   69.28.143.23;
	   69.28.143.24;
	   69.28.143.50;
	   69.28.143.51;
	   127.0.0.1;
	};
        auth-nxdomain no;
        recursion no;
        notify no;
	max-rr-records 2;
        query-log-sample 100;

	rrset-order {
	    order random;
        };
};
controls {
	inet 127.0.0.1 allow { trusted; } keys { rndc_key; };
};

logging {
	channel querychan {
		file "/logs/dns/named-anycast.queries" size 100M;
		print-time yes;
	};
	#category queries { null; };
	category queries { querychan; };

	channel defchan {
		file "/var/log/named-anycast" versions 2 size 100M;
		print-time yes;
	};
	category default { defchan; };
};

zone "." {
	type hint;
	file "/home/dns/root.cache";
};

zone "0.0.127.in-addr.arpa" {
	type master;
	file "/home/dns/127.0.0";
};

zone "llnwd-int.net" {
        type master;
        file "/local/geo/llnwd/llnwd-int.net";
        allow-query { any; };
};
zone "llnwd-a.net" {
        type master;
        file "/local/geo/llnwd/llnwd.net";
        allow-query { any; };
};
zone "llnwd.net" {
	type master;
	file "/local/geo/llnwd/$llnwd_zone";
	allow-query { any; };
};

};

opendir(DOMAINS, $domaindir) || die "$domaindir: $!";
DOMAIN: while ($d = readdir(DOMAINS)) {
    next if $d =~ /^\./;

    # make sure all includes are present
    open(DOMAIN, "$domaindir/$d") || die "$domaindir/$d: $!";
    while (<DOMAIN>) {
	if (/RESTRICT: (.*)$/i) {
	    next DOMAIN unless &eval_restrict($1);
	}
	if (/^\$INCLUDE (.*)$/i) {
	    next DOMAIN unless -f $1;
	}
    }

    print CONF qq{

zone "$d" {
	type master;
	file "$domaindir/${d}";
	allow-query { any; };
};

};
    
}

close(CONF);
rename("$conffile.new", $conffile);

#system(q{
#egrep '^rr test.vo' /local/geo/geo.conf | sed s/test.vo/aa-test.llnw.net:test/ >> /local/geo/geo.conf
#});

sub eval_restrict {
    my ($str) = @_;

    my $parengrp = qr{
                              \(
                              (?:
                                 (?> [^()]+ )    # Non-parens without backtracking
                               |
                                 (??{ $re })     # Group with matching parens
                              )*
                              \)
                           }x;

    $str =~ s/^[ \t]*//;
    $str =~ s/[ \t]*$//;

    print "Evaluating '$str'\n" if $debug;
    
    my $res;

    if ($str =~ $parengrp) {
	$res = &eval_restrict($1);
    } elsif ($str =~ /^($parengrp|[^\(\)]+)\|\|($parengrp|[^\(\)]+)$/) {
	my ($first, $second) = ($1, $2);
	print "Or of '$first' and '$second'\n" if $debug;
	$res = &eval_restrict($first) || &eval_restrict($second);
    } elsif ($str =~ /^!(.*)$/) {
	print "Not '$1'\n" if $debug;
	$res = !&eval_restrict($1);
    } elsif ($str eq 'dns200') {
	if ($hostname =~ /^dns2[0-9][0-9]\./) {
	    $res = 1;
	} else {
	    $res = 0;
	}
    } else {
	print "Searching for tag '$str'\n" if $debug;
	$res = 0;
	open(TAGS, "/local/geo/llnwd/sitetags.dat") || die "sitetags.dat: $!";
	while (my $tag = <TAGS>) {
	    chop $tag;
	    $res = 1 if $tag eq $str;
	}
    }
    print "Evaluated '$str' to '$res'\n" if $debug;
    return $res;
}
