# vim: sts=2 ts=2 sw=2 et ai
{% from "pepper/map.jinja" import defaults with context %}


include:
  - .executables
  - .logpusher
  - .fstab
  - .dirs
  - .crontab
  - .hosts
  - cfengine.remove
  - resolver.mkresolvsh
  - syslog-conf
  - sae-xfer
  - sae-sudoers.dns100-xfer
  - sae-sudoers.OpsEngGroup
  - dns-metrics
  - dns-lockedrunq

extend:
   core|syslog-conf|freebsd-syslog-ngconf:
     file:
       - source: salt://sae-dns100/files/syslog-ng.conf

sae|dns100|rcconf:
  file.append:
    - name: /etc/rc.conf
    - text:
      - quagga_daemons="zebra bgpd"

sae|dns100|rclocal:
  file.append:
    - name: /etc/rc.local
    - text:
      - 'rm -f /usr/local/etc/quagga/zebra.conf /usr/local/etc/quagga/bgpd.conf'
      - '/usr/local/bin/dns_ipfw.pl'
    - require:
      - file: sae|dns100|exec|dns_ipfw.pl

sae|dns100|logfiles:
  file.exists:
    - names:
      - /var/log/healthd
      - /var/log/geod
    - require:
      - file: core|syslog-conf|freebsd-syslog-ngconf
      - service: core|syslog-ng|service

sae|dns100|ipfw-enable:
  sysctl.present:
    - name: net.inet.ip.fw.enable
    - value: 1
    - config: /etc/sysctl.conf

sae|dns100|ipfw6-enable:
  sysctl.present:
    - name: net.inet6.ip6.fw.enable
    - value: 1
    - config: /etc/sysctl.conf

sae|dns100|newsyslog:
  file.append:
    - name: /etc/newsyslog.conf
    - text:
      - '/var/log/healthd			644  9	   1000	*     C'
      - '/var/log/geod				644  9	   1000	*     C'
    - require:
      - service: core|syslog-ng|service

sae|dns100|homedir|root-cache:
  file.managed:
    - name: /home/dns/root.cache
    - source: salt://sae-dns100/files/root.cache
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 644

sae|dns100|homedir|localhost:
  file.managed:
    - name: /home/dns/127.0.0
    - source: salt://sae-dns100/files/127.0.0
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 644

sae|dns100|homedir|llnwd-symlink:
  file.symlink:
    - name: /home/xfer/llnwd
    - target: /local/geo/llnwd
    - force: True
    - mode: 755

sae|dns100|conf|snmpd:
  file.managed:
    - name: /usr/local/etc/snmpd.conf
    - source: salt://sae-dns100/files/snmpd.conf
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 644

sae|dns100|conf|healthd:
  file.managed:
    - name: /usr/local/etc/healthd.conf
    - source: salt://sae-dns100/files/healthd.conf
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 644

sae|dns100|conf|healthd-symlink:
  file.symlink:
    - name: /etc/healthd.conf
    - target: /usr/local/etc/healthd.conf
    - force: True

sae|dns100|conf|bgpd:
  file.managed:
    - name: /usr/local/etc/quagga/bgpd.conf
    - source: salt://sae-dns100/files/bgpd.conf
    - user: quagga
    - group: quagga
    - template: jinja
    - mode: 644
    - makedirs: True
    - dir_mode: 755
    - replace : False
    - defaults:
        bgpd_password: {{ salt['pillar.get']('secrets:sae-dns100:bgpd_password') }}
        bgpd_enable_password: {{ salt['pillar.get']('secrets:sae-dns100:bgpd_enable_password') }}

sae|dns100|conf|zebra:
  file.managed:
    - name: /usr/local/etc/quagga/zebra.conf
    - source: salt://sae-dns100/files/zebra.conf
    - user: quagga
    - group: quagga
    - template: jinja
    - mode: 644
    - makedirs: True
    - dir_mode: 755
    - replace : False
    - defaults:
        zebra_password: {{ salt['pillar.get']('secrets:sae-dns100:zebra_password') }}
        zebra_enable_password: {{ salt['pillar.get']('secrets:sae-dns100:zebra_enable_password') }}

sae|dns100|conf|named:
  cmd.run:
    - umask: "022"
    - timeout: 60
    - name: /usr/local/bin/mknamedconf.pl
    - require:
      - file: sae|dns100|exec|mknamedconf.pl

sae|dns100|setupaliases:
  cmd.run:
    - names:
      - ifconfig lo0 alias 69.28.143.11 netmask 255.255.255.255
      - ifconfig lo0 alias 69.28.143.12 netmask 255.255.255.255
      - ifconfig lo0 alias 69.28.143.13 netmask 255.255.255.255
      - ifconfig lo0 alias 69.28.143.14 netmask 255.255.255.255
      - ifconfig lo0 alias 69.28.143.15 netmask 255.255.255.255
      - ifconfig lo0 alias 69.28.143.16 netmask 255.255.255.255
      - ifconfig lo0 alias 69.28.143.17 netmask 255.255.255.255
      - ifconfig lo0 alias 69.28.143.18 netmask 255.255.255.255
      - ifconfig lo0 alias 69.28.143.34 netmask 255.255.255.255
      - ifconfig lo0 alias 69.28.143.35 netmask 255.255.255.255
      - ifconfig lo0 alias 69.28.143.36 netmask 255.255.255.255
      - ifconfig lo0 alias 69.28.143.37 netmask 255.255.255.255
      - ifconfig lo0 alias 69.28.143.50 netmask 255.255.255.255
      - ifconfig lo0 alias 69.28.143.51 netmask 255.255.255.255
      - ifconfig lo0 alias 10.255.1.10 netmask 255.255.255.255

sae|dns100|run|named:
  service.running:
    - name: named
    - enable: True
    - require: 
      - file: sae|dns100|custom-named-bin
      - cmd: sae|dns100|conf|named

sae|dns100|run|logpusher:
  service.running:
    - name: logpusher
    - enable: True
    - require: 
      - file: sae|dns100|logpusher

sae|dns100|run|healthd:
  service.running:
    - name: healthd
    - enable: True
    - require: 
      - cmd: sae|dns100|healthd-pkg
      - file: sae|dns100|conf|healthd

sae|dns100|run|geod:
  service.running:
    - name: geod
    - enable: True
    - require: 
      - cmd: sae|dns100|geo-pkg
      - mount: sae|dns100|fstab|mount-logs
      - mount: sae|dns100|fstab|mount-local

sae|dns100|run|quagga:
  service.dead:
    - name: quagga
    - enable: False

sae|dns100|run|dns_ipfw.pl:
  cmd.wait:
    - umask: "022"
    - name: /usr/local/bin/dns_ipfw.pl
    - onlyif: pgrep bgpd
    - timeout: 60
    - require:
      - cmd: sae|dns100|setupaliases
      - file: sae|dns100|exec|dns_ipfw.pl
      - sysctl: sae|dns100|ipfw-enable
      - sysctl: sae|dns100|ipfw6-enable

sae|dns100|run|extra:
  cmd.run:
    - umask: "022"
    - timeout: 60
    - name: /usr/bin/killall -9 geod;/bin/sleep 1;ulimit -v 2500000;ulimit -c 1500000;/usr/local/bin/geod
    - require:
      - service: sae|dns100|run|geod
