# We need cfengine to think that Salt is not really present on DNSXD so that it
# will apply the configs normally disabled when Salt is present. This file
# turns off, hides, and disables the usual Salt presence indicators.
#
# Specifically, if /etc/salt.enabled is present, the salt-bootstrap script will
# be run. Not a big deal, but a waste of resources. If /etc/salt.lastcontact is
# present, a lot of standard cfengine configs will not be run. salt-minion and
# lastcontact should be prevented from running due to exclusions in sae-dnsxd,
# so the states here are really just a backup in case they are created some
# other way.
#
# Note that zabbix will be unable to monitor Salt on DNSXD, but that's OK since
# we don't really want it monitored.
#
# order: last ensures that these states are run at the end of a highstate.

{% from 'salt/map.jinja' import salt_map %}

# DNSXD should not have the minion service running all the time
sae|dnsxd|salt|minion-service-dead:
  service.dead:
    - enable: False
    - name: {{ salt_map['minion-service'] }}
    - order: last

# Presence of /etc/salt.enabled will trigger salt-bootstrap
sae|dnsxd|salt|enabled-absent:
  file.absent:
    - name: /etc/salt.enabled
    - require:
      - service: sae|dnsxd|salt|minion-service-dead
    - order: last

# A lot of basic cfengine-provided config depends on the absence of
# /etc/salt.lastcontact
sae|dnsxd|salt|lastcontact-absent:
  file.absent:
    - name: /etc/salt.lastcontact
    - require:
      - service: sae|dnsxd|salt|minion-service-dead
    - order: last
