#!/usr/bin/perl

use strict;
use warnings;
use YAML qw(LoadFile);
use File::Temp;
use Getopt::Long;

my ($conf_file, $if_file, $write_changes);
do_flags();

my $conf = LoadFile($conf_file);
my $ucarp = $conf;

open my $in, '<', $if_file or die "Failed to open $if_file: $!";
my $seen = 0;
while (my $line = <$in>) {
    if ($line =~ /ucarp/) {
        $seen++;
        last;
    }
}

if (!$seen) {
    seek($in, 0, 0) or die "Failed to seek to start of file: $!";
    my $out = File::Temp->new(UNLINK => 0);
    OUTER:
    while (my $line = <$in>) {
        $line = fix_indent($line);
        if ($line =~ /^iface\s+$ucarp->{interface}\s+inet\s+(\S+)/) {
            my $method = $1;
            print $out $line or die "Failed to write to disk: $!";
            while ($line = <$in>) {
                $line = fix_indent($line);
                if ($line =~ /^\S+/ || $line =~ /^\s*$/) {
                    my $ok = print $out <<UCARP;
    ucarp-vid $ucarp->{vid}
    ucarp-vip $ucarp->{vip}
    ucarp-password $ucarp->{password}
    ucarp-advskew $ucarp->{advskew}
    ucarp-advbase $ucarp->{advbase}
    ucarp-nomcast $ucarp->{nomcast}
    ucarp-upscript $ucarp->{upscript}
    ucarp-downscript $ucarp->{downscript}

iface $ucarp->{interface}:ucarp inet $method
    address $ucarp->{vip}
    netmask $ucarp->{netmask}
UCARP
                    die "Failed to write to disk: $!" unless $ok;
                    redo OUTER;
                } else {
                    print $out $line;
                }
            }
        } else {
            print $out $line or die "Failed to write to disk: $!";
        }
    }
    my $nfile = $out->filename;
    close $out or die "Failed to close tempfile: $!";
    if ($write_changes) {
        rename($nfile, $if_file) or die "Failed to rename $nfile -> $if_file: $!";
    } else {
        open my $tin, '<', $nfile or die "failed to open tempfile: $!";
        while (my $line = <$tin>) { print $line; }
    }
}
close $in or die "Failed to close handle: $!";

sub fix_indent {
    my $line = shift;
    if ($line =~ /^\s+\S+/) {
        $line =~ s/^\s+/    /g; # normalize indentation
    }
    return $line;
}

sub do_flags {
    GetOptions(
        'config-file=s'    => \$conf_file,
        'interface-file=s' => \$if_file,
        'write-changes'    => \$write_changes,
    ) or help();

    $conf_file && $if_file || help();
}

sub help {
    print STDERR <<HELP;
    usage:

    Write changes to the interface file:
    $0 --config-file settings.yml --interface-file /etc/network/interfaces --write-changes

    Print changes to the interface file to stdout:
    $0 --config-file settings.yml --interface-file /etc/network/interfaces
HELP
    exit 1;
}

__END__

=head1 PURPOSE

    I'm unable to find a way via salt or debian/ubuntu tooling to configure ucarp in /etc/network/interfaces
    or via interfaces.d without clobbering the existing interface configs.  As of today sysops manually
    provisions IP addresses and configures the interface file.

    I attempted to do this via salt file.replace, but the regex to only do the replacement if the string ucarp
    was not found proved too difficult.  The logic is much easier when you have total control, like in this script.

=head1 Author

    Jeremy Singletary <jsingletary@llnw.com>, <jeremys@rickyninja.net>
