# vim: sts=2 ts=2 sw=2 et ai

include:
  - carp

sae|dnsxd-mc|apt-repo:
  pkgrepo.managed:
    - names:
      - deb http://repo.llnw.net/llnw/ubuntu/production/dnsxd {{ grains['oscodename'] }}/
    - file: /etc/apt/sources.list.d/llnw.dnsxd.{{ grains['oscodename'] }}.list

sae|dnsxd-mc|dns-xd-health-pkg:
  pkg.installed:
    - name: dns-xd-health
    - version: 1.0.2
    - require:
      - pkgrepo: sae|dnsxd-mc|apt-repo

# mysql-cli for debugging connection.
# redis-cli is installed via dns-xd-health -> redis-server -> redis-tools -> redis-cli
# curl is used in ocf_heartbeat_anything monitor_hook via monitor-healthrpc.
sae|dnsxd-mc|pkgs:
  pkg.installed:
    - names:
      - mysql-client
      - curl
      - perl
      - libyaml-perl

sae|dnsxd-mc|dns-xd-health-yml:
  file.managed:
    - name: /etc/dns-xd-health.yml
    - user: dns-xd
    - mode: 600
    - source: salt://sae-dnsxd/mc/files/dns-xd-health.yml
    - template: jinja

sae|dnsxd-mc|noit-server-key:
  file.managed:
    - user: dns-xd
    - name: /etc/dns-xd-health/noit-server-key.pem
    - contents_pillar: secrets:sae-noit:noit_priv_key
    - backup: False
    - mode: 600

{% set env = salt['grains.get']('team_env', default='dev') %}
sae|dnsxd-mc|noit-server-cert:
  file.managed:
    - name: /etc/dns-xd-health/noit-server-cert.pem
    - source: salt://sae-dnsxd/noit/files/env/{{ env }}/noit-server-cert.pem

sae|dnsxd-mc|interfaces:
  cmd.run:
    - name: /usr/local/bin/add-ucarp-to-interface.pl --config-file /etc/ucarp.yml --interface-file /etc/network/interfaces --write-changes
    - onlyif: /usr/local/bin/ucarp-not-configured.pl
    - require:
      - pkg: sae|dnsxd-mc|pkgs
      - file: sae|dnsxd-mc|ucarp-settings
      - file: sae|dnsxd-mc|ucarp-not-configured
      - file: sae|dnsxd-mc|add-ucarp-to-interface

sae|dnsxd-mc|ucarp-settings:
  file.managed:
    - name: /etc/ucarp.yml
    - template: jinja
    - source: salt://sae-dnsxd/mc/files/ucarp.yml
    - mode: 644

sae|dnsxd-mc|ucarp-not-configured:
  file.managed:
    - name: /usr/local/bin/ucarp-not-configured.pl
    - source: salt://sae-dnsxd/mc/files/ucarp-not-configured.pl
    - mode: 755

sae|dnsxd-mc|add-ucarp-to-interface:
  file.managed:
    - name: /usr/local/bin/add-ucarp-to-interface.pl
    - source: salt://sae-dnsxd/mc/files/add-ucarp-to-interface.pl
    - mode: 755

sae|dnsxd-mc|vip-up:
  file.managed:
    - name: /usr/local/bin/vip-up.sh
    - source: salt://sae-dnsxd/mc/files/vip-up.sh
    - mode: 755
    - template: jinja

sae|dnsxd-mc|vip-down:
  file.managed:
    - name: /usr/local/bin/vip-down.sh
    - source: salt://sae-dnsxd/mc/files/vip-down.sh
    - mode: 755
    - template: jinja
