{% set env = salt['grains.get']('team_env', default='dev') %}
{% from "pepper/map.jinja" import netblocks %}

sae|dnsxd-noit|apt-repo:
  pkgrepo.managed:
    - names:
      - deb http://repo.llnw.net/llnw/ubuntu/production/dnsxd trusty/
    - file: /etc/apt/sources.list.d/llnw.dnsxd.trusty.list

sae|dnsxd|noitd-pkg:
  pkg.installed:
    - name: reconnoiter
    - version: 1.0-llnw-1
    - require:
      - pkgrepo: sae|dnsxd-noit|apt-repo
  service.running:
    - name: reconnoiter
    - require:
      - pkg: sae|dnsxd|noitd-pkg
    - watch:
      - file: sae|dnsxd|noit-conf
      - file: sae|dnsxd-noit|noit-server-cert
      - file: sae|dnsxd-noit|noit-server-key
      - file: sae|dnsxd-noit|noit-CA

{% if 'epdns.noit.firewall' in salt['grains.get']('cornerstone:tags', {}) %}
include:
  - firewall.standard

sae|dnsxd-noit|firewall:
  firewall.accept:
    - tcp:
      - [ 32322, {{ netblocks }}]
      - [ 32323, {{ netblocks }}]
      - [ 43191, {{ netblocks }}]
    - require_in:
      - firewall: core|firewall|final-reject
{% endif %}

# Only place this file upon package installation.  This file will normally
# be updated when clients interact with the API.
sae|dnsxd|noit-conf:
  file.managed:
    - name: /etc/noit/noit.conf
    - source: salt://sae-dnsxd/noit/files/noit.conf
    - replace: False

sae|dnsxd-noit|noit-CA:
  file.managed:
    - name: /etc/noit/noit-CA.pem
    - source: salt://sae-dnsxd/noit/files/env/{{ env }}/noit-CA.pem

sae|dnsxd-noit|noit-server-key:
  file.managed:
    - name: /etc/noit/noit-server-key.pem
    - contents_pillar: secrets:sae-noit:noit_priv_key
    - backup: False
    - mode: 600

sae|dnsxd-noit|noit-server-cert:
  file.managed:
    - name: /etc/noit/noit-server-cert.pem
    - source: salt://sae-dnsxd/noit/files/env/{{ env }}/noit-server-cert.pem

sae|dnsxd|monit-pkg:
  pkg.installed:
    - name: monit
  service.running:
    - name: monit
    - require:
      - pkg: sae|dnsxd|monit-pkg
    - watch:
      - file: sae|dnsxd|monit-noit

# llnw noitd is leaking memory, so using monit to restart noitd when using > 60% memory.
sae|dnsxd|monit-noit:
  file.managed:
    - name: /etc/monit/conf.d/noitd
    - source: salt://sae-dnsxd/noit/files/monit/noitd
