# vim: sts=2 ts=2 sw=2 et ai

{% from "pepper/map.jinja" import defaults with context %}
{% from "sae-edge-ipv6-dns/map.jinja" import conf with context %}

include:
  - dns-automation

sae|edge-ipv6-dns-rectifier|deps-pkgs:
  pkgrepo.managed:
    - name: deb http://repo.llnw.net/llnw/ubuntu/{{ conf.repo_env }}/python-modules {{ grains['oscodename'] }}/
    - file: /etc/apt/sources.list.d/llnw.python-modules-{{ grains['oscodename'] }}.list
  pkg.installed:
    - skip_verify: True
    - names:
      - python-ipaddress
    - require:
      - pkgrepo: sae|edge-ipv6-dns-rectifier|deps-pkgs

sae|edge-ipv6-dns-rectifier|executable:
  file.managed:
    - name: {{ conf.path }}/bin/edge-ipv6-dns-rectifier
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755
    - makedirs: True
    - source: salt://sae-edge-ipv6-dns/files/edge-ipv6-dns-rectifier
    - require:
      - pkg: dns-automation
      - pkg: python-ipaddress

sae|edge-ipv6-dns-rectifier|config:
  file.managed:
    - name: {{ conf.path }}/etc/edge-ipv6-dns-rectifier.yml
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 644
    - makedirs: True
    - source: salt://sae-edge-ipv6-dns/templates/edge-ipv6-dns-rectifier.yml.jinja
    - template: jinja

sae|edge-ipv6-dns-rectifier|crontab|user:
  user.present:
    - name: {{ conf.run_as }}
    - system: true

sae|edge-ipv6-dns-rectifier|crontab|logfile:
  file.managed:
    - name: {{ conf.logfile }}
    - user: {{ conf.run_as }}
    - group: {{ defaults['root_group'] }}
    - mode: 644
    - require:
      - user: {{ conf.run_as }}

sae|edge-ipv6-dns-rectifier|crontab|logfile-rotate:
  file.managed:
    - name: /etc/logrotate.d/edge-ipv6-dns-rectifier
    - user: root
    - group: {{ defaults['root_group'] }}
    - contents: |
        {{ conf.logfile }} {
          rotate 5
          weekly
        }

sae|edge-ipv6-dns-rectifier|crontab|user-conf:
  file.managed:
    - name: /home/{{ conf.run_as }}/.dnsng.yml
    - user: {{ conf.run_as }}
    - group: {{ defaults['root_group'] }}
    - mode: 600
    - makedirs: True
    - contents: |
        ---
        username: {{ conf.api_username|json }}
        password: {{ conf.api_password|json }}
    - require:
      - user: {{ conf.run_as }}

sae|edge-ipv6-dns-rectifier|crontab:
{% if 'role-sae-edge-ipv6-dns.active' in salt['grains.get']('cornerstone:tags', {}) %}
  cron.present:
    - order: last
    - minute: 0
    - hour: '*/2'
{% else %}
  cron.absent:
{% endif %}
    - user: {{ conf.run_as }}
    - identifier: edge-ipv6-dns-rectifier-run
    - name: |
        flock /var/lock/cron_edge-ipv6-dns-rectifier -c "{{ conf.path }}/bin/edge-ipv6-dns-rectifier >>{{ conf.logfile }} 2>&1"

