# vim: sts=2 ts=2 sw=2 et ai
{%- from "sae-edgeinfo/map.jinja" import ei_api_pkg_install, ei_api_defaults with context %}

# EQ repo - for precise to get the py27-psutil library
{% if grains['oscodename'] == 'precise' %}
sae|edgeinfo|repo:
  pkgrepo.managed:
    - name: deb http://repo.llnw.net/llnw/ubuntu/production/edgequery/ precise/
    - file: /etc/apt/sources.list.d/llnw.edgeinfo-precise.list
    - refresh_db: true
    - watch_in:
      - module: core|base_repos|apt-refresh-db
    - require_in:
      - sae|edgeinfo|psutil

sae|edgeinfo|psutil:
  pkg.installed:
    - name: py27-psutil
    - require_in:
      - sae|edgeinfo|validate|prerequisites
      - sae|edgeinfo|validate|api|script
      - sae|edgeinfo|validate|api|cfg
      - sae|edgeinfo|validate|api|run
      - sae|edgeinfo|validate|edgeinfo|script
    
{% endif %}


# This is our ROLLUP state, it's used to write the validation file /etc/salt/validate/sae-edgeinfo.prerequisites
sae|edgeinfo|validate|prerequisites:
  llnw_validate.rollup: 
    - name: prerequisites
    - system_name: sae-edgeinfo

sae|edgeinfo|validate|prerequisites|fail:
  file.managed: 
    - name: /etc/salt/validate/sae-edgeinfo.prerequisites
    - contents: fail
    - contents_newline: False
    - onfail: 
      - sae|edgeinfo|validate|prerequisites

{% if ei_api_pkg_install['api'] is defined %}
{%   for pkg in ei_api_pkg_install['api'] %}
sae|edgeinfo|validate|package|{{ pkg }}:  # test that the packages needed for the api is loaded
  llnw_validate.pkg_installed:
    - package: {{ pkg }}
    - system_name: sae-edgeinfo
    - write_validate: False
    - require_in:
      - llnw_validate: sae|edgeinfo|validate|prerequisites
    - require:
      - sae|edgeinfo|api|api_pkgs
{%   endfor %}
{% endif %}

sae|edgeinfo|validate|api|script:
  llnw_validate.is_executable: 
    - filename: {{ei_api_defaults.cgi_dir}}/edgeinfo_api.pl
    - system_name: sae-edgeinfo
    - write_validate: False
    - require_in:
      - llnw_validate: sae|edgeinfo|validate|prerequisites
    - require:
      - sae|edgeinfo|api|edgeinfo_api_pl

sae|edgeinfo|validate|api|cfg:
  llnw_validate.is_file:
    - filename: {{ei_api_defaults.cgi_dir}}/eiapi_sql.cfg
    - system_name: sae-edgeinfo
    - write_validate: False
    - require_in:
      - llnw_validate: sae|edgeinfo|validate|prerequisites
    - require:
      - sae|edgeinfo|api|db_cfg

sae|edgeinfo|validate|api|run:
  llnw_validate.http_path_is: 
    - url: http://127.0.0.1/cgi-bin/edgeinfo_api.pl/
    - code: 200
    - timeout: 30
    - system_name: sae-edgeinfo
    - write_validate: False
    - require_in:
      - llnw_validate: sae|edgeinfo|validate|prerequisites
    - require:
      - sae|edgeinfo|validate|api|cfg
      - sae|edgeinfo|validate|api|script

sae|edgeinfo|validate|edgeinfo|script:
  llnw_validate.is_executable:
    - filename: {{ei_api_defaults.cgi_dir}}/edgeinfo.pl
    - system_name: sae-edgeinfo
    - write_validate: False
    - require_in:
      - llnw_validate: sae|edgeinfo|validate|prerequisites
    - require:
      - sae|edgeinfo|edgeinfo-pl
