# Firmware Flashing Tool Chain

## Overview
This salt state is for the management/reporting/alerting of firmware. The two main components are the monitoring/reporting and flashing.

**The current focus is EPOS and CDS hosts. This will be changing with OSPrey, ansible, and tikerbell.**

#### Device Types

- **HBA** | Host Bus Adapter - Anything that connects IO to the system. This would but like SAS controllers and backplanes (Excludes motherboard).
- **DISK** | Physical disks in the system.
- **NIC** | Network Interface cards - Any add on card that adds network connectivity (Excludes motherboard).
- **BIOS** | Motherboard bios and can include onboard items (excludes BMC).
- **BMC** | Baseboard Management Controller - Remote management and monitoring interface.

#### Device MAP (devicemap.yaml)
The file devicemap.yaml utilized the following format. 
```
---
HBA:
  "{device model}":
    model: "{device model}"
    description: {Human device name}
    comments:
    - "Multiple comments",
    - "Code can loop over these and concatenate",
    - "or treat each as its own item."
    firmware:
      target: {firmware target for flashing}
      supported:
      - "{Firmware that needs no action}",
      - "{Firmware that needs no action}"
      legacy:
      - "{Firmware that should be updated}",
      - "{We also alert if running fw matches}"
      remote: "{HTTP(s) location to download firmware single file or tar archive}"
      local: "{local file | directory for the firmware}",
      checksum: "{md5 checksum | url to md5file }"
    monitored: {true|false}
  SAS3008: ...
  SAS3224: ...
DISK: ...
NIC: ...
BMC: ...
BIOS: ...
```

Example:
```
---
HBA:
  SAS3216:
    model: SAS3216
    description: Avago Technologies (LSI) SAS3216
    comments:
    - Monitoring disabled until bulk of the updates are done.
    - Unclear if 14.00.00.00 should be updated so its out of scope.
    - If on the 16.00.05.00 firmware we have known impact that appears to randomly
      crash hosts.
    firmware:
      target: 16.00.11
      supported:
      - 16.00.11
      - 14.00.00.00
      legacy:
      - 16.00.05.00
      remote: http://llnwsysops.vo.llnwd.net/v1/firmware/HBA/SAS3216/16.00.11.00/aoc-3216l-16.00.11.00.tar
      local: "/usr/local/firmware/HBA/SAS3216/16.00.11.00"
      checksum: http://llnwsysops.vo.llnwd.net/v1/firmware/HBA/SAS3216/16.00.11.00/aoc-3216l-16.00.11.00.tar.md5
    monitored: false
  SAS2008: {}
  SAS-3 3008: {}
  SAS3008: {}
  SAS3224: {}
DISK:
  MTFDDAK1T9TCB:
    model: MTFDDAK1T9TCB
    description: Micron 5100 PRO 2.5" 1.9TB SATA 6Gbs 3D NAND
    comments:
    - Monitoring disabled until bulk of the updates are done.
    - Old firmware <071 has a knonw bug where the drive hangs
    firmware:
      target: U071
      supported:
      - U071
      - D0MU071
      legacy:
      - D0MU037
      - D0MU045
      remote: http://images.llnw.net/firmware/micron5100/5100_D0MU071.bin
      local: /usr/local/firmware/DISK/5100/D0MU071/5100_D0MU071.bin
      checksum: http://llnwsysops.vo.llnwd.net/v1/firmware/DISK/5100/D0MU071/5100_D0MU071.bin.md5
    monitored: false

NIC: {}
BMC: {}
BIOS: {}
```

## Monitoring
check_firmware.py
=================
Compares hardware firmware against a targeted version in devicemap.json
and returns a status code.
```
usage: check_firmware.py [-h] [-f FILE] [-v]

########################################################
##################### Status Codes #####################
########################################################
#0 - device is firmware good
#1 - device firmware is incorrect and monitoring is supressed
#2 - device firmware is incorrect and monitoring is NOT supressed
#3 - device not found in JSON file
#4 - script failed to run

optional arguments:
  -h, --help            show this help message and exit
  -f FILE, --file FILE  Provide a JSON file
  -v, --verbose         Show target FW version
```

*See __salt-sae/sae-edge-tools/firmware/monitor__ for code*

## Flashing
In the event that a firmware matches a legacy version. We should attempt to flash that firmware on system boot to the correct version. 

*See __salt-sae/sae-edge-tools/firmware/flash__ for code*

#### Storage
We use the System Operations agile account() for the storage of tooling, docs and files used for flashing. 

These files are downloaded from the non secure cdn url (http://llnwsysops.vo.llnwd.net/v1/).

Inside `/content/firmware/` we use the following structure to lay out the various files. 
```
/content/firmware/
├── {DEVICE TYPE}/
│   ├── {DEVICE MODEL}/
|      ├── {VERSION}/
          ├── {file.tar.md5 | file.bin.md5 }
|         └── {file.tar | file.bin}
│      └── ...
│   └── ...
└── ...
```

Example:
```
/content/firmware/
├── HBA/
│   └──  SAS3216/
|      └── 16.00.11.00/
|          ├── aoc-3216l-16.00.11.00.tar
|          └── aoc-3216l-16.00.11.00.tar.md5

```

Tar file URL: http://llnwsysops.vo.llnwd.net/v1/firmware/HBA/SAS3216/16.00.11.00/aoc-3216l-16.00.11.00.tar

Hash file URL : http://llnwsysops.vo.llnwd.net/v1/firmware/HBA/SAS3216/16.00.11.00/aoc-3216l-16.00.11.00.tar.md5


## Q/A
###### Q: Don't we already have this in [salt-states/firmware](https://github.llnw.net/llnw/salt-states/tree/master/firmware)?
Yes, we have some scripts that already try to flash firmware. Those salt states are all mixed together and do many other things than they say they do. So this state is to break that habit.

###### Q: Shouldn't this be built into a larger system that manages firmware?
Yes, firmware management is something we need to do at a larger scale but is outside the scope of these tools. 
