#!/usr/bin/env python
import subprocess
import re
import json
import time
import socket
import httplib
import urllib
from base64 import b64encode

INFLUX_SERVER = 'opscap-ingest.llnw.net'
INFLUX_PORT = '50002'
INFLUX_DATABASE = 'taskData'
INFLUX_USER = 'ingest'
INFLUX_PASSWD = 'senddata'
DB_PRECISION = 's'
DB_RET = 'nintydays'

netstat_pattern = r'''tcp:
@(?P<tcp_packetsSent>\d+) packets sent
@@(?P<tcp_sent_dataPackets>\d+) data packets \((?P<tcp_sent_dataBytes>\d+) bytes\)
@@(?P<tcp_sent_packetsRexp>\d+) data packets \((?P<tcp_sent_packetsRexB>\d+) bytes\) retransmitted
@@(?P<tcp_sent_packetsRexpUnnecessary>\d+) data packets unnecessarily retransmitted
@@(?P<tcp_sent_packetsResendMTU>\d+) resends initiated by MTU discovery
@@(?P<tcp_sent_packetsAckOnly>\d+) ack-only packets \((?P<tcp_sent_packetsAckOnlyDelayed>\d+) delayed\)
@@(?P<tcp_sent_packetsURGOnly>\d+) URG only packets
@@(?P<tcp_sent_packetsWindowProbe>\d+) window probe packets
@@(?P<tcp_sent_packetsWindowUpdate>\d+) window update packets
@@(?P<tcp_sent_packetsControl>\d+) control packets
@@(?P<tcp_sent_packetsTailLossProbes>\d+) tail loss probes \((?P<tcp_sent_packetsTailLossBytes>\d+) bytes\)
@(?P<tcp_packetsRecived>\d+) packets received
@@(?P<tcp_recived_acks>\d+) acks \(for \d+ bytes\)
@@(?P<tcp_recived_acksDuplicate>\d+) duplicate acks
@@(?P<tcp_recived_acksForUnsentData>\d+) acks for unsent data
@@(?P<tcp_recived_packetsInSequence>\d+) packets \((?P<tcp_recived_bytesInSequence>\d+) bytes\) received in-sequence
@@(?P<tcp_recived_packetsDuplicateAll>\d+) completely duplicate packets \((?P<tcp_recived_packetsDuplicateAllBytes>\d+) bytes\)
@@(?P<tcp_recived_packetsDuplicateOld>\d+) old duplicate packets
@@(?P<tcp_recived_packetsDuplicateSome>\d+) packets with some dup. data \((?P<tcp_recived_packetsDuplicateSomeBytes>\d+) bytes duped\)
@@(?P<tcp_recived_packetsOutOfOrder>\d+) out-of-order packets \((?P<tcp_recived_packetsOutOfOrderBytes>\d+) bytes\)
@@(?P<tcp_recived_packetsAfterWindow>\d+) packets \((?P<tcp_recived_packetsAfterWindowBytes>\d+) bytes\) of data after window
@@(?P<tcp_recived_windowProbes>\d+) window probes
@@(?P<tcp_recived_packetsWindowUpdates>\d+) window update packets
@@(?P<tcp_recived_packetsRevicedAfterClose>\d+) packets received after close
@@(?P<tcp_recived_packetsDiscardedBadChecksum>\d+) discarded for bad checksums
@@(?P<tcp_recived_packetsDiscardedBadHeaderOffset>\d+) discarded for bad header offset fields
@@(?P<tcp_recived_packetsDiscardedTooShort>\d+) discarded because packet too short
@@(?P<tcp_recived_packetsDiscardedMemoryProblem>\d+) discarded due to memory problems
@(?P<tcp_connectionRequests>\d+) connection requests
@(?P<tcp_connectionAccepts>\d+) connection accepts
@(?P<tcp_connectionBadAttempts>\d+) bad connection attempts
@(?P<tcp_ListenQueueEverflow>\d+) listen queue overflows
@(?P<tcp_RSTIgnoredInWindow>\d+) ignored RSTs in the windows
@(?P<tcp_connectionsEstablished>\d+) connections established \(including.+accepts\)
@@(?P<tcp_connectionsTimesUsedRTTHostcache>\d+) times used RTT from hostcache
@@(?P<tcp_connectionsTimesUsedRTTVarianceHostcache>\d+) times used RTT variance from hostcache
@@(?P<tcp_connectionsTimesUsedSlowStartHostcache>\d+) times used slow-start threshold from hostcache
@(?P<tcp_connectionsClosed>\d+) connections closed \(including \d+ drops\)
@@\d+ connections updated cached RTT on close
@@\d+ connections updated cached RTT variance on close
@@\d+ connections updated cached ssthresh on close
@\d+ embryonic connections dropped
@\d+ segments updated rtt \(of \d+ attempts\)
@\d+ retransmit timeouts
@@\d+ connections dropped by rexmit timeout
@\d+ persist timeouts
@@\d+ connections dropped by persist timeout
@\d+ Connections \(fin_wait_2\) dropped because of timeout
@\d+ keepalive timeouts
@@\d+ keepalive probes sent
@@\d+ connections dropped by keepalive
@\d+ correct ACK header predictions
@\d+ correct data packet header predictions
@\d+ syncache entries added
@@\d+ retransmitted
@@\d+ dupsyn
@@\d+ dropped
@@\d+ completed
@@\d+ bucket overflow
@@\d+ cache overflow
@@\d+ reset
@@\d+ stale
@@\d+ aborted
@@\d+ badack
@@\d+ unreach
@@\d+ zone failures
@\d+ cookies sent
@\d+ cookies received
@\d+ hostcache entries added
@@\d+ bucket overflow
@\d+ SACK recovery episodes
@\d+ segment rexmits in SACK recovery episodes
@\d+ byte rexmits in SACK recovery episodes
@\d+ SACK options \(SACK blocks\) received
@\d+ SACK options \(SACK blocks\) sent
@\d+ SACK scoreboard overflow
@\d+ packets with ECN CE bit set
@\d+ packets with ECN ECT\(0\) bit set
@\d+ packets with ECN ECT\(1\) bit set
@\d+ successful ECN handshakes
@\d+ times ECN reduced the congestion window
@\d+ packets with matching signature received
@\d+ packets with bad signature received
@\d+ times failed to make signature due to no SA
@\d+ times unexpected signature received
@\d+ times no signature provided by segment
TCP connection count by state:
@(?P<tcp_connectionsStateCLOSED>\d+) connections?\s? in CLOSED state
@(?P<tcp_connectionsStateLISTEN>\d+) connections?\s? in LISTEN state
@(?P<tcp_connectionsStateSYNSENT>\d+) connections?\s? in SYN_SENT state
@(?P<tcp_connectionsStateSYNRCVD>\d+) connections?\s? in SYN_RCVD state
@(?P<tcp_connectionsStateESTABLISHED>\d+) connections?\s? in ESTABLISHED state
@(?P<tcp_connectionsStateCLOSEWAIT>\d+) connections?\s? in CLOSE_WAIT state
@(?P<tcp_connectionsStateFINWAIT>\d+) connections?\s? in FIN_WAIT_1 state
@(?P<tcp_connectionsStateCLOSING>\d+) connections?\s? in CLOSING state
@(?P<tcp_connectionsStateLASTACK>\d+) connections?\s? in LAST_ACK state
@(?P<tcp_connectionsStateFINWAIT2>\d+) connections?\s? in FIN_WAIT_2 state
@(?P<tcp_connectionsStateTIMEWAIT>\d+) connections?\s? in TIME_WAIT state.*'''

def _run_cmd(cmd, shell=True, quit_on_failure=True):
    '''
    Runs a system command and can return the failure or exit the program. 
    Parameters
    ----------
    cmd : string
        shell command string to be ran
    shell : bool, optional
        If shell is True, the specified command will be executed through 
        the shell. (Default is True)
    quit_on_failure : bool, optional
        If we get a bad return code and we want to kill the current running
        python process.
    Returns
    ------- 
    string
        Output of the command that ran
    Raises
    ------
    CalledProcessError
        Exception raised when a process run by check_call() or check_output() returns a non-zero exit status.
    '''

    try:
        result = subprocess.check_output(
            cmd,
            shell=shell,
            stderr=subprocess.STDOUT
            )

        return result.rstrip()

    except subprocess.CalledProcessError as e:
        if quit_on_failure:
            # If we dont want to trust the data if the command fails and think
            # its better to exit than report in any data we will quit.
            print("Failed to run command: {}".format(e.cmd))
            print("CODE: {}".format(e.returncode))
            print("OUTPUT: {}".format(e.output))
            quit(1)
        else:
            # raise the error so that the upstream can process the failure.
            raise

def get_netstat_data():
    cmd = 'netstat -s -p tcp | tr "\t" "@"'
    netstat_output = _run_cmd(cmd)
    netstat_regex = re.compile(netstat_pattern)
    netstat_data = re.match(netstat_regex, netstat_output).groupdict()

    return netstat_data


def getBasicAuth(user, password):
    crypt = b64encode(b"{}:{}").format(user, password).decode("ascii")
    return 'Basic {}'.format(crypt)

def influxPush(influxData, hostname=INFLUX_SERVER, port=INFLUX_PORT, user=INFLUX_USER, password=INFLUX_PASSWD, database=INFLUX_DATABASE, precision=DB_PRECISION, rp=DB_RET):
    conn = httplib.HTTPSConnection('{}:{}'.format(
        hostname,
        port))
    params = urllib.urlencode({
        'db': database,
        'precision': precision,
        'rp': rp
    })
    conn.set_debuglevel(5)
    headers = {
        'Accept': 'text/plain',
        'Authorization': getBasicAuth(user, password)
    }

    conn.request("POST", "/write?{}".format(params), '\n'.join(influxData), headers)

    r1 = conn.getresponse()
    print r1.status, r1.reason, r1.read()

def build_influxdata(netstat_dict):
    tags = {
        'fqdn': socket.gethostname()
    }

    tagValues = ','.join({"{}={}".format(k,v) for k, v in tags.items()})
    datValues = ','.join({"{}={}".format(k,v) for k, v in netstat_dict.items()})

    influx_lines = []

    influx_line = '{},{} {} {}'.format(
            "netstat",
            tagValues,
            datValues,
            int(time.time())
        )
    influx_lines.append(influx_line)
    
    return influx_lines


if __name__ == '__main__':
    # Collect "netstat -s" output
    netstat_dict = get_netstat_data()

    # Generate influxdb lines
    influx_lines = build_influxdata(netstat_dict)

    # Send in data
    influxPush(influx_lines)
