# Salt rules for the elastic infrastructure installs.

## Roles

### role-sae-elastic.master
Master nodes to handle orchestration. We should, realistically, ad 2 more of these to total 3.

### role-sae-elastic.frontend
Web UI and API hosts running nginx and kibana. These are balanced upstream by DNS-XD.

### role-sae-elastic.ingest
Ingest nodes

### role-sae-elastic.hot
elastic initial storage nodes.

### role-sae-elastic.warm
elastic mid-range storage nodes.

### role-sae-elastic.cold
Cold storage for older data. Data is moved here by curator.

### role-sae-elastic.jdbc
JDBC host(s) are individual one-offs for ingesting data from external DBs.

### role-sae-elastic.standalone
Standalone server used for testing.  Generally run in a local Vagrant environment,
but may also be run in an internal testing environments (e.g., staging, qa, etc.).

## Environments
Different Elastic Search configurations may be associated with different
"Elastic environments".  These are set by assigning the corresponding tag to
a host.

Currently supported environments:
- elastic-env-main : main (production) environment
- elastic-env-dev : dev (devnet) environment
- elastic-env-standalone : testing (Vagrant or VM) environment

### Running in Vagrant

The following tags must be set in Cornerstone/csmock.yml, in order to run
Elastic Search on a Xenial host in a Vagrant environment:

- elastic-env-standalone
- role-sae-elastic.standalone

## Operational Info

To be fleshed out further with runbook links etc.
TBD: structuring ingests to reflect salt roles

### Data flow

Events are collected on the edge by a variety of processes, primarily elastic beats. These events go into the ingest nodes, which splits the events out and parses them. They are then sent to the hot nodes for indexing. Hot nodes finish processing the data and hold it for searching. Then, after a 

### Useful Commands

Many commands on elasticsearch are, sadly, just API calls. Here are a few useful ones:

#### Get cluster status
```curl -XGET 'localhost:9200/_cluster/health?pretty'```

#### Get cluster state
```curl -XGET 'localhost:9200/_cluster/state?pretty'```

#### Node info
```curl -XGET 'localhost:9200/_nodes?pretty'```

#### See pending cluster tasks
```curl -XGET 'localhost:9200/_cluster/pending_tasks?pretty'```

Many other commands are available in the [official documentation](https://www.elastic.co/guide/en/elasticsearch/reference/current/index.html).

## Administrative Info

### Adding hosts

Hosts that are "in production" status and properly tagged for their role in the cluster in CS will automatically be brought into the cluster. 

### Hot/Warm Routing Policy

Making a new index template is accomplished via the API. The following command sets an index template for all indexes, requiring that they be indexed on a hot node. 

```
curl -XPUT 'localhost:9200/_template/template_main?pretty' -H 'Content-Type: application/json' -d'
{
  "template" : "*",
  "version" : 50001,
  "settings" : {
           "index.routing.allocation.require.box_type": "hot"
  }
}
'
```
After that is accomplished, one can rotate indices from the hot nodes to the warm ones using curator. This will be automated soon.
