# vim: sts=2 ts=2 sw=2 et ai

{% from "pepper/map.jinja" import netblocks %}
{%- from "sae-elastic/envs.jinja" import elastic_envs with context %}

include:
  - java.default-openjdk8
  - firewall.standard

sae|elastic|elastic|firewall:
  firewall.accept:
    - tcp:
{% for node in elastic_envs['nodes_elastic'] %}
      - ['9200', {{ node }}] # elasticsearch
      - ['9300:9400', {{ node }}] # elasticsearch, for clustering
{% endfor %}
    - require_in:
      - firewall: core|firewall|final-reject

sae|elastic|elastic|elastic-pkg:
  pkg.installed:
    - name: elasticsearch
{% if elastic_envs['elastic_ver']|default(False) %}
    - version: {{ elastic_envs['elastic_ver'] }}
{% endif %}
    - require:
      - pkg: core|java|pkg-openjdk8
      - pkgrepo: sae|elastic|elastic-repo

sae|elastic|elastic|elasticsearch-default:
  file.managed:
    - name: /etc/default/elasticsearch
    - user: root
    - group: root
    - mode: 644
    - source: salt://sae-elastic/templates/elasticsearch.jinja
    - template: jinja
    - defaults:
        java_ver: {{ elastic_envs.java_ver }}
    - require:
      - pkg: sae|elastic|elastic|elastic-pkg

sae|elastic|elastic|curator-pkg:
  pkg.installed:
    - name: elasticsearch-curator
{% if elastic_envs['curator_ver']|default(False) %}
    - version: {{ elastic_envs['curator_ver'] }}
{% endif %}
    - require:
      - pkg: sae|elastic|elastic|elastic-pkg
      - pkgrepo: sae|elastic|elastic-repo

sae|elastic|elastic|elastic-dir:
  file.directory:
    - name: /data/elastic
    - user: elasticsearch
    - group: elasticsearch
    - makedirs: true
    - recurse:
      - user
      - group
    - require:
      - pkg: sae|elastic|elastic|elastic-pkg

sae|elastic|elastic|elasticsearch-yml:
  file.managed:
    - name: /etc/elasticsearch/elasticsearch.yml
    - user: root
    - group: root
    - mode: 644
    - source: salt://sae-elastic/templates/elasticsearch.yml.jinja
    - template: jinja
    - elastic_envs: {{elastic_envs}}
    - backup: True
    - require:
      - pkg: sae|elastic|elastic|elastic-pkg

sae|elastic|elastic|elasticsearch-jvm-options:
  file.managed:
    - name: /etc/elasticsearch/jvm.options
    - user: root
    - group: root
    - mode: 644
    - source: salt://sae-elastic/templates/elastic-jvm.options.jinja
    - template: jinja
    - elastic_envs: {{elastic_envs}}
    - backup: True
    - require:
      - pkg: sae|elastic|elastic|elastic-pkg

sae|elastic|elastic|elastic-service:
  service.running:
    - name: elasticsearch
    - enable: True
#    - full_restart: True
#    - watch:
#      - pkg: sae|elastic|elastic|elastic-pkg
#      - file: sae|elastic|elastic|elasticsearch-yml
#      - sae|elastic|elastic|elasticsearch-jvm-options
