# vim: sts=2 ts=2 sw=2 et ai

{% from "pepper/map.jinja" import netblocks %}
{%- from "sae-elastic/envs.jinja" import elastic_envs with context %}

include:
  - .init
  - firewall.standard
  - firewall.web
  - certs
  - .elastic
  - .kibana

sae|elastic|frontend|nginx-pkg:
  pkg.latest:
    - names:
      - nginx-extras

sae|elastic|frontend|nginx-conf:
  file.managed:
    - name: /etc/nginx/nginx.conf
    - user: root
    - group: root
    - mode: 644
    - source: salt://sae-elastic/templates/nginx.conf.jinja
    - template: jinja
    - elastic_envs: {{elastic_envs}}
    - backup: True
    - require:
      - pkg: sae|elastic|frontend|nginx-pkg

sae|elastic|frontend|pam-nginx:
  file.managed:
    - name: /etc/pam.d/nginx
    - user: root
    - group: root
    - mode: 644
    - contents:
      - auth    required     /lib/x86_64-linux-gnu/security/pam_ldap.so
      - account required     /lib/x86_64-linux-gnu/security/pam_ldap.so

sae|elastic|frontend|firewall:
  firewall.accept:
    - tcp:
      - [9200, '69.164.61.157/32'] # tsdbng-read-1 (grafana)
      - [9200, '69.164.61.158/32'] # tsdbng-read-2 (grafana)
      - [8080, {{ netblocks }}] # for cerebro
      - [5601, {{ netblocks }}] # for metricbeats
    - require_in:
      - firewall: core|firewall|final-reject

sae|elastic|frontend|nginx-service:
  service.running:
    - name: nginx
    - enable: True
    - full_restart: True
    - watch:
      - pkg: sae|elastic|frontend|nginx-pkg
      - file: sae|elastic|frontend|nginx-conf

{# the standalone (testing) instance allows local unix users (vagrant) #}
{# to log into kibana; ED (LDAP) logins can be used if PAM is configured #}
{# to use ldap and local accounts (usually the case) #}
{% if "standalone" in elastic_envs['env'] %}
sae|elastic|frontend|nginx-enable-unix-user-auth-via-pam:
  group.present:
    - name: shadow
    - addusers:
      - www-data
    - watch_in:
      - service: sae|elastic|frontend|nginx-service

{% endif %}

{% if grains['team_env'] != 'production'|default('production') %}
sae|elastic|frontend|cerebro-pkg:
  pkg.installed:
    - name: cerebro
    - version: {{ elastic_envs.cerebro_config.version }}
    - require:
      - pkgrepo: sae|elastic|elastic-repo

sae|elastic|frontend|cerebro-cfg:
  file.managed:
    - name: /usr/share/cerebro/conf/application.conf
    - source: salt://sae-elastic/templates/application.conf.jinja
    - template: jinja
    - defaults:
        cluster_name: {{ elastic_envs.cerebro_config.cluster_name }}
        secret: {{ elastic_envs.cerebro_config.secret }}
        data_path: {{ elastic_envs.cerebro_config.data_path }}
        bind_user: {{ elastic_envs.cerebro_config.bind_user }}
        bind_pass: {{ elastic_envs.cerebro_config.bind_pass }}
    - require:
      - pkg: sae|elastic|frontend|cerebro-pkg
      - file: sae|elastic|frontend|cerebro-data-dir

sae|elastic|frontend|cerebro-data-dir:
  file.directory:
    - name: {{ elastic_envs.cerebro_config.data_path }}
    - user: cerebro
    - group: cerebro
    - require:
      - pkg: sae|elastic|frontend|cerebro-pkg

sae|elastic|frontend|cerebro-service:
  service.running:
    - name: cerebro
    - require:
      - pkg: sae|elastic|frontend|cerebro-pkg
      - file: sae|elastic|frontend|cerebro-data-dir
{% endif %}
