# vim: sts=2 ts=2 sw=2 et ai

{% from "pepper/map.jinja" import netblocks %}
{%- from "sae-elastic/envs.jinja" import elastic_envs with context %}

include:
  - java.default-openjdk8

sae|elastic|logstash|logstash-pkg:
  pkg.installed:
    - name: logstash
{% if elastic_envs['logstash_ver']|default(False) %}
    - version: {{ elastic_envs['logstash_ver'] }}
{% endif %}
    - require:
      - pkg: core|java|pkg-openjdk8
      - pkgrepo: sae|elastic|elastic-repo

sae|elastic|logstash|logstash-dir:
  file.directory:
    - name: /data/logstash
    - user: logstash
    - group: adm
    - recurse:
      - user
      - group
    - require:
      - pkg: sae|elastic|logstash|logstash-pkg

sae|elastic|logstash|logstash-conf-d-dir:
  file.recurse:
    - name: /etc/logstash/conf.d/
    - user: logstash
    - group: adm
    - recurse:
      - user
      - group
    - clean: true
    - source: salt://sae-elastic/files/logstash-core/
    - require:
      - pkg: sae|elastic|logstash|logstash-pkg

sae|elastic|logstash|logstash-patterns-dir:
  file.recurse:
    - name: /etc/logstash/patterns/
    - user: logstash
    - group: adm
    - recurse:
      - user
      - group
    - clean: true
    - source: salt://sae-elastic/files/logstash-patterns/
    - require:
      - pkg: sae|elastic|logstash|logstash-pkg

sae|elastic|logstash|logstash-yml:
  file.managed:
    - name: /etc/logstash/logstash.yml
    - user: root
    - group: root
    - mode: 644
    - source: salt://sae-elastic/templates/logstash.yml.jinja
    - template: jinja
    - elastic_envs: {{elastic_envs}}
    - backup: True
    - require:
      - pkg: sae|elastic|logstash|logstash-pkg

sae|elastic|logstash|logstash-jvm-options:
  file.managed:
    - name: /etc/logstash/jvm.options
    - user: root
    - group: root
    - mode: 644
    - source: salt://sae-elastic/templates/logstash-jvm.options.jinja
    - template: jinja
    - elastic_envs: {{elastic_envs}}
    - defaults:
        heap_override: {{ elastic_envs['logstash_heap_override']|default("") }}
    - backup: True
    - require:
      - pkg: sae|elastic|elastic|elastic-pkg

sae|elastic|logstash|logstash-service:
  service.running:
    - name: logstash
    - enable: True
# For now at least, we do not want salt auto-restarting logstash when we make changes
#    - full_restart: False
#    - watch:
#      - pkg: sae|elastic|logstash|logstash-pkg
#      - file: sae|elastic|logstash|logstash-yml
#      - file: sae|elastic|logstash|logstash-jvm-options
