# This is optimized for use on the vagrant salt-master

{% from "pepper/map.jinja" import rfc1918blocks %}
{% from "sae-elastic/envs.jinja" import elastic_envs with context %}

{% set repo_env = 'testing' %}
{% set oscodename = salt['grains.get']('oscodename', '') %}

{% do salt['grains.set']("cornerstone:tags:elastic-env-standalone", {'name': 'elastic-env-standalone', 'meta_source': 'standalone.sls'}) %}

include:
  - base_repos
  - java.default-openjdk8
  - certs
  - firewall.standard
  - sae-sudoers.elk-admin

sae|elastic|vagrant|firewall:
  firewall.accept:
    - tcp:
      - [5601, {{ rfc1918blocks }}] # kibana
      - [9200, {{ rfc1918blocks }}] # elasticsearch
    - require_in:
      - firewall: core|firewall|final-reject

sae|elastic|vagrant|elastic-repo:
  pkgrepo.managed:
    - name: deb http://repo.llnw.net/llnw/ubuntu/{{ repo_env }}/elastic/ {{ oscodename }}/
    - file: /etc/apt/sources.list.d/llnw.elastic.{{ oscodename }}.list
    - refresh_db: true

sae|elastic|vagrant|pkgs:
  pkg.installed:
    - pkgs:
      - iftop
      - iotop
      - nmap
      - tcpflow
      - nginx-extras
      - elasticsearch: {{ elastic_envs['elastic_ver'] }}
      - elasticsearch-curator: {{ elastic_envs['curator_ver'] }}
      - kibana

sae|elastic|vagrant|data-dir:
  file.directory:
    - name: /data
    - user: root
    - group: root

sae|elastic|vagrant|elastic-dir:
  file.directory:
    - name: /data/elastic
    - user: elasticsearch
    - group: elasticsearch
    - makedirs: true
    - recurse:
      - user
      - group
    - require:
      - pkg: sae|elastic|vagrant|pkgs
      - file: sae|elastic|vagrant|data-dir

sae|elastic|vagrant|elasticsearch-yml:
  file.managed:
    - name: /etc/elasticsearch/elasticsearch.yml
    - user: root
    - group: root
    - mode: 644
    - source: salt://sae-elastic/templates/elasticsearch.yml.jinja
    - template: jinja
    - elastic_envs: {{ elastic_envs }}
    - backup: True
    - require:
      - pkg: sae|elastic|vagrant|pkgs

sae|elastic|vagrant|elasticsearch-jvm-options:
  file.managed:
    - name: /etc/elasticsearch/jvm.options
    - user: root
    - group: root
    - mode: 644
    - source: salt://sae-elastic/templates/elastic-jvm.options.jinja
    - template: jinja
    - elastic_envs: {{ elastic_envs }}
    - backup: True
    - require:
      - pkg: sae|elastic|vagrant|pkgs

sae|elastic|vagrant|nginx-conf:
  file.managed:
    - name: /etc/nginx/nginx.conf
    - user: root
    - group: root
    - mode: 644
    - source: salt://sae-elastic/templates/nginx.conf.jinja
    - template: jinja
    - elastic_envs: {{ elastic_envs }}
    - backup: True
    - require:
      - pkg: sae|elastic|vagrant|pkgs

sae|elastic|vagrant|pam-nginx:
  file.managed:
    - name: /etc/pam.d/nginx
    - user: root
    - group: root
    - mode: 644
    - contents:
      - auth    required     /lib/x86_64-linux-gnu/security/pam_ldap.so
      - account required     /lib/x86_64-linux-gnu/security/pam_ldap.so

sae|elastic|vagrant|nginx-enable-unix-user-auth-via-pam:
  group.present:
    - name: shadow
    - addusers:
      - www-data

sae|elastic|vagrant|kibana-yml:
  file.managed:
    - name: /etc/kibana/kibana.yml
    - user: root
    - group: root
    - mode: 644
    - source: salt://sae-elastic/templates/kibana.yml.jinja
    - template: jinja
    - elastic_envs: {{ elastic_envs }}
    - backup: True
    - require:
      - pkg: sae|elastic|vagrant|pkgs

sae|elastic|vagrant|elastic-service:
  service.running:
    - name: elasticsearch
    - enable: True
    - full_restart: True
    - watch:
      - pkg: sae|elastic|vagrant|pkgs
      - file: sae|elastic|vagrant|elasticsearch-yml
      - file: sae|elastic|vagrant|elasticsearch-jvm-options

sae|elastic|vagrant|nginx-service:
  service.running:
    - name: nginx
    - enable: True
    - full_restart: True
    - watch:
      - pkg: sae|elastic|vagrant|pkgs
      - file: sae|elastic|vagrant|nginx-conf
      - group: sae|elastic|vagrant|nginx-enable-unix-user-auth-via-pam

sae|elastic|vagrant|kibana-service:
  service.running:
    - name: kibana
    - enable: True
    - full_restart: True
    - require:
      - service: sae|elastic|vagrant|nginx-service
      - service: sae|elastic|vagrant|elastic-service
    - watch:
      - pkg: sae|elastic|vagrant|pkgs
      - file: sae|elastic|vagrant|kibana-yml
