# vim: sts=2 ts=2 sw=2 et ai

{% from "pepper/map.jinja" import defaults with context %}
{% set secret_key_filename = "/usr/local/etc/cert-mgmt/secret-key.asc" %}
{% set key_id = salt['pillar.get']('secrets:cert-mgmt:key-id') %}

include:
  - sae-xfer

sae|ep-ssl|cert-mgmt|pkgs:
  pkg.installed:
    - name: gnupg

# GPG becomes confused in some envs when the homedir opt is not explicity passed
# If older instances have created a db in an improper location, clean it up
sae|ep-ssl|cert-mgmt|gnupg-slash-dir-remove:
  file.absent:
    - name: /.gnupg

sae|ep-ssl|cert-mgmt|gnupg-slash-proc-kill:
  cmd.run:
    - name: pkill -f 'gpg-agent --homedir //.gnupg'
    - onlyif: pgrep -f 'gpg-agent --homedir //.gnupg'
    - onchanges:
      - file: sae|ep-ssl|cert-mgmt|gnupg-slash-dir-remove

# The xfer user needs to be able to traverse this directory to get to pems.
sae|ep-ssl|cert-mgmt|etc-dir:
  file.directory:
    - name: /usr/local/etc/cert-mgmt
    - mode: 755
    - user: root
    - group: {{ defaults.root_group }}

# GridConfig or Hermes cds_sync running as xfer will place encrypted certs
# here. If they run as root, though, that will still work.
sae|ep-ssl|cert-mgmt|pem-dir:
  file.directory:
    - name: /usr/local/etc/cert-mgmt/pems
    - mode: 700
    - user: xfer
    - group: xfer
    - require:
      - sae|ep-ssl|cert-mgmt|etc-dir
      - sae|xfer|user

sae|ep-ssl|cert-mgmt|secret-key-file:
  file.managed:
    - name: {{ secret_key_filename }}
    - mode: 400
    - user: root
    - group: {{ defaults.root_group }}
    - contents_pillar: secrets:cert-mgmt:secret-key
    - require:
      - sae|ep-ssl|cert-mgmt|etc-dir

sae|ep-ssl|cert-mgmt|secret-key-import:
  cmd.run:
    - name: gpg --homedir /root/.gnupg --import {{ secret_key_filename }}
    - unless: gpg --homedir /root/.gnupg --list-secret-keys | grep -q {{ key_id }}
    - require:
      - sae|ep-ssl|cert-mgmt|pkgs
      - sae|ep-ssl|cert-mgmt|secret-key-file
