#!/usr/bin/perl -w

use strict;
use POSIX;
use IO::Socket;
use JSON;
use LWP::UserAgent;
use Digest::MD5 qw(md5_hex);

$ENV{'PERL_LWP_SSL_VERIFY_HOSTNAME'} = 0;

my $cache = '/logs/squid/cache1.log';
my $log = '/logs/auto_precache.'.time.'.log';

die "/logs doesn't exist" unless -d '/logs';
die "$cache doesn't exist" unless -e $cache;

&daemonize;

my @uname=uname();
my $hostname = $uname[1];

my $line;

my $cache1 = {};
my $cache2 = {};
my $cache_cycle = 0;
my $last_time;

# open LOG and set it to flush on print
open(LOG, '>>', $log) || die "Can't open $log";
my $ofh = select LOG;
$| = 1;
select $ofh;

while (1) {
	# added /var/log/debug.log to make sure that the while loop never just hangs.  yes it is an ugly hack
	print LOG time, " reopen /logs/squid/*access*.log /var/log/debug.log\n";
	unless (open(CACHE, "tail -0F /logs/squid/*access*.log /var/log/debug.log|")) {
		print LOG time, " error opening access*.log: $!\n";
	}
	$last_time = time;
	while ($line = <CACHE>) {
		my @words = split /\s+/, $line;
		if (scalar @words >= 27) {
			my $response_code = $words[3];
			my $origin_url = $words[6];
			my $acct_id = $words[11];
			my $miss_bytes = $words[26];
			if ($acct_id eq "397" && $origin_url =~ /\.lldns\.net/ && $miss_bytes > 0 && $response_code =~ /206/) {
				$words[18] =~ /(.*?)\?/;
				my $urlstem = $1;
				my $mv = md5_hex("eij4jD4DIIPvgsj0edmnca" . $urlstem);
				my $url = sprintf("%s?h=%s",$urlstem, $mv);
				if (!&check_cache($url)) {
					&precache($url);
					last;
				}
			}
		}
		last if ((time - $last_time) > 300); # basically, redo the tail if it's been 5 minutes with no TCP_MISS statements
	}
	close CACHE;
	sleep .25;  # if cache1.log doesn't exist, try to be nice
}

close(LOG);

sub check_cache {
	my $url = shift;
	if ($cache1->{$url} || $cache2->{$url}) {
		print LOG time, " skip $url\n";
		return 1;
	}
	$cache_cycle++;
	$cache1->{$url} = "true";
	if ($cache_cycle > 100) {
		$cache2 = $cache1;
		$cache1 = {};
		$cache_cycle = 0;
	}
	return 0;
}

sub precache {
	my $url = shift;

	my %pre;
	$pre{'username'} = "bhawn";
	$pre{'token'} = "testing";
	$pre{'sites'} = ["United States"];
	my @urls = "$url";
	$pre{'urls'} = \@urls;
	$pre{'ticket'} = "123456";
	$pre{'shortname'} = "amazon";
	$pre{'duration'} = 3600;
	$pre{'interval'} = 1800;
#	$pre{'compress'} = JSON::XS::false;
	my $jreq = JSON->new->allow_nonref->encode({%pre});

	my $conn = LWP::UserAgent->new();
	$conn->timeout(10);
	my $req = HTTP::Request->new(POST => "https://ops-tools.phx2.llnw.net:5443/precache/request");
	$req->content_type("application/json");
	$req->content($jreq);
	my $res = $conn->request($req);
	if (! $res->is_success) {
		print LOG time, " Failed to insert precache request for $url: " . $res->status_line . "\n";
	} else {
		print LOG time, " precache request for $url inserted\n";
	}
}

sub daemonize {
	chdir '/'		or die "Can't chdir to /: $!";
	open STDIN, '/dev/null' or die "Can't read /dev/null: $!";
	open STDOUT, '>/dev/null' or die "Can't write to /dev/null: $!";
	defined(my $pid = fork)	or die "Can't fork: $!";
	exit if $pid;
	die "Can't start a new session: $!" if POSIX::setsid == -1;
	open STDERR, '>&STDOUT'	or die "Can't dup stdout: $!";
}

sub purge {
	my $url = shift;

	my $fh = IO::Socket::INET->new(PeerAddr => "127.0.0.1:80", Timeout => 1.5);
	if (! $fh) {
		print LOG time, " unable to connect to 127.0.0.1:80\n";
		return;
	}
	my $req = "PURGE $url HTTP/1.0\r\n";
	$req .= "X-Evict: 1\r\n";
	$req .= "\r\n";
	print $fh $req;
	my $line;
	$line = <$fh>;
	if (($line =~ /^HTTP\S+ (\S+)/) && $1 == 200) {
		print LOG time, " purged $url\n";
	} else {
		print LOG time, " purge_failed $url\n";
	}
	while ($line = <$fh>) {};
	close $fh;
}
