#!/usr/bin/perl

use strict;
use warnings;
use Sys::Hostname;

my $osreldate = `sysctl -n kern.osreldate`;
my $mem_phy = &fbsd_mem_phy;
my $mem_net = &fbsd_mem_net;
my $mem_net_portion = $mem_net / $mem_phy;
my $interactive = -t STDIN;
if ($interactive) {
  printf "mem_phy=%s mem_net=%s mem_net_portion=%s\n",
    $mem_phy, $mem_net, $mem_net_portion;
}

if ($mem_net_portion > 0.1) {
  &adjust_reduced;
} else {
  &adjust_normal;
}

fix_em_limit();

sub adjust_normal {
  &sysctl('kern.ipc.nmbclusters', int($mem_phy / 4 / 2048));
  &sysctl('kern.ipc.nmbjumbop', int($mem_phy / 4 / 4096));
  &sysctl('net.inet.tcp.recvbuf_auto', 1);
  #Start with machines with 60gigs or more of ram
  if ( $mem_phy >= 60000000000 ) {
    &sysctl('net.inet.tcp.recvbuf_max', 512*1024);
  } else {
    &sysctl('net.inet.tcp.recvbuf_max', 256*1024);
  }
  &sysctl('net.inet.tcp.recvspace', 200000);
  &sysctl('net.inet.tcp.sendbuf_auto', 1);
  &sysctl('net.inet.tcp.sendbuf_max', 256*1024);
  &sysctl('net.inet.tcp.sendspace', 200000);
}
sub adjust_reduced {
  my $hostname = hostname();
  &sysctl('net.inet.tcp.recvbuf_max', 32*1024);
  &sysctl('net.inet.tcp.recvspace', 32*1024);
  &sysctl('net.inet.tcp.sendbuf_max', 32*1024);
  my $cmd = 'echo "I just cut back my sendbuf_max and recvbuf_max because of low available free memory" | mail -s "High Memory Usage $hostname" bradh@llnw.com,jwillbanks@llnw.com,jason@llnw.com';
  system($cmd);
}

sub fix_em_limit {
  open(my $IFCONFIG,"ifconfig -l |") || die "Failed: $!\n";
  while (my $row = <$IFCONFIG>) {
    if ($row =~ /em[01]/) {
      &sysctl('dev.em.0.rx_processing_limit',-1);
      &sysctl('dev.em.1.rx_processing_limit',-1);
    }
  }
  close($IFCONFIG) || fatal("Failed to close: $IFCONFIG $!\n");
}

sub fbsd_mem_phy {
  my $cmd = 'sysctl -n hw.realmem';
  my $mem;
  open(SC, "$cmd|") or die "can't open $cmd: $!";
  while (<SC>) {
    s/\s+//g;
    $mem = $_;
  }
  close SC;
  return $mem;
}

sub fbsd_mem_net {
  my($item, $size, $limit, $used, $free, $requests);
  my($rest, $thismem, $allmem);
  my $cmd = 'vmstat -z';
  open(VMSTAT, "$cmd|") or die "can't run $cmd: $!";
  while (<VMSTAT>) {
    next if (! /^mbuf/);
    next if (! /:/);
    tr/,//d;
    ($item, $rest) = split(/:/);
    ($size, $limit, $used, $free, $requests) = split(" ", $rest);
    $thismem = $size * $used;
    $allmem += $thismem;
  }
  close VMSTAT;
  return $allmem;
}

sub sysctl {
  my($key, $val) = @_;
  my $cmd = "sysctl $key=$val";
  if (! $interactive) {
    $cmd .= ' > /dev/null 2>&1';
  }
  system($cmd);
}
