#!/usr/bin/perl -w

use Getopt::Long;
use Pod::Usage;

use strict;

my $help = 0;
my $man = 0;
my $miss = 0;
my $requests = 0;
my @keyvalues;
my $xvideos = 0;
my $id_summary = 0;
my $ip_summary = 0;
my $host_summary = 0;
my $base_url_summary = 0;
my $limit = 10;

GetOptions('help|h|?' => \$help,
	'man' => \$man,
	'miss|m' => \$miss,
	'requests|r' => \$requests,
	'limit|l=i' => \$limit,
	'keyvalue|k=s' => \@keyvalues,
	'xvideos|x' => \$xvideos,
	'acct|a' => \$id_summary,
	'ip|i', => \$ip_summary,
	'host|o', => \$host_summary,
	'url|u', => \$base_url_summary) or pod2usage(2);
pod2usage(1) if $help;
pod2usage(-exitstatus => 0, -verbose => 2) if $man;

if (!$id_summary && !$ip_summary && !$host_summary && !$base_url_summary) {
	$id_summary = 1;
	$host_summary = 1;
	$base_url_summary = 1;
}
if ($xvideos) {
	push @keyvalues, 'porn.:.x.xvideos.com:xvideos-___.vo.llnwd.net';
}

my $line;
my @line;
my %id_bytes;
my %ip_bytes;
my %host_bytes;
my %base_url_bytes;
my $total_bytes = 0;

for( my $i = 0; $i < scalar(@keyvalues); $i++) {
	my $digits = 0;
	$digits++ while $keyvalues[$i] =~ /_/g;
	$keyvalues[$i] =~ s/_+/%0${digits}d/;
}

while($line = <>) {
	@line = split /\s+/, $line;

	next if $#line < 27;
	my $bytes = 0;

	if ($requests) {
		my $is_miss = $line[26] > ($line[4]/2);
		$bytes = 1 if ($is_miss && $miss) || (!$is_miss && !$miss);
	} else {
		if ($miss) {
			$bytes = $line[26];
		} else {
			$bytes = $line[4];
		}
	}
	my $url = $line[18];
	my $host = 'none';
	if ($url =~ /^https?:\/\/(.*?)\//) {
		$host = $1;
	}

	for my $kv (@keyvalues) {
		my ($prefix, $suffix, $cname) = split /:/, $kv;
		if ($host =~ /^\Q$prefix\E(.*)\Q$suffix\E$/) {
			my $keyvalue = $1;
			my @terms = split /\./, $keyvalue;
			my $media_index = index($terms[0], 'm') + 1;
			if ($media_index <= $#terms) {
				my $lcp = $terms[$media_index] % 1000;
				$host = sprintf $cname, $lcp;
			}
		}
	}

	if ($id_summary) {
		my $acct_id = $line[11];
		$id_bytes{$acct_id} += $bytes;
	}
	if ($ip_summary) {
		my $client = $line[2];
		$ip_bytes{$client} += $bytes;
	}
	if ($host_summary) {
		$host_bytes{$host} += $bytes;
	}
	if ($base_url_summary) {
		my $base_url = $url;
		$base_url =~ s/\?.*//;
		$base_url_bytes{$base_url} += $bytes;
	}

	$total_bytes += $bytes;
}

&show_summary("percent distribution by acct_id", \%id_bytes, $total_bytes, $limit) if $id_summary;
&show_summary("percent distribution by source ip", \%ip_bytes, $total_bytes, $limit) if $ip_summary;
&show_summary("percent distribution by host", \%host_bytes, $total_bytes, $limit) if $host_summary;
&show_summary("percent distribution by base URL", \%base_url_bytes, $total_bytes, $limit) if $base_url_summary;


sub show_summary {
	my $title = shift;
	my $hash = shift;
	my $total_bytes = shift;
	my $limit = shift;

	print "$title\n\n";
	my @sorted = sort { $hash->{$b} <=> $hash->{$a} } keys %$hash;
	if (scalar(@sorted) > $limit) {
		@sorted = @sorted[0..($limit-1)];
	}

	for my $key (@sorted) {
		printf "%s: %.2f\n", $key, 100*$hash->{$key}/$total_bytes;
	}
	print "\n";
}

__END__

=head1 NAME

who_is_it_simple.pl - Summarize edge logs

=head1 SYNOPSIS

who_is_it_simple.pl [options]

 Options:
   -help|?|h		brief help message
   -man			full documentation
   -miss|m		use cache miss bytes instead of delivered bytes
   -requests|r		use requests instead of bytes
   -limit|l n		limit summaries to n entries; default 10
   -keyvalue|k d	map keyvalues according to definition
   -xvideos|x		use hard coded xvideos keyvalue translation
   -acct|a		summarize by account id
   -host|o		summarize by published host
   -ip|i		summarize by ip address
   -url|u		summarize by url

=head1 OPTIONS

=over 8

=item B<-help|?|h>

Print a brief help message and exit.

=item B<-man>

Print the manual page and exit.

=item B<-miss|m>

Count cache miss bytes instead of delivered bytes.

=item B<-requests|r>

Use request count to find top talkers instead of bytes.

=item B<-limit|l n>

Each summary selected will be limited to only the top n entries.  The default value is 10.

=item B<-keyvalue|k d>

Translate A4 / keyvalue hostnames according to the definition.  There are 3 colon separated values,
the prefix, suffix, and cname target.  See xvideos for an example.  The prefix can be nothing.

=item B<-xvideos|x>

Translate A4 / keyvalue hostnames specifically for xvideos.

equivalent to:

-k porn.:.x.xvideos.com:xvideos-___.vo.llnwd.net

=item B<-acct|a>

Summarize log entries by account id.

=item B<-host|o>

Summarize log entries by published host.

=item B<-ip|i>

Summarize log entries by client IP address.

=item B<-url|u>

Summarize log entries by published url

=back

=head1 DESCRIPTION

B<who_is_it_simple.pl> will read edgeprism log entries from STDIN and
summarize the data according to the options provided.  Typically this is
used with cataccess:

cataccess | who_is_it_simple.pl

If no summarizations are selected, then account, host, and url summaries will be selected.

=cut
