#!/bin/bash

# Ensure that we are a cds or ics server by name
if ! uname -n | grep -qE '^cds|^ics'; then 
	echo "$(uname -n) is not a cds or ics server, exiting"
	exit 1
fi


# create drive and mount variables
while read words; do
	set -- $words
	drives="$drives $1"
	mounts="$mounts $2"
done < <(cat /etc/fstab | sed 's/#.*//' | awk '$2 ~ /^\/d[0-9]+$/ {sub(/s1e|p1/, "", $1); print $1,$2}')

for mnt in $mounts; do
	if [ -d "$mnt/lama" ]; then
		echo server is running agile, will not wipe drives
		exit 1
	fi
done

# stop edgeprism
/etc/sq/rc.squid stop

sleep 2

pkill squid

sleep 2

pkill squid

echo -n waiting for shutdown...
while [ "x`ps -auxww|egrep '/squid |\(squid\) '|grep -v grep`" != "x" ]; do
	echo -n .
	sleep 1
done
echo " done"

# unmount mounts
for mnt in $mounts; do 
	umount $mnt
done

# intentionally break the data partitions
for d in $drives; do 
	dd if=/dev/zero of=$d bs=512k count=10
done

# reconstruct the data partitions
yes | /etc/sq/cdsdisk.pl

# verify fstab matches current partitions
drives=""
while read words; do
        set -- $words
        drives="$drives $1"
done < <(cat /etc/fstab | sed 's/#.*//' | awk '$2 ~ /^\/d[0-9]+$/ {sub("^/dev/", "", $1); print $1}')

while read words; do
        set -- $words
        partitions="$partitions $1"
done < <(ls -1 /dev | egrep '^(ad|da|ada)(0s1f|[1-9][0-9]?(s1e|p1))$')

for p in $partitions; do 
	exists="0"

	for d in $drives; do 
		if [ $d == $p ]; then 
			exists="1"
		fi
	done

	if [ "$exists" == "0" ]; then 
		d=$(echo $p | sed "s/p1/s1e/")
		sed -i '' "s/$d/$p /" /etc/fstab
	fi 
done

# remount the mounts
for mnt in $mounts; do 
	mount $mnt
done

# start edgeprism
/etc/sq/rc.squid start
