# vim: sts=2 ts=2 sw=2 et ai

{% from "pepper/map.jinja" import defaults with context %}

include:
  - salt.minion
  - zabbix.squelch-sh

# logic from this script was moved to rc.squid
sae|ep|ep_traffic_ctrl-script:
  file.absent:
    - name: /usr/local/bin/ep_traffic_ctrl

sae|ep|age_sq-script:
  file.managed:
    - name: /usr/local/bin/age_sq.pl
    - source: salt://sae-ep/files/age_sq.pl
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755

sae|ep|rclocal:
  file.append:
    - name: /etc/rc.local
    - text:
      - /usr/local/bin/age_sq.pl
      - rm /usr/local/squid/logs/*.pid
      - (sleep 30; /etc/sq/rc.squid)&
    - require:
      - file: sae|ep|age_sq-script

sae|ep|logfeed-script:
  file.managed:
    - name: /usr/local/bin/logfeed.pl
    - source: salt://sae-ep/files/logfeed.pl
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755

{% if grains['singel'] is not defined %}
sae|ep|logfeed-restart:
  cmd.run:
    - name: "/bin/pkill -f logfeed.pl; sleep 2; /usr/local/bin/logfeed.pl"
    - onchanges:
      - file: sae|ep|logfeed-script
{% endif %}

sae|ep|amazon_precache-script:
  file.managed:
    - name: /usr/local/bin/amazon_precache.pl
    - source: salt://sae-ep/files/amazon_precache.pl
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755

# This bonding script is FreeBSD specific
{% if grains['os_family'] == 'FreeBSD' %}
sae|ep|bond-ethernet-vlan-check:
  file.managed:
    - name: /usr/local/bin/ethbondcheck
    - source: http://images.llnw.net/bins/ethbondcheck-fbsd
    - source_hash: http://images.llnw.net/bins/ethbondcheck-fbsd.md5
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755

sae|ep|bond-ethernet-no-neg-script:
  file.managed:
    - name: /usr/local/bin/bond-ethernet-no-neg.sh
    - source: salt://sae-ep/files/bond-ethernet-no-neg.sh
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755
    - require:
      - file: sae|ep|bond-ethernet-vlan-check

sae|ep|bond-ethernet-no-neg-rclocal:
  file.prepend:
    - name: /etc/rc.local
    - text: "/usr/local/bin/bond-ethernet-no-neg.sh"
    - require:
      - file: sae|ep|bond-ethernet-no-neg-script
{% endif %}

sae|ep|manage_amazon-script:
  file.managed:
    - name: /usr/local/bin/manage_amazon.sh
    - source: salt://sae-ep/files/manage_amazon.sh
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755

sae|ep|cataccess-script:
  file.managed:
    - name: /usr/local/bin/cataccess
    - source: salt://sae-ep/files/cataccess
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755

sae|ep|delete_old_logs-script:
  file.managed:
    - name: /usr/local/bin/delete_old_logs.pl
    - source: salt://sae-ep/files/delete_old_logs.pl
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755

sae|ep|dfIndex-script:
  file.managed:
    - name: /usr/local/bin/dfIndex.pl
    - source: salt://sae-ep/files/dfIndex.pl
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755

sae|ep|ep_upgrade-script:
  file.managed:
    - name: /usr/local/bin/ep_upgrade.sh
    - source: salt://sae-ep/files/ep_upgrade.sh
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755

sae|ep|popCheck-script:
  file.managed:
    - name: /usr/local/bin/popCheck.pl
    - source: salt://sae-ep/files/popCheck.pl
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755

{% if grains['osmajorrelease']|int < 12 or '2017.1' in grains.get('llbsdbranch', '') %}
sae|ep|netadjust-script:
  file.managed:
    - name: /usr/local/bin/netadjust.pl
    - source: salt://sae-ep/files/netadjust.pl
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755
{% endif %}

sae|ep|httpSQ-script:
  file.managed:
    - name: /usr/local/bin/httpSQ.pl
    - source: salt://sae-ep/files/httpSQ.pl
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755

sae|ep|who_is_it_simple-script:
  file.managed:
    - name: /usr/local/bin/who_is_it_simple.pl
    - source: salt://sae-ep/files/who_is_it_simple.pl
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755

sae|ep|ttfb_by_acct-script:
  file.managed:
    - name: /usr/local/bin/ttfb_by_acct.py
    - source: salt://sae-ep/files/ttfb_by_acct.py
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755

# removed in favor of genzbxdiscovery.pl
sae|ep|make_sqprocs-script|last-rites:
  file.absent:
    - name: /usr/local/bin/make_sqprocs.sh

sae|ep|wipe_ep_data-script:
  file.managed:
    - name: /usr/local/bin/wipe_ep_data.sh
    - source: salt://sae-ep/files/wipe_ep_data.sh
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 744

sae|ep|ipv6_mtu-script:
  file.managed:
    - name: /usr/local/bin/ipv6_mtu.sh
    - source: salt://sae-ep/files/ipv6_mtu.sh
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755
