{% from 'sae-eqagent/map.jinja' import defaults, eqagent_default, oscodename, osmajorrelease with context %}

include:
  - post-edgeinfo

{# covers 2 cases:1.real rollout with version change, rollout with initial covered;2.just repeate the same state run #}
{# THE ROLLOUT. set of rollout/rollback vars #}
{% if rollout_version is defined %}
{# save the current(rollouted) version for rollback if rollout unsuccessfull #}
{%   set eqagent_ver = rollout_version %}
{%   set eqagent_ver_rollback = salt['grains.get']('apps:eqagent:rollouted') %}
{# IF WE ROLLOUTS/ROLLBACKS TAKING REMOVE LIST FROM ROLLOUTED GRAIN #}
{%   if rollout_version == salt['grains.get']('apps:eqagent:rollouted') %}
{%      set eqagent_ver_rollback = salt['grains.get']('apps:eqagent:rollback') %}
{# IF we run again the same rolloute state, kind of highstate #}
{%   elif not salt['grains.has_value']('apps:eqagent:rollouted') %}
{# IF we rollouts with out initial grains switch #}
{%      set eqagent_ver_rollback = eqagent_default['eqagent_ver']['rollback'] %}
{%   endif %}
{% else %}
{# highstate cases:1.we have grains, do not touch them just read; #}
{#   2.have grains but they are older(highstate rollout); #}
{#   3.we do not have grains, set them. #}
{# THE HIGHSTATE set of rollout/rollback vars (no changes) if we have grains, otherwise set them #}
{%   if salt['grains.has_value']('apps:eqagent:rollouted') %}
{%     set eqagent_ver = salt['grains.get']('apps:eqagent:rollouted') %}
{%     set eqagent_ver_rollback = salt['grains.get']('apps:eqagent:rollback') %}
{# this will intend for set minimal version through the highstate with defaults#}
{%     if eqagent_ver < eqagent_default['eqagent_ver']['rollouted'] %}
{%        set eqagent_ver_rollback = eqagent_ver %}
{%        set eqagent_ver = eqagent_default['eqagent_ver']['rollouted'] %}
{%     endif %}
{%   else %}
{### INITIAL PROVISION OF DEAULT VERSIONS    VVV ###}
{%     set eqagent_ver = eqagent_default['eqagent_ver']['rollouted'] %}
{%     set eqagent_ver_rollback = eqagent_default['eqagent_ver']['rollback'] %}
{%   endif %}
{% endif %}

sae|eqagent|set-grains-rollback:
  grains.present:
     - name: apps:eqagent:rollback
     - value: {{ eqagent_ver_rollback }}

sae|eqagent|set-grains-rollouted:
  grains.present:
     - name: apps:eqagent:rollouted
     - value: {{ eqagent_ver }}

{% set pkg_list = defaults[eqagent_ver] %}
{% set pkg_list_remove = defaults[eqagent_ver_rollback] %}

{% if grains['os'] == 'FreeBSD' %}

{# Removing old(rollback) packages #}
{%  if pkg_list_remove is defined %}
{%-    for pkg in pkg_list_remove if pkg not in pkg_list %}
sae|eqagent|{{ pkg }}-removed:
  cmd.run:
    - name: 'pkg delete -y {{ pkg }}'
    - onlyif: 'pkg info -e {{ pkg }}'
{%       if rollout_version is defined %}
    - require:
      - cmd: sae|eqagent|services-stop
{%       endif %}
{%    endfor %}
{%  endif %}

sae|eqagent|pcre-install:
  pkg.installed:
    - name: pcre

# For eqagent >= 3.3.0, we need to uninstall old py27-psutil221 and use the
# system-provided py27-psutil. For eqagent 3.2.0, we need to uninstall the
# system-provided py27-psutil and use py27-psutil221.
{%   if eqagent_ver in ['3.3.0', '3.5.0', '3.5.1'] %}
{%     set system_psutil = True %}
{%     set old_psutil = False %}
{%   elif eqagent_ver in ['3.2.0'] %}
{%     set old_psutil = True %}
{%     set system_psutil = False %}
{%   endif %}

{%   if system_psutil %}
{%     if osmajorrelease == '10' %}
{%       set psutil_version = '4.3.0' %}
{%     else %}
{%       set psutil_version = '5.2.2' %}
{%     endif %}
sae|eqagent|psutil-remove-221:
  pkg.removed:
    - pkgs:
        - py27-psutil221-2.2.1
        - py27-psutil-2.2.1
sae|eqagent|psutil-install-newest:
  pkg.installed:
    - name: py27-psutil
    - version: {{ psutil_version }}
    - require:
      - pkg: sae|eqagent|psutil-remove-221
{%   endif %}

{% if old_psutil %}
sae|eqagent|psutil-remove-default:
  pkg.removed:
    - name: py27-psutil
{%   endif %}

{# FreeBSD packages are installed using direct URL #}
{%-  for package, url in pkg_list.iteritems() %}
sae|eqagent|{{ package }}-installed:
  cmd.run:
    - name: 'pkg add -f {{ url }}'
    - unless: 'pkg info -e {{ package }}'
{%      if 'edgequery' not in package %}
    - require_in:
      - cmd: sae|eqagent|{% for pkg in pkg_list if 'edgequery' in pkg %}{{ pkg }}{% endfor %}-installed
{%      endif %}
    - require:
{%      set pkg_first = 'ipgeo' %}
{%      if pkg_first in pkg_list and not package.startswith(pkg_first) %}
      - cmd: sae|eqagent|{{ pkg_first }}-installed
{%      endif %}
{%      for pkg in pkg_list_remove if pkg not in pkg_list %}
      - cmd: sae|eqagent|{{ pkg }}-removed
{%      endfor %}
      - pkg: sae|eqagent|pcre-install
{%      if system_psutil %}
      - pkg: sae|eqagent|psutil-install-newest
{%      endif %}
{%      if old_psutil %}
      - pkg: sae|eqagent|psutil-remove-default
{%      endif %}
    - watch_in:
      - service: sae|eqagent|billing|restart
      - service: sae|eqagent|reporting|restart
{%      if 'edgequery' in package %}
      - grains: sae|eqagent|set-grains-rollback
      - grains: sae|eqagent|set-grains-rollouted
    - onchanges_in:
      - cmd: core|post-edgeinfo|run
{%      endif %}
{%-  endfor %}

{% elif salt['grains.get']('os', '') in ['Ubuntu','CentOS'] %}

{%   if salt['grains.get']('os', '') == 'Ubuntu' and oscodename != 'precise' %}
sae|eqagent|edgequery|repo-ubuntu:
  pkgrepo.managed:
    - name: deb http://repo.llnw.net/llnw/ubuntu/production/edgequery/ {{ oscodename }}/
    - file: /etc/apt/sources.list.d/llnw-edgequery-production-{{ oscodename }}.list
{%   endif %}

{# Linux packages installed from apt/yum repo #}
sae|eqagent|install:
  pkg.installed:
    - pkgs:
{%   for package, version in pkg_list.iteritems() %}
        - {{ package }}: {{ version }}
{%   endfor %}
    - skip_verify: True
    - force_yes: True
{%   if salt['grains.get']('os', '') == 'Ubuntu' and oscodename != 'precise' %}
    - require:
      - pkgrepo: sae|eqagent|edgequery|repo-ubuntu
{%   endif %}
    - watch_in:
      - service: sae|eqagent|billing|restart
      - service: sae|eqagent|reporting|restart
      - grains: sae|eqagent|set-grains-rollback
      - grains: sae|eqagent|set-grains-rollouted

{% endif %}
