{% from 'sae-eqagent/map.jinja' import defaults, oscodename with context %}

{% if grains['os'] == 'Ubuntu' %}
{%     if oscodename == 'xenial' %}

sae|eqagent|rldp|service:
  file.managed:
    - name: /etc/systemd/system/eqrldp.service
    - source: salt://sae-eqagent/eqagent.service
    - template: jinja
    - instance: Rldp
    - process_name: eqrldp
    - config_file: {{ defaults['path'] }}/{{ defaults['rldp_config'] }}
    - user: root
    - group: root
    - mode: 664

sae|eqagent|rldp|init-for-systemd:
  file.managed:
    - name: /usr/local/etc/init.d/eqrldp
    - source: salt://sae-eqagent/templates/eqrldp_init
    - user: root
    - group: root
    - mode: 777

sae|eqagent|rldp|reload-systemd:
  module.run:
    - name: service.systemctl_reload
    - onchanges:
      - file: sae|eqagent|rldp|service

sae|eqagent|rldp|restart:
  service.running:
    - enable: True
    - name: eqrldp.service
    - watch:
      - module: sae|eqagent|rldp|reload-systemd
      - file: sae|eqagent|rldp|config
{%     else %}

sae|eqagent|rldp|init:
  file.managed:
    - name: /etc/init.d/eqrldp
    - source: salt://sae-eqagent/templates/eqrldp_init
    - user: root
    - group: root
    - mode: 777
    - require_in:
      - service: sae|eqagent|rldp|restart

{%     endif %}
{% endif %}

{% if salt['grains.get']('os', '') == 'FreeBSD' %}

sae|eqagent|rldp|freebsd|init:
  file.managed:
    - name: /usr/local/etc/rc.d/eqrldp
    - source: salt://sae-eqagent/templates/eqrldp_init_freebsd
    - user: root
    - mode: 777
    - require_in:
      - service: sae|eqagent|rldp|restart

{% endif %}

{% if oscodename != 'xenial' %}

sae|eqagent|rldp|remove-old-checkpoint:
  file.absent:
    - name: /var/run/edgequery-rldp.checkpoint

sae|eqagent|rldp|remove-old-snap:
  file.absent:
    - name: /var/run/edgequery-rldp.snap

sae|eqagent|rldp|restart:
  service.running:
    - name: eqrldp
    - enable: True
    - watch:
      - file: sae|eqagent|rldp|config
    - require:
      - file: sae|eqagent|rldp|remove-old-checkpoint
      - file: sae|eqagent|rldp|remove-old-snap

{% endif %}
