{% from slspath ~ '/map.jinja' import defaults with context %}

{% set oscodename = salt['grains.get']('oscodename', '') %}

# Removal on Ubuntu Hosts
{% if salt['grains.get']('os', '') in ['Ubuntu'] %}
sae|eqagent|stop:
  service.dead:
    - names:
      - eqbilling
      - edgequeryd
      - eqrldp

sae|eqagent|uninit:
  file.absent:
    - names:
      - /etc/init.d/eqbilling
      - /etc/init.d/edgequeryd
      - /etc/init.d/eqrldp
      - /etc/systemd/system/edgequery.service
      - /etc/systemd/system/eqbilling.service
      - /etc/systemd/system/eqrldp.service
    - require:
      - service: sae|eqagent|stop

{% if salt['test.provider']('service') == 'systemd' %}
sae|eqagent|systemctl-reload:
  module.run:
    - name: service.systemctl_reload
    - require:
      - file: sae|eqagent|uninit
{% endif %}

sae|eqagent|unconfig:
  file.absent:
    - names:
      - {{defaults['path']}}/edgequery-billing.conf
      - {{defaults['path']}}/edgequery.conf
      - {{defaults['path']}}/edgequery-rldp.conf
    - require:
      - file: sae|eqagent|uninit

sae|eqagent|uninstall:
  pkg.purged:
    - pkgs:
      - eq-ipgeo-libs
      - py27-amqp-shrapnel
      - py27-coro
      - py27-edgequery-client
      - py27-psutil
      - py27-pyyaml
      - py27-qlang2
    - require:
      - file: sae|eqagent|unconfig

sae|eqagent|remove-repo:
  pkgrepo.absent:
    - name: llnw-edgequery-production-{{ oscodename }}.list
    - require:
      - pkg: sae|eqagent|uninstall

sae|eqagent|delete-varlog:
  file.absent:
    - names:
      - /var/log/edgequery.log
      - /var/log/edgequery-billing.log
      - /var/log/edgequery-rldp.log
      - /var/log/edgequery
      - /var/log/edgequery-billing
      - /var/log/edgequery-rldp
    - require:
      - service: sae|eqagent|stop

sae|eqagent|delete-varrun:
  file.absent:
    - names:
      - /var/run/edgequery-billing.checkpoint
      - /var/run/edgequery-billing.snap
      - /var/run/edgequery.checkpoint
      - /var/run/edgequery.snap
      - /var/run/edgequery-rldp.checkpoint
      - /var/run/edgequery-rldp.snap
    - require:
      - service: sae|eqagent|stop
{% endif %}

# Removal on FreeBSD Hosts
{% if salt['grains.get']('os', '') == 'FreeBSD' %}
sae|eqagent-freebsd|stop:
  service.dead:
    - names:
      - eqbilling
      - edgequeryd
      - eqrldp

sae|eqagent-freebsd|uninit:
  file.absent:
    - names:
      - /usr/local/etc/rc.d/eqbilling
      - /usr/local/etc/rc.d/edgequeryd
      - /usr/local/etc/rc.d/eqrldp
    - require:
      - service: sae|eqagent-freebsd|stop

sae|eqagent-freebsd|unconfig:
  file.absent:
    - names:
      - {{defaults['path']}}/edgequery-billing.conf
      - {{defaults['path']}}/edgequery.conf
      - {{defaults['path']}}/edgequery-rldp.conf
    - require:
      - file: sae|eqagent-freebsd|uninit

# Remove all EQ Agent related packages 
# All versions defined in map.jinja will be removed (if installed)
{% for eqagent_ver in defaults %}
{%   if  eqagent_ver.startswith('3') %}
{%     set pkg_list_remove = defaults[eqagent_ver] %}
# Removing Agent related packages
{%     if pkg_list_remove is defined %}
{%-      for pkg in pkg_list_remove %}
sae|eqagent-freebsd|agent-{{eqagent_ver}}-package-{{ pkg }}-removed:
  cmd.run:
    - name: 'pkg delete -y {{ pkg }}'
    - onlyif: 'pkg info -e {{ pkg }}'
{%       endfor %}
{%     endif %}
{%   endif %}
{% endfor %}


sae|eqagent|delete-varlog:
  file.absent:
    - names:
      - /var/log/edgequery.log
      - /var/log/edgequery-billing.log
      - /var/log/edgequery-rldp.log
      - /var/log/edgequery
      - /var/log/edgequery-billing
      - /var/log/edgequery-rldp
    - require:
      - service: sae|eqagent-freebsd|stop

sae|eqagent|delete-varrun:
  file.absent:
    - names:
      - /var/run/edgequery-billing.checkpoint
      - /var/run/edgequery-billing.snap
      - /var/run/edgequery.checkpoint
      - /var/run/edgequery.snap
      - /var/run/edgequery-rldp.checkpoint
      - /var/run/edgequery-rldp.snap
    - require:
      - service: sae|eqagent-freebsd|stop

{% endif %}

# Remove eqagnet grains
{% do salt['grains.set']('apps:eqagent', None, force=True, destructive=True) %}
