# vim: sts=2 ts=2 sw=2 et ai syntax=yaml

{% from "pepper/map.jinja" import netblocks %}
{% from "pepper/map.jinja" import defaults with context %}
{% from "sudoers/map.jinja" import sudo_map with context %}

{% set release = grains['oscodename'] %}

{% if 'sae-foresight.qa' in grains['roles'] or grains['virtual'] in ['VirtualBox'] %}
{% set env = 'testing' %}
{% else %}
{% set env = 'production' %}
{% endif %}

include:
  - firewall.standard
  - base_repos

sae|foresight|sudo:
  file.managed:
    - name: {{ sudo_map.includedir }}/foresight
    - user: root
    - group: {{ defaults.root_group }}
    - mode: 440
    - contents: |
        %posix-foresight-admin ALL=(ALL) ALL

sae|foresight|repo:
  pkgrepo.managed:
    - name: deb http://repo.llnw.net/llnw/ubuntu/{{ env }}/foresight/ {{ release }}/
    - file: /etc/apt/sources.list.d/llnw.foresight.{{ release }}.list
    - refresh_db: false
    - watch_in:
      - module: core|base_repos|apt-refresh-db

sae|foresight|pkg:
  pkg.latest:
    - names:
      - llnw-foresight
    - skip_verify: True
    - require:
      - pkgrepo: sae|foresight|repo

sae|foresight|conf:
  file.managed:
    - name: /etc/foresight/foresight.conf
    - template: jinja
    - source: salt://sae-foresight/templates/foresight.conf.jinja
    - require:
      - pkg: foresight_pkg
    - context:
        foresight:
          db_host: capcheck-dev-db.llnw.com
          db_user: cap_check_rw
          db_password: {{ salt["pillar.get"]("secrets:sae-foresight:db_password")|yaml_encode }}
          db_name: cap_check
          unix_api_user: capacity-agent
          accounts_api_user: capacity-agent
          accounts_api_password: {{ salt["pillar.get"]("secrets:sae-foresight:accounts_api_password")|yaml_encode }}
          logtool_ftp_host: "asnstats-int.logs.llnw.net"
          logtool_ftp_user: "asnstats-int"
          logtool_ftp_password: {{ salt["pillar.get"]("secrets:sae-foresight:logtool_ftp_password")|yaml_encode }}
          logtool_ftp_directory: "banana"
          edgequery_key: FCST
          edgequery_secret: {{ salt["pillar.get"]("secrets:sae-foresight:edgequery_secret")|yaml_encode }}
          splunk_user: foresight@llnw.com
          splunk_password: {{ salt["pillar.get"]("secrets:sae-foresight:splunk_password")|yaml_encode }}
          zabbix_user: zabbix-api-outbound-data-grab
          zabbix_password: {{ salt["pillar.get"]("secrets:sae-foresight:zabbix_password")|yaml_encode }}
          csapi_user: foresight
          csapi_password: {{ salt["pillar.get"]("secrets:sae-foresight:csapi_password")|yaml_encode }}
          planned_capacity_client_email: '446310511188-lle1is2k6hiaqvamuos61j2rfti63rl3@developer.gserviceaccount.com'
          planned_capacity_private_key: {{ salt["pillar.get"]("secrets:sae-foresight:planned_capacity_private_key")|yaml_encode }}
          planned_capacity_sheet_key: '1PiexjuDtc66b-_6_jazkktJVqirWh3MBrSIkkJamscU'
          geoip_db_host: geoip-dev-db.llnw.com
          geoip_db_user: foresight
          geoip_db_password: {{ salt["pillar.get"]("secrets:sae-foresight:geoip_db_password")|yaml_encode }}
          geoip_db_name: geo
          management_db_host: management-qa-db.llnw.com
          management_db_user: foresight
          management_db_password: {{ salt["pillar.get"]("secrets:sae-foresight:management_db_password")|yaml_encode }}
          management_db_name: management
