include:
  - openssh
  - sae-sudoers.github-admin
  - pepper.nobluekey
  - firewall.standard
  - zfs

{% set ghe_home = '/opt/ghe' %}

# Shamelessly stolen from bgallews original implementation on the bacula servers

sae|github-backup|repo:
  pkgrepo.managed:
    - name: deb http://repo.llnw.net/llnw/ubuntu/production/ghe/ {{ grains['oscodename'] }}/
    - file: /etc/apt/sources.list.d/ghe.list

# Going to set up the user manually, because we specifically want the home directory to be /data/ghe
sae|github-backup|user:
  user.present:
    - name: ghe
    - fullname: Github Enterprise Backups
    - empty_password: True
    - system: True
    - home: {{ ghe_home }}

# This is Debian-only AFAICT.  When it's time to update the package you'll
# need to upload it to repo.llnw.net in the "bacula" repository.

sae|github-backup|pkg:
  pkg.latest:
    - name: github-backup-utils
    - require:
      - pkgrepo: sae|github-backup|repo
      - user: sae|github-backup|user
      - file: sae|github-backup|ghe-backup-dirs

sae|github-backup|script:
  file.managed:
    - name: {{ ghe_home }}/llnw_backup_github.sh
    - user: ghe
    - group: ghe
    - mode: 700
    - source: salt://sae-github-backup/files/llnw_backup_github.sh
    - require:
      - user: sae|github-backup|user
      - file: sae|github-backup|confdir
    - backup: True

sae|github-backup|cron:
  cron.present:
    - name: /opt/ghe/llnw_backup_github.sh
    - minute: 5
    - hour: 00,08,16
    - user: ghe
    - identifier: sae|github-backup|cron
    - require:
      - pkg: sae|github-backup|pkg
      - file: sae|github-backup|script

sae|github-backup|log-cleanup-cron:
  cron.present:
    - name: /usr/bin/find /opt/ghe/logs/ -type f -mtime +7 -delete
    - minute: 1
    - hour: 0
    - user: ghe
    - identifier: sae|github-backup|log-cleanup-cron
    - require:
      - user: sae|github-backup|user

# Lockdown ssh
sae|github-backup|sshd-config:
  file.accumulated:
    - name: extra_sshd_config
    - filename: /etc/ssh/sshd_config
    - text: |
        # This portion is managed by salt in salt-sae/sae-github-backup/
        # Local ssh group is for temporary access and vagrant is for... well, vagrant
        AllowGroups posix-github-admin ssh vagrant
    - require_in:
      - file: core|openssh|sshd-config

sae|github-backup|ssh|dir:
  file.directory:
    - name: {{ ghe_home }}/.ssh
    - user: ghe
    - group: ghe
    - dir_mode: '0700'
    - require:
      - user: sae|github-backup|user

sae|github-backup|ghe-backup-dirs:
  file.directory:
    - names:
      - {{ ghe_home }}/data
      - {{ ghe_home }}/logs
    - user: ghe
    - group: ghe
    - dir_mode: '0700'
    - require:
      - user: sae|github-backup|user

sae|github-backup|priv-key:
  file.managed:
    - name: {{ ghe_home }}/.ssh/id_rsa
    - user: ghe
    - group: ghe
    - mode: 600
    - backup: False
    - contents_pillar: secrets:ghe:github_backup_key
    - require:
      - user: sae|github-backup|user

sae|github-backup|confdir:
  file.directory:
    - name: {{ ghe_home }}/.github-backup-utils
    - user: ghe
    - group: ghe
    - dir_mode: '0755'
    - require:
      - user: sae|github-backup|user

sae|github-backup|conf:
  file.managed:
    - name: {{ ghe_home }}/.github-backup-utils/backup.config
    - require:
      - user: sae|github-backup|user
      - file: sae|github-backup|confdir
    - contents: |
        GHE_HOSTNAME="github.llnw.net"
        GHE_DATA_DIR="{{ ghe_home }}/data"
        GHE_NUM_SNAPSHOTS=96
