# vim: sts=2 ts=2 sw=2 et ai
{% from "pepper/map.jinja" import defaults %}
{#
   For staging and production:
      - If the superbroker is being replaced but brokers stay the same:
          change CNAME gr-conf-sbr.llnw.net to point to the new superbroker.
      - If the clients should switch to a different superbroker AND brokers:
          set seedhostname to the new superbroker's name.
          This will activate ...|client|clearcache below.
#}
{% set seedhostname = salt['grains.filter_by']({
  'dynamic':    'sae-gridconfig-broker1',
  'lab':        'gr-conf-sbr160.lab.llnw.net',
  'qa':         'gr-conf.qa.llnw.net',
  'dev':        'gr-conf-dev.vm.phx2.llnw.net',
  'staging':    'gr-conf-sbr.llnw.net',
  'production': 'gr-conf-sbr.llnw.net'
}, grain='team_env', default='production') %}
{% set client_version = '1.96' %}

sae|gridconfig|v|client|seedhost:
  file.managed:
    - name: /usr/local/gridconfig/etc/gridconfigseedhost.conf
    - contents: {{ seedhostname }}
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 644
    - makedirs: True

sae|gridconfig|v|client|clearcache:
  file.absent:
    - name: /usr/local/gridconfig/cache/{{ salt['grains.get']('fqdn','NOFQDN') }}.json
    - onchanges:
      - file: sae|gridconfig|v|client|seedhost

sae|gridconfig|v|client|pkg:
{% if grains['os_family'] == 'FreeBSD' and grains['osmajorrelease']|int >= 11 %}
  cmd.run:
    - name: 'env ABI=freebsd:10:amd64 pkg add http://images.llnw.net/fbsd/amd64/gridconfigclient-1.96.txz'
    - unless: pkg info -e gridconfigclient
{% else %}
  pkg.installed:
    - sources:
      - gridconfigclient: http://images.llnw.net/fbsd/amd64/gridconfigclient-1.96.txz
{% endif %}
