# vim: sts=2 ts=2 sw=2 et ai
{% from "pepper/map.jinja" import defaults %}
{#
   For staging and production:
      - If the superbroker is being replaced but brokers stay the same:
          change CNAME gr-conf-sbr.llnw.net to point to the new superbroker.
      - If the clients should switch to a different superbroker AND brokers:
          set seedhostname to the new superbroker's name.
          This will activate ...|client|clearcache below.
#}
{% set seedhostname = salt['grains.filter_by']({
  'dynamic':    'sae-gridconfig-broker1',
  'lab':        'gr-conf-sbr160.lab.llnw.net',
  'qa':         'gr-conf.qa.llnw.net',
  'dev':        'gr-conf-dev.vm.phx2.llnw.net',
  'staging':    'gr-conf-sbr.llnw.net',
  'production': 'gr-conf-sbr.llnw.net'
}, grain='team_env', default='production') %}
{% set client_version = '2.0.5.110' %}
{% set linux_client_version = '2.0.5.112' %}

include:
  - sae-xfer

sae|gridconfig|v|client|wrapper-script:
  file.managed:
    - name: /usr/local/gridconfig/bin/GridConfigClientWrapper.sh
    - source: salt://{{ slspath }}/files/GridConfigClientWrapper.sh
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755
    - makedirs: True
    - require:
      - sae|xfer|user

sae|gridconfig|v|client|seedhost:
  file.managed:
    - name: /usr/local/gridconfig/etc/gridconfigseedhost.conf
    - contents: {{ seedhostname }}
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 644
    - makedirs: True
    - require:
      - sae|gridconfig|v|client|pkg

sae|gridconfig|v|client|clearcache:
  file.absent:
    - name: /usr/local/gridconfig/cache/{{ salt['grains.get']('fqdn','NOFQDN') }}.json
    - onchanges:
      - file: sae|gridconfig|v|client|seedhost


{% if grains['os_family'] == 'FreeBSD' %}
sae|gridconfig|v|client|deps:
  pkg.installed:
    - names:
      - p5-JSON
      - p5-LWP-Protocol-https

sae|gridconfig|v|client|pkg:
  cmd.run:
    - name: pkg delete -fy gridconfigclient; env ABI=freebsd:10:amd64 pkg add -f http://images.llnw.net/fbsd/amd64/gridconfig/FreeBSD:10:amd64/All/{{ client_version }}/gridconfigclient-{{ client_version }}.txz && sed -i "" '/GridConfigClient.pl/ d' /etc/crontab
    - unless: pkg info -e 'gridconfigclient={{ client_version }}'
    - require:
      - sae|gridconfig|v|client|deps
{% endif %}


{% if grains['os_family'] == 'Debian' %}
{% set pkgenv = salt['grains.filter_by']({
  'dynamic':    'testing',
  'lab':        'testing',
  'dev':        'testing',
  'qa':         'qa',
  'staging':    'qa',
  'production': 'production'
}, grain='team_env', default='production') %}

sae|gridconfig|v|client|source-list:
  pkgrepo.managed:
    - name: deb [ trusted=yes ] http://repo.llnw.net/llnw/ubuntu/{{ pkgenv }}/gridconfig {{ grains['oscodename'] }}/
    - file: /etc/apt/sources.list.d/llnw-gridconfig.list
    - clean_file: true

sae|gridconfig|v|client|pkg:
  pkg.installed:
    - pkgs:
      - gridclient: {{ linux_client_version }}
    - require:
      - sae|gridconfig|v|client|source-list
{% endif %}
