{% from slspath ~ "/map.jinja" import gr with context %}
{%- from "pepper/map.jinja" import netblocks %}
{% from "certs/map.jinja" import cert_path with context %}


include:
  - base_repos
  - apache2
  - apache2.acl
  - apache2.prefork
  - apache2.ssl
  - firewall.web
  - firewall.standard
  - certs
  - sae-sudoers.ops-noc
  - sae-sudoers.OpsEngGroup
  - sae-sudoers.sre-delivery
  - sae-sudoers.sre-dns
  - sae-sudoers.platform
  - sae-sudoers.gridconfig-admin

sae|gridconfig|v|server|logrotate:
  file.managed:
    - name: /etc/logrotate.d/gridconfig
    - mode: 644
    - user: root
    - group: root
    - contents: |
        /usr/local/gridconfig/log/gridconfig.log {
          rotate 4
          create 644 www-data www-data
          missingok
          compress
          size=4G
        }

# we'll manage the crons ourselves, thankyouverymuch
sae|gridconfig|v|server|no-pkg-cron:
  file.absent:
    - name: /etc/cron.d/gridconfig
    - require:
      - sae|gridconfig|v|server|pkgs

sae|gridconfig|v|server|cleanup-edgeprism:
  cron.present:
    - name: find /var/www/configs/EdgePrism/. -mmin +360 -exec rm {} \;
    - identifier: gridconfig-cleanup-edgeprism
    - user: root
    - minute: 10

sae|gridconfig|v|server|cleanup-accelerate:
  cron.absent:
    - identifier: gridconfig-cleanup-accelerate

sae|gridconfig|v|server|cleanup-hds:
  cron.present:
    - name: find /var/www/configs/Hds/. -mtime +7 -exec rm {} \;
    - identifier: gridconfig-cleanup-hds
    - user: root
    - minute: 15
    - hour: 0

sae|gridconfig|v|server|gridgitcache:
  file.directory:
    - name: /var/www/configs
    - user: www-data
    - group: www-data
    - require:
      - pkg: core|apache2|pkg

sae|gridconfig|v|server|gitcache:
  file.directory:
    - name: /var/cache/GridConfig
    - user: www-data
    - group: root
    - mode: 755
    - makedirs: True
    - require:
      - sae|gridconfig|v|server|pkgs

sae|gridconfig|v|server|cachedir:
  file.directory:
    - name: /usr/local/gridconfig/cache
    - user: www-data
    - group: root
    - mode: 755
    - makedirs: True
    - require:
      - sae|gridconfig|v|server|pkgs

sae|gridconfig|v|server|logdir:
  file.directory:
    - name: /usr/local/gridconfig/log
    - user: root
    - group: root
    - mode: 755
    - makedirs: True
    - require:
      - sae|gridconfig|v|server|pkgs

# circumvents security to avoid 404 on apt update
sae|gridconfig|v|server|source-list:
  pkgrepo.managed:
    - name: deb [ trusted=yes ] http://repo.llnw.net/llnw/ubuntu/{{ gr.pkgenv }}/gridconfig {{ grains['oscodename'] }}/
    - file: /etc/apt/sources.list.d/llnw-gridconfig.list
    - clean_file: true

sae|gridconfig|v|server|pkgs:
  pkg.installed:
    - pkgs:
      - python-simplejson
      - git-daemon-sysvinit
      - gridserver : {{ gr.server_version }}
      - gridconfig-tools : {{ gr.tools_version }}
    - require:
      - pkgrepo: sae|gridconfig|v|server|source-list
    - watch_in:
      - service: core|apache2|service

sae|gridconfig|v|server|sites-available:
  file.recurse:
    - name: /etc/apache2/sites-available
    - source: salt://{{slspath}}/files/sites-available
    - makedirs: True
    - template: jinja
    - context:
        certpath: {{ cert_path['certdir'] }}/{{ cert_path['certname'] }}.crt
        keypath: {{ cert_path['keydir'] }}/{{ cert_path['certname'] }}.key
    - require:
      - pkg: sae|gridconfig|v|server|pkgs
    - watch_in:
      - service: core|apache2|service

sae|gridconfig|v|server|sites-enabled|900:
  apache_site.enabled:
    - name: 900-gridconfigserver.conf
    - require:
      - file: sae|gridconfig|v|server|sites-available
      - file: core|certs|star|{{ cert_path['certname'] }}-key
      - file: core|certs|star|{{ cert_path['certname'] }}
    - require_in:
      - file: sae|gridconfig|v|server|docroot
    - watch_in:
      - service: core|apache2|service

sae|gridconfig|v|server|sites-enabled|901:
  apache_site.enabled:
    - name: 901-gridgit.conf
    - require:
      - file: sae|gridconfig|v|server|sites-available
    - require_in:
      - file: sae|gridconfig|v|server|docroot
    - watch_in:
      - service: core|apache2|service

sae|gridconfig|v|server|docroot:
  file.line:
    - name: /etc/apache2/apache2.conf
    - mode: ensure
    - content: DocumentRoot "/var/www"
    - before: <Directory />
    - require:
      - pkg: sae|gridconfig|v|server|pkgs
    - watch_in:
      - service: core|apache2|service
