{% from slspath ~ "/map.jinja" import gr, gitclients with context %}

include:
  - apache2
  - firewall.standard
  - .server

sae|gridconfig|v|superbroker|gridconfig-conf:
  file.managed:
    - name: /etc/llnw/gridconfig.yml
    - source: salt://{{slspath}}/files/gridconfig.yml
    - template: jinja
    - makedirs: True
    - require:
      - pkg: sae|gridconfig|v|server|pkgs
    - watch_in:
      - service: core|apache2|service
    - context:
        cfg: {{ gr.superbroker }}

sae|gridconfig|v|superbroker|gitremote:
  cmd.wait:
    - name: /usr/local/gridconfig/bin/gridtool setsuper "{{ gr.superbroker.host }}"
    - watch:
      - file: sae|gridconfig|v|superbroker|gridconfig-conf

sae|gridconfig|v|superbroker|gitdaemon-cfg:
  file.managed:
    - name: /etc/default/git-daemon
    - user: root
    - group: root
    - mode: 644
    - require:
      - pkg: sae|gridconfig|v|server|pkgs
    - contents: |
        GIT_DAEMON_ENABLE=true
        GIT_DAEMON_USER=gitdaemon
        GIT_DAEMON_BASE_PATH=/var/lib/git
        GIT_DAEMON_DIRECTORY=/var/lib/git
        GIT_DAEMON_OPTIONS="--export-all --enable=receive-pack"

# MOPs reference /home/git
sae|gridconfig|v|superbroker|gitdaemon-dir:
  file.symlink:
    - name: /home/git
    - target: /var/lib/git
    - force: False
    - user: gitdaemon
    - group: root
    - require:
      - pkg: sae|gridconfig|v|server|pkgs

sae|gridconfig|v|superbroker|gitdaemon-svc:
  service.running:
    - name: git-daemon
    - enable: True
    - require:
      - pkg: sae|gridconfig|v|server|pkgs
    - watch:
      - file: sae|gridconfig|v|superbroker|gitdaemon-cfg

sae|gridconfig|v|superbroker|gitdaemon-firewall:
  firewall.accept:
    - tcp:
      - [ 9418, {{ gitclients }} ]
    - require_in:
      - firewall: core|firewall|final-reject

{# clean up copilot service we don't use anymore #}

sae|gridconfig|v|superbroker|cleanup-copilot-log:
  cron.absent:
    - name: grconf [ -x /usr/local/gridconfig/bin/copilot_cli.pl ] && /usr/local/gridconfig/bin/copilot_cli.pl generatemessages >/usr/local/gridconfig/log/copilot-cli.log 2>&1
    - identifier: gridconfig-copilot-log
    - user: root

sae|gridconfig|v|superbroker|cleanup-copilot-log-rotate:
  file.absent:
    - name: /etc/logrotate.d/copilot-cli

sae|gridconfig|v|superbroker|cleanup-regen-hosts:
  cron.absent:
    - name: grconf [ -x /usr/local/gridconfig/bin/hostlist_updater.pl ] && /usr/local/gridconfig/bin/hostlist_updater.pl >>/usr/local/gridconfig/log/hostlist_updater.log 2>&1

sae|gridconfig|v|superbroker|cleanup-copilot-service:
  service.dead:
    - name: copilotd
    - provider: runit
    - enable: False
    - require:
      - sae|gridconfig|v|server|pkgs

sae|gridconfig|v|superbroker|cleanup-copilot-run:
  file.absent:
    - name: /etc/service/copilotd
    - require:
      - sae|gridconfig|v|superbroker|cleanup-copilot-service

sae|gridconfig|v|superbroker|cleanup-copilot-conf:
  file.absent:
    - name: /etc/llnw/copilot.yml
    - require:
      - sae|gridconfig|v|superbroker|cleanup-copilot-service
