#!/bin/sh

#
DIR=${1}
PRUNETO=${2-100}

#
GIT="/usr/bin/git"

#
usage() {
	MSG=${1}
	if [ "$MSG" ]
	then
		echo "ERROR: ${MSG}\n"
	fi
	cat <<EOF
$0 {directory} {prune}
Directory: Git directory you wish to prune
Prune: The max revision history you want to keep (default: 100)
EOF
	exit 1;
}

#
logit() {
	MSG=${1}
	echo ${MSG}
	echo ${MSG} | logger -t "$0"
}

## Check inputs
if [ "${DIR}" = "" ]
then
	usage "Invalid directory"
elif [ ! $(echo ${PRUNETO} | grep -E "^[0-9]+$") ]
then
	usage "Invalid prune"
fi

if [ -O ${DIR} ] && [ -x ${DIR} ]
then
	cd "${DIR}"
	if [ "$?" = "1" ]
	then
		echo "Failed to change directory to $1"
		exit 1;
	fi
else
	echo "Invalid directory or owner\n"
	exit 1;
fi

#
dusum(){
	RETURN=$(du -sh . | perl -F"\s+" -ane 'print $F[0]')
	echo ${RETURN}
}

### Revision list count is a number
CURREV=$(${GIT} rev-list --count HEAD)
CURSIZE=$(dusum)
SHALLOWTO=$(${GIT} rev-parse HEAD~${PRUNETO})

## Perform steps
## Avoid conflict, file should not exist
if [ ! -f .git/gc.pid ]
then
	echo ${SHALLOWTO} > .git/shallow
	${GIT} gc --prune=now >/dev/null 2>&1
else
	 logit "ERROR: GIT GC already running"
	 exit 1
fi

NOWREV=$(${GIT} rev-list --count HEAD)
NOWSIZE=$(dusum)

logit "From ${CURREV} Commits ($CURSIZE) => ${NOWREV} Commits ($NOWSIZE)"
