# vim: sts=2 ts=2 sw=2 et ai

{% from 'pepper/map.jinja' import defaults, netblocks with context %}
{% from 'certs/map.jinja' import cert_path with context %}
{% from 'apache2/map.jinja' import apache %}
{% from 'sae-hw-procurement/map.jinja' import hw_procurement_config as config %}

include:
  - apache2
  - apache2.acl
  - apache2.prefork
  - apache2.ssl
  - certs
  - firewall.standard
  - firewall.web

sae|hw-procurement|repo:
  pkgrepo.managed:
    - name: deb http://repo.llnw.net/llnw/ubuntu/{{ config.pkg_repo_env }}/hw-procurement/ {{ salt['grains.get']('oscodename') }}/
    - file: /etc/apt/sources.list.d/llnw.hw-procurement.{{ salt['grains.get']('oscodename') }}.list
    - clean_file: True

sae|hw-procurement|pkg:
{% if config.pkg_version == 'latest' %}
  pkg.latest:
    - pkgs:
      - hw-procurement
{% else %}
  pkg.installed:
    - pkgs:
      - hw-procurement: {{ config.pkg_version }}
{% endif %}
    - skip_verify: True
    - require:
      - pkgrepo: sae|hw-procurement|repo
    - watch_in:
      - service: core|apache2|service

sae|hw-procurement|conf:
  file.managed:
    - name: /usr/share/hw-procurement/content/html/config.php
    - source: salt://sae-hw-procurement/templates/config.php.jinja
    - template: jinja
    - require:
      - pkg: sae|hw-procurement|pkg

sae|hw-procurement|sql-query-log-file:
  file.managed:
    - name: {{ config.sql_query_log_file }}
    - user: www-data
    - group: www-data

sae|hw-procurement|rotate_sql_query_log:
  file.managed:
    - name: /etc/logrotate.d/hw_sql_query
    - user: root
    - group: {{ defaults['root_group'] }}
    - contents: |
        {{ config.sql_query_log_file }} {
          rotate 5
          size 10M
        }

sae|hw-procurement|hw-procurement-apache:
  file.managed:
    - name: {{ apache['confdir'] }}/sites-available/hw.conf
    - source: salt://sae-hw-procurement/templates/apache_hw.conf.jinja
    - template: jinja
    - require:
      - pkg: sae|hw-procurement|pkg
    - context:
        config: {{ config }}
    - watch_in:
      - service: core|apache2|service

sae|hw-procurement|a2enmod-rewrite:
  apache_module.enabled:
    - name: rewrite
    - require:
      - pkg: core|apache2|pkg
    - watch_in:
      - service: core|apache2|service

sae|hw-procurement|a2ensite-hw:
  cmd.run:
    - name: "a2ensite hw"
    - unless: test -L {{ apache['confdir'] }}/sites-enabled/hw.conf
    - watch:
      - file: sae|hw-procurement|hw-procurement-apache
    - watch_in:
      - service: core|apache2|service

# https://github.llnw.net/asset-mgmt/hw_assets/blob/master/README.md talks
# about a crontab entry for fetchmail, but that does not exist on the
# production host limon-1.lax.llnw.net and the log file it would write
# /tmp/fetchmail.log does not exist either, so it has not been salted.
