# vim: sts=2 ts=2 sw=2 et ai

{% from "pepper/map.jinja" import defaults with context %}

{% set mp4split_pkg_name = "mp4split" %}
{% set mss_pkg_name = "mod_smooth_streaming" %}
{% set pkg_version = "1.7.10llnw3.6.5.0" %}

{% set images_cdn_secret = salt['pillar.get']('secrets:sae:images_cdn_mediavault_secret') %}
{% set cdn_base_url = "http://test.vo.llnwd.net/images/ics/llbsd" + grains['osmajorrelease'] + "/ics3" %}

{% set mss_llnw_url = salt['mediavault.buildurl'](images_cdn_secret,'%s/%s-%s.txz'|format(cdn_base_url,mss_pkg_name,pkg_version)) %}
{% set mp4split_llnw_url = salt['mediavault.buildurl'](images_cdn_secret,'%s/%s-%s.txz'|format(cdn_base_url,mp4split_pkg_name,pkg_version)) %}

# We need the EXACT version in case of downgrade
{% set comp_op = '=' %}

include:
  - .common
  - apache2
  - apache2.acl

sae|ics|mp4split-remove:
 cmd.run:
   - name: /usr/sbin/pkg delete -fy mp4split; pkg add '{{ mp4split_llnw_url }}' 
   - unless: /usr/sbin/pkg info -D "mp4split{{ comp_op }}{{ pkg_version }}"
   - require_in:
     - cmd: sae|ics|mod_smooth_streaming-remove

sae|ics|mod_smooth_streaming-remove:
 cmd.run:
   - name: /usr/sbin/pkg delete -fy mod_smooth_streaming; pkg add '{{ mss_llnw_url }}' 
   - unless: /usr/sbin/pkg info -D "mod_smooth_streaming{{ comp_op }}{{ pkg_version }}"
   - require_in:
     - pkg: sae|ics|mod_smooth_streaming

sae|ics|mod_smooth_streaming:
  pkg.installed:
    - sources:
      - mod_smooth_streaming: {{ mss_llnw_url }}
    - require:
      - pkg: core|apache2|pkg
      - pkg: sae|ics|mp4split

sae|ics|mp4split:
  pkg.installed:
    - sources:
      - mp4split: {{ mp4split_llnw_url }}

sae|ics|apache24_httpd_conf:
  file.managed:
    - name: /usr/local/etc/apache24/httpd.conf
    - source: salt://{{ slspath }}/files/apache24_httpd.conf
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 644
    - makedirs: True
    - dir_mode: 755
    - onchanges_in:
      - cmd: sae|ics|apache24-reload
      - cmd: sae|ics|apache24-checkconfigs
    - require:
      - file: core|apache2|acl-apache
      - pkg: core|apache2|pkg
    - require_in:
      - service: core|apache2|service

sae|ics|apache24_mfs_vod_conf:
  file.managed:
    - name: /usr/local/etc/apache24/Includes/mfs_vod.conf
    - source: salt://{{ slspath }}/files/mfs_vod.conf
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 644
    - template: jinja
    - makedirs: True
    - dir_mode: 755
    - onchanges_in:
      - cmd: sae|ics|apache24-reload
      - cmd: sae|ics|apache24-checkconfigs
    - require:
      - pkg: sae|ics|mod_smooth_streaming
      - pkg: sae|ics|mp4split
      - pkg: core|apache2|pkg
      - file: sae|ics|apache24_httpd_conf
    - require_in:
      - service: core|apache2|service

sae|ics|apache24-logs:
  file.directory:
    - name: /logs/apache24/old
    - dir_mode: 755
    - user: root
    - group: {{ defaults['root_group'] }}
    - makedirs: True

sae|ics|apache24-checkconfigs:
  cmd.run:
    - name: /usr/local/sbin/apachectl -t

sae|ics|apache24-check-mpm-event:
  cmd.run: 
    - name: service apache24 restart
    - unless: "curl http://localhost/server-status -o - -s | grep -c 'Server MPM: event'"
    - require:
      - pkg: core|apache2|pkg
      - file: sae|ics|apache24_mfs_vod_conf
      - file: sae|ics|apache24_httpd_conf
      - file: sae|ics|apache24-logs
      - cmd: sae|ics|apache24-checkconfigs
      - service: sae|ics|apache24-service-enabled

sae|ics|apache24-reload:
  cmd.run:
    - name: service apache24 reload
    - require:
      - cmd: sae|ics|apache24-checkconfigs
      - service: sae|ics|apache24-service-enabled
      - service: core|apache2|service

sae|ics|apache24-service-enabled:
  service.enabled:
    - name: apache24

sae|ics|apache24-415-error-document:
  file.managed:
    - name: /usr/local/www/mfs/415
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 644
    - makedirs: True
    - dir_mode: 755
    - require_in:
      - service: core|apache2|service   

sae|ics|apache24-416-error-document:
  file.managed:
    - name: /usr/local/www/mfs/416
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 644
    - makedirs: True
    - dir_mode: 755
    - require_in:
      - service: core|apache2|service      
