{% from "pepper/map.jinja" import defaults with context %}

# placeholder/backup incase rollout/current are not set correctly
{% set jail_ics_version = '1.7.10llnw3.4.1.5' %}
{% set jail_name = 'ics10' %}
{% set instance_number = '2' %}
{% set jail_root = jail_name %}

{% set host_ifs = [] %}
{% for i, _ in salt['network.interfaces']().iteritems() %}
  {% do host_ifs.append(i) %}
{% endfor %}

{% set jail_if_possible = [] %}
{% set jail_if_options = ["vtnet0", "em1", "em0", "igb1", "ix1", "cxl1", "igb0", "ix0", "cxl0", "lagg0"] %}
{% for i in jail_if_options %}
  {% if i in host_ifs %}
    {% do jail_if_possible.append(i) %}
  {% endif %}
{% endfor %}

sae|ics|jail|guess-network-interface:
{% if jail_if_possible|length > 0 %}
  {% set jail_if = jail_if_possible[-1] %}
  test.succeed_without_changes:
    - name: ICS JAIL use [{{ jail_if }}] network interface, {{ jail_if_possible }} are all possibilities.
{% else %}
  {% set jail_if = "missing" %}
  test.fail_without_changes:
    - name: ICS JAIL failed to find supported network interfaces, only {{ jail_if_options }} are supported.
{% endif %}

include:
  - .common
  - .apache24
  - apache2
  - apache2.acl
  - .packages-2

{% set host_hostname = grains['fqdn']%}
{% set jail_hostname = salt['mproc.instance_hostname'](host_hostname, 2) %} # 1st jail == 2nd ics instance

{% set jail_ip = 'missing' %}
#branching dynamic reqs via 127.0.0.{instance-index} for jails
#working w/ cdn_rewrite http://localhost:10960/dynamic-instance-{([0-9]+)}/a319/ http://127.0.0.\1:8135/a319/ acct_id 319
{% set jail_localhost_ip = '127.0.0.2' %}
{% set jail_ismd_prefix  = 'dynamic-instance-2/' %}

#ics jail deployment exits if jail ip can't be resolved.
sae|ics|jail|resolve-ip:
{% if grains['salt_states_vb'] is defined %}
  {% set jail_ip = '192.168.170.230' %}
  test.succeed_without_changes:
    - name: Vagrant ICS JAIL {{ jail_name }} hostname[{{ jail_hostname }}] has IP of {{ jail_ip }}.
    - require:
      - test: sae|ics|jail|guess-network-interface
{% else %}
  {% set jail_ipv4s = salt['dnsutil.A'](jail_hostname) %}
  {% if jail_ipv4s|length == 1 %}
  {% set jail_ip = jail_ipv4s[0] %}
  test.succeed_without_changes:
    - name: ICS JAIL {{ jail_name }} hostname[{{ jail_hostname }}] has IP of {{ jail_ip }}.
    - require:
      - test: sae|ics|jail|guess-network-interface    
  {% else %}
  test.fail_without_changes:
    - name: ICS JAIL {{ jail_name }} hostname[{{ jail_hostname }}] failed to be resolved {{ jail_ipv4s }}.
  {% endif %}
{% endif %}


sae|ics|jail|gz:
  file.managed:
    - name: /tmp/{{ jail_name }}.gz
    - source: http://images.llnw.net/ics/jail/{{ jail_name }}.{{ jail_ics_version }}.gz
    - source_hash: md5=5234177377a794c219fa0318ea555a37
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 644
    - makedirs: True
    - require:
      - test: sae|ics|jail|resolve-ip

sae|ics|jail|gz-extract:
  cmd.wait:
    - name: service jail onestop {{ jail_name }} >& /dev/null; umount /{{ jail_root }}/logs/apache24/ >& /dev/null; chflags -R 0 /{{ jail_root }} >& /dev/null; rm -rf /{{ jail_root }} >& /dev/null; tar xzf /tmp/{{ jail_name }}.gz
    - cwd: /
    - require:
      - file: sae|ics|jail|gz
    - watch: 
      - file: /tmp/{{ jail_name }}.gz

sae|ics|jail|conf:
  file.managed:
    - name: /etc/jail.conf
    - source: salt://{{ slspath }}/files/jail.conf
    - context:
        jail_name: {{ jail_name }}
        jail_root: {{ jail_root }}
        jail_hostname: {{ jail_hostname }}
        jail_if: {{ jail_if }}
        jail_ip: {{ jail_ip }},lo0|{{ jail_localhost_ip }}
    - template: jinja
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 644
    - require:
      - cmd: sae|ics|jail|gz-extract

#includes from .common
sae|ics|jail|crossdomain_xml:
  file.managed:
    - name: /{{ jail_root }}/usr/local/www/mfs/crossdomain.xml
    - use:
      - file: sae|ics|crossdomain_xml
    - require:
      - cmd: sae|ics|jail|gz-extract

sae|ics|jail|clientaccesspolicy_xml:
  file.managed:
    - name: /{{ jail_root }}/usr/local/www/mfs/clientaccesspolicy.xml
    - use:
      - file: sae|ics|clientaccesspolicy_xml
    - require:
      - cmd: sae|ics|jail|gz-extract

sae|ics|jail|952100bad8d1486ca7f5fee26ee5927d_ismv:
  file.managed:
    - name: /{{ jail_root }}/usr/local/www/mfs/952100bad8d1486ca7f5fee26ee5927d.ismv
    - use:
      - file: sae|ics|952100bad8d1486ca7f5fee26ee5927d_ismv
    - require:
      - cmd: sae|ics|jail|gz-extract

sae|ics|jail|atombomb_512k_ism:
  file.managed:
    - name: /{{ jail_root }}/usr/local/www/mfs/atombomb_512kb.ism
    - use:
      - file: sae|ics|atombomb_512k_ism
    - require:
      - cmd: sae|ics|jail|gz-extract

#includes from .apache24
sae|ics|jail|apache24_httpd_conf:
  file.managed:
    - name: /{{ jail_root }}/usr/local/etc/apache24/httpd.conf
    - use:
      - file: sae|ics|apache24_httpd_conf
    - onchanges_in:
      - cmd: sae|ics|jail|apache24-reload
      - cmd: sae|ics|jail|apache24-checkconfigs
    - require:
      - cmd: sae|ics|jail|gz-extract
      - file: core|apache2|acl-apache
      - pkg: core|apache2|pkg
    - require_in:
      - service: core|apache2|service

sae|ics|jail|apache24-logs:
  file.directory:
    - name: /{{ jail_root }}/logs/apache24/old
    - use:
      - file: sae|ics|apache24-logs
    - require:
      - cmd: sae|ics|jail|gz-extract

sae|ics|jail|apache24-415-error-document:
  file.managed:
    - name: /{{ jail_root }}/usr/local/www/mfs/415
    - use:
      - file: sae|ics|apache24-415-error-document
    - require:
      - cmd: sae|ics|jail|gz-extract
    - require_in:
      - service: core|apache2|service  

sae|ics|jail|apache24-416-error-document:
  file.managed:
    - name: /{{ jail_root }}/usr/local/www/mfs/416
    - use:
      - file: sae|ics|apache24-416-error-document
    - require:
      - cmd: sae|ics|jail|gz-extract
    - require_in:
      - service: core|apache2|service

#not including mfs_vod.conf - creating new
sae|ics|jail|apache24_mfs_vod_conf:
  file.managed:
    - name: /{{ jail_root }}/usr/local/etc/apache24/Includes/mfs_vod.conf
    - source: salt://{{ slspath }}/files/mfs_vod.conf
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 644
    - template: jinja
    - makedirs: True
    - dir_mode: 755
    - context:
        log_file_prefix: mfs-{{ jail_name }}-
        monitoring_path: monitoring{{ instance_number }}
        public_ip: {{ jail_ip }}
        local_ip: {{ jail_localhost_ip }}
        ismd_prefix: {{ jail_ismd_prefix }}
    - onchanges_in:
      - cmd: sae|ics|jail|apache24-reload
      - cmd: sae|ics|jail|apache24-checkconfigs
    - require:
      - pkg: sae|ics|mod_smooth_streaming
      - pkg: sae|ics|mp4split
      - pkg: core|apache2|pkg
      - file: sae|ics|apache24_httpd_conf
      - cmd: sae|ics|jail|gz-extract
    - require_in:
      - service: core|apache2|service

sae|ics|jail|carry-host-acl:
  file.copy:
    - name: /{{ jail_root }}/usr/local/etc/apache24/apache.allow.llnw
    - source: /usr/local/etc/apache24/apache.allow.llnw
    - require:
        - cmd: sae|ics|jail|gz-extract

sae|ics|jail|apache24-enable:
  file.managed:
    - name: /{{ jail_root }}/etc/rc.conf
    - user: root
    - group: {{ defaults.root_group }}
    - mode: 644
    - contents: |
        apache24_enable="YES"
    - require:
      - cmd: sae|ics|jail|gz-extract

sae|ics|jail|apache24-log-mount:
  mount.mounted:
    - name: /{{ jail_root }}/logs/apache24
    - device: /logs/apache24
    - fstype: nullfs
    - opts:
        - rw
    - require:
      - cmd: sae|ics|jail|gz-extract

sae|ics|jail|start:
  cmd.run:
    - name: service jail onestart {{ jail_name }}
    - unless: jls | grep {{ jail_name }}
    - require:
      - cmd: sae|ics|jail|gz-extract
      - file: sae|ics|jail|apache24-enable
      - mount: sae|ics|jail|apache24-log-mount

sae|ics|jail|apache24-checkconfigs:
  cmd.run:
    - name: jexec {{ jail_name }} /usr/local/sbin/apachectl -t

sae|ics|jail|apache24-reload:
  cmd.wait:
    - name: jexec {{ jail_name }} service apache24 reload
    - require:
      - cmd: sae|ics|jail|start
    - watch:
      - file: sae|ics|jail|carry-host-acl
      - file: sae|ics|jail|apache24_httpd_conf
      - file: sae|ics|jail|apache24_mfs_vod_conf

sae|ics|jail|zabbix_lld:
  file.serialize:
    - name: /usr/local/llnw/zabbix/json/ics_instances.json
    - formatter: json
    - dataset:
        data:
          - {% raw %}"{#ICS_INSTANCE_HOSTNAME}"{% endraw %}: {{ jail_hostname }}
            {% raw %}"{#ICS_INSTANCE_IP}"{% endraw %}: {{ jail_ip }}
    - require:
      - cmd: sae|ics|jail|start
