#!/bin/sh

PATH=/sbin:/bin:/usr/sbin:/usr/bin:/usr/local/sbin:/usr/local/bin

if [ "`uname -s`" = "FreeBSD" ]; then
  dir=/usr/local/llnw/ipgeo
elif uname -n | grep -q '^vps-'; then
  dir=/usr/local/llnw/ipgeo
else
  dir=/llnw
fi

url=http://geoip-edge-config.lldns.net/ipgeo
httpproxy=test.vo.llnwd.net
if hostname | grep -qe ^cds -e ^fcds -e ^waa -e ^qcds; then
  localpcds=`dig -4 +short $httpproxy @127.0.0.1 | head -n1`
else
  localpcds=`dig -4 +short $httpproxy | head -n1`
fi
ipgeofile=geo.db.bz2
ipgeofile_ipv6=geo_ipv6.db.bz2
logfile=/tmp/update-ipgeo-wget.out

if [ ! -d $dir/db ]; then
  mkdir -p $dir/db
fi

wget -N -o $logfile --directory-prefix=$dir -ehttp_proxy=$localpcds $url/$ipgeofile
if [ $? -ne 0 ]; then
  logger -p local0.err "ipgeowget.sh: Could not wget $url/$ipgeofile.  My IP Geo data will not be updated!"
  exit 1
fi

wget -N -o $logfile --directory-prefix=$dir -ehttp_proxy=$localpcds $url/$ipgeofile".shasum"
if [ $? -ne 0 ]; then
  logger -p local0.err "ipgeowget.sh: Could not wget $url/$ipgeofile.shasum.  My IP Geo data will not be updated!"
  exit 1
fi

wget -N -o $logfile --directory-prefix=$dir -ehttp_proxy=$localpcds $url/$ipgeofile_ipv6
if [ $? -ne 0 ]; then
  logger -p local0.err "ipgeowget.sh: Could not wget $url/$ipgeofile_ipv6.  My IP Geo data will not be updated!"
  exit 1
fi

wget -N -o $logfile --directory-prefix=$dir -ehttp_proxy=$localpcds $url/$ipgeofile_ipv6".shasum"
if [ $? -ne 0 ]; then
  logger -p local0.err "ipgeowget.sh: Could not wget $url/$ipgeofile_ipv6.shasum.  My IP Geo data will not be updated!"
  exit 1
fi

grep 'Server file no newer than local file' $logfile > /dev/null
if [ $? -eq 0 ]; then
  rm $logfile
  exit 0
fi
rm $logfile

cd $dir
shasum -c "$ipgeofile.shasum"
if [ $? -ne 0 ]; then
  logger -p local0.err "ipgeowget.sh: shasum for the $ipgeofile validation failed.  My IP Geo data will not be updated!"
  exit 1
fi


shasum -c "$ipgeofile_ipv6.shasum"
if [ $? -ne 0 ]; then
  logger -p local0.err "ipgeowget.sh: shasum for the $ipgeofile_ipv6 validation failed.  My IP Geo data will not be updated!"
  exit 1
fi

bunzip2 -kf $dir/$ipgeofile
if [ $? -ne 0 ]; then
  # bunzip failed
  logger -p local0.err "ipgeowget.sh: bunzip2 $ipgeofile failed. My IP Geo data will not be updated!"
  rm $dir/$ipgeofile
  exit $?
fi

bunzip2 -kf $dir/$ipgeofile_ipv6
if [ $? -ne 0 ]; then
  # bunzip failed
  logger -p local0.err "ipgeowget.sh: bunzip2 $ipgeofile_ipv6 failed. My IP Geo data will not be updated!"
  rm $dir/$ipgeofile_ipv6
  exit $?
fi

if [ "`uname -s`" = "FreeBSD" ]; then
  chmod 755 $dir/..
fi
chmod 755 $dir $dir/db
chmod 644 $dir/`echo $ipgeofile | sed s/\.bz2$//`
chmod 644 $dir/`echo $ipgeofile_ipv6 | sed s/\.bz2$//`
mv $dir/`echo $ipgeofile | sed s/\.bz2$//` $dir/db
mv $dir/`echo $ipgeofile_ipv6 | sed s/\.bz2$//` $dir/db


if [ "`uname -s`" = "Linux" ]; then
  chown xfer:xfer /llnw/geo.db.bz2 /llnw/db /llnw/db/geo.db
fi
