#!/bin/bash
PATH=/sbin:/bin:/usr/sbin:/usr/bin:/usr/local/sbin:/usr/local/bin

# Add a random sleep timer in, so that we dont have a reload of the entire network at one time.

sleeplimit=300
sleeptime=$(( ( $RANDOM % $sleeplimit )  + 1 ))
sleep $sleeptime

# Settings
dir=/usr/local/llnw/ipgeo
sha1sum=shasum
url=http://geoip-edge-config.lldns.net/ipgeo
httpproxy=test.vo.llnwd.net
localpcds=$(dig -4 +short $httpproxy @127.0.0.1 | head -n1)
ipwhitelistfile=whitelist.db.bz2
logfile=/tmp/update-ipgeo-whitelist.log

# Create the directory if it doesn't already exist.
if [ ! -d $dir/db ]; then
  mkdir -p $dir/db
fi

# Download a new copy of the database if it exists
wget -N -o $logfile --directory-prefix=$dir -ehttp_proxy=$localpcds $url/$ipwhitelistfile
if [ $? -ne 0 ]; then
  logger -p local0.err "ipwhitelistwget.sh: Could not wget $url/$ipwhitelistfile.  My IP whitelist.db data will not be updated!"
  exit 1
fi

# Download the shasum file (if it is new)
wget -N -o $logfile --directory-prefix=$dir -ehttp_proxy=$localpcds $url/$ipwhitelistfile".shasum"
if [ $? -ne 0 ]; then
  logger -p local0.err "ipwhitelistwget.sh: Could not wget $url/$ipwhitelistfile.shasum.  My IP whitelist.db data will not be updated!"
  exit 1
fi

# Check to see if a new version was downloaded
grep -e 'Server file no newer than local file' -e 'not modified on server' $logfile > /dev/null
if [ $? -eq 0 ]; then
  rm $logfile
  exit 0
fi
rm $logfile

# check the shasum of the file 
cd $dir
$sha1sum -c "$ipwhitelistfile.shasum"
if [ $? -ne 0 ]; then
  logger -p local0.err "ipwhitelistwget.sh: shasum for the $ipwhitelistfile validation failed.  My IP whitelist.db data will not be updated!"
  exit 1
fi

# bunzip the file 
bunzip2 -kf $dir/$ipwhitelistfile
if [ $? -ne 0 ]; then
  # bunzip failed
  logger -p local0.err "ipwhitelistwget.sh: bunzip2 $ipwhitelistfile failed. My IP Whitelist data will not be updated!"
  rm $dir/$ipwhitelistfile
  exit $?
fi

# chmod the files / direcotries 
chmod 755 $dir/..
chmod 755 $dir $dir/db
chmod 644 $dir/$(echo $ipwhitelistfile | sed s/\.bz2$//)
# Move the file to the correct location 
mv $dir/`echo $ipwhitelistfile | sed s/\.bz2$//` $dir/db

# Reconfigure EP
touch /etc/sq/reconfig
