# vim: sts=2 ts=2 sw=2 et ai

{% from 'pepper/map.jinja' import defaults, netblocks with context %}
{% from "sae-ircd/map.jinja" import ircd_config with context %}

# Hosts not within LLNW space that we allow to connect to our IRCDs
{% set safe_hosts = ['63.230.232.67'] %}
{% set hybrid_ver = '7.2.1' %}

include:
  - firewall.standard

sae|ircd-hybrid|pkg:
  cmd.run:
    - name: /usr/sbin/pkg add http://test.vo.llnwd.net/o1/fbsd/{{ grains['osarch'] }}/10/ircd-hybrid-{{ hybrid_ver }}.txz
    - unless: /usr/sbin/pkg info -e "ircd-hybrid={{ hybrid_ver }}"

sae|ircd-hybrid|dirs:
  file.directory:
    - names:
      - /var/run/ircd
      - /var/log/ircd
    - user: ircd
    - group: ircd
    - mode: 755
    - makedirs: True
    - require:
      - cmd: sae|ircd-hybrid|pkg

sae|ircd-hybrid|motd:
  file.managed:
    - name: /usr/local/etc/ircd-hybrid/ircd.motd
    - user: root
    - group: {{ defaults.root_group }}
    - mode: 644
    - contents: |
        Welcome to the Limelight Networks IRC Server!
        -----
        ATTENTION: The use of this tool is for Limelight Networks'
        business purposes only.  Your access to, and use of, both
        the public and private channels of this system is subject
        to the Limelight Networks' employment policies and guidelines
        including, but not limited to, the Code of Ethics and Business
        Conduct.  Inappropriate conduct and comments (public or private)
        will not be tolerated and may lead to disciplinary action, up to
        and including termination of employment.  Please contact HR for
        questions or concerns about these policies and/or complaints about
        use of the IRC system.

sae|ircd-hybrid|conf:
  file.managed:
    - name: {{ defaults['config-path'] }}/ircd-hybrid/ircd.conf
    - user: ircd
    - template: jinja
    - makedirs: True
    - source: salt://sae-ircd/templates/ircd.conf.jinja
    - defaults:
        server_desc: {{ ircd_config['server_desc'] }}
        server_id: {{ ircd_config['server_id'] }}
        server_name: {{ ircd_config['server_name'] }}
        remote_hostname: {{ ircd_config['remote_hostname'] }}
        remote_ip: {{ ircd_config['remote_ip'] }}
        remote_pass: {{ salt['pillar.get']('secrets:sae-ircd:server_pass') }}

sae|ircd-hybrid|server-firewall:
  firewall.accept:
    - tcp:
      - [6667-6669, {{ netblocks }}]
      - [6667-6669, {{ safe_hosts }}]
    - require_in:
      - firewall: core|firewall|final-reject
