# vim: sts=2 ts=2 sw=2 et ai

{% from slspath ~ "/map.jinja" import jenkins, jenkins_plugins with context %}

include:
  # - firewall.web
  - java.default-openjdk8

sae|jenkins2|repo:
  pkgrepo.managed:
{% if grains['os_family'] == 'Debian' %}
    - file: /etc/apt/sources.list.d/jenkins2.list
    - name: deb http://pkg.jenkins.io/debian-stable binary/
    - key_url: https://pkg.jenkins.io/debian/jenkins.io.key
{% endif %}

sae|jenkins2|pkg:
  pkg.installed:
    - pkgs:
      - {{ jenkins.pkg }}
      - xmlstarlet
    - require:
      - pkg: core|java|pkg-openjdk8


sae|jenkins2|service:
  service.running:
    - name: {{ jenkins.svc }}
    - require:
      - pkg: sae|jenkins2|pkg

sae|jenkins2|jenkinslib:
  file.managed:
    - name: /var/lib/jenkins/jenkinslib.sh
    - source: salt://{{slspath}}/files/jenkinslib.sh
    - require:
      - service: sae|jenkins2|service

sae|jenkins2|installcli:
  cmd.script:
    - name: salt://{{slspath}}/files/downloadcli.sh
    - cwd: /var/lib/jenkins
    - creates: /var/lib/jenkins/jenkins-cli.jar
    - stateful: True
    - require:
      - file: sae|jenkins2|jenkinslib

sae|jenkins2|installplugin|ldap:
  cmd.script:
    - name: salt://{{slspath}}/files/installplugin.sh
    - args: ldap
    - cwd: /var/lib/jenkins
    - creates: /var/lib/jenkins/plugins/ldap.jpi
    - stateful: True
    - require:
      - cmd: sae|jenkins2|installcli

sae|jenkins2|configurejenkins:
  cmd.script:
    - name: salt://{{slspath}}/files/setupjenkins.sh
    - cwd: /var/lib/jenkins
    - creates: /var/lib/jenkins/autosetup.txt
    - stateful: True
    - require:
      - cmd: sae|jenkins2|installplugin|ldap


{% for plugin in jenkins_plugins %}
sae|jenkins2|installplugin|{{plugin}}:
  cmd.script:
    - name: salt://{{slspath}}/files/installplugin.sh
    - cwd: /var/lib/jenkins
    - args: {{plugin}}
    - creates: /var/lib/jenkins/plugins/{{plugin}}.jpi
    - stateful: True
    - require:
      - cmd: sae|jenkins2|configurejenkins
{% endfor %}
