# vim: sts=2 ts=2 sw=2 et ai

{% from "pepper/map.jinja" import defaults, netblocks with context %}
{% from "tcpwrappers/map.jinja" import extend_hosts with context %}

include:
  - firewall.standard
  - firewall.ossec
  - openssh
  - pam.ldap
  - pam.ldap-sudo
  - pam.mkhomedir
  - pepper.nobluekey
  - tcpwrappers
  - sae-jumphost.loaderconf
  - sae-jumphost.sshkeys
  - sae-sudoers.jumphost-admin
  - sae-sudoers.jumphost-env-keep
  - sae-sudoers.fgfinder
  - sae-sudoers.flashtools
  - zabbix.squelch-pl
  - zabbix.squelch-sh
  - .noc
  - .scripts
  - .ssh_audit
  - .sysops
  - .team_dirs

sae|jumphost|ssh-config:
  file.accumulated:
    - name: extra_ssh_config
    - filename: /etc/ssh/ssh_config
    - text: |
        # Use IPv4 by default, the v6 hits ACLs and libwraps
        AddressFamily inet
        # Avoid prompts for sessions to new hosts
        StrictHostKeyChecking no
        # Allow older keys to be used
        PubkeyAcceptedKeyTypes +ssh-dss
        HostkeyAlgorithms +ssh-dss
        KexAlgorithms +diffie-hellman-group1-sha1
        Ciphers +3des-cbc
    - require_in:
      - file: core|openssh|ssh-config

sae|jumphost|sshd-config:
  file.accumulated:
    - name: extra_sshd_config
    - filename: /etc/ssh/sshd_config
    - text: |
        AllowAgentForwarding yes
    - require_in:
      - file: core|openssh|sshd-config

sae|jumphost|llnw-dir:
  file.directory:
    - name: /local/llnw
    - user: root
    - group: {{ defaults['root_group'] }}

sae|jumphost|dedicated-conf-touch:
  file.touch:
    - name: /local/llnw/dedicated.conf
    - unless: test -e /local/llnw/dedicated.conf
    - require:
      - file: sae|jumphost|llnw-dir

sae|jumphost|dedicated-conf:
  http.query:
    - name: https://unix.llnw.com:8081/cvs/cfg/dedicated.conf
    - username: jumphost-tools
    - password: {{ salt['pillar.get']('secrets:sae-jumphost:aperature-api') }}
    - status: 200
    - verify_ssl: False
    - text_out: /local/llnw/dedicated.conf
    - require:
      - file: sae|jumphost|dedicated-conf-touch

sae|jumphost|rctl-conf:
  file.managed:
    - name: /etc/rctl.conf
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 644
    - contents: |
        # Limit each user to a total of 20G
        loginclass:default:vmemoryuse:deny=20G/user

{{ extend_hosts('sshd', '[2607:f4e8:12:fffc:225:90ff:fe03:74aa]', 'downside') }}
{{ extend_hosts('sshd', '68.142.79.') }}
{{ extend_hosts('sshd', '68.142.86.', 'PHX7.TELCO.ROOM') }}
{{ extend_hosts('sshd', '69.28.141.') }}
{{ extend_hosts('sshd', '68.142.86.84', 'JFW1.PHX7') }}
{{ extend_hosts('sshd', '68.142.97.') }}
{{ extend_hosts('sshd', '68.142.98.104', 'Infosec01 scanner') }}
{{ extend_hosts('sshd', '68.142.66.29', 'jh01.phx7') }}
{{ extend_hosts('sshd', '69.28.128.28', 'jh02.phx3') }}
{{ extend_hosts('sshd', '68.142.115.') }}
{{ extend_hosts('sshd', '69.28.130.113', 'Devnet Firewall public address') }}
{{ extend_hosts('sshd', '69.28.132.', 'PHX3 servers and vpn.phx3 pool') }}
{{ extend_hosts('sshd', '69.28.173.', 'NOC 2') }}
{{ extend_hosts('sshd', '69.28.175.') }}
{{ extend_hosts('sshd', '69.164.58.99', 'ra-tunnel') }}
{{ extend_hosts('sshd', '208.111.136.', 'origin space') }}
{{ extend_hosts('sshd', '10.45.', 'LEX Office') }}
{{ extend_hosts('sshd', '10.50.', 'SDL3') }}
{{ extend_hosts('sshd', '10.12.98.') }}
{{ extend_hosts('sshd', '10.12.93.', 'PHX3 Office') }}
{{ extend_hosts('sshd', '10.12.94.', 'PHX3 Office') }}
{{ extend_hosts('sshd', '68.142.64.177', 'PHX3 Office') }}
{{ extend_hosts('sshd', '10.14.77.', 'Personal VMs 2') }}
{{ extend_hosts('sshd', '10.14.79.', 'Personal VMs 3') }}
{{ extend_hosts('sshd', '10.32.97.', 'BOS8') }}
{{ extend_hosts('sshd', '10.32.98.', 'BOS8 2') }}
{{ extend_hosts('sshd', '10.62.96.', 'Ukraine office') }}
{{ extend_hosts('sshd', '10.62.81.', 'Ukraine office') }}
{{ extend_hosts('sshd', '10.62.83.', 'Ukraine office') }}
{{ extend_hosts('sshd', '10.62.85.', 'Ukraine office') }}
{{ extend_hosts('sshd', '10.62.89.', 'Ukraine office') }}
{{ extend_hosts('sshd', '10.63.97.', 'PAR8') }}
{{ extend_hosts('sshd', '10.63.98.', 'PAR8 2') }}
{{ extend_hosts('sshd', '172.16.2.', 'New Trusted Network VPN IT') }}
{{ extend_hosts('sshd', '172.16.12.', 'New Trusted Network VPN IT 2') }}
{{ extend_hosts('sshd', '172.16.5.', 'New Trusted Network VPN CDN ENG') }}
{{ extend_hosts('sshd', '172.16.15.', 'New Trusted Network VPN CDN ENG 2') }}
{{ extend_hosts('sshd', '172.16.8.', 'New Trusted Network VPN INFOSEC') }}
{{ extend_hosts('sshd', '172.16.18.', 'New Trusted Network VPN INFOSEC 2') }}
{{ extend_hosts('sshd', '172.16.7.', 'New Trusted Network VPN DEV') }}
{{ extend_hosts('sshd', '172.16.17.', 'New Trusted Network VPN DEV 2') }}
{{ extend_hosts('sshd', '172.16.4.', 'Trusted Network VPN FIN_ACC REMOTE 2') }}
{{ extend_hosts('sshd', '172.16.14.', 'Trusted Network VPN FIN_ACC REMOTE 2') }}
{{ extend_hosts('sshd', '172.16.0.', 'New emergency VPN') }}
{{ extend_hosts('sshd', '172.16.1.', 'New emergency VPN') }}
{{ extend_hosts('sshd', '172.16.', 'New emergency VPN') }}

sae|jumphost|pkgs:
  pkg.installed:
    - names:
      - 3proxy
      - 6tunnel
      - GeoIP
      - base64
      - cscope
      - curl
      - emacs-nox11
      - fusefs-libs
      - fusefs-sshfs
      - gawk
      - gist
      - hping
      - httperf
      - ipcalc
      - iperf
      - jwhois
      - links
      - m4
      - mercurial
      - mtr-nox11
      - mysql56-client
      - ncftp
      - ngrep
      - nmap
      - p5-Crypt-OpenSSL-Bignum
      - p5-Crypt-OpenSSL-CA
      - p5-Crypt-OpenSSL-PKCS10
      - p5-Crypt-OpenSSL-Random
      - p5-Crypt-OpenSSL-RSA
      - p5-Date-Manip
      - p5-DateTime-Format-Strptime
      - p5-DBD-mysql
      - p5-Tie-InsertOrderHash
      - p5-IO-Tty
      - p5-Net-SCP
      - p5-Net-SCP-Expect
      - p5-RT-Client-REST
# This is currentl conflicting with a number of other pkgs, causing a number
# of removals and additions on each highstate as they fight
# https://github.llnw.net/gist/jason/985a08f75241fc510e46
#     - p5-Specio-llnw
      - parallel
      - pssh
      - pstree
      - pv
      - py27-gspread
      - py27-jsonrpc-llnw
      - py27-jsonrpclib-llnw
      - py27-MySQLdb
      - py27-oauth2client
      - py27-ordereddict
      - py27-paramiko
      - py27-pip
      - py27-powerline-status
      - py27-psutil
      - py27-python-gnupg-llnw
      - py27-python-rtkit
      - py27-pyzabbix-llnw
      - py27-termcolor
      - py27-virtualenv
      - rpm2cpio
      - ruby
      - screen
      - sqlite3
      - ssldump
      - subnetcalc
      - subversion
      - tcl86
      - tcpflow
      - tcptrace
      - tmux
      - unrar
      - unzip
      - vim-lite
      - whowatch
      - xmbmon
      - zip
      - zsh
