# Load the standard Versioned States macro (invoked at end)
{% from "versioned-states/macros.jinja" import versioned_target_state %}

# Load env-specific Versioned States data dictionaries from plain YAML files
{% import_yaml slspath ~ "/production_vs.yaml" as production %}

# Get component name from vs.sls
{% from slspath ~ "/vs.sls" import product %}
{% set component = sls %}
# component: {{ component }}

{% set disable_grain = product ~ ":disable:" ~ component %}
{%- set is_disabled = salt["grains.get"](disable_grain, False) %}

# Get current state of Versioned State grains for this component
{% set version_has_grain = "vs:" ~ component ~ ":version_has" %}
{% set version_wants_grain = "vs:" ~ component ~ ":version_wants" %}
{% set version_has_str = salt['grains.get'](version_has_grain, '') %}
{% set version_wants_str = salt['grains.get'](version_wants_grain, '') %}
# version_has_str: {{ version_has_str }}
# version_wants_str: {{ version_wants_str }}

# Look up global minimum version for env in appropriate dictionary
{% set team_env = salt['grains.get']('team_env','production') %}
{% set minimum_version_str = production[team_env]['version_state'] %}

# Convert from version strings to ints (e.g. "v1" to 1)
{% set minimum_version = minimum_version_str[1:]|int() %}
{% if version_has_str == '' %} # handle new turn ups
{%   set version_has = -1 %}
{% else %} # Convert version string to int
{%   set version_has = version_has_str[1:]|int() %}
{% endif %}
{% if version_wants_str == '' %} # handle unset wants grain
{%   set version_wants = 0 %}
{% else %} # Convert version string to int
{%   set version_wants = version_wants_str[1:]|int() %}
{% endif %}


# Make sure everything stays up to date by setting version_wants if needed
{% if version_has < minimum_version %}
#     version_has < minimum_version
#     {{ version_has }} < {{ minimum_version }}
{%   if version_wants < minimum_version %}
#     version_wants < minimum_version
#     {{ version_wants }} < {{ minimum_version }}
#     do salt['grains.set']( {{ version_wants_grain }}, {{ minimum_version_str }})
{%     do salt['grains.set'](version_wants_grain, minimum_version_str) %}
{%   endif %}
{% endif %}

# Invoke the Versioned States macro to branch an sls include: of the appropriate version
# e.g.
# include:
#   - .v123
#

{%- if not is_disabled %}
{{ versioned_target_state(minimum_version_str) }}
{%- else %}
{% from slspath ~ "/no-op.sls" import no_op %}
{{ no_op(slspath ~ "/" ~ component) }}
{%- endif %}
