# Limon Backend

## Overview
Setup of apache sites for (2) releases defined in releases.yml.  Each site will operate on it's own port.  The primary site will be exposed locally by haproxy to the front-end UI site/component.

## Transfer Process on upgrade
Upgrading the backend packages, process, assuming a new versioned state exists with the new release defined in releases.yml:
1. Set the grain for the versioned state `vs:sae-limon.limon-components.backend:version_wants` to the new v#.
2. Run the node or highstate 'state' `salt-call state.apply sae-limon.limon-node`

What happens in the backend:
* Salt state identifies running releases on the box using the salt/grains
  * https://github.llnw.net/mglaske/salt-sae/blob/mwg/sae-limon/limon-components/backend/v0/map.jinja#L33-L43
* If the new release-ver is not one of the running releases, we're upgrading.
  * https://github.llnw.net/mglaske/salt-sae/blob/mwg/sae-limon/limon-components/backend/v0/map.jinja#L41
* Set the dictionary that defines release versions to A or B deployments
  * https://github.llnw.net/mglaske/salt-sae/blob/mwg/sae-limon/limon-components/backend/v0/map.jinja#L53-L65
* Extract the new package to a 'versioned' directory
  * https://github.llnw.net/mglaske/salt-sae/blob/mwg/sae-limon/limon-components/backend/v0/limon2-backend.sls#L9-L26
* Lay down a 'version' file in the new package directory, indicating the release ver.
  * https://github.llnw.net/mglaske/salt-sae/blob/mwg/sae-limon/limon-components/backend/v0/limon2-backend.sls#L33-L42
* Update the apache site for the non-primary A/B to point to the new release files.
  * https://github.llnw.net/mglaske/salt-sae/blob/mwg/sae-limon/limon-components/backend/v0/apache.sls#L21-L26
* Reload apache (this is fine, since haproxy is pointing to the primary instance)
  * https://github.llnw.net/mglaske/salt-sae/blob/mwg/sae-limon/limon-components/backend/v0/apache.sls#L52-L56
* Rebuild the haproxy config file to redirect the backend to the non-primary instance
  * https://github.llnw.net/mglaske/salt-sae/blob/mwg/sae-limon/limon-components/backend/v0/apache.sls#L85-L92
* Reload haproxy (this is hitless)
  * https://github.llnw.net/mglaske/salt-sae/blob/mwg/sae-limon/limon-components/backend/v0/apache.sls#L101-L110
* Provided the 'version' file is egressable via haproxy, we've switched successfully.
  * https://github.llnw.net/mglaske/salt-sae/blob/mwg/sae-limon/limon-components/backend/v0/validate.sls#L116-L119
* Update the grains with the release versions installed and which is A/B and which is primary/non-primary
  * https://github.llnw.net/mglaske/salt-sae/blob/mwg/sae-limon/limon-components/backend/v0/init.sls#L13-L32
* If upgrade was successful, we cleanup the old versioned directories.
  * https://github.llnw.net/mglaske/salt-sae/blob/mwg/sae-limon/limon-components/backend/v0/cleanup.sls#L7-L16
* Cron jobs are re-written to point to the new release directory.
  * https://github.llnw.net/mglaske/salt-sae/blob/mwg/sae-limon/limon-components/backend/v0/cron.sls#L22-L31

## Grains
* `limon:primary_instance` = A or B depending
* `limon:instance_A:port` = allow  you to change the ports if you need to, defaults to 8081
* `limon:instance_B:port` = same, 8082 by default
* `limon:instance_A:release` = the release version for A currently
* `limon:instance_B:release` = the release version for B currently
