
{%- set repo_map = {"dynamic": "testing", "dev": "testing", "qa": "testing", "staging": "staging", "production": "production"} %}
{%- set team_env = salt["grains.get"]("team_env", "dev") %}
{%- from slspath ~ "/map.jinja" import limon_backend_configs %}
{%- from slspath ~ "/releases.jinja" import release, releases_raw, release_ver %}

# For A & B versions
{%- for rv in releases_raw.releases_enabled %}
{# Get the package #}

{%- set release_info = release.get(rv, {}) %}
{%- set package_version = release_info.get("main", {}).get("limon2", "n/a") %}
{%- set pkg_name = "limon2-" ~ rv.replace("-", ".") ~ "~" ~ package_version ~ ".deb" %}

{%- set pkg_path = "http://repo.llnw.net/llnw/ubuntu/" ~ repo_map[team_env] ~ "/limon/" ~ grains.get("oscodename", "trusty") ~ "/" ~ pkg_name %}
{%- set pkg_dest = limon_backend_configs.packages_dir ~ "/" ~ rv %}
sae-limon|component|backend|{{ rv }}|fetch-package:
  file.managed:
    - name: /tmp/{{ pkg_name }}
    - source: {{ pkg_path }}
    - skip_verify: True

sae-limon|component|backend|{{ rv }}|perms:
  file.directory:
    - name: {{ pkg_dest }}/var/www/
    - makedirs: True
    - user: www-data
    - group: www-data
    - file_mode: 644
    - dir_mode: 755
    - recurse:
      - user
      - group
      - mode

sae-limon|component|backend|{{ rv }}|extract-package:
  cmd.run:
    - name: dpkg-deb --extract /tmp/{{ pkg_name }} {{ pkg_dest }}/
    - onlyif: test -f /tmp/{{ pkg_name }}
    - require:
      - file: sae-limon|component|backend|{{ rv }}|fetch-package
      - file: sae-limon|component|backend|{{ rv }}|perms
    - watch_in:
      - service: core|beats|filebeat|service

# We have dependencies on extract-package in services and routescan
sae-limon|component|backend|{{ rv }}|cleanup:
  file.absent:
    - name: /tmp/{{ pkg_name }}
    - require:
      - file: sae-limon|component|backend|{{ rv }}|fetch-package

{# used for validation to ensure egress of correct version #}
sae-limon|component|backend|{{ rv }}|versions_file:
  file.managed:
    - name: {{ pkg_dest }}/var/www/ui/public/release.txt
    - user: www-data
    - group: www-data
    - mode: 0644
    - makedirs: true
    - contents:
      - {{ rv }}
    - require_in:
      - llnw_validate: sae-limon|component|backend|published|version
      - llnw_validate: sae-limon|component|frontend|published|version

sae-limon|component|backend|{{ rv }}|dot_env:
  file.symlink:
    - name: {{ pkg_dest }}/var/www/ui/.env
    - target: /var/www/ui/.env
    - force: true

sae-limon|component|backend|{{ rv }}|app_dir:
  file.directory:
    - name: /var/www/ui/storage/app
    - user: www-data
    - group: www-data
    - dir_mode: 775
    - makedirs: True

sae-limon|component|backend|{{ rv }}|app_dir_symlink:
  file.symlink:
    - name: {{ pkg_dest }}/var/www/ui/storage/app
    - target: /var/www/ui/storage/app
    - force: true
    - user: www-data
    - group: www-data
    - dir_mode: 775
    - require:
      - file: sae-limon|component|backend|{{ rv }}|app_dir

sae-limon|component|backend|{{ rv }}|framework_dir:
  file.directory:
    - name: {{ pkg_dest }}/var/www/ui/storage/framework
    - user: www-data
    - group: www-data
    - dir_mode: 775

sae-limon|component|backend|{{ rv }}|cache_dir:
  file.directory:
    - name: {{ pkg_dest }}/var/www/ui/storage/framework/cache
    - user: www-data
    - group: www-data
    - dir_mode: 775
    - makedirs: True

sae-limon|component|backend|{{ rv }}|views_dir:
  file.directory:
    - name: {{ pkg_dest }}/var/www/ui/storage/framework/views
    - user: www-data
    - group: www-data
    - dir_mode: 775
    - makedirs: True

sae-limon|component|backend|{{ rv }}|sessions_dir:
  file.directory:
    - name: {{ pkg_dest }}/var/www/ui/storage/framework/sessions
    - user: www-data
    - group: www-data
    - dir_mode: 775
    - makedirs: True

# To run only one time per package install, not for each high state
sae-limon|component|backend|{{ rv }}|artisan|routescan:
  cmd.run:
    - name: {{ limon_backend_configs.php_bin }} {{ limon_backend_configs.packages_dir }}/{{ release_ver }}/var/www/ui/artisan route:scan
    - require:
      - cmd: sae-limon|component|backend|{{ rv }}|extract-package
      - test: sae-limon|component|limon_backend|releases|pkg_prereq

{%- endfor %}


