# Each host should have limon-queue-high
# Master host with limon-handle-all-queues grain should have limon-queue-high & limon-queue-low & limon-queue-mails

# High queue will be installed in case role-limon.queue-high grain is present in Cornerstone.

{% if 'role-limon.queue-high' in salt['grains.get']('cornerstone:tags', {})|list %}
sae-limon|component|dev|limon-queue-high|runit:
  llnw_runit.present:
    - name: limon-queue-high
    - runas_user: www-data
    - runas_group: www-data
    - ulimit: 200000
    - command: php
    - args:
      - "/var/www/dev/limon-backend/artisan"
      - "queue:work"
      - "database"
      - "--tries=3"
      - "--sleep=3"
      - "--delay=0"
      - "--queue=high"
      - "--once"
    - svlogd: True
    - svlogd_dir: /var/log
    - svlogd_size: 50000000
    - svlogd_num: 10
    - svlogd_error: False
    - start: True
    - restart: False
    - default_down: False

sae-limon|component|dev|limon-queue-high|reload:
  llnw_runit.reload:
    - name: limon-queue-high
    - onchanges:
      - file: sae|limon|node|dot-env

{% else %}
sae-limon|component|dev|limon-queue-high|remove:
  llnw_runit.absent:
    - name: limon-queue-high
{% endif %}

# Low queue will be installed in case role-limon.queue-low grain is present in Cornerstone.

{% if 'role-limon.queue-low' in salt['grains.get']('cornerstone:tags', {})|list %}
sae-limon|component|dev|limon-queue-low|runit:
  llnw_runit.present:
    - name: limon-queue-low
    - runas_user: www-data
    - runas_group: www-data
    - ulimit: 200000
    - command: php
    - args:
      - "/var/www/dev/limon-backend/artisan"
      - "queue:work"
      - "database"
      - "--tries=3"
      - "--queue=low"
    - svlogd: True
    - svlogd_dir: /var/log
    - svlogd_size: 50000000
    - svlogd_num: 10
    - svlogd_error: False
    - start: True
    - restart: False
    - default_down: False

sae-limon|component|dev|limon-queue-low|reload:
  llnw_runit.reload:
    - name: limon-queue-low
    - onchanges:
      - file: sae|limon|node|dot-env
{% else %}
sae-limon|component|dev|limon-queue-low|remove:
  llnw_runit.absent:
    - name: limon-queue-low
{% endif %}

# Mails queue will be installed in case role-limon.queue-mails grain is present in Cornerstone

{% if 'role-limon.queue-mails' in salt['grains.get']('cornerstone:tags', {})|list %}
sae-limon|component|dev|limon-queue-mails|runit:
  llnw_runit.present:
    - name: limon-queue-mails
    - runas_user: www-data
    - runas_group: www-data
    - ulimit: 200000
    - command: php
    - args:
      - "/var/www/dev/limon-backend/artisan"
      - "queue:work"
      - "database"
      - "--tries=3"
      - "--queue=mails"
    - svlogd: True
    - svlogd_dir: /var/log
    - svlogd_size: 50000000
    - svlogd_num: 10
    - svlogd_error: False
    - start: True
    - restart: False
    - default_down: False

sae-limon|component|dev|limon-queue-mails|reload:
  llnw_runit.reload:
    - name: limon-queue-mails
    - onchanges:
      - test: sae-limon|component|limon_backend|releases|pkg_prereq|changed
      - file: sae|limon|node|dot-env
{% else %}
sae-limon|component|dev|limon-queue-mails|remove:
  llnw_runit.absent:
    - name: limon-queue-mails
{% endif %}

# Loris queue will be installed in case role-limon.queue-loris grain is present in Cornerstone

{% if 'role-limon.queue-loris' in salt['grains.get']('cornerstone:tags', {})|list %}
sae-limon|component|dev|limon-queue-loris|runit:
  llnw_runit.present:
    - name: limon-queue-loris
    - runas_user: www-data
    - runas_group: www-data
    - ulimit: 200000
    - command: php
    - args:
      - "/var/www/dev/limon-backend/artisan"
      - "queue:work"
      - "database"
      - "--tries=3"
      - "--delay=180"
      - "--queue=loris"
    - svlogd: True
    - svlogd_dir: /var/log
    - svlogd_size: 50000000
    - svlogd_num: 10
    - svlogd_error: False
    - start: True
    - restart: False
    - default_down: False

sae-limon|component|dev|limon-queue-loris|reload:
  llnw_runit.reload:
    - name: limon-queue-loris
    - onchanges:
      - file: sae|limon|node|dot-env
{% else %}
sae-limon|component|dev|limon-queue-loris|remove:
  llnw_runit.absent:
    - name: limon-queue-loris
{% endif %}
