{%- from slspath ~ "/map.jinja" import  limon_env %}
{%- from slspath ~ "/releases.jinja" import release_ver %}
{%- set www_owner = "www-data" %}

{%- set git_repo_directory = "/var/www/limon2/backend/" ~ release_ver ~ "/var/www/ui" %}
{%- set git_repo_directory = "/opt" %}

sae-limon|components|loris-te|github_known_hosts:
  ssh_known_hosts.present:
    - name: github.llnw.net

sae-limon|components|loris-te|directory:
  file.directory:
    - names:
      - {{ git_repo_directory }}/{{ limon_env.loris["src_path"] }}
      - {{ git_repo_directory }}/{{ limon_env.loris["tgt_path"] }}
      - {{ git_repo_directory }}/{{ limon_env.loris["autote_path"] }}
    - user: {{ www_owner }}
    - group: {{ www_owner }}
    - makedirs: true

# TE UI
sae-limon|components|loris-te|limon-loris-deploy-key:
  file.managed:
    - name: {{ git_repo_directory }}/{{ limon_env.loris["src_rsa_path"] }}
    - user: {{ www_owner }}
    - group: {{ www_owner }}
    - mode: 400
    - makedirs: true
    - contents_pillar: secrets:sae-limon:loris_deploy_key

sae-limon|components|loris-te|limon-loris-repo:
  git.latest:
    - name: {{ limon_env.loris["src_repo"] }}
    - target: {{ git_repo_directory }}/{{ limon_env.loris["src_path"] }}
    - user: {{ www_owner }}
    - branch: master
    - force_reset: true
 # Compare the git remote with the desired repo.  Update if different.
    - unless: diff  <(git -C {{ git_repo_directory }}/{{ limon_env.loris['src_path'] }} config --get remote.origin.url | cat) <(echo "{{ limon_env.loris['src_repo'] }}")
    - identity:
      - {{ git_repo_directory }}/{{ limon_env.loris["src_rsa_path"] }}
    - require:
      - pkg: sae-limon|component|limon_backend|releases|pkg_prereq
      - file: sae-limon|components|loris-te|limon-loris-deploy-key


# LORIS FORK REPO
sae-limon|components|loris-te|limon-loris-fork-deploy-key:
  file.managed:
    - name: {{ git_repo_directory }}/{{ limon_env.loris["tgt_rsa_path"] }}
    - user: {{ www_owner }}
    - group: {{ www_owner }}
    - mode: 400
    - contents_pillar: secrets:sae-limon:loris_fork_deploy_key

sae-limon|components|loris-te|limon-loris-fork-repo:
  git.latest:
    - name: {{ limon_env.loris["tgt_repo"] }}
    - target: {{ git_repo_directory }}/{{ limon_env.loris["tgt_path"] }}
    - user: {{ www_owner }}
    - branch: master
    - force_reset: true
    # Compare the git remote with the desired repo.  Update if different.
    - unless: diff  <(git -C {{ git_repo_directory }}/{{ limon_env.loris['tgt_path'] }} config --get remote.origin.url | cat) <(echo "{{ limon_env.loris['tgt_repo'] }}")
    - identity:
      - {{ git_repo_directory}}/{{ limon_env.loris["tgt_rsa_path"] }}
    - require:
      - pkg: sae-limon|component|limon_backend|releases|pkg_prereq
      - file: sae-limon|components|loris-te|limon-loris-fork-deploy-key

sae-limon|components|loris-te|limon-loris-fork-user:
  git.config_set:
    - name: user.name
    - value: TE UI
    - repo: {{ git_repo_directory }}/{{ limon_env.loris["tgt_path"] }}
    - require:
      - git: sae-limon|components|loris-te|limon-loris-fork-repo

sae-limon|components|loris-te|limon-loris-fork-user-email:
  git.config_set:
    - name: user.email
    - value: te-ui@llnw.com
    - repo: {{ git_repo_directory }}/{{ limon_env.loris["tgt_path"] }}
    - require:
      - git: sae-limon|components|loris-te|limon-loris-fork-repo

sae-limon|components|loris-te|limon-autote-deploy-key:
  file.managed:
    - name: {{ git_repo_directory }}/{{ limon_env.loris["autote_rsa_path"] }}
    - user: {{ www_owner }}
    - group: {{ www_owner }}
    - mode: 400
    - contents_pillar: secrets:sae-limon:autote_deploy_key

sae-limon|components|loris-te|limon-autote-repo:
  git.latest:
    - name: {{ limon_env.loris["autote_repo"] }}
    - target: {{ git_repo_directory }}/{{ limon_env.loris["autote_path"] }}
    - user: {{ www_owner }}
    - branch: production
    - force_reset: true
    # Compare the git remote with the desired repo.  Update if different.
    - unless: diff  <(git -C {{ git_repo_directory }}/{{ limon_env.loris['autote_path'] }} config --get remote.origin.url | cat) <(echo "{{ limon_env.loris['autote_repo'] }}")
    - identity:
      - {{ git_repo_directory }}/{{ limon_env.loris["autote_rsa_path"] }}
    - require:
      - pkg: sae-limon|component|limon_backend|releases|pkg_prereq
      - file: sae-limon|components|loris-te|limon-autote-deploy-key


# SYMLINK TO COMMON REPOS, NO NEED TO DUPLICATE FOR EACH RELEASE
sae-limon|components|loris-te|{{ release_ver }}|src_path|symlink:
  file.symlink:
    - name: /var/www/limon2/backend/{{ release_ver }}/var/www/ui/{{ limon_env.loris["src_path"][0:-1] }}
    - target: {{ git_repo_directory}}/{{ limon_env.loris["src_path"][0:-1] }}
    - force: true
    - makedirs: true

sae-limon|components|loris-te|{{ release_ver }}|tgt_path|symlink:
  file.symlink:
    - name: /var/www/limon2/backend/{{ release_ver }}/var/www/ui/{{ limon_env.loris["tgt_path"][0:-1] }}
    - target: {{ git_repo_directory}}/{{ limon_env.loris["tgt_path"][0:-1] }}
    - force: true
    - makedirs: true

sae-limon|components|loris-te|{{ release_ver }}|autote_path|symlink:
  file.symlink:
    - name: /var/www/limon2/backend/{{ release_ver }}/var/www/ui/{{ limon_env.loris["autote_path"][0:-1] }}
    - target: {{ git_repo_directory}}/{{ limon_env.loris["autote_path"][0:-1] }}
    - force: true
    - makedirs: true
