{%- from slspath ~ "/map.jinja" import  limon_env %}
{%- set www_owner = "www-data" %}

sae-limon|components|loris-te|github_known_hosts:
  ssh_known_hosts.present:
    - name: github.llnw.net

sae-limon|components|loris-te|te-folder:
  file.directory:
    - name: /var/www/te
    - user: {{ www_owner }}
    - group: {{ www_owner }}
    - mode: 775

# TE UI
sae-limon|components|loris-te|limon-loris-base-path:
  file.directory:
    - name: {{ limon_env.loris["src_path"] }}
    - makedirs: True
    - user: {{ www_owner }}
    - group: {{ www_owner }}
    - dir_mode: 755
    - recurse:
      - user
      - group
      - mode

sae-limon|components|loris-te|limon-loris-deploy-key:
  file.managed:
    - name: {{ limon_env.loris["src_rsa_path"] }}
    - user: {{ www_owner }}
    - group: {{ www_owner }}
    - mode: 400
    - makedirs: true
    - contents_pillar: secrets:sae-limon:loris_deploy_key

sae-limon|components|loris-te|limon-loris-repo:
  git.latest:
    - name: {{ limon_env.loris["src_repo"] }}
    - target: {{ limon_env.loris["src_path"] }}
    - user: {{ www_owner }}
    - branch: master
    - force_reset: true
 # Compare the git remote with the desired repo.  Update if different.
    - unless: diff  <(git -C {{ limon_env.loris['src_path'] }} config --get remote.origin.url | cat) <(echo "{{ limon_env.loris['src_repo'] }}")
    - identity:
      - {{ limon_env.loris["src_rsa_path"] }}
    - require:
      - pkg: sae-limon|component|limon_backend|releases|pkg_prereq
      - file: sae-limon|components|loris-te|limon-loris-deploy-key


# LORIS FORK REPO
sae-limon|components|loris-te|limon-loris-fork-deploy-key:
  file.managed:
    - name: {{ limon_env.loris["tgt_rsa_path"] }}
    - user: {{ www_owner }}
    - group: {{ www_owner }}
    - mode: 400
    - contents_pillar: secrets:sae-limon:loris_fork_deploy_key

sae-limon|components|loris-te|limon-loris-fork-repo:
  git.latest:
    - name: {{ limon_env.loris["tgt_repo"] }}
    - target: {{ limon_env.loris["tgt_path"] }}
    - user: {{ www_owner }}
    - branch: master
    - force_reset: true
    # Compare the git remote with the desired repo.  Update if different.
    - unless: diff  <(git -C {{ limon_env.loris['tgt_path'] }} config --get remote.origin.url | cat) <(echo "{{ limon_env.loris['tgt_repo'] }}")
    - identity:
      - {{ limon_env.loris["tgt_rsa_path"] }}
    - require:
      - pkg: sae-limon|component|limon_backend|releases|pkg_prereq
      - file: sae-limon|components|loris-te|limon-loris-fork-deploy-key

sae-limon|components|loris-te|limon-loris-fork-user:
  git.config_set:
    - name: user.name
    - value: TE UI
    - repo: {{ limon_env.loris["tgt_path"] }}
    - require:
      - git: sae-limon|components|loris-te|limon-loris-fork-repo

sae-limon|components|loris-te|limon-loris-fork-user-email:
  git.config_set:
    - name: user.email
    - value: te-ui@llnw.com
    - repo: {{ limon_env.loris["tgt_path"] }}
    - require:
      - git: sae-limon|components|loris-te|limon-loris-fork-repo

sae-limon|components|loris-te|limon-autote-deploy-key:
  file.managed:
    - name: {{ limon_env.loris["autote_rsa_path"] }}
    - user: {{ www_owner }}
    - group: {{ www_owner }}
    - mode: 400
    - makedirs: true
    - contents_pillar: secrets:sae-limon:autote_deploy_key

sae-limon|components|loris-te|limon-autote-repo:
  git.latest:
    - name: {{ limon_env.loris["autote_repo"] }}
    - target: {{ limon_env.loris["autote_path"] }}
    - user: {{ www_owner }}
    - branch: production
    - force_reset: true
    # Compare the git remote with the desired repo.  Update if different.
    - unless: diff  <(git -C {{ limon_env.loris['autote_path'] }} config --get remote.origin.url | cat) <(echo "{{ limon_env.loris['autote_repo'] }}")
    - identity:
      - {{ limon_env.loris["autote_rsa_path"] }}
    - require:
      - pkg: sae-limon|component|limon_backend|releases|pkg_prereq
      - file: sae-limon|components|loris-te|limon-autote-deploy-key
