{%- from slspath ~ "/map.jinja" import limon_backend_configs, limon_env %}
{% from slspath ~ "/map.jinja" import limon_backend_configs %}

{%- set www_owner = "www-data" %}
{%- set release_ver = limon_backend_configs.active_release %}

# High queue will be installed in case role-limon.queue-high grain is present in Cornerstone.
# PS: Each host should have role-limon.queue-high enabled for correct service work.

{% if 'role-limon.queue-high' in salt['grains.get']('cornerstone:tags', {})|list %}
sae-limon|component|backend|limon-queue-high|runit:
  llnw_runit.present:
    - name: limon-queue-high
    - runas_user: {{ www_owner }}
    - runas_group: {{ www_owner }}
    - ulimit: 200000
    - command: {{ limon_backend_configs.php_bin }}
    - args:
      - "{{ limon_backend_configs.packages_dir }}/{{ release_ver }}/var/www/ui/artisan"
      - "queue:work"
      - "database"
      - "--tries=3"
      - "--sleep=3"
      - "--delay=0"
      - "--queue=high"
      - "--once"
    - svlogd: True
    - svlogd_dir: /var/log
    - svlogd_size: 50000000
    - svlogd_num: 10
    - svlogd_error: False
    - start: True
    - restart: False
    - default_down: False
    - require:
      - cmd: sae-limon|component|backend|{{ release_ver }}|extract-package
      - pkg: sae-limon|component|limon_backend|releases|pkg_prereq

sae-limon|component|backend|limon-queue-high|reload:
  llnw_runit.reload:
    - name: limon-queue-high
    - onchanges:
      - pkg: sae-limon|component|limon_backend|releases|pkg_prereq
      - file: sae-limon|node|dot_env
{% else %}
sae-limon|component|backend|limon-queue-high|remove:
  llnw_runit.absent:
    - name: limon-queue-high
{% endif %}

# Low queue will be installed in case role-limon.queue-low grain is present in Cornerstone.

{% if 'role-limon.queue-low' in salt['grains.get']('cornerstone:tags', {})|list %}
sae-limon|component|backend|limon-queue-low|runit:
  llnw_runit.present:
    - name: limon-queue-low
    - runas_user: www-data
    - runas_group: www-data
    - ulimit: 200000
    - command: {{ limon_backend_configs.php_bin }}
    - args:
      - "{{ limon_backend_configs.packages_dir }}/{{ release_ver }}/var/www/ui/artisan"
      - "queue:work"
      - "database"
      - "--tries=3"
      - "--sleep=3"
      - "--delay=0"
      - "--queue=low"
      - "--once"
    - svlogd: True
    - svlogd_dir: /var/log
    - svlogd_size: 50000000
    - svlogd_num: 10
    - svlogd_error: False
    - start: True
    - restart: False
    - default_down: False
    - require:
      - cmd: sae-limon|component|backend|{{ release_ver }}|extract-package
      - pkg: sae-limon|component|limon_backend|releases|pkg_prereq

sae-limon|component|backend|limon-queue-low|reload:
  llnw_runit.reload:
    - name: limon-queue-low
    - onchanges:
      - pkg: sae-limon|component|limon_backend|releases|pkg_prereq
      - file: sae-limon|node|dot_env
{% else %}
sae-limon|component|backend|limon-queue-low|remove:
  llnw_runit.absent:
    - name: limon-queue-low
{% endif %}

# Mails queue will be installed in case role-limon.queue-mails grain is present in Cornerstone

{% if 'role-limon.queue-mails' in salt['grains.get']('cornerstone:tags', {})|list %}
sae-limon|component|backend|limon-queue-mails|runit:
  llnw_runit.present:
    - name: limon-queue-mails
    - runas_user: www-data
    - runas_group: www-data
    - ulimit: 200000
    - command: {{ limon_backend_configs.php_bin }}
    - args:
      - "{{ limon_backend_configs.packages_dir }}/{{ release_ver }}/var/www/ui/artisan"
      - "queue:work"
      - "database"
      - "--tries=3"
      - "--queue=mails"
    - svlogd: True
    - svlogd_dir: /var/log
    - svlogd_size: 50000000
    - svlogd_num: 10
    - svlogd_error: False
    - start: True
    - restart: False
    - default_down: False
    - require:
      - cmd: sae-limon|component|backend|{{ release_ver }}|extract-package
      - pkg: sae-limon|component|limon_backend|releases|pkg_prereq

sae-limon|component|backend|limon-queue-mails|reload:
  llnw_runit.reload:
    - name: limon-queue-mails
    - onchanges:
      - pkg: sae-limon|component|limon_backend|releases|pkg_prereq
      - file: sae-limon|node|dot_env

{% else %}
sae-limon|component|backend|limon-queue-mails|remove:
  llnw_runit.absent:
    - name: limon-queue-mails
{% endif %}

# Loris queue will be installed in case role-limon.queue-loris grain is present in Cornerstone

{% if 'role-limon.queue-loris' in salt['grains.get']('cornerstone:tags', {})|list %}
sae-limon|component|backend|limon-queue-loris|runit:
  llnw_runit.present:
    - name: limon-queue-loris
    - runas_user: www-data
    - runas_group: www-data
    - ulimit: 200000
    - command: {{ limon_backend_configs.php_bin }}
    - args:
      - "{{ limon_backend_configs.packages_dir }}/{{ release_ver }}/var/www/ui/artisan"
      - "queue:work"
      - "database"
      - "--tries=3"
      - "--queue=loris"
    - svlogd: True
    - svlogd_dir: /var/log
    - svlogd_size: 50000000
    - svlogd_num: 10
    - svlogd_error: False
    - start: True
    - restart: False
    - default_down: False
    - require:
      - cmd: sae-limon|component|backend|{{ release_ver }}|extract-package
      - pkg: sae-limon|component|limon_backend|releases|pkg_prereq

sae-limon|component|backend|limon-queue-loris|reload:
  llnw_runit.reload:
    - name: limon-queue-loris
    - onchanges:
      - pkg: sae-limon|component|limon_backend|releases|pkg_prereq
      - file: sae-limon|node|dot_env
{% else %}
sae-limon|component|backend|limon-queue-loris|remove:
  llnw_runit.absent:
    - name: limon-queue-loris
{% endif %}