{% from "certs/map.jinja" import cert_path with context %}
{% from slspath ~ "/releases.jinja" import release, releases_raw, release_ver %}
{% from slspath ~ "/map.jinja" import limon_backend_configs %}
{%- from "sae-limon/limon-node/vs.sls" import state_version as node_vs %}
{%- from "sae-limon/limon-node/" + node_vs + "/environment.jinja" import environment, user, group  %}

# DEBUG configs: {{ limon_backend_configs }}

include:
  - firewall.standard
  - sae-limon.limon-node
  - certs.pem

{# ACTUAL SITE #}
{% for rv in releases_raw.releases_enabled %}
{%   set ab = limon_backend_configs.release_ab.get(rv, None) %}
{%   if ab %}
sae-limon|components|backend|limon_site|{{ rv }}:
  file.managed:
    - name: /etc/apache2/sites-available/limon2-backend-{{ ab }}.conf
    - source: salt://{{ slspath }}/templates/limon2-backend-site.conf.jinja
    - user: {{ user }}
    - group: {{ group }}
    - mode: 644
    - template: jinja
    - makedirs: true
    - context:
        port: {{ limon_backend_configs.release_ports[rv] }}
        rv: {{ rv }}
        ha_hostname: {{ limon_backend_configs.ha_hostname }}
        hostname: {{ grains['fqdn'] }}
        source_path: {{ limon_backend_configs.packages_dir }}/{{ rv }}/var/www
    - watch_in:
      - service: sae-limon|node|apache2
    - require_in:
      - service: sae-limon|node|apache2

# Limon backend configuration for Apache
sae-limon|components|backend|apache-a2ensite-limon2|{{ rv }}:
  apache_site.enabled:
    - name: limon2-backend-{{ ab }}
    - require_in:
      - service: sae-limon|node|apache2
    - require:
      - file: sae-limon|components|backend|limon_site|{{ rv }}
      - cmd: sae-limon|component|backend|{{ rv }}|extract-package

{# this file really shouldn't change unless the ports change #}
{%   set bind_on = limon_backend_configs.bind_on %}
{%   set bind_port = limon_backend_configs.release_ports[rv] %}
sae-limon|component|backend|haproxy|backend|{{ ab }}:
  file.managed:
    - name: /etc/haproxy/haproxy_limonbackend_{{ ab }}.cfg
    - makedirs: true
    - contents: |
        backend limon-backend-{{ ab }}
          mode http
          timeout connect 10000
          timeout server 305000
          option httpchk GET /release.txt
          balance roundrobin
          server lbs-{{ ab }} {{ bind_on }}:{{ bind_port }} check port {{ bind_port }} inter 1000 fall 2
    - watch_in:
      - service: sae-limon|node|haproxy|running
    - require_in:
      - service: sae-limon|node|haproxy|running
    - require:
      - pkg: sae-limon|node|haproxy

{%   endif %}
{% endfor %}

# NOTE: should bind on 127.0.0.1, unless things outside of UI need
# to access the backend.. TODO
sae-limon|component|backend|haproxy|frontend:
  file.managed:
    - name: /etc/haproxy/haproxy_limonbe_fe.cfg
    - makedirs: true
    - replace: true
    - contents:
      - " frontend limon-backend-expose"
      - "   bind *:{{ limon_backend_configs.publish_port }} ssl crt {{ cert_path.certdir }}/{{ cert_path.certname }}.pem"
      - "   timeout client 305000"
      - "   reqadd X-Forwarded-Proto:\\ https"
      - "   mode http"
      - "   # Add CORS Headers when Origin Header is present"
      - "   capture request header origin len 128"
      - "   http-response set-header Access-Control-Allow-Origin %[capture.req.hdr(0)] if { capture.req.hdr(0) -m found }"
      - "   rspadd Access-Control-Allow-Methods:\\ GET,\\ POST,\\ PUT,\\ DELETE if { capture.req.hdr(0) -m found }"
      - "   rspadd Access-Control-Allow-Credentials:\\ true if { capture.req.hdr(0) -m found }"
      - "   rspadd Access-Control-Allow-Headers:\\ Origin,\\ Accept,\\ X-Requested-With,\\ Content-Type,\\ Access-Control-Request-Method,\\ Access-Control-Request-Headers,\\ Authorization,\\ X-XSRF-TOKEN,\\ X-CSRF-TOKEN,\\ X-Requested-With  if { capture.req.hdr(0) -m found }"
      - "   default_backend limon-backend-{{ limon_backend_configs.active }}"
    - watch_in:
      - service: sae-limon|node|haproxy|running
    - require_in:
      - service: sae-limon|node|haproxy|running
    - require:
      - pkg: sae-limon|node|haproxy

# TODO, likely we dont' want the backend exposed from this host
# Open 8080 port for limon api backend
{% from "pepper/map.jinja" import netblocks %}
sae-limon|components|backend|backend-firewall-setup:
  firewall.accept:
    - tcp:
      - [8070, {{ netblocks }}]
      - [8081, {{ netblocks }}]
      - [8082, {{ netblocks }}]
      - [{{ limon_backend_configs.publish_port }}, {{ netblocks }}]
    - stateful: True
    - require_in:
      - firewall: core|firewall|final-reject
