{%- from "certs/map.jinja" import cert_path with context %}
{%- from "sae-limon/limon-node/vs.sls" import state_version as node_vs %}
{%- from "sae-limon/limon-node/" + node_vs + "/environment.jinja" import environment, user, group  %}

include:
  - firewall.standard
  - sae-limon.limon-node
  - certs.pem

{# ACTUAL SITE #}
sae-limon|components|backend|dev|limon-site:
  file.managed:
    - name: /etc/apache2/sites-available/limon2-backend-dev.conf
    - source: salt://{{ slspath }}/templates/limon2-backend-site-dev.conf.jinja
    - user: {{ user }}
    - group: {{ group }}
    - mode: 644
    - template: jinja
    - makedirs: true
    - replace: false
    - context:
        port: 8081
        rv: dev
        hostname: {{ grains['fqdn'] }}
        source_path: /var/www/dev/limon-backend/public
    - watch_in:
      - service: sae-limon|node|apache2
    - require_in:
      - service: sae-limon|node|apache2

# Limon backend configuration for Apache
sae-limon|components|backend|dev|apache|a2ensite-limon-backend:
  apache_site.enabled:
    - name: limon2-backend-dev
    - require_in:
      - service: sae-limon|node|apache2
    - require:
      - file: sae-limon|components|backend|dev|limon-site
      - cmd: sae-limon|components|backend|dev|install-vendor-dependencies

# NOTE: should bind on 127.0.0.1, unless things outside of UI need
# to access the backend.. TODO
sae-limon|component|backend|dev|haproxy-cfg:
  file.managed:
    - name: /etc/haproxy/haproxy_limon_backend_dev.cfg
    - makedirs: true
    - contents:
      - " listen limon-backend-dev"
      - "   bind *:8080 ssl crt {{ cert_path.certdir }}/{{ cert_path.certname }}.pem"
      - "   timeout client 305000"
      - "   reqadd X-Forwarded-Proto:\\ https"
      - "   mode http"
      - "   # Add CORS Headers when Origin Header is present"
      - "   capture request header origin len 128"
      - "   http-response set-header Access-Control-Allow-Origin %[capture.req.hdr(0)] if { capture.req.hdr(0) -m found }"
      - "   rspadd Access-Control-Allow-Methods:\\ GET,\\ POST,\\ PUT,\\ DELETE if { capture.req.hdr(0) -m found }"
      - "   rspadd Access-Control-Allow-Credentials:\\ true if { capture.req.hdr(0) -m found }"
      - "   rspadd Access-Control-Allow-Headers:\\ Origin,\\ Accept,\\ X-Requested-With,\\ Content-Type,\\ Access-Control-Request-Method,\\ Access-Control-Request-Headers,\\ Authorization,\\ X-XSRF-TOKEN,\\ X-CSRF-TOKEN,\\ X-Requested-With  if { capture.req.hdr(0) -m found }"
      - "   server server2 127.0.0.1:8081 maxconn 32"
    - watch_in:
      - service: sae-limon|node|haproxy|running
    - require_in:
      - service: sae-limon|node|haproxy|running
    - require:
      - pkg: sae-limon|node|haproxy

# TODO, likely we dont' want the backend exposed from this host
# Open 8080 port for limon api backend
{% from "pepper/map.jinja" import netblocks %}
sae-limon|components|backend|dev|backend-firewall-setup:
  firewall.accept:
    - tcp:
      - [8080, {{ netblocks }}]
      - [8081, {{ netblocks }}]
    - stateful: True
    - require_in:
      - firewall: core|firewall|final-reject
