{%- from slspath ~ "/map.jinja" import <component>_configs, base %}
{%- from slspath ~ "/releases.jinja" import release, release_ver %}

{%- if "enabled" in salt["grains.get"]("agentd_logging", "") %}
include:
  - storage-agentd
{%- endif %}

limon|component|<component>|directories:
  file.directory:
    - user: {{ base.user }}
    - group: {{ base.roup }}
    - dir_mode: 755
    - file_mode: 640
    - makedirs: True
    - names:
      - {{ base.config_dir }}/<component>
      - /var/run/limon/<component>
    - recurse:
      - user
      - group
      - mode

{%- for pkgname, pkgver in release[ release_ver ]["main"].iteritems() %}
limon|component|<component>|package|{{ pkgname }}:
{%-   if pkgver == "latest" %}
  pkg.latest:
    - name: {{ pkgname }}
{%-   else %}
  pkg.installed:
    - name: {{ pkgname }}
    - version: {{ pkgver }}
{%-   endif %}
{%- endfor %}


# Alternative package deployment using agile storage and a custom module # 
{#- note, staging and prod are set to 'dev' for now, since we have no escalation path with qa/scripts atm #}
{%- set pkg_tr = {"dynamic": "dev", "dev": "dev", "qa": "dev", "staging": "dev", "production": "dev"} %}
limon|component|<component>|package:
  storage_pkg.installed:
    - pkgs:
{%-   for pkgname, pkgver in release[ release_ver ]["main"].iteritems() %}
{%-     if pkgver == "latest" %}
      - {{ pkgname }}
{%-     else %}
      - {{ pkgname }}: {{ pkgver }}
{%-     endif %}
{%   endfor %}
    - host: global.mt.lldns.net
    - location: /llnwstor/secure/packages/
    - team_env: {{ pkg_tr[grains.get("team_env", "production")] }}


# this can also be 'file.managed', but dot_configs is part of lconfig.
limon|component|<component>|config:
  lconfig.managed:
    - name: {{ <component>_configs.config_file }}
    - source: salt://{{ slspath }}/templates/<component>.yaml.jinja
    - template: jinja
    - mode: 640
    - user: {{ base.user }}
    - group: {{ base.group }}
    - context:
       base: {{ base }}
       <component>_configs: {{ <component>_configs }}
    - dot_configs: {{ <component>_configs.configs }}
    - require:
      - file: limon|component|<component>|directories

# CONFIGURE RUNIT
{# FOR TESTING, if the 'testing' config exists, use that instead #}
{%- set runit_config_file = {{ <component>_configs.config_file }} %}
{%- set runit_service_name = "limon-<component>" %}
{%- if salt['file.file_exists'](base.config_dir + "/<component>-testing.yaml") %}
{%-   set runit_config_file = base.config_dir + "/<component>-testing.yaml" %}
{%- endif %}
{%- if salt['file.file_exists'](base.config_dir + "/<component>-testing-" + release_ver + ".yaml") %}
{%-   set runit_config_file = base.config_dir + "/<component>-testing-" + release_ver + ".yaml" %}
{%- endif %}
limon|component|<component>|runit:
  llnw_runit.present:
    - name: {{ runit_service_name }}
    - precmds: "export GOMAXPROCS=2"
    - runas_user: {{ base.user }}
    - runas_group: {{ base.group }}
    - ulimit: 200000
    - command: /usr/local/limon/<component>-{{ release_ver }}/bin/<component>
    - args:
      - "-c {{ runit_config_file }}"
      - "-l info"
    - svlogd: True
    - svlogd_dir: {{ base.log_dir }}
    - svlogd_size: 409600000
    - svlogd_num: 10
    - svlogd_error: True
    - start: True
    - restart: True
    - default_down: False
    - require:
      - pkg: limon|component|<component>|package
      - lconfig: limon|component|<component>|config
      - file: limon|component|<component>|directories

# RESTART COMPONENT IF OUR CONFIG CHANGES
limon|component|<component>|restart:
  llnw_runit.restart:
    - name: {{ runit_service_name }}
    - onchanges:
      - lconfig: limon|component|<component>|config
      - file: limon|component|<component>|certificate
      - file: limon|component|<component>|certificate_key

{% if "enabled" in salt["grains.get"]("agentd_logging", "") %}
{%   from "storage-agentd/macros.jinja" import agentd_log %}
{{   agentd_log("limon", "<component>", base.log_dir + "/{{ runit_service_name }}/*") }}
{% endif %}
