{%- from "certs/map.jinja" import cert_path with context %}
{%- from slspath ~ "/releases.jinja" import release, releases_raw, release_ver %}
{%- from slspath ~ "/map.jinja" import limon_frontend_configs %}

# DEBUG limon_frontend_configs {{ limon_frontend_configs }}

include:
  - firewall.standard
  - sae-limon.limon-node
  - certs.pem

{# ACTUAL SITE #}
{%- for rv in releases_raw.releases_enabled %}
{%-   set ab = limon_frontend_configs.release_ab[rv] %}
sae-limon|components|frontend|limon_site|{{ rv }}:
  file.managed:
    - name: /etc/apache2/sites-available/limon2-ui-{{ ab }}.conf
    - source: salt://{{ slspath }}/templates/limon2-ui-site.conf.jinja
    - user: www-data
    - group: www-data
    - mode: 644
    - template: jinja
    - makedirs: true
    - context:
        port: {{ limon_frontend_configs.release_ports[rv] }}
        rv: {{ rv }}
        ha_hostname: {{ limon_frontend_configs.ha_hostname }}
        hostname: {{ grains['fqdn'] }}
        source_path: {{ limon_frontend_configs.packages_dir }}/{{ rv }}/var/www
    - watch_in:
      - service: sae-limon|node|apache2
    - require:
      - cmd: sae-limon|component|frontend|{{ rv }}|extract-package

# Limon frontend configuration for Apache
sae-limon|components|frontend|apache-a2ensite-limon2-ui|{{ rv }}:
  apache_site.enabled:
    - name: limon2-ui-{{ ab }}
    - watch_in:
      - service: sae-limon|node|apache2
    - require:
      - file: sae-limon|components|frontend|limon_site|{{ rv }}

sae-limon|components|frontend|apache|{{ ab }}|reload:
  cmd.run:
    - name: service apache2 reload
    - watch:
      - file: sae-limon|components|frontend|limon_site|{{ rv }}

{# this file really shouldn't change unless the ports change #}
{%-   set bind_port = limon_frontend_configs.release_ports[rv] %}
sae-limon|component|frontend|haproxy|frontend|{{ ab }}:
  file.managed:
    - name: /etc/haproxy/haproxy_limonfe_be_{{ ab }}.cfg
    - makedirs: true
    - contents: |
        backend limon-frontend-{{ ab }}
          mode http
          timeout connect 10000
          timeout server 305000
          option httpchk GET /release.txt
          balance roundrobin
          server lfs-{{ ab }} 127.0.0.1:{{ bind_port }} check port {{ bind_port }} inter 1000 fall 2
    - require:
      - service: sae-limon|node|apache2
      - pkg: sae-limon|node|haproxy
      - file: sae-limon|components|frontend|limon_site|{{ rv }}

sae-limon|component|frontend|haproxy|{{ ab }}|reload:
  cmd.run:
    - name: service haproxy reload
    - watch:
      - file: sae-limon|component|frontend|haproxy|frontend|{{ ab }}
    - require:
      - pkg: sae-limon|node|haproxy
{% endfor %}

sae-limon|component|frontend|haproxy|frontend:
  file.managed:
    - name: /etc/haproxy/haproxy_limonfe_fe.cfg
    - makedirs: true
    - contents: |
        frontend limon-frontend-expose
          bind *:80
          bind *:443 ssl crt {{ cert_path.certdir }}/{{ cert_path.certname }}.pem
          mode http
          redirect scheme https code 301 if !{ ssl_fc }
          timeout client 305000
          default_backend limon-frontend-{{ limon_frontend_configs.active }}
    - require:
      - pkg: sae-limon|node|haproxy

{# FOR FIRST RUNS, ENSURE THE SERVICE IS STARTED #} 
sae-limon|component|frontend|haproxy:
  service.running:
    - name: haproxy
    - require:
      - pkg: sae-limon|node|haproxy
      - service: sae-limon|node|haproxy|running

{# THIS ACTUALLY SWITCHES #}
sae-limon|component|frontend|haproxy|switch:
  cmd.run:
    - name: service haproxy reload
    - watch:
      - file: sae-limon|component|frontend|haproxy|frontend
    - require:
      - pkg: sae-limon|node|haproxy
      - file: sae-limon|component|frontend|haproxy|frontend
      - file: sae-limon|component|frontend|haproxy|frontend|{{ limon_frontend_configs.active }}
      - file: sae-limon|components|frontend|limon_site|{{ release_ver }}
      
{% from "pepper/map.jinja" import netblocks %}
sae-limon|components|frontend|frontend-firewall-setup:
  firewall.accept:
    - tcp:
      - [443, {{ netblocks }}]
      - [80, {{ netblocks }}]
    - stateful: True
    - require_in:
      - firewall: core|firewall|final-reject
