{%- from "certs/map.jinja" import cert_path with context %}

include:
  - firewall.standard
  - sae-limon.limon-node
  - certs.pem

sae-limon|components|frontend|dev|limon-site:
  file.managed:
    - name: /etc/apache2/sites-available/limon2-frontend-dev.conf
    - source: salt://{{ slspath }}/templates/limon2-ui-site-dev.conf.jinja
    - user: www-data
    - group: www-data
    - mode: 644
    - template: jinja
    - makedirs: true
    - replace: false
    - context:
        port: 8181
        rv: dev
        fe_path: /var/www/dev/limon-frontend/dist
        be_path: /var/www/dev/limon-backend
    - watch_in:
      - service: sae-limon|node|apache2
    - require_in:
      - service: sae-limon|node|apache2

# Limon frontend configuration for Apache
sae-limon|components|frontend|dev|apache|a2ensite-limon2-ui:
  apache_site.enabled:
    - name: limon2-frontend-dev
    - require_in:
      - service: sae-limon|node|apache2
    - require:
      - file: sae-limon|components|frontend|dev|limon-site
      - cmd: sae-limon|components|frontend|dev|build-repo

sae-limon|component|frontend|dev|haproxy|frontend:
  file.managed:
    - name: /etc/haproxy/haproxy_limon_frontend_dev.cfg
    - makedirs: true
    - contents: |
        listen limon-dev-frontend
          bind *:80
          bind *:443 ssl crt {{ cert_path.certdir }}/{{ cert_path.certname }}.pem
          mode http
          redirect scheme https code 301 if !{ ssl_fc }
          timeout client 305000
          server server1 127.0.0.1:8181 maxconn 32
    - watch_in:
      - service: sae-limon|node|haproxy|running
    - require_in:
      - service: sae-limon|node|haproxy|running
    - require:
      - pkg: sae-limon|node|haproxy

{% from "pepper/map.jinja" import netblocks %}
sae-limon|components|frontend|frontend-firewall-setup:
  firewall.accept:
    - tcp:
      - [443, {{ netblocks }}]
      - [80, {{ netblocks }}]
    - stateful: True
    - require_in:
      - firewall: core|firewall|final-reject
