{% from slspath ~ '/map.jinja' import limon_configs %}

sae-limon|node|haproxy:
  pkg.installed:
    - name: haproxy
{%- if grains['oscodename'] == 'bionic' %}
    - version: 1.8.8-1ubuntu0.9
{%- else %}
    - version: 1.6.14-1ppa1~trusty
{%- endif %}

sae-limon|node|haproxy|enable:
  file.managed:
    - name: /etc/default/haproxy
    - user: root
    - group: root
    - mode: 644
    - contents:
      - ENABLED=1
{%- if grains['oscodename'] == 'bionic' %}
      - EXTRAOPTS="-f /etc/haproxy"
{%- else %}
      - EXTRAOPTS=$(for i in `find /etc/haproxy/haproxy_*.cfg -type f`; do echo -n "-f $i "; done)
{%- endif %}
    - require:
      - pkg: sae-limon|node|haproxy


# LOGGING (precise has syslog-ng, xenial and future have rsyslog)
{%- set has_syslog_ng = salt['service.available']('syslog-ng') %}
{%- set has_rsyslog = salt['service.available']('rsyslog') %}
sae-limon|node|haproxy|logging|socket_dir:
  file.directory:
    - name: /var/lib/haproxy/dev
    - user: haproxy
    - group: haproxy
    - makedirs: True

{%- if has_syslog_ng %}
# sets up the syslog-ng socket for collecting logs like rsyslog
sae-limon|node|haproxy|logging|syslog:
  file.managed:
    - name: /etc/syslog-ng/conf.d/haproxy.conf
    - source: salt://{{ slspath }}/files/syslog_haproxy.conf
    - user: root
    - mode: 644

sae-limon|node|haproxy|logging|rotate:
  file.managed:
    - name: /etc/logrotate.d/syslog-ng-haproxy
    - source: salt://{{ slspath }}/files/logrotate-haproxy-log.conf
    - user: root
    - mode: 644

sae-limon|node|haproxy|logging|syslog-ng|restart:
  service.running:
    - name: syslog-ng
    - reload: true
    - watch:
      - file: sae-limon|node|haproxy|logging|syslog
{%- endif %}
{%- if has_rsyslog %}
# IF we have rsyslog, likely we installed rsyslog before haproxy, and such
# rsyslog didn't see the /var/lib/haproxy/dev directory, so it never
# setup the dgram socket.  reloading fixes this.
{%-   if not salt['file.find']('/var/lib/haproxy/dev/log', type='s') %}
sae-limon|node|haproxy|logging|rsyslog|socket:
  file.exists:
    - name: /var/lib/haproxy/dev/log


# can't reload, rsyslog only supports force-reload and restart
sae-limon|node|haproxy|logging|rsyslog|restart:
  cmd.run:
    - name: service rsyslog restart
    - onfail:
      - file: sae-limon|node|haproxy|logging|rsyslog|socket
{%-   endif %}
{%- endif %}


{% if salt['grains.get']('haproxy-stats', '') == 'enabled' %}
sae-limon|node|haproxy|enable-stats|config:
  file.accumulated:
    - name: haproxy-listens
    - filename: /etc/haproxy/haproxy.cfg
    - text: |
        # HAPROXY STATS ENABLED
        listen  stats
          bind            0.0.0.0:{{ limon_configs.haproxy_stats.port }}
          mode            http
          log             global
          option httplog
          maxconn 10
          timeout client  100s
          timeout server  100s
          timeout connect 100s
          timeout queue   100s
          stats enable
          stats hide-version
          stats refresh 30s
          stats show-node
          stats auth {{ limon_configs.haproxy_stats.username }}:{{ limon_configs.haproxy_stats.password }}
          stats uri  /haproxy?stats
    - require_in:
      - file: sae-limon|node|haproxy|config
{% endif %}

sae-limon|node|haproxy|config:
  file.managed:
    - name: /etc/haproxy/haproxy.cfg
    - source: salt://{{ slspath }}/templates/haproxy.cfg.jinja
    - template: jinja

sae-limon|node|haproxy|running:
  service.running:
    - name: haproxy
    - enable: True
    - reload: True
    - watch:
      - file: sae-limon|node|haproxy|config
    - require:
      - pkg: sae-limon|node|haproxy

{% from "pepper/map.jinja" import netblocks %}
sae-limon|node|haproxy-stats-expose:
  firewall.accept:
    - tcp:
      - [{{ limon_configs.haproxy_stats.port }}, {{ netblocks }}]
    - stateful: True
    - require_in:
      - firewall: core|firewall|final-reject
