# vim: sts=2 ts=2 sw=2 et ai syntax=yaml

# Install additional dev-dependencies
sae|limon|limon-dev-pkgs:
  pkg.latest:
    - names:
      - mysql-server
{%- if grains['oscodename'] == 'bionic' %}
      - python-mysqldb
      - runit-systemd
{%- endif %}
      - php7.0
      - git
    - skip_verify: True

sae|limon|limon-dev-go:
  archive.extracted:
    - name: /usr/local
    - source: https://dl.google.com/go/go1.12.5.linux-amd64.tar.gz
    - source_hash: aea86e3c73495f205929cfebba0d63f1382c8ac59be081b6351681415f4063cf
    - trim_output: 0
    - if_missing: /usr/local/go

sae|limon|limon-dev-go-path:
  file.append:
    - name: /etc/profile
    - text:
      - export PATH=$PATH:/usr/local/go/bin

sae|limon|node|limon-dev-go-log-path:
  file.directory:
    - name: /var/log/rts-dash-backend/glog
    - makedirs: True
    - user: www-data
    - group: www-data
    - dir_mode: 755

sae|limon|limon-dev-script:
  file.managed:
    - name: /usr/local/bin/limon-dev-env.sh
    - user: root
    - group: root
    - mode: 755
    - contents:
      - "#!/bin/sh"
      - "alias log=\"tail -f /var/log/limon/backend/laravel.log\""
      - "alias mysqlr=\"mysql -uroot\""
      - "salt-call grains.set limon:rts-dash-backend:dev_exe $HOME/rts-dash-backend/rts-dash-backend"

# Install Composer
sae|limon|install-composer:
  cmd.run:
    - name: "curl -sS https://getcomposer.org/installer | sudo php -- --install-dir=/usr/local/bin --filename=composer"
    - unless: test -f /usr/local/bin/composer
    - require:
      - pkg: sae|limon|limon-dev-pkgs

# Install Node.js (npm)
sae|limon|nodejs:
  cmd.run:
    - name: "curl -L https://raw.githubusercontent.com/tj/n/master/bin/n | sudo bash -s -- 11.6.0"
    - unless: test -d /usr/local/n/versions/node/11.6.0
    - require:
      - pkg: sae|limon|limon-dev-pkgs

# Install Yarn
sae|limon|yarn-pkg:
  pkgrepo.managed:
    - name: deb https://dl.yarnpkg.com/debian/ stable main
    - file: /etc/apt/sources.list.d/yarn.list
    - key_url: https://dl.yarnpkg.com/debian/pubkey.gpg
    - require: # Required?
      - cmd: sae|limon|nodejs

sae|limon|install-yarn:
  pkg.installed:
    - pkgs:
      - yarn
    - require:
      - pkgrepo: sae|limon|yarn-pkg
