{%- set a_release = salt["grains.get"]("limon-frontend:instance_A:release") %}
{%- set b_release = salt["grains.get"]("limon-frontend:instance_B:release") %}
{%- from slspath ~ "/environment.jinja" import environment, user, group %}

{% set tstamp = salt["cmd.run"]("date +%Y_%m_%d") %}

sae-limon|node|apache2|pkg:
  pkg.latest:
    - name: apache2

# www-data for all env or vagrant for dynamic env
sae-limon|node|limon-user:
  group.present:
    - name: {{ group }}
  user.present:
    - name: {{ user }}
    - groups:
      - {{ group }}
    - createhome: False
    - shell: /bin/bash
    - require:
      - pkg: sae-limon|node|apache2|pkg

sae-limon|node|apache2|dir-perms:
  file.directory:
    - name: /var/www
    - user: {{ user }}
    - group: {{ group }}
    - mode: 750

{% if environment in ["dynamic", "dev"] %}
sae-limon|node|apache2|dev|dir-perms:
  file.directory:
    - name: /var/www/dev
    - user: {{ user }}
    - group: {{ group }}
    - mode: '775'
    - makedirs: True
{% endif %}

# EMPTY FILE /etc/apache2/ports.conf
sae-limon|node|apache2|no-port-80:
  file.managed:
    - name: /etc/apache2/ports.conf
    - contents: ""

# Disable PHP5, not used
sae|limon|apache-a2dismod:
  apache_module.disabled:
    - name: php5
    - watch_in:
      - service: sae-limon|node|apache2

# disable default site
sae-limon|node|apache-a2dissite-default:
  cmd.run:
    - name: a2dissite 000-default
    - onlyif: test -L /etc/apache2/sites-enabled/000-default.conf
    - watch_in:
      - service: sae-limon|node|apache2

{% for mod in ['rewrite', 'headers'] %}
sae-limon|node|apache-a2enmod-{{ mod }}:
  apache_module.enabled:
    - name: {{ mod }}
    - watch_in:
      - service: sae-limon|node|apache2
    - require:
      - pkg: sae-limon|node|apache2|pkg
{% endfor %}

sae-limon|node|apache2:
  service.running:
    - name: apache2
    - reload: True
    - require:
      - pkg: sae-limon|node|apache2|pkg

{% if environment in ["dynamic"] %}

# Adding vagrant user & group for dynamic env
sae-limon|node|apache2|user:
  file.replace:
    - name: /etc/apache2/envvars
    - pattern: 'APACHE_RUN_USER=www-data'
    - repl: 'APACHE_RUN_USER=vagrant'
    - show_changes: True
    - require:
      - service: sae-limon|node|apache2

sae-limon|node|apache2|group:
  file.replace:
    - name: /etc/apache2/envvars
    - pattern: 'APACHE_RUN_GROUP=www-data'
    - repl: 'APACHE_RUN_GROUP=vagrant'
    - show_changes: True
    - require:
      - service: sae-limon|node|apache2

{% endif %}

# php.ini managed by salt
sae-limon|node|apache2|config:
  file.managed:
    - name: /etc/php/7.0/apache2/php.ini
    - source: salt://{{ slspath }}/templates/php.ini.jinja
    - template: jinja

# Open extra ports
{% set portList = salt['grains.get']('limon-node:portList', []) %}
{% if portList|length > 0 and environment in ["dynamic", "dev"] %}
{% from "pepper/map.jinja" import netblocks %}
sae-limon|node|ports-expose:
  firewall.accept:
    - tcp:
{%    for port in portList %}
      - [{{ port }}, {{ netblocks }}]
{%    endfor %}
    - stateful: True
    - require_in:
      - firewall: core|firewall|final-reject
{% endif %}

{% if environment in ["production", "staging"] %}
# failover.txt for both release_A & release_B

{% if not salt['file.path_exists_glob']('/var/www/limon2/frontend/%s/var/www/limon-ui/failover.txt*' % a_release) %}
sae-limon|node|apache2|failovertxt_A:
  file.managed:
    - name: /var/www/limon2/frontend/{{ a_release }}/var/www/limon-ui/failover.txt.{{ tstamp }}
    - user: {{ user }}
    - group: {{ group }}
    - mode: '0644'
{%- endif %}

{% if not salt['file.path_exists_glob']('/var/www/limon2/frontend/%s/var/www/limon-ui/failover.txt*' % b_release) %}
sae-limon|node|apache2|failovertxt_B:
  file.managed:
    - name: /var/www/limon2/frontend/{{ b_release }}/var/www/limon-ui/failover.txt.{{ tstamp }}
    - user: {{ user }}
    - group: {{ group }}
    - mode: '0644'
{%- endif %}

{% endif %}