{% from slspath ~ '/properties.yaml' import haproxy with context %}

include:
  - firewall.standard
  - sae-sudoers.loci-admins
  - sae-sudoers.OpsEngGroup
  - sysctl.ipv6_disable
  - openssh

{% if "sox-in-scope" in salt['grains.get']('cornerstone:tags', {}) %}
sae|loci|haproxy|sshd-config:
  file.accumulated:
    - name: extra_sshd_config
    - filename: /etc/ssh/sshd_config
    - text: | # Allow only these groups to login due to SOX restrictions
              AllowGroups posix-sox-loci-admin posix-sox-loci-user OpsEngGroup
    - require_in:
      - file: core|openssh|sshd-config
{% endif %}


# Install haproxy package
sae|loci|haproxy|install:
  pkg.installed:
    - name: haproxy
    - version: 1.6.3-1

# Create haproxy workirs
sae|loci|haproxy|workdirs:
  file.directory:
    - names:
      - /etc/haproxy
      - /etc/haproxy/errors
    - makedirs: True
    - user: root
    - group: root
    - mode: 755

# Copy haproxy config files
sae|loci|haproxy|haproxy_cfg_file:
  file.managed:
    - names:
      - /etc/haproxy/haproxy.cfg
    - source:
      - salt://{{ slspath }}/files/haproxy.cfg
    - makedirs: True

sae|loci|haproxy|llnw_ip_block_file:
  file.managed:
    - names:
      - /etc/haproxy/llnw_ip_blocks
    - source:
      - salt://{{ slspath }}/files/llnw_ip_blocks
    - makedirs: True

# Create HAProxy PEM file
sae|loci|haproxy|haproxy_pem_file:
  file.managed:
    - name: /etc/haproxy/haproxy.pem
    - contents_pillar: secrets:sae-loci:loci-haproxy-pem-2022

# Check HAProxy config file
sae|loci|haproxy|check_file:
  cmd.wait:
    - name: sudo haproxy -f /etc/haproxy/haproxy.cfg -c
    - watch:
      - file: sae|loci|haproxy|haproxy_cfg_file
      - file: sae|loci|haproxy|llnw_ip_block_file

# Copy rsyslog file
sae|loci|haproxy|rsyslog:
  file.managed:
    - name: /etc/rsyslog.d/49-haproxy.conf
    - source: salt://{{ slspath }}/files/49-haproxy.conf
    - makedirs: True

# Create haproxy logdir
sae|loci|haproxy|logdir:
  file.directory:
    - name: /var/log/haproxy
    - makedirs: True
    - user: root
    - group: root
    - mode: 755

# Add logrotate
sae|loci|haproxy|logrotate:
  file.managed:
    - name: /etc/logrotate.d/haproxy
    - contents: |
       /var/log/haproxy*.log 
        {
          copytruncate
          daily
          rotate 20
          size 50M
          compress
          delaycompress
          missingok
          notifempty
        }

# Start haproxy service
sae|loci|haproxy|haproxy_start:
  service.running:
    - enable: True
    - name: haproxy.service
    - watch:
      - pkg: sae|loci|haproxy|install
      - cmd: sae|loci|haproxy|check_file

# Restart rsyslog service
sae|loci|haproxy|rsyslog_start:
  service.running:
    - enable: True
    - name: rsyslog.service
    - watch:
      - file: sae|loci|haproxy|logrotate
      - file: sae|loci|haproxy|rsyslog

# Firewall
sae|loci|haproxy|firewall|haproxy_base_ports:
  firewall.accept:
    - tcp:
      - 80
      - 443
    - stateful: True
    - require_in:
      - firewall: core|firewall|final-reject

sae|loci|haproxy|firewall|haproxy_ui_access:
  firewall.accept:
    - tcp:
      - ["22002",{{ haproxy.base_acl_blocks }}]
    - stateful: True
    - require_in:
      - firewall: core|firewall|final-reject
