{% from slspath ~ '/map.jinja' import settings with context %}
{% from 'nginx/map.jinja' import sslvhost with context %}

include:
  - sae-sudoers.loci-admins
  - proxy
  - certs
  - nginx
  - sysctl.ipv6_disable
  - .packages
{% if salt['grains.get']('team_env', '') in ['production'] %}
  - .loci-access.sox-openssh
{% endif %}


{% load_yaml as locations_yaml %}
- path: /
  static: /var/www/loci.llnw.com/app/static
  proxy: http://127.0.0.1:3000
  file: $uri/
- path: /api/
  static: /var/www/loci.llnw.com/app/static
  proxy: http://127.0.0.1:3000
{% endload %}

{{ sslvhost("loci", {
    'oscp_staple': False,
    'names': ['loci.llnw.com'],
    'locations': locations_yaml })
}}


sae|loci|basemap_install:
  cmd.run:
    - name: |
        if [ -d /usr/local/basemap-1.1.0/geos-3.3.3 ] && [ ! -h /usr/lib/x86_64-linux-gnu/libgeos-3.3.3.so ]; then
          export GEOS_DIR=/usr/local
          cd /usr/local/basemap-1.1.0/geos-3.3.3
          ./configure --prefix=$GEOS_DIR
          make
          make install
          cd /usr/local/basemap-1.1.0
          python3 setup.py install
          cd /usr/lib/x86_64-linux-gnu
          ln -s /usr/local/lib/libgeos-3.3.3.so
        fi
    - shell: /bin/bash
    - timeout: 300
    - require:
      - sae|loci|loci-package

# Setting up Oracle Instantclient
sae|loci|loci-oracle-instantclient:
  file.managed:
    - name: /etc/ld.so.conf.d/oracle-instantclient.conf
    - user: root
    - group: root
    - mode: 644
    - source: salt://{{ slspath }}/templates/oracle-instantclient.conf

sae|loci|loci-oracle-instantclient_install:
  file.symlink:
    - name: /usr/lib/oracle/12.1/client64/lib/libclntsh.so
    - target: /usr/lib/oracle/12.1/client64/lib/libclntsh.so.12.1
    - user: loci-dev
    - group: nogroup
    - mode: 644
    - require:
      - sae|loci|loci-dev-user
      - sae|loci|loci-oracle-instantclient

sae|loci|ldconfig:
  cmd.run:
    - name: ldconfig
    - onchanges:
      - sae|loci|loci-oracle-instantclient
      - sae|loci|loci-oracle-instantclient_install

# Base directory for logs
sae|loci|log-directory:
  file.directory:
    - name: /var/log/loci
    - user: loci-dev
    - group: nogroup
    - mode: 755
    - require:
      - sae|loci|loci-dev-user

# Configuration file for loci
sae|loci|loci-config:
  file.managed:
    - name: /usr/share/loci/app/config.py
    - user: loci-dev
    - group: nogroup
    - mode: 640
    - template: jinja
    - source: salt://{{ slspath }}/templates/config.py.jinja
    - context:
        settings: {{ settings|json }}
    - require:
      - sae|loci|loci-dev-user

# Setting up Gunicorn
sae|loci|loci-gunicorn:
  file.managed:
    - name: /usr/local/bin/gunicorn
    - user: loci-dev
    - group: nogroup
    - mode: 700
    - source: salt://{{ slspath }}/templates/gunicorn
    - require:
      - sae|loci|loci-dev-user

# loci userc
sae|loci|loci-dev-user:
  user.present:
    - name: loci-dev
    - empty_password: True
    - groups:
      - www-data

# Access log
sae|loci|access-log:
  file.managed:
    - name: /var/log/loci/access.log
    - user: loci-dev
    - group: nogroup
    - require:
      - sae|loci|loci-dev-user
      - sae|loci|log-directory

# Error log
sae|loci|error-log:
  file.managed:
    - name: /var/log/loci/error.log
    - user: loci-dev
    - group: nogroup
    - require:
      - sae|loci|loci-dev-user
      - sae|loci|log-directory

sae|loci|logrotate-conf:
  file.managed:
    - name: /etc/logrotate.d/loci    
    - makedirs: True           
    - contents: |
        /var/log/loci/access.log /var/log/loci/error.log {
          rotate 14
          daily
          create 0644 loci-dev nogroup
          sharedscripts
          postrotate
            kill -USR1 $(systemctl show -p MainPID loci.service 2>/dev/null | cut -d= -f2)
          endscript
        } 
    - require:
      - sae|loci|access-log
      - sae|loci|error-log

sae|loci|service-loci-enabled:
  service.enabled:
    - name: loci

sae|loci|service-loci-running:
  service.running:
    - reload: True
    - enable: True
    - names:
      - loci
    - onchanges:
      - sae|loci|loci-package
      - sae|loci|loci-config
      - sae|loci|loci-gunicorn
