{% from 'pepper/map.jinja' import netblocks %}

include:
  - sae-lxvm.base
  - firewall.standard
  - firewall.web

sae|lxvm|metrics-pkg:
  pkg.latest:
    - names:
      - lxvm-metrics
    - skip_verify: True
    - require:
      - pkgrepo: sae|lxvm|repo
    - watch_in:
      - service: sae|lxvm|metrics

sae|lxvm|metrics-apache:
  file.managed:
    - name: /etc/apache2/sites-available/lxvm-metrics.conf
    - source: salt://sae-lxvm/files/admin/lxvm-metrics.conf
    - require:
      - pkg: sae|lxvm|metrics-pkg
    - watch_in:
      - service: sae|lxvm|apache2

sae|lxvm|a2dissite-default:
  cmd.run:
    - name: "a2dissite 000-default"
    - onlyif: test -L /etc/apache2/sites-enabled/000-default.conf
    - require:
      - pkg: sae|lxvm|metrics-pkg
    - watch_in:
      - service: sae|lxvm|apache2

sae|lxvm|a2ensite-lxvm-metrics:
  cmd.run:
    - name: "a2ensite lxvm-metrics"
    - unless: test -L /etc/apache2/sites-enabled/lxvm-metrics.conf
    - require:
      - file: sae|lxvm|metrics-apache
    - watch_in:
      - service: sae|lxvm|apache2

sae|lxvm|server-signature:
  file.replace:
    - name: /etc/apache2/conf-enabled/security.conf
    - pattern: ServerSignature On
    - repl: ServerSignature Off
    - watch_in:
      - service: sae|lxvm|apache2

sae|lxvm|server-acl-apache:
  file.managed:
    - name: /etc/apache2/apache.allow.llnw
    - source: salt://sae-lxvm/templates/apache.allow.llnw.jinja
    - template: jinja
    - require:
      - pkg: sae|lxvm|metrics-pkg
    - watch_in:
      - service: sae|lxvm|apache2
    - defaults:
        netblocks: {{ netblocks }}

sae|lxvm|apache2:
  service.running:
    - name: apache2

sae|lxvm|mysql-server:
  pkg.installed:
    - name: mysql-server
  service.running:
    - name: mysql
    - require:
      - pkg: sae|lxvm|mysql-server

sae|lxvm|history-database:
  cmd.run:
    - name: mysql -u root -e"create database lxvm_history"
    - unless:  mysql -u root -e"show databases" | grep lxvm_history
    - require:
      - service: sae|lxvm|mysql-server

sae|lxvm|metrics:
  service.running:
    - name: lxvm-metrics
    - require:
      - cmd: sae|lxvm|history-database
      - pkg: sae|lxvm|metrics-pkg
