{% from "collectd/map.jinja" import collectd with context %}
{% from "pepper/map.jinja" import defaults with context %}
{% from "sudoers/map.jinja" import sudo_map with context %}
{% from "tcpwrappers/map.jinja" import extend_hosts with context %}

include:
  - sae-lxvm.base
  - collectd
  - sysctl.ipv6_disable
  - tcpwrappers

sae|lxvm|sudoers-hypervisor:
  file.managed:
    - name: {{ sudo_map.includedir }}/lxvm-hypervisor
    - user: root
    - group: {{ defaults.root_group }}
    - mode: 440
    - source: salt://sae-lxvm/files/hypervisor/sudoers
    - require:
      - file: core|sudoers|includedir

{% set sysctl_settings = {
  'net.ipv4.tcp_timestamps': 1,
  'net.core.rmem_max': 16777216,
  'net.core.wmem_max': 16777216,
  'net.core.netdev_max_backlog': 2500,
  'net.ipv4.tcp_rmem': '4096 87380 16777216',
  'net.ipv4.tcp_wmem': '4096 65536 16777216',
  'net.ipv4.ip_local_port_range': '1024 65535',
  'net.ipv4.tcp_max_tw_buckets': 1440000,
  'net.ipv4.tcp_no_metrics_save': 1,
  'net.ipv4.tcp_tw_recycle': 0,
  'fs.file-max': 200000,
  'net.bridge.bridge-nf-call-ip6tables': 0,
  'net.bridge.bridge-nf-call-iptables': 0,
  'net.bridge.bridge-nf-call-arptables': 0,
  'net.bridge.bridge-nf-filter-vlan-tagged': 0,
  'vm.swappiness': 0,
  'vm.vfs_cache_pressure': 10000,
  'vm.dirty_background_ratio': 5,
  'vm.dirty_ratio': 5,
  'vm.zone_reclaim_mode': 0,
}
%}

{% for name, value in sysctl_settings.items() %}
sae|lxvm|sysctl-{{ name }}:
  sysctl.present:
    - name: {{name}}
    - value: {{value}}
    - config: /etc/sysctl.d/50-lxvm.conf
  # We used to put the settings directly into sysctl.conf, clean up that mess
  file.replace:
    - name: /etc/sysctl.conf
    - pattern: '^{{name}}.*\n'
    - repl: ''
    - bufsize: file
    - flags:
      - MULTILINE
{% endfor %}

{{ extend_hosts('sshd', '10.12.39.', 'PHX2 Management Network', 'allow') }}
{{ extend_hosts('sshd', '10.14.16.', 'PHX7 Management Network', 'allow') }}

sae|lxvm|pkg-bin:
  pkg.latest:
    - names:
      - lxvm-bin
      - libvirt-bin
      - sipcalc
    - skip_verify: True
    - require:
      - pkgrepo: sae|lxvm|repo

sae|lxvm|dirs:
  file.directory:
    - names:
      - /srv/kvm/configs
      - /srv/kvm/images
      - /srv/kvm/kernels
    - user: libvirt-qemu
    - group: kvm
    - mode: 755
    - require:
      # need the libvirt-qemu user from libvirt-bin postinst
      - pkg: sae|lxvm|pkg-bin

{% if grains['osrelease'] in ["14.04", "12.04"] %}
# Collectd is not available on 16.04 and later
sae|lxvm|collectd:
  file.managed:
    - name: {{ collectd.llnwdir }}/libvirt.conf
    - source: salt://sae-lxvm/files/hypervisor/collectd.conf
    - mode: 400
    - watch_in:
      - service: core|collectd|service
{% endif %}

# This user is used by the gocons script to provide console access. We should
# refactor this and make this user go away as shared accounts with password
# auth should be shot in the head execution style.
sae|lxvm|user|InReach:
  user.present:
    - name: InReach
    - password: $6$75Jv.vRR2.wKzV$5PBjZa6f370PhW8k8lfkRzoz.gwfvGwpNXnpWSJ.J1rp2EpOCB0oHwos.YOJjUk2Sx0yhUvtxtPZztN8um.au0
    - gid_from_name: True
    - createhome: False

sae|lxvm|cornerstone-lib-symlink:
  file.symlink:
    - name: /usr/share/perl/5.22/CSAPI
    - target: /usr/share/perl/5.18/CSAPI
    - require:
      - pkg: sae|lxvm|pkg-bin

# Ensure the required network interfaces for the 404 vlan are in place
sae|lxvm|rtshypervisor|pkg-net:
  pkg.latest:
    - names:
      - bridge-utils
