{% from "pepper/map.jinja"  import defaults, netblocks with context %}
{% from "sudoers/map.jinja" import sudo_map with context %}

{% if 'team_env' in  grains -%}
{% set environment = grains['team_env'] -%}
{%- else -%}
{% set environment = 'production' -%}
{%- endif -%}

{% set release = grains['oscodename'] %}
{% import_yaml "sae-mmr/core_map.yaml" as core_map %}
{% set env_map = core_map[environment] %}

include:
  - sudoers.setup
  - firewall.standard
  - java.openjdk8-jre

sae|mmr|core-sudo:
  file.managed:
    - name: {{ sudo_map.includedir }}/mmr-core
    - user: root
    - group: {{ defaults.root_group }}
    - mode: 440
    - contents: |
        %posix-mmr-admin ALL=(ALL) NOPASSWD: ALL
        %posix-zabbix-admins ALL=(ALL) NOPASSWD: ALL
    - require:
      - file: core|sudoers|includedir

sae|mmr|core-firewall:
  firewall.accept:
    - tcp:
      - [80, {{netblocks}}]
    - require_in:
      - firewall: core|firewall|final-reject


sae|mmr|repo:
  pkgrepo.managed:
    - name: deb http://repo.llnw.net/llnw/ubuntu/{{ env_map['repo_env'] }}/mmr/ {{ release }}/
    - file: /etc/apt/sources.list.d/llnw.mmr.core.{{ release }}.list

sae|mmr|package:
  pkg.installed:
    - name: llnw-mmr-core
    - skip_verify: True
    - version: "{{ env_map['version'] }}"
    - require:
      - pkgrepo: sae|mmr|repo
      - file: sae|mmr|conf
      - file: sae|mmr|components.def
      - file: sae|mmr|correlated_events.def
      - file: sae|mmr|events.def
      - file: sae|mmr|metrics.def
      - file: sae|mmr|notifications.def
      - file: sae|mmr|rules.def
      - file: sae|mmr|log4j2.xml

# Restart mmr-core on config changes.
sae|mmr|service:
  service.running:
    - name: mmr-core
    - watch:
      - file: sae|mmr|conf
      - file: sae|mmr|components.def
      - file: sae|mmr|correlated_events.def
      - file: sae|mmr|events.def
      - file: sae|mmr|metrics.def
      - file: sae|mmr|notifications.def
      - file: sae|mmr|rules.def
      - file: sae|mmr|log4j2.xml
    - require:
      - pkg: llnw-mmr-core


sae|mmr|conf_dir:
  file.directory:
    - name: /etc/llnw-mmr-core
    - user: root
    - group: {{ defaults.root_group }}
    - mode: 755

sae|mmr|conf:
  file.managed:
    - require:
      - file: sae|mmr|conf_dir
    - name: /etc/llnw-mmr-core/mmr_core.conf
    - user: root
    - group: {{ defaults.root_group }}
    - mode: 644
    - source: salt://sae-mmr/templates/{{ env_map['repo_env'] }}/mmr_core.conf.jinja
    - template: jinja
    - context:
        mmr_core:
          input_zabbix_user: {{ salt['pillar.get']('secrets:sae-mmr-core:input_zabbix_user') }}
          input_zabbix_password: {{ salt['pillar.get']('secrets:sae-mmr-core:input_zabbix_password') }}
          input_eq_secret: {{ salt['pillar.get']('secrets:sae-mmr-core:input_eq_secret') }}
          output_zabbix_user: {{ salt['pillar.get']('secrets:sae-mmr-core:output_zabbix_user') }}
          output_zabbix_password: {{ salt['pillar.get']('secrets:sae-mmr-core:output_zabbix_password') }}

          erum_url: {{ env_map['erum_url'] }}
          erum_port: {{ env_map['erum_port'] }}
          input_zabbix_api: "{{ env_map['input_zabbix_api'] }}"
          output_zabbix_api: "{{ env_map['output_zabbix_api'] }}"
          eq_host: "{{ env_map['eq_host'] }}"
          eq_port:  {{ env_map['eq_port'] }}
          log_level: "{{ env_map['log_level'] }}"

sae|mmr|inventory_conf:
  file.managed:
    - require:
      - file: sae|mmr|conf_dir
    - name: /etc/llnw-mmr-core/inventory.conf
    - user: root
    - group: {{ defaults.root_group }}
    - mode: 644
    - source: salt://sae-mmr/templates/{{ env_map['repo_env'] }}/inventory.conf.jinja
    - template: jinja
    - context:
        mmr_core:
          cornerstone_api_password: {{ salt['pillar.get']('secrets:sae-mmr-core:cornerstone_api_password') }}

          cornerstone_api_url: {{ env_map['cornerstone_api_url'] }}
          cornerstone_api_user: {{ env_map['cornerstone_api_user'] }}

sae|mmr|components.def:
  file.managed:
    - name: /etc/llnw-mmr-core/components.def
    - user: root
    - group: {{ defaults.root_group }}
    - mode: 644
    - source: salt://sae-mmr/templates/{{ env_map['repo_env'] }}/components.def.jinja
    - template: jinja
    - require:
      - file: sae|mmr|conf_dir

sae|mmr|correlated_events.def:
  file.managed:
    - name: /etc/llnw-mmr-core/correlated_events.def
    - user: root
    - group: {{ defaults.root_group }}
    - mode: 644
    - source: salt://sae-mmr/templates/{{ env_map['repo_env'] }}/correlated_events.def.jinja
    - template: jinja
    - require:
      - file: sae|mmr|conf_dir

sae|mmr|events.def:
  file.managed:
    - name: /etc/llnw-mmr-core/events.def
    - user: root
    - group: {{ defaults.root_group }}
    - mode: 644
    - source: salt://sae-mmr/templates/{{ env_map['repo_env'] }}/events.def.jinja
    - template: jinja
    - require:
      - file: sae|mmr|conf_dir

sae|mmr|metrics.def:
  file.managed:
    - name: /etc/llnw-mmr-core/metrics.def
    - user: root
    - group: {{ defaults.root_group }}
    - mode: 644
    - source: salt://sae-mmr/templates/{{ env_map['repo_env'] }}/metrics.def.jinja
    - template: jinja
    - require:
      - file: sae|mmr|conf_dir

sae|mmr|notifications.def:
  file.managed:
    - name: /etc/llnw-mmr-core/notifications.def
    - user: root
    - group: {{ defaults.root_group }}
    - mode: 644
    - source: salt://sae-mmr/templates/{{ env_map['repo_env'] }}/notifications.def.jinja
    - template: jinja
    - require:
      - file: sae|mmr|conf_dir

sae|mmr|rules.def:
  file.managed:
    - name: /etc/llnw-mmr-core/rules.def
    - user: root
    - group: {{ defaults.root_group }}
    - mode: 644
    - source: salt://sae-mmr/templates/{{ env_map['repo_env'] }}/rules.def.jinja
    - template: jinja
    - require:
      - file: sae|mmr|conf_dir

sae|mmr|log4j2.xml:
  file.managed:
    - name: /etc/llnw-mmr-core/log4j2.xml
    - user: root
    - group: {{ defaults.root_group }}
    - mode: 644
    - source: salt://sae-mmr/templates/{{ env_map['repo_env'] }}/log4j2.xml.jinja
    - template: jinja
    - require:
      - file: sae|mmr|conf_dir

sae|lmmr|mmr-core-restart_cron:
  file.managed:
    - name: /etc/cron.d/mmr-core-restart
    - user: root
    - group: root
    - mode: 644
    - template: jinja
    - source: salt://sae-mmr/templates/{{ env_map['repo_env'] }}/mmr-core-restart.cron.jinja
    - require:
      - pkg: sae|mmr|package
    - context:
        minute: '59'
        hour: '23'
        day: '*'
        month: '*'
        dayofweek: '*'
        run_as_user: 'root'

sae|lmmr|mmr_core_cron:
  file.managed:
    - name: /etc/cron.d/mmr_core
    - user: root
    - group: root
    - mode: 644
    - template: jinja
    - source: salt://sae-mmr/templates/{{ env_map['repo_env'] }}/mmr_core.cron.jinja
    - require:
      - pkg: sae|mmr|package
    - context:
        minute: '00'
        hour: '1'
        day: '*'
        month: '*'
        dayofweek: '*'
        run_as_user: 'root'
