{% from "pepper/map.jinja" import defaults, netblocks with context %}
{% from "sudoers/map.jinja" import sudo_map with context %}

{% if 'team_env' in  grains -%}
{% set environment = grains['team_env'] -%}
{%- else -%}
{% set environment = 'testing' -%}
{%- endif -%}
{% set release = grains['oscodename'] %}

include:
  - firewall.standard

sae|mmr|erum-sudo:
  file.managed:
    - name: {{ sudo_map.includedir }}/mmr-erum
    - user: root
    - group: {{ defaults.root_group }}
    - mode: 440
    - contents: |
        %posix-mmr-admin ALL=(ALL) NOPASSWD: ALL
        %posix-zabbix-admins ALL=(ALL) NOPASSWD: ALL
    - require:
      - file: core|sudoers|includedir

sae|mmr|erum-firewall:
  firewall.accept:
    - tcp:
      - [80, {{netblocks}}]
      - [8888, {{netblocks}}]
    - require_in:
      - firewall: core|firewall|final-reject

# eRUM 1.0 to 1.1 upgrade requires removal of previous .list
sae|mmr|ruma-repo-auto-remove:
  file.absent:
    - name : /etc/apt/sources.list.d/llnw.ruma.{{ release }}.list

sae|mmr|ruma-repo:
  pkgrepo.managed:
    - name: deb http://repo.llnw.net/llnw/ubuntu/{{ environment }}/mmr/ {{ release }}/
    - file: /etc/apt/sources.list.d/llnw.ruma.{{ release }}.list
    - require: 
      - file: sae|mmr|ruma-repo-auto-remove

sae|mmr|cedexis-pkg:
  pkg.installed:
    - name: llnw-rum-cedexis-collector
    - version: 1.0.1.23
    - skip_verify: True
    - require:
      - pkgrepo: sae|mmr|ruma-repo

sae|mmr|utorrent-pkg:
  pkg.latest:
    - names:
      - llnw-rum-utorrent-collector
    - skip_verify: True
    - require:
      - pkgrepo: sae|mmr|ruma-repo

sae|mmr|ruma-pkg:
  pkg.installed:
    - name: llnw-mmr-ruma
    - version: 0.4.64-SNAPSHOT.145-master
    - skip_verify: True
    - require:
      - pkgrepo: sae|mmr|ruma-repo

sae|mmr|cedexis-collector-dir:
  file.directory:
    - name: /usr/share/llnw-rum-cedexis-collector
    - user: svc_rum
    - group: users
    - mode: 755

sae|mmr|cedexis_collector-conf:
  file.managed:
    - require:
      - file: sae|mmr|cedexis-collector-dir
    - name: /usr/share/llnw-rum-cedexis-collector/cedexis_collector.conf
    - user: svc_rum
    - group: users
    - mode: 644
    - source: salt://sae-mmr/templates/cedexis_collector.conf.jinja
    - template: jinja
    - context:
        mmr_cedexis_collector:
          app_name: mmr-collectors/cedexis
          app_varroot: /var
          app_raw_logging: False

          source_auth_params_client_id: {{ salt['pillar.get']('secrets:sae-mmr-erum:source_auth_params_client_id') }}
          source_auth_params_client_secret: {{ salt['pillar.get']('secrets:sae-mmr-erum:source_auth_params_client_secret') }}
