# vim: sts=2 ts=2 sw=2 et ai

{% from "sae-mrtg/map.jinja" import mrtg_conf, mrtg_dir with context %}

include:
  - firewall
  - .user

sae|mrtg|mounts|points:
  file.directory:
    - name: {{ mrtg_dir }}
    - user: {{ mrtg_conf.user }}
    - group: {{ mrtg_conf.group }}
    - dirmode: 755
    - makedirs: True
    - require:
      - user: sae|mrtg|user
      - group: sae|mrtg|group

{% if 'sae-mrtg.master' in salt['grains.get']('roles', []) %}

sae|mrtg|mounts|unmount:
  mount.unmounted:
    - name: {{ mrtg_dir }}

sae|mrtg|index-html:
  file.managed:
    - name: {{ mrtg_dir }}/index.html
    - source: salt://sae-mrtg/files/index.html
    - require:
      - mount: sae|mrtg|mounts|unmount

sae|mrtg|metro-combo:
  file.managed:
    - name: {{ mrtg_dir }}/combo/metro.combo
    - source: salt://sae-mrtg/files/metro.combo
    - require:
      - mount: sae|mrtg|mounts|unmount

sae|mrtg|head-html:
  file.managed:
    - name: /local/apache/htdocs/head.html
    - source: salt://sae-mrtg/files/head.html

sae|mrtg|mounts|server-pkgs:
  pkg.latest:
    - names:
      - nfs-kernel-server

sae|mrtg|mounts|exports:
  file.managed:
    - name: /etc/exports
    - user: root
    - group: root
    - mode: 644
    - contents:
{% for export in mrtg_conf.exports %}
      - "{{ export.path }} {{ export.network }}({{ export.options|join(',') }})"
{% endfor %}

sae|mrtg|mounts|reload-exports:
  service.running:
    - name: nfs-kernel-server
    - enable: True
    - reload: True
    - watch:
      - sae|mrtg|mounts|exports

{% if mrtg_conf.get('exports', []) %}
sae|mrtg|mounts|firewall:
  firewall.accept:
    - both:
  {%- for export in mrtg_conf.exports %}
      - [0, ['{{ export.network }}']]
  {%- endfor %}
    - require_in:
      - firewall: core|firewall|final-reject
{%- endif %}

{% else %}

sae|mrtg|mounts|pkgs:
  pkg.latest:
    - names:
      - nfs-common

sae|mrtg|mounts|no-exports:
  file.absent:
    - name: /etc/exports

sae|mrtg|mounts|stop-exports:
  service.disabled:
    - name: nfs-kernel-server

sae|mrtg|mounts|htdocs:
  mount.mounted:
    - name: {{ mrtg_dir }}
    - device: {{ mrtg_conf.master }}:{{ mrtg_dir }}
    - fstype: nfs
    - opts: defaults
    - require:
      - service: sae|mrtg|mounts|stop-exports

{% endif %}
