# vim: sts=2 ts=2 sw=2 et ai

{% from "pepper/map.jinja" import defaults with context %}

include:
  - .pkgs

# dnsmasq and related services
sae|msops|dnsmasq-pkg:
  pkg.latest:
    - names:
      - coyote-python
      - coyote-python-amqp
      - coyote-python-config
      - dnsmasq
    - skip_verify: True
    - require:
      - pkgrepo: sae|msops|repo

sae|msops|lease-tracker-pkg:
  pkg.installed:
    - name: lease_tracker
    - version: 1.3.3

sae|msops|dnsmasq-conf:
  file.managed:
    - name: /etc/dnsmasq.conf
    - user: root
    - group: root
    - mode: 644
    - source: salt://sae-msops/files/dnsmasq.conf
    - template: jinja
    - require:
      - pkg: sae|msops|dnsmasq-pkg

sae|msops|dnsmasq-local-conf:
  file.managed:
    - name: /etc/dnsmasq.d/dnsmasq.local.conf
    - user: root
    - group: root
    - mode: 644
    - source: salt://sae-msops/templates/dnsmasq.local.conf.jinja
    - template: jinja
    - require:
      - pkg: sae|msops|dnsmasq-pkg

sae|msops|lease-tracker-conf:
  file.managed:
    - name: /etc/lease-tracker.yaml
    - user: root
    - group: root
    - mode: 644
    - source: salt://sae-msops/templates/lease-tracker.yaml.jinja
    - template: jinja
    - context:
      lease_manager: leasemgr.llnw.net:9090
      ipmi_primary_username: InReach
      ipmi_primary_password: {{ salt["pillar.get"]("secrets:core:ipmi_passwd") }}
      ipmi_fallback_username: ADMIN
      ipmi_fallback_password: ADMIN
    - require:
      - pkg: sae|msops|lease-tracker-pkg


sae|msops|dnsmasq-service:
  service.running:
    - name: dnsmasq
    - enable: True
    - full_restart: True
    - require: 
      - pkg: sae|msops|lease-tracker-pkg
      - file: sae|msops|coyote-creds
    - watch:
      - file: sae|msops|dnsmasq-conf
      - file: sae|msops|dnsmasq-local-conf
      - file: sae|msops|coyote-creds

sae|msops|dnsmasq-restart-cron:
  cron.present:
    - name: 'service dnsmasq restart'
    - identifier: dnsmasq-restart-cron
    - minute: random
    - hour: 2
    - require:
      - service: sae|msops|dnsmasq-service

sae|msops|coyote-confdir:
  file.directory:
    - name: /etc/coyote/
    - user: root
    - group: root
    - mode: 755
    - makedirs: True

sae|msops|coyote-creds:
  file.managed:
    - name: /etc/coyote/credentials.xml
    - user: root
    - group: root
    - mode: 755
    - source: salt://sae-msops/templates/credentials.xml
    - template: jinja
    - require:
      - file: sae|msops|coyote-confdir

