# vim: sts=2 ts=2 sw=2 et ai

{% from "pepper/map.jinja" import defaults with context %}

# iperf3 for performance testing and measurement
sae|msops|iperf3-pkg:
  pkg.latest:
    - names:
      - iperf3

sae|msops|iperf3-conf:
  file.managed:
    - name: /etc/init/iperf3.conf
    - user: root
    - group: root
    - mode: 644
    - source: salt://sae-msops/files/iperf3.conf
    - require:
      - pkg: sae|msops|iperf3-pkg

sae|msops|iperf3-service-enabled:
  service.enabled:
    - name: iperf3

sae|msops|iperf3-service-running:
  service.running:
    - name: iperf3
    - enable: True

sae|msops|hostlist:
  file.serialize:
    - name: /usr/local/llnw/ms-ops-hosts.json
    - user: root
    - group: root
    - mode: 644
    - formatter: json
    - dataset: { boxes: {{ salt['publish.runner']('cs.cached_search', [['AND', ['=', 'tag_name', 'role-sae-msops'], ['=', 'status', '100']], "keys=['name', 'domain_name']"])|sequence|sort }} }
    - require:
      - pkg: sae|msops|iperf3-pkg

sae|msops|perftest:
  file.managed:
    - name: /usr/local/bin/perftest.pl
    - user: root
    - group: root
    - mode: 755
    - source: salt://sae-msops/files/perftest.pl
    - require:
      - pkg: sae|msops|iperf3-pkg

sae|msops|iperf3-cron:
  cron.present:
    - name: '/usr/local/bin/perftest.pl'
    - identifier: five-minute-performance
    - minute: '*/5'
    - require:
      - file: sae|msops|perftest

sae|msops|iperf3-cron-cleanup:
  cron.present:
    - name: "for i in $(ps axh -O etimes | grep 'iperf3 -J' | awk '$2 > 3600 {print $1}'); do kill $i; done" 
    - identifier: cleanup-old-iperf-processes
    - hour: '*'
    - require:
      - file: sae|msops|perftest

sae|msops|iperf3-cron-restart:
  cron.present:
    - name: "/usr/sbin/service iperf3 restart"
    - identifier: restart-iperf3-daemon
    - hour: '*'
    - require:
      - file: sae|msops|perftest
