{% from "certs/map.jinja" import cert_path with context %}

include:
  - certs.star

sae|msops|nginx|logs:
  file.directory:
    - name: /var/log/nginx
    - user: root
    - group: root
    - mode: 755
    - makedirs: True

sae|msops|nginx|logrotate:
  file.managed:
    - name: /etc/logrotate.d/nginx
    - source: salt://sae-msops/files/nginx.logrotate
    - require:
      - file: sae|msops|nginx|logs

sae|msops|nginx|package:
  pkg.installed:
    - name: nginx

sae|msops|nginx|config:
  file.managed:
    - name: /etc/nginx/nginx.conf
    - source: salt://sae-msops/files/nginx.conf
    - mode: 644 
    - makedirs: True
    - dir_mode: 755

sae|msops|nginx|sites:
  file.managed:
    - name: /etc/nginx/sites-available/default
    - source: salt://sae-msops/files/nginx.sites.msops.jinja
    - template: jinja
    - mode: 644
    - makedirs: True
    - dir_mode: 755
    - context:
        ssl_cert: {{ cert_path['certdir'] }}/{{ cert_path['certname'] }}.combined.crt
        ssl_key: {{ cert_path['keydir'] }}/{{ cert_path['certname'] }}.key
    - require:
      - file: sae|msops|nginx|logs
      - sls: certs.star

sae|msops|nginx|service|enabled:
  service.enabled:
    - name: nginx

sae|msops|nginx|service|running:
  service.running:
    - name: nginx
    - watch:
        - file: sae|msops|nginx|config
        - file: sae|msops|nginx|sites
