{% from 'sae-nexus/map.jinja' import config with context %}

include:
  - firewall.standard
  - sae-sudoers.devops-team

# When a new image is downloaded from storge this stops current container and removes old image 
# Then reinstalls the newly downloaded image and starts running a new container  

sae|nexus|pkgs:
  pkg.installed:
    - names:
        - git
        - docker.io
        - python-pip
        - python-docker
        - httpie

sae|nexus|download:
  file.managed:
    - name: /{{ config.nexus_image_file }}
    - source: http://llnwsae.vo.llnwd.net/v1/nexus/{{ config.nexus_image_file }}
    - mode: 775
    - skip_verify: True
    - require:
      - pkg: sae|nexus|pkgs

# Removal Section
sae|nexus|stop:
  dockerng.absent:
    - name: nexus
    - force: True
    - onchanges:
      - sae|nexus|download
    - require_in:
      - sae|nexus|install

sae|nexus|image:
  dockerng.image_absent:
    - name: {{ config.image_name }}
    - onchanges:
      - sae|nexus|download
    - require_in:
      - sae|nexus|install

# Reinstall Section 
sae|nexus|install:
  dockerng.image_present:
    - name: {{ config.image_name }}
    - load: /{{ config.nexus_image_file }}

sae|nexus|volume:
  dockerng.volume_present:
    - name: nexus-data

sae|nexus|run:
  dockerng.running:
    - name: nexus
    - image: {{ config.image_name }}
    - detach: True
    - user: nexus
    - restart_policy: on-failure
    - binds:
      - nexus-data:/nexus-data
    - port_bindings:
      - {{ config.port_bindings }}
    - require:
      - sae|nexus|install
      - sae|nexus|volume

sae|nexus|path|nexus:
  file.directory:
    - name: /opt/nexus
    - mode: 755
    - makedirs: True

sae|nexus|ldap-config:
  file.managed:
    - name: /opt/nexus/provision-ldap.groovy
    - source: salt://sae-nexus/files/provision-ldap.groovy.jinja
    - template: jinja
    - mode: 755
    - require:
      - file: sae|nexus|path|nexus

sae|nexus|ldap-exec:
  file.managed:
    - name: /opt/nexus/execute-nexus-ldap.sh
    - source: salt://sae-nexus/files/execute-nexus-ldap.sh
    - mode: 755
    - require:
      - file: sae|nexus|path|nexus

sae|nexus|ldap-run:
  cmd.run:
   - name: /opt/nexus/execute-nexus-ldap.sh
   - timeout: 600
   - onchanges:
     - sae|nexus|volume
