{% from slspath ~ "/map.jinja" import one_version, one_repo_version, networks, public_key, private_key, public_key_value with context %}
{% from "tcpwrappers/map.jinja" import extend_hosts with context %}
include:
  - tcpwrappers
  - sae-sudoers.ops-sysops

{% if networks %}
{%   for network in networks %}
{{     extend_hosts('sshd', network, 'Opennebula command and control') }}
{%   endfor %}
{% endif %}

sae|opennebula|repo:
  pkgrepo.managed:
    - humanname: Opennebula
    - architectures: amd64
    - name: deb http://llnwsae.vo.llnwd.net/v1/packages/mirrors/daily-update/debian/downloads.opennebula.org/repo/{{ one_repo_version }}/Ubuntu/{{ salt['grains.get']('osrelease') }} stable opennebula
    - key_url: http://llnwsae.vo.llnwd.net/v1/packages/mirrors/daily-update/debian/downloads.opennebula.org/repo/repo.key
    - file: /etc/apt/sources.list.d/opennebula.list

sae|opennebula|ssh-key:
  file.managed:
    - name: /var/lib/one/.ssh/id_rsa
    - contents_pillar: "secrets:sae-opennebula:{{private_key}}"
    - user: oneadmin
    - group: oneadmin
    - mode: 600

{% if public_key_value %}
sae|opennebula|ssh-pubkey:
  file.managed:
    - name: /var/lib/one/.ssh/id_rsa.pub
    - contents: "{{public_key_value}}"
    - user: oneadmin
    - group: oneadmin
    - mode: 644

sae|opennebula|ssh-authorized-keys:
  file.managed:
    - name: /var/lib/one/.ssh/authorized_keys
    - contents: "{{public_key_value}}"
    - user: oneadmin
    - group: oneadmin
    - mode: 644
{% else %}
sae|opennebula|ssh-pubkey:
  file.managed:
    - name: /var/lib/one/.ssh/id_rsa.pub
    - contents: "{{public_key}}"
    - user: oneadmin
    - group: oneadmin
    - mode: 644

sae|opennebula|ssh-authorized-keys:
  file.managed:
    - name: /var/lib/one/.ssh/authorized_keys
    - contents: "{{public_key}}"
    - user: oneadmin
    - group: oneadmin
    - mode: 644
{% endif %}
sae|opennebula|ssh-config:
  file.managed:
    - name: /var/lib/one/.ssh/config
    - contents: |
        StrictHostKeyChecking no
        LogLevel ERROR
    - user: oneadmin
    - group: oneadmin
    - mode: 644

sae|opennebula|datastore:
  file.directory:
    - name: /opt/one
    - makedirs: true
    - require:
      - pkgrepo: sae|opennebula|repo

sae|opennebula|datastore-symlink:
  file.symlink:
    - name: /var/lib/one
    - target: /opt/one
    - makedirs: true
    - force: false
    - require:
      - file: sae|opennebula|datastore