{% from slspath ~ "/map.jinja" import one_version, groups, admin_group, dbconfig, clusterid, onegate_endpoint, nginx_host with context %}
{% from "pepper/map.jinja" import defaults with context %}
{% from "sudoers/map.jinja" import sudo_map with context %}

include:
  - .common
  - sudoers.setup
  - resolver.anycachestatic
{%- if nginx_host %}
  - nginx

{% load_yaml as locations %}
- path: /
  proxy: http://localhost:9869
- path: /RPC2
  proxy: http://localhost:2633
{% endload %}

{% from "nginx/map.jinja" import sslvhost with context %}

{{ sslvhost("opennebula", {
    'oscp_staple': False,
    'names': [nginx_host],
    'locations': locations })
}}

{% endif %}

sae|opennebula|master-opennebula-repo:
  pkgrepo.managed:
    - humanname: OpenNebula-automation
    - name: deb [trusted=yes] http://repo.llnw.net/llnw/ubuntu/production/opennebula/ {{ grains.get("oscodename") }}/
    - file: /etc/apt/sources.list.d/opennebula-automation.list
    - require:
      - file: sae|opennebula|datastore-symlink

sae|opennebula|pkg-master:
  pkg.installed:
    - pkgs:
        - opennebula: {{one_version}}
        - opennebula-sunstone: {{one_version}}
        - opennebula-gate: {{one_version}}
        - opennebula-flow: {{one_version}}
        - agilemarket
        - xmlstarlet
        - libssl-dev
        - python-pyone
        - opennebula-rubygems
    - require:
      - pkgrepo: sae|opennebula|master-opennebula-repo
    - require_in:
      - file: sae|opennebula|ssh-key
      - file: sae|opennebula|ssh-pubkey
      - file: sae|opennebula|ssh-authorized-keys
      - file: sae|opennebula|ssh-config

sae|opennebula|agile-market-config:
  file.managed:
    - name: /etc/oneagile.yaml
    - source:
      - salt://{{ slspath }}/files/oneagile.yaml
    - template: jinja
    - user: oneadmin
    - group: oneadmin
    - mode: 600

sae|opennebula|master|tmpdir:
  file.directory:
    - name: /opt/tmp
    - user: oneadmin
    - group: oneadmin
    - mode: 755

{% if clusterid %}
sae|opennebula|oned-config:
  file.managed:
    - name: /etc/one/oned.conf
    - source:
      - salt://{{ slspath }}/files/oned.conf.jinja
    - template: jinja
    - user: root
    - group: root
    - mode: 644
    - context:
      oned:
        dbconfig: {{ dbconfig }}
        clusterid: {{ clusterid }}
        onegate_endpoint: {{ onegate_endpoint }}

sae|opennebula|master|sunstone-config:
  file.managed:
    - name: /etc/one/sunstone-server.conf
    - source:
      - salt://{{ slspath }}/files/sunstone-server.conf
    - user: root
    - group: root
    - mode: 644

sae|opennebula|master|sunstone-views:
  file.managed:
    - name: /etc/one/sunstone-views.yaml
    - source:
      - salt://{{ slspath }}/files/sunstone-views.yaml
    - user: root
    - group: root
    - mode: 644

sae|opennebula|ldap-config:
  file.managed:
    - name: /etc/one/auth/ldap_auth.conf
    - source:
      - salt://{{ slspath }}/files/ldap_auth.conf
    - require:
      - pkg: sae|opennebula|pkg-master

sae|opennebula|opennebula-service:
  service.running:
    - name: opennebula
    - enable: true
    - watch:
      - file: sae|opennebula|oned-config
    - require:
      - file: sae|opennebula|ldap-config
      - file: sae|opennebula|oned-config

sae|opennebula|sunstone-service:
  service.running:
    - name: opennebula-sunstone
    - enable: true
    - watch:
      - file: sae|opennebula|master|sunstone-config
    - require:
      - file: sae|opennebula|master|sunstone-config
      - service: sae|opennebula|opennebula-service

sae|opennebula|master|groups-tmp-file:
  file.managed:
    - name: /tmp/groups.txt
    - contents: |
        {%- for group in groups %}
        {{ group }}
        {%- endfor %}

sae|opennebula|groups:
  cmd.script:
    - name: salt://{{ slspath }}/scripts/create_group.sh
    - args: {{ admin_group }} /var/lib/one/server1.yaml /tmp/groups.txt
    - stateful: true
    - require:
      - service: sae|opennebula|opennebula-service
      - file: sae|opennebula|master|groups-tmp-file

sae|opennebula|setup-marketplace:
  cmd.script:
    - name: salt://{{ slspath }}/scripts/install_market.sh
    - stateful: true
    - unless: onemarket list | grep agile
    - require:
      - cmd: sae|opennebula|groups

sae|opennebula|zabbix-sudoers:
  file.managed:
    - name: {{ sudo_map.includedir }}/opennebula_zabbix
    - user: root
    - group: {{ defaults.root_group }}
    - mode: 440
    - contents: |
        # silence syslog output for the zabbix user
        Defaults:zabbix !syslog
        zabbix ALL=(oneadmin) NOPASSWD: /usr/bin/onedatastore list *,/usr/bin/onehost list *,/usr/bin/onevm list *,/usr/bin/onevnet list *,/usr/bin/oneuser list *,/usr/bin/onegroup list *,/usr/bin/onetemplate list *,/usr/local/llnw/zabbix/bin/one.sh
    - require:
      - cmd: sae|opennebula|setup-marketplace

{% else %}
sae|opennebula|master-missing-cluster:
  test.configurable_test_state:
    - comment: "Cluster ID is not defined. This is required to finish setting up the service."
    - result: False
    - changes: False
{% endif %}
