#!/bin/bash

# Creates a group, and maps that group to the managed groups file
# Usage: create_group.sh GROUP_NAME FILE_PATH

CHANGED=0

if [[ -z "$1" ]]; then
    echo "Missing positional argument: primary admin group name"
    exit 1
fi

PRIMARY=$1
shift

if [[ -z "$1" ]]; then
    echo "Missing positional argument: file path"
    exit 1
fi

FILE=$1
shift

if [[ ! -f "$FILE" ]]; then
    CHANGED=1
else
    HASH=$(md5sum $FILE)
fi

echo "### This file is managed by salt. DO NOT EDIT" > $FILE
echo "### Primary admin group" >> $FILE
echo "cn=${PRIMARY},ou=Groups,dc=llnw,dc=com: 0" >> $FILE

for group in $@; do
    gid=$(onegroup create $group 2>/dev/null)
    res=$?
    if [[ $res != 0 ]]; then
        # The group already exists
        gid=$(echo "${gid}" | sed 's/.*GROUP //; s/\.$//')
    else
        gid=$(echo -n $gid | sed 's/ID: //')
    fi
    echo "cn=${group},ou=Groups,dc=llnw,dc=com: ${gid}" >> $FILE
done

if [[ $CHANGED == 0 ]]; then
    NEWHASH=$(md5sum $FILE)
    if [[ $HASH != $NEWHASH ]]; then
        CHANGED=1
    fi
fi

if [[ $CHANGED == 1 ]]; then
    echo "changed=true"
else
    echo "changed=false"
fi