# vim: sts=2 ts=2 sw=2 et ai

{% from "zookeeper/map.jinja" import zookeeper_map with context %}
{% from "zfs/init.sls" import arclimit with context %}

{% if grains['os_family'] == 'FreeBSD' -%}

include:
  - sae-opentsdb.shared

sae|opentsdb|datanode-pkgs:
  pkg.installed:
    - name: opentsdb

sae|opentsdb|datanode-opentsdbconf:
  file.managed:
    - name: /usr/local/etc/opentsdb/opentsdb.conf
    - mode: 444
    - template: jinja
    - source: salt://sae-opentsdb/templates/opentsdb.conf.jinja
    - defaults:
        zookeeper_servers: {{ zookeeper_map['servers']|sequence }}
    - watch_in:
      - service: sae|opentsdb|datanode-opentsdb-service

sae|opentsdb|datanode-opentsdblogconf:
  file.managed:
    - name: /usr/local/etc/opentsdb/logback.xml
    - mode: 444
    - source: salt://sae-opentsdb/templates/logback.xml.jinja
    - watch_in:
      - service: sae|opentsdb|datanode-opentsdb-service

sae|opentsdb|datanode-opentsdbconfhack:
  file.symlink:
    - name: /etc/opentsdb
    - target: /usr/local/etc/opentsdb

{% set services_datanode = ['hbase_regionserver', 'datanode', 'opentsdb' ] -%}

{% for service in services_datanode -%}
sae|opentsdb|datanode-{{ service }}-service:
  service.running:
    - name: {{ service }}
    - enable: True
{% endfor %}

{% endif %}

sae|opentsdb|datanode-tsdhealthinfo:
  cron.present:
    - name: '/usr/local/bin/curl -s "`hostname`:4242/api/stats" | /usr/local/bin/curl -s -H "Content-Type: application/json" -d @- "`hostname`:4242/api/put"'
    - user: opentsdb
    - minute: '*/1'
