# vim: sts=2 ts=2 sw=2 et ai
{% from "ldap/map.jinja" import ldap with context%}
{% from "zookeeper/map.jinja" import zookeeper_map with context%}

{% if grains['os_family'] == 'FreeBSD' -%}

{%   set grafanamajor = 'grafana4' %}

include:
  - sae-opentsdb.shared

sae|opentsdb|readernode-pkgs:
  pkg.installed:
    - pkgs:
      - opentsdb
      - {{ grafanamajor }}

sae|opentsdb|readernode-grafanaconf:
  file.managed:
    - name: /usr/local/etc/{{ grafanamajor }}.conf
    - mode: 644
    - template: jinja
    - source: salt://sae-opentsdb/templates/opentsdb.conf.jinja
    - watch_in:
      - service: sae|opentsdb|readernode-{{ grafanamajor }}-service

sae|opentsdb|readernode-grafanaldap:
  file.managed:
    - name: /usr/local/etc/grafana-ldap.toml
    - mode: 640
    - user: grafana
    - template: jinja
    - source: salt://sae-opentsdb/templates/grafana-ldap.toml.jinja
    - context:
        host: {{ ldap['server'] }}
        port: 636
        use_ssl: true
        search_filter: "(|(mail=%s)({{ ldap['uidattr']}}=%s))"
        search_base_dns: "[ou=people,{{ ldap['basedn'] }}]"
        uidattr: {{ ldap['uidattr'] }}
        basedn: {{ ldap['basedn'] }}
    - watch_in:
      - service: sae|opentsdb|readernode-{{ grafanamajor }}-service

sae|opentsdb|readernode-opentsdbconf:
  file.managed:
    - name: /usr/local/etc/opentsdb/opentsdb.conf
    - mode: 444
    - template: jinja
    - source: salt://sae-opentsdb/templates/opentsdb.conf.jinja
    - defaults:
        zookeeper_servers: {{ zookeeper_map['servers']|sequence }}
    - watch_in:
      - service: sae|opentsdb|readernode-opentsdb-service

sae|opentsdb|readernode-opentsdblogconf:
  file.managed:
    - name: /usr/local/etc/opentsdb/logback.xml
    - mode: 444
    - source: salt://sae-opentsdb/templates/logback.xml.jinja
    - watch_in:
      - service: sae|opentsdb|readernode-opentsdb-service

{% set services_readernode = ['opentsdb', {{ grafanamajor }}] -%}

{% for service in services_readernode -%}
sae|opentsdb|readernode-{{ service }}-service:
  service.running:
    - name: {{ service }}
    - enable: True
{% endfor %}

{% endif %}
