# vim: sts=2 ts=2 sw=2 et ai
{% from "sae-opentsdb/map.jinja" import beastly_hadoop with context %}
{% from "zookeeper/map.jinja" import zookeeper_map with context %}
{% from "zfs/freebsd.sls" import arclimit with context %}

include:
- zfs
- sae-opentsdb

# We want the majority of the RAM used for HDFS/HBase Java heap
{{ arclimit(8) }}

sae|opentsdb|hosts:
  host.present:
    - name: {{ grains['fqdn'] }}
    - ip: {{ grains['fqdn_ip4'] }}

sae|opentsdb|shared-pkgs:
  pkg.installed:
    - pkgs:
      - hadoop2
      - hbase

sae|opentsdb|hbase-groups:
  user.present:
    - name: hbase
    - groups:
      - hbase
      - hadoop
    - require:
      - pkg: sae|opentsdb|shared-pkgs

{% set hadoop_conf_llnw = ['hdfs-site.xml', 'core-site.xml', 'hadoop-env.sh', 'log4j.properties'] %}

{% set hbase_conf_llnw = ['hbase-site.xml', 'hdfs-site.xml', 'core-site.xml', 'hbase-env.sh', 'log4j.properties'] %}

sae|opentsdb|hdfs-dir:
  file.directory:
    - name: /tsdb/hdfs
    - makedirs: True
    - user: hdfs
    - group: hadoop
    - mode: 750
    - require:
      - user: sae|opentsdb|hbase-groups

sae|opentsdb|shared-hadoop-conf-llnw-dir:
  file.directory:
    - name: /usr/local/etc/hadoop/
    - user: root
    - group: hadoop

sae|opentsdb|shared-hadoop-pid-llnw-dir:
  file.directory:
    - name: /usr/local/share/hadoop/pids
    - user: hdfs
    - group: wheel

sae|opentsdb|shared-hadoop-socket-llnw-dir:
  file.directory:
    - name: /var/run/hadoop-hdfs
    - user: hdfs
    - group: wheel

sae|opentsdb|shared-hadoop-log-llnw-dir:
  file.directory:
    - name: /tsdb/logs
    - makedirs: True
    - user: hdfs
    - group: wheel
    - mode: 777

{% for conf in hadoop_conf_llnw %}
sae|opentsdb|shared-hadoop-{{ conf }}-conf:
  file.managed:
    - name: /usr/local/etc/hadoop/{{ conf }}
    - mode: 644
    - user: root
    - group: hadoop
    - template: jinja
    - source: salt://sae-opentsdb/templates/{{ conf }}.jinja
    - defaults:
        zookeeper_servers: {{ zookeeper_map['servers']|sequence }}
        datanodes: {{ beastly_hadoop['datanodes']|sequence }}
        namenodes: {{ beastly_hadoop['namenodes']|sequence }}
        journalnodes: {{ beastly_hadoop['journalnodes']|sequence }}
        beastly_hadoop: {{ beastly_hadoop }}
{% endfor %}

{% for conf in hbase_conf_llnw %}
sae|opentsdb|shared-hbase-{{ conf }}-conf:
  file.managed:
    - name: /usr/local/etc/hbase/{{ conf }}
    - mode: 644
    - user: root
    - group: hadoop
    - template: jinja
    - source: salt://sae-opentsdb/templates/{{ conf }}.jinja
    - defaults:
        zookeeper_servers: {{ zookeeper_map['servers']|sequence }}
        datanodes: {{ beastly_hadoop['datanodes']|sequence }}
        namenodes: {{ beastly_hadoop['namenodes']|sequence }}
        journalnodes: {{ beastly_hadoop['journalnodes']|sequence }}
        beastly_hadoop: {{ beastly_hadoop }}
{% endfor %}
