# vim: sts=2 ts=2 sw=2 et ai

{% from slspath ~ "/map.jinja" import credentials, jenkins, jenkins_plugins with context %}
{% from "pepper/map.jinja" import netblocks %}
{% set oscodename = salt['grains.get']('oscodename', '') %}

{% set jenkins_credentials_pillar = 'sae-ops-jenkins' %}
{% set credentials = salt['pillar.get']('secrets:' + jenkins_credentials_pillar)|json|json %}

{% set popvms_pillar = 'sae-pop-vms' %}
{% set popvms_credentials = salt['pillar.get']('secrets:' + popvms_pillar)|json|json %}

include:
  - firewall.standard
  - firewall.web
  - java.default-openjdk8
  - cd-api
  - sae-sudoers.posix-opsjenkins-admin
  - .nginx

sae|opsjenkins|jenkins-repo:
  pkgrepo.managed:
    - file: /etc/apt/sources.list.d/jenkins.list
    - name: deb http://llnwsae.vo.llnwd.net/v1/packages/mirrors/daily-update/debian/pkg.jenkins.io/debian-stable binary/
    - key_url: http://llnwsae.vo.llnwd.net/v1/packages/mirrors/daily-update/debian/pkg.jenkins.io/debian/jenkins.io.key

sae|opsjenkins|deadsnakes-repo:
  pkgrepo.managed:
    - file: /etc/apt/sources.list.d/deadsnakes.list
    - name: deb http://ppa.launchpad.net/deadsnakes/ppa/ubuntu {{ oscodename }} main
    - key_url: http://llnwsae.vo.llnwd.net/v1/packages/mirrors/daily-update/debian/ppa.launchpad.net/deadsnakes/0x308C15A29AD198E9.key
  
sae|popcopsjenkinsheckapi|llnw-repo:
  pkgrepo.managed:
    - file: /etc/apt/sources.list.d/llnw.autopop.{{ oscodename }}.list
    - name: deb [trusted=yes] http://repo.llnw.net/llnw/ubuntu/production/autopop/ {{ oscodename }}/

sae|opsjenkins|pkg:
  pkg.installed:
    - pkgs:
      - {{ jenkins.pkg }}
      - xmlstarlet
      - python3.7
      - python-pip
      - git
      - dh-virtualenv
      - dpkg-dev
      - debhelper
      - jq
      - firefox
      - popvms
    - reload_modules: True
    - require:
      - pkg: core|java|pkg-openjdk8
      - pkgrepo: sae|opsjenkins|jenkins-repo
      - pkgrepo: sae|opsjenkins|deadsnakes-repo

sae|opsjenkins|pip-install:
  file.managed:
    - name: /var/lib/jenkins/server_pip_requirements.txt
    - source: salt://{{slspath}}/files/requirements.txt
  cmd.run:
    - name: pip install -r /var/lib/jenkins/server_pip_requirements.txt
    - require:
      - pkg: sae|opsjenkins|pkg

sae|opsjenkins|service:
  service.running:
    - name: {{ jenkins.svc }}
    - require:
      - pkg: sae|opsjenkins|pkg

sae|opsjenkins|jenkinslib:
  file.managed:
    - name: /var/lib/jenkins/jenkinslib.sh
    - source: salt://{{slspath}}/files/jenkinslib.sh
    - require:
      - service: sae|opsjenkins|service

sae|opsjenkins|installcli:
  cmd.script:
    - name: salt://{{slspath}}/files/downloadcli.sh
    - cwd: /var/lib/jenkins
    - creates: /var/lib/jenkins/jenkins-cli.jar
    - stateful: True
    - require:
      - file: sae|opsjenkins|jenkinslib

sae|opsjenkins|pluginproxy:
  cmd.script:
    - name: salt://{{slspath}}/files/configureproxy.sh
    - cwd: /var/lib/jenkins
    - creates: /var/lib/jenkins/proxy.xml
    - stateful: True
    - require:
      - cmd: sae|opsjenkins|installcli

sae|opsjenkins|installplugin|ldap:
  cmd.script:
    - name: salt://{{slspath}}/files/installplugin.sh
    - args: ldap
    - cwd: /var/lib/jenkins
    - creates: /var/lib/jenkins/plugins/ldap.jpi
    - stateful: True
    - require:
      - cmd: sae|opsjenkins|pluginproxy

sae|opsjenkins|configurejenkins:
  cmd.script:
    - name: salt://{{slspath}}/files/setupjenkins.sh
    - cwd: /var/lib/jenkins
    - creates: /var/lib/jenkins/autosetup.txt
    - stateful: True
    - require:
      - cmd: sae|opsjenkins|installplugin|ldap

{% for plugin in jenkins_plugins %}
sae|opsjenkins|installplugin|{{plugin}}:
  cmd.script:
    - name: salt://{{slspath}}/files/installplugin.sh
    - cwd: /var/lib/jenkins
    - args: {{plugin}}
    - creates: /var/lib/jenkins/plugins/{{plugin}}.jpi
    - stateful: True
    - require:
      - cmd: sae|opsjenkins|configurejenkins
{% endfor %}

sae|opsjenkins|createcredentials:
  cmd.script:
    - name: salt://{{slspath}}/files/createcredentials.sh
    - cwd: /var/lib/jenkins
    - args: '{{credentials}} {{jenkins_credentials_pillar}}'
    - stateful: True
    - require:
        - cmd: sae|opsjenkins|configurejenkins

sae|opsjenkins|create-popvms-credentials:
  cmd.script:
    - name: salt://{{slspath}}/files/createcredentials.sh
    - cwd: /var/lib/jenkins
    - args: '{{popvms_credentials}} {{popvms_pillar}}'
    - stateful: True
    - require:
        - cmd: sae|opsjenkins|configurejenkins