{% from 'pepper/map.jinja' import netblocks %}
{% from "certs/map.jinja" import cert_path with context %}
{% set hostname = salt['grains.get']('fqdn', 'localhost') %}

include:
  - certs.star

sae|ops-jenkins|nginx|logs:
  file.directory:
    - name: /var/log/nginx
    - user: root
    - group: root
    - mode: 755
    - makedirs: True

sae|ops-jenkins|nginx|logs-rotate:
  file.managed:
    - name: /etc/logrotate.d/nginx
    - source: salt://{{ slspath }}/files/nginx.logrotate
    - require:
      - file: sae|ops-jenkins|nginx|logs

sae|ops-jenkins|nginx|sites-jenkins:
  file.managed:
    - name: /etc/nginx/sites-available/default
    - source: salt://{{ slspath }}/files/nginx.sites.jenkins.jinja
    - template: jinja
    - mode: 644
    - makedirs: True
    - dir_mode: 755
    - context:
        hostname: {{ hostname }}
        ssl_cert: {{ cert_path['certdir'] }}/{{ cert_path['certname'] }}.combined.crt
        ssl_key: {{ cert_path['keydir'] }}/{{ cert_path['certname'] }}.key
    - require:
      - file: sae|ops-jenkins|nginx|logs
      - sls: certs.star

sae|ops-jenkins|nginx|conf:
  file.managed:
    - name: /etc/nginx/nginx.conf
    - source: salt://{{ slspath }}/files/nginx.conf
    - mode: 644
    - makedirs: True
    - dir_mode: 755
    - require:
      - file: sae|ops-jenkins|nginx|logs
      - file: sae|ops-jenkins|nginx|sites-jenkins

sae|ops-jenkins|nginx|install:
  pkg.installed:
    - name: nginx-light
    - require:
      - file: sae|ops-jenkins|nginx|conf

sae|ops-jenkins|nginx|service:
  service.running:
    - name: nginx
    - enable: True
    - reload: True
    - watch:
      - pkg: sae|ops-jenkins|nginx|install
      - file: sae|ops-jenkins|nginx|conf
      - file: sae|ops-jenkins|nginx|logs
