{% from slspath ~ "/map.jinja" import opsramp_config,gateway_cs_dict,host_regex,host_regex_phx with context %}
{%- import_yaml slspath ~ '/defaults.yaml' as defaults %}

# host_regex: {{ host_regex }}
# host_regex_phx: {{ host_regex_phx }}
# dict: {{ gateway_cs_dict|json }}
#
# config: {{ opsramp_config|json }}

{% set os_family = salt['grains.get']('os_family', 'unknown') %}
{% set os_majorrelease = salt['grains.get']('osmajorrelease', '0')|int %}
{% if 'FreeBSD' in os_family and os_majorrelease == 10 %}
include:
  - crontab
{% endif %}

salt-sae|opsramp|agent|init-sls:
  test.show_notification:                          
    - text: Executing {{ slspath + '/' + sls  }}.sls

salt-sae|opsramp|agent|agent-user:
  group.present:
    - name: {{ defaults['component_group'] }}
  user.present:
    - name: {{ defaults['component_user'] }}
    - shell: /bin/false
    - home: /opt/opsramp
    - gid_from_name: True
    - createhome: False
    - system: True

salt-sae|opsramp|agent|install-sls:
  test.show_notification:
    - text: Executing {{ slspath + '/' + sls  }}.sls

{% if (grains['os_family'] == 'Debian') %}
salt-sae|opsramp|agent|deb-repo:
  pkgrepo.managed:
    - name: deb [trusted=yes] http://repo.llnw.net/llnw/ubuntu/{{ opsramp_config['environment'] }}/opsramp/ {{ grains['oscodename'] }}/
    - file: /etc/apt/sources.list.d/opsramp-{{ grains['oscodename'] }}.list
    - clean_file: true

salt-sae|opsramp|agent|environ:
  environ.setenv:
    - name: ISNONROOT
    - value: 'Y'

salt-sae|opsramp|agent|install:
  pkg.installed:
    - pkgs:
      - {{ opsramp_config['agent_package'] }}: {{ opsramp_config['agent_version'] }}
    - skip_verify: True
    - refresh: True 
    - requires:
      - sae|opsramp|agent|deb-repo
      - sae|opsramp|agent|environ
      - sae|opsramp|agent|agent-user

salt-sae|opsramp|agent|logrotate:
  file.managed:
    - name: /etc/logrotate.d/opsramp-agent
    - user: root
    - group: root
    - mode: 644
    - contents: |
        /var/log/opsramp/configure-opsramp-agent.log {
          daily
          rotate 4
          compress
        }

{% elif (grains['os_family'] == 'FreeBSD') and (salt['cmd.run']('pkg query "%v" ' + opsramp_config['agent_package']) != opsramp_config['agent_version']) %}

{# It is currently required to install the BSD package via cmd.run, and check the package with 'pkg query' due to the hyphen in the version number being incompatible with salt's pkgng module #}
salt-sae|opsramp|agent|install:
  environ.setenv:
    - name: ISNONROOT
    - value: 'Y'
  cmd.run:
    - name: 'pkg add -f https://llnwsae.mt.lldns.net/llnwsae/packages/llnw/opsramp/{{ grains['os_family']|lower }}/{{ opsramp_config['agent_package'] + "-" + opsramp_config['agent_version'] + "_" + grains['os_family']|lower + grains['osmajorrelease'] + "-amd64.txz" }}'
    - requires:
      - sae|opsramp|agent|agent-user

salt-sae|opsramp|agent|newsyslog:
  file.managed:
    - name: /usr/local/etc/newsyslog.conf.d/configure-opsramp-agent.conf
    - user: opsramp
    - group: opsramp
    - mode: 644
    - contents: |
        # logfilename mode count size when flags
        /var/log/opsramp/configure-opsramp-agent.log 666 4 * $W0 JN
{% else %}
{# needed when FreeBSD already has the right package version #}
salt-sae|opsramp|agent|install:
  test.succeed_without_changes:
    - name: salt-sae-opsramp-agent-install-no-op-always-passes
{% endif %}

{# make the script #}
salt-sae|opsramp|agent|make|configure-opsramp-agent.sh:
  file.managed:
    - name: /usr/local/bin/configure-opsramp-agent.sh
    - source: salt://{{slspath}}/files/configure-opsramp-agent.sh
    - owner: opsramp
    - group: opsramp
    - mode: 755
    - template: jinja
    - context:
        gateways: {{opsramp_config['gateways']|json}}
        preferred_gateway: '{{opsramp_config['preferred_gateway']}}'
        port: {{opsramp_config['gateway_port']}}
        agent_key: {{ salt['pillar.get'](opsramp_config['agent_key_pillar'])}}
        agent_secret: {{ salt['pillar.get'](opsramp_config['agent_secret_pillar'])}}
        opsramp_api_endpoint: '{{opsramp_config['opsramp_api_endpoint']}}'
        go_direct: {{opsramp_config['direct']}}
    - requires:
      - sae|opsramp|agent|install

salt-sae|opsramp|agent|service|upgrade:
  service.dead:
    - name: opsramp-agent
    - onchanges:
      - salt-sae|opsramp|agent|install

{# configure-opsramp-agent script will configure new agent if the #}
{# service is not actually running #}
salt-sae|opsramp|shield|service|upgrade:
  service.dead:
    - name: opsramp-agent
    - onchanges:
      - salt-sae|opsramp|agent|install

{# remove file to force upgraded agent to reconfigure itself #}
salt-sae|opsramp|agent|upgrade|remove|current_gateway:
  file.absent:
    - name: /tmp/current_opsramp_gateway 
    - onchanges:
      - salt-sae|opsramp|agent|install

{# run the script #}
salt-sae|opsramp|agent|run|configure-opsramp-agent.sh:
    cmd.run:
        - name: /usr/local/bin/configure-opsramp-agent.sh
        - stateful: true
        - requires:
            - salt-sae|agent|make|configure-opsramp-agent.sh

{% if 'FreeBSD' in os_family and os_majorrelease == 10 %}
salt-sae|opsramp|agent|cron:
  file.accumulated:
    - filename: /etc/crontab
    - require_in:
      - file: core|crontab|base
    - text: |
        # opsramp-agent
        0,10,20,30,40,50 * * * * root /usr/local/bin/configure-opsramp-agent.sh >/dev/null
{% else %}
{# rerun the script to make sure the gateway is up;     #}
{# if the current gateway is down, switch to what works #}
salt-sae|opsramp|agent|cron:
  file.managed:
    - name: /etc/cron.d/opsramp-agent
    - user: root
    - mode: 640
    - template: jinja
    - source: salt://{{ slspath }}/files/opsramp-agent.jinja

{% endif %}
