# vim: sts=2 ts=2 sw=2 et ai

{% from "pepper/map.jinja" import defaults with context %}
{% from "pepper/map.jinja" import netblockswithv6 %}
{% from "pepper/map.jinja" import egblocks %}
{% from "zabbix/map.jinja" import zabbix_proxy_ips, zabbix_proxy_ranges %}

# Reference https://confluence.atlas.llnw.com/display/SWENG/CDS+Approved+ports,+protocols,+services+table
#
# Publicly open ports
# 80        Edgeprism squid1, squid2
# 443       IRR (general pool), Edgeprism SSL (enterprise pool)
# 1119      EdgePrism (squid1, for Blizzard and EP1 monitoring)

# Internally open ports
# 22        SSH
# 123       NTP
# 2002      Loghitbyte
# 7171      POP Selection Probe Agent
# 8000      EdgePrism (squid2)
# 8001-8256 EdgePrism (squid1 MPEP child)
# 8888      Edgeprism Exporter
# 9001-9256 EdgePrism (squid2 MPEP child)
# 10050     Zabbix
# 17000     EQ Logstreamer

include:
  - firewall

ep|component|firewall|vs|enable_v6:
  grains.present:
    - name: fw_ipv6_enabled
    - value: True

ep|component|firewall|vs|rules:
  firewall.accept:
    - udp:
      - [123, {{ netblockswithv6 }}]
    - tcp:
      - [22, {{ netblockswithv6 }}]
      - 80
      - 443
      - 1119
      - [2002, {{ netblockswithv6 }}]
      - [7171, {{ netblockswithv6 }}]
      - [8000, {{ netblockswithv6 + egblocks }}]
{%   for port in range(8001,8256) %}
      - [{{ port }}, {{ netblockswithv6 + egblocks }}]
{%   endfor %}
      - [8888, {{ netblockswithv6 }}]
{%   for port in range(9001,9256) %}
      - [{{ port }}, {{ netblockswithv6 + egblocks }}]
{%   endfor %}
{%   for zbx_ip in zabbix_proxy_ips %}
      - [10050, {{ zbx_ip }}]
{%   endfor %}
{%   for zbx_range in zabbix_proxy_ranges %}
      - [10050, {{ zbx_range }}]
{%   endfor %}
      - [17000, {{ netblockswithv6 }}]
    - stateful: True
    - require_in:
      - firewall: core|firewall|final-reject
