# vim: sts=2 ts=2 sw=2 et ai

{% from 'pepper/map.jinja' import netblocks %}
{% set oscodename = salt['grains.get']('oscodename', '') %}

include:
  - firewall.standard
  - firewall.web
  - sae-sudoers.ops-sysops
  - .nginx

sae|popcheckapi|repo:
  pkgrepo.managed:
    - file: /etc/apt/sources.list.d/llnw.autopop.{{ oscodename }}.list
    - name: deb [trusted=yes] http://repo.llnw.net/llnw/ubuntu/testing/autopop/ {{ oscodename }}/

sae|popcheckapi|pkg:
  pkg.installed:
    - pkgs:
        - python3
        - popcheckapi
    - require:
      - pkgrepo: sae|popcheckapi|repo

# TODO: add logrotation
sae|popcheckapi|logs:
  file.directory:
    - name: /var/log/uwsgi
    - user: root
    - group: root
    - mode: 755
    - makedirs: True

sae|popcheckapi|popcheckapi.ini:
  file.managed:
    - name: /opt/venvs/popcheckapi/popcheckapi.ini
    - source: salt://{{slspath}}/files/popcheckapi.ini
    - require:
        - pkg: sae|popcheckapi|pkg
        - file: sae|popcheckapi|logs

sae|popcheckapi|sync-robotdocs-db:
  cmd.script:
    - name: salt://{{slspath}}/files/sync_robot_docs.py
    - cwd: /opt/venvs/popcheckapi
    - stateful: True
    - require:
        - pkg: sae|popcheckapi|pkg

sae|popcheckapi|systemd-unit:
  file.managed:
    - name: /etc/systemd/system/popcheckapi.service
    - source:  salt://{{slspath}}/files/popcheckapi.service
    - require:
        - file: sae|popcheckapi|popcheckapi.ini

sae|popcheckapi|robotdocs-systemd-unit:
  file.managed:
    - name: /etc/systemd/system/robotdocs.service
    - source:  salt://{{slspath}}/files/robotdocs.service
    - require:
        - cmd: sae|popcheckapi|sync-robotdocs-db

sae|popcheckapi|service-running:
  service.running:
    - name: popcheckapi
    - enable: true
    - watch:
        - file: sae|popcheckapi|popcheckapi.ini
        - module: sae|popcheckapi|reload-systemctl

sae|popcheckapi|robotdocs-service-running:
  service.running:
    - name: robotdocs
    - enable: true
    - watch:
        - cmd: sae|popcheckapi|sync-robotdocs-db
        - module: sae|popcheckapi|reload-systemctl

sae|popcheckapi|reload-systemctl:
  module.run:
    - name: service.systemctl_reload
    - onchanges:
        - file: sae|popcheckapi|systemd-unit
        - file: sae|popcheckapi|robotdocs-systemd-unit
