{% from 'pepper/map.jinja' import netblocks %}
{% from "certs/map.jinja" import cert_path with context %}
{% set hostname = salt['grains.get']('fqdn', 'localhost') %}

include:
  - certs.star

sae|popcheckapi|nginx|install:
  pkg.installed:
    - name: nginx-full

sae|popcheckapi|nginx|logs:
  file.directory:
    - name: /var/log/nginx
    - user: root
    - group: root
    - mode: 755
    - makedirs: True

sae|popcheckapi|nginx|logs-rotate:
  file.managed:
    - name: /etc/logrotate.d/nginx
    - source: salt://{{ slspath }}/files/nginx.logrotate
    - require:
      - file: sae|popcheckapi|nginx|logs

sae|popcheckapi|nginx|conf:
  file.managed:
    - name: /etc/nginx/nginx.conf
    - source: salt://{{ slspath }}/files/nginx.conf
    - mode: 644
    - dir_mode: 755
    - require:
        - file: sae|popcheckapi|nginx|logs
        - pkg: sae|popcheckapi|nginx|install

sae|popcheckapi|nginx|sites-popcheckapi:
  file.managed:
    - name: /etc/nginx/sites-available/popcheckapi
    - source: salt://{{ slspath }}/files/nginx.sites.popcheckapi.jinja
    - template: jinja
    - mode: 644
    - dir_mode: 755
    - context:
        hostname: {{ hostname }}
        ssl_cert: {{ cert_path['certdir'] }}/{{ cert_path['certname'] }}.combined.crt
        ssl_key: {{ cert_path['keydir'] }}/{{ cert_path['certname'] }}.key
        ssl_trust: {{ cert_path['certdir'] }}/{{ cert_path['intermediatebundle'] }}
    - require:
      - file: sae|popcheckapi|nginx|conf

sae|popcheckapi|nginx|site-enable:
  file.symlink:
    - name: /etc/nginx/sites-enabled/popcheckapi
    - target: /etc/nginx/sites-available/popcheckapi
    - require:
        - file: sae|popcheckapi|nginx|sites-popcheckapi

sae|popcheckapi|nginx|disable-default:
  file.absent:
    - name: /etc/nginx/sites-enabled/default
    - require:
        - file: sae|popcheckapi|nginx|site-enable

sae|popcheckapi|nginx|service:
  service.running:
    - name: nginx
    - enable: True
    - reload: True
    - watch:
      - pkg: sae|popcheckapi|nginx|install
      - file: sae|popcheckapi|nginx|conf
      - file: sae|popcheckapi|nginx|logs
    - require:
        - file: sae|popcheckapi|nginx|disable-default