# vim: sts=2 ts=2 sw=2 et ai

{% from "pepper/map.jinja" import netblocks with context %}
{% from "sae-poudriere/map.jinja" import llports_map, zpool with context %}

include:
  - kernel_mods.linuxulator
  - jenkins.slave
  - firewall.standard
  - firewall.web
  - sysctl

sae|poudriere|firewall:
  firewall.accept:
    - tcp:
      - [8080, {{ netblocks }}] # Web port
    - require_in:
      - firewall: core|firewall|final-reject

sae|poudriere|pkg:
  pkg.installed:
    - name: poudriere-devel

sae|poudriere|git-pkg:
  pkg.installed:
    - name: git

sae|poudriere|nginx-pkg:
  pkg.installed:
    - name: nginx

sae|poudriere|pkg-signing-key:
  file.managed:
    - name: /usr/local/etc/poudriere.d/pki/llnw-sae.key
    - mode: 600
    - makedirs: True
    - backup: False
    - contents_pillar: secrets:pkgng:pkg_repo_signing_key
    - require:
      - pkg: sae|poudriere|pkg

sae|poudriere|ports-distfiles-zfs:
  zfs.filesystem_present:
    - name: {{ zpool }}/{{ llports_map['build-host']['distfilesdataset'] }}
    - properties:
        compression: off
        mountpoint: /{{ zpool }}/{{ llports_map['build-host']['distfilesdataset'] }}

sae|poudriere|poudriere-conf:
  file.managed:
    - name: /usr/local/etc/poudriere.conf
    - source: salt://sae-poudriere/files/poudriere.conf.jinja
    - template: jinja
    - defaults:
        ccachedir: {{ llports_map['build-host']['ccachedir'] }}
        poudrieredataset: {{ llports_map['build-host']['poudrieredataset'] }}
        distfilesdataset: {{ llports_map['build-host']['distfilesdataset'] }}
        hostname: {{ grains['fqdn'] }}
        signingkey: {{ llports_map['build-host']['signingkey'] }}
        urlbase: http://{{ grains['fqdn'] }}/
        zpool: {{ zpool }}
    - require:
      - pkg: sae|poudriere|pkg

sae|poudriere|nginx-conf:
  file.managed:
    - name: /usr/local/etc/nginx/nginx.conf
    - source: salt://sae-poudriere/files/nginx.conf.jinja
    - template: jinja
    - defaults:
        hostname: {{ grains['fqdn'] }}
        poudriere_basefs: /{{ zpool }}/{{ llports_map['build-host']['poudrieredataset'] }}
    - require:
      - pkg: sae|poudriere|nginx-pkg

sae|poudriere|nginx-service:
  service.running:
    - name: nginx
    - enable: True
    - require:
      - pkg: sae|poudriere|nginx-pkg
    - watch:
      - file: sae|poudriere|nginx-conf

sae|poudriere|ccache-tmpfs-mount:
  zfs.filesystem_present:
    - name: {{ zpool }}/poudriere-ccache
    - properties:
        compression: on
        mountpoint: /poudriere-ccache

{% for pname in llports_map['ports-trees'] %}
sae|poudriere|portlist_{{ pname }}:
  file.managed:
    - name: /usr/local/etc/all_ports_{{ pname }}.txt
    - source: salt://sae-poudriere/files/all_ports_{{ pname }}.txt
    - mode: 644
    - require:
      - pkg: sae|poudriere|pkg
{% endfor %}

sae|poudriere|make-conf:
  file.managed:
    - name: /usr/local/etc/poudriere.d/make.conf
    - source: salt://sae-poudriere/files/poudriere.d/make.conf.jinja
    - template: jinja
    - require:
      - pkg: sae|poudriere|pkg

{% for jname, jail in llports_map['build-jails'].iteritems() %}
sae|poudriere|jail-{{ jname }}:
  cmd.run:
    - name: poudriere jail -c -j '{{ jname }}' -m '{{ jail['method'] }}' -v '{{ jail['ref'] }}'
    - unless: poudriere jail -qln | grep -q '{{ jname }}'
    - shell: /bin/sh
    - require:
      - pkg: sae|poudriere|pkg

sae|poudriere|make-conf-{{ jname }}:
  file.managed:
    - name: /usr/local/etc/poudriere.d/{{ jname }}-make.conf
    - source: salt://sae-poudriere/files/poudriere.d/{{ jname }}-make.conf.jinja
    - template: jinja
    - require:
      - pkg: sae|poudriere|pkg

{% for tname in llports_map['merged-trees'] %}
sae|poudriere|make-conf-{{ jname }}-{{ tname }}:
  file.managed:
    - name: /usr/local/etc/poudriere.d/{{ jname }}-{{ tname }}-make.conf
    - source: salt://sae-poudriere/files/poudriere.d/{{ jname }}-{{ tname }}-make.conf.jinja
    - template: jinja
    - require:
      - pkg: sae|poudriere|pkg

sae|poudriere|make-conf-{{ jname }}-{{ tname }}-cds:
  file.managed:
    - name: /usr/local/etc/poudriere.d/{{ jname }}-{{ tname }}-cds-make.conf
    - source: salt://sae-poudriere/files/poudriere.d/{{ jname }}-{{ tname }}-cds-make.conf.jinja
    - template: jinja
    - require:
      - pkg: sae|poudriere|pkg
{% endfor %}
{% endfor %}

{% for ptreename, ptree in llports_map['ports'].iteritems() %}
sae|poudriere|portstree-{{ ptreename }}:
  cmd.run:
    - name: poudriere ports -c -p '{{ ptreename }}' -m '{{ ptree['method'] }}' -U '{{ ptree['url'] }}' -B '{{ ptree['branch'] }}'
    - unless: poudriere ports -qln | grep -q '{{ ptreename }}'
    - shell: /bin/sh
    - require:
      - pkg: sae|poudriere|pkg
sae|poudriere|portlist_{{ ptreename }}:
  file.managed:
    - name: /usr/local/etc/all_ports_{{ ptreename }}.txt
    - source: salt://sae-poudriere/files/all_ports_{{ ptreename }}.txt
    - mode: 644
    - require:
      - pkg: sae|poudriere|pkg
{% endfor %}
