{% from "sae-prometheus/map.jinja" import prometheus_config with context %}
{% from "pepper/map.jinja" import netblocks %}

include:
  - firewall.standard

sae|prometheus|alertmanager-firewall:
  firewall.accept:
    - tcp:
      - [ {{ prometheus_config.alertmanager_port }}, {{ netblocks }} ]
      - [ {{ prometheus_config.alertmanager_cluster_port }}, {{ netblocks }} ]
    - require_in:
      - firewall: core|firewall|final-reject

sae|prometheus|alertmanager-archive:
  archive.extracted:
    - name: /opt
    - source: http://images.llnw.net/prometheus/alertmanager-{{ prometheus_config.alertmanager_version }}.linux-amd64.tar.gz
    - source_hash: http://images.llnw.net/prometheus/alertmanager-{{ prometheus_config.alertmanager_version }}.linux-amd64.tar.gz.md5
    - if_missing: /opt/alertmanager-{{ prometheus_config.alertmanager_version }}.linux-amd64
    - user: alertmanager
    - group: alertmanager
    - require:
      - user: sae|prometheus|alertmanager-user
      - group: sae|prometheus|alertmanager-user

sae|prometheus|alertmanager-symlink:
  file.symlink:
    - name: /opt/alertmanager
    - target: /opt/alertmanager-{{ prometheus_config.alertmanager_version }}.linux-amd64
    - force: True
    - require:
      - archive: sae|prometheus|alertmanager-archive

sae|prometheus|alertmanager-sbin-symlink:
  file.symlink:
    - name: /usr/sbin/alertmanager
    - target: /opt/alertmanager-{{ prometheus_config.alertmanager_version }}.linux-amd64/alertmanager
    - force: True
    - require:
      - archive: sae|prometheus|alertmanager-archive

sae|prometheus|alertmanager-data-dir:
  file.directory:
    - name: /var/lib/alertmanager/data
    - makedirs: True
    - user: alertmanager
    - group: alertmanager
    - dir_mode: 755
    - file_mode: 644
    - require:
      - user: sae|prometheus|alertmanager-user
      - group: sae|prometheus|alertmanager-user

sae|prometheus|alertmanager-user:
  group.present:
    - name: alertmanager
  user.present:
    - name: alertmanager
    - shell: /bin/false
    - gid_from_name: True
    - createhome: False
    - system: True

sae|prometheus|alertmanager-config:
  file.managed:
    - name: /etc/prometheus/alertmanager.yml
    - source: salt://sae-prometheus/files/alertmanager.yml.jinja
    - template: jinja
    - user: alertmanager
    - group: alertmanager
    - makedirs: True
    - require:
      - user: sae|prometheus|alertmanager-user
      - group: sae|prometheus|alertmanager-user

sae|prometheus|alertmanager-service:
  file.managed:
    - name: /etc/systemd/system/alertmanager.service
    - source: salt://sae-prometheus/files/alertmanager.service.jinja
    - template: jinja
    - defaults:
        alertmanager_environment_file: {{ prometheus_config.alertmanager_environment_file }}
        alertmanager_version: {{ prometheus_config.alertmanager_version }}
    - watch_in:
      - service: sae|prometheus|alertmanager-service-running

sae|prometheus|alertmanager-service-running:
  service.running:
    - name: alertmanager
    - enable: True
    - require:
      - file: sae|prometheus|alertmanager-service
    - watch:
      - file: sae|prometheus|alertmanager-service
      - file: sae|prometheus|alertmanager-default
      - archive: sae|prometheus|alertmanager-archive

sae|prometheus|alertmanager-service-reload:
  module.run:
    - name: service.systemctl_reload
    - onchanges:
      - file: sae|prometheus|alertmanager-service

sae|prometheus|alertmanager-default:
  file.managed:
    - name: /etc/default/alertmanager
    - source: salt://sae-prometheus/files/alertmanager_options.jinja
    - template: jinja
    - defaults:
        prometheus_config: {{ prometheus_config }}
    - require:
      - archive: sae|prometheus|alertmanager-archive
