{% from "sae-prometheus/exporter/map.jinja" import exporter_config with context %}
{% from "pepper/map.jinja" import netblocks %}

include:
  - firewall.standard

sae|prometheus|exporter|blackbox-firewall:
  firewall.accept:
    - tcp:
      - [ {{ exporter_config.blackbox_exporter_port }}, {{ netblocks }} ]
    - require_in:
      - firewall: core|firewall|final-reject

sae|prometheus|exporter|blackbox-exporter-archive:
  archive.extracted:
    - name: /opt
    - source: http://images.llnw.net/prometheus/blackbox_exporter-{{ exporter_config.blackbox_exporter_version }}.linux-amd64.tar.gz
    - source_hash: http://images.llnw.net/prometheus/blackbox_exporter-{{ exporter_config.blackbox_exporter_version }}.linux-amd64.tar.gz.md5
    - if_missing: /opt/blackbox_exporter-{{ exporter_config.blackbox_exporter_version }}.linux-amd64
    - user: blackbox_exporter
    - group: blackbox_exporter
    - require:
      - user: sae|prometheus|exporter|blackbox-exporter-user
      - group: sae|prometheus|exporter|blackbox-exporter-user

sae|prometheus|exporter|blackbox-exporter-symlink:
  file.symlink:
    - name: /opt/blackbox_exporter
    - target: /opt/blackbox_exporter-{{ exporter_config.blackbox_exporter_version }}.linux-amd64
    - force: True
    - require:
      - archive: sae|prometheus|exporter|blackbox-exporter-archive

sae|prometheus|exporter|blackbox-exporter-sbin-symlink:
  file.symlink:
    - name: /usr/sbin/blackbox_exporter
    - target: /opt/blackbox_exporter-{{ exporter_config.blackbox_exporter_version }}.linux-amd64/blackbox_exporter
    - force: True
    - require:
      - archive: sae|prometheus|exporter|blackbox-exporter-archive

sae|prometheus|exporter|blackbox-exporter-user:
  group.present:
    - name: blackbox_exporter
  user.present:
    - name: blackbox_exporter
    - shell: /bin/false
    - gid_from_name: True
    - createhome: False
    - system: True

sae|prometheus|exporter|blackbox-exporter-service:
  file.managed:
    - name: /etc/systemd/system/blackbox_exporter.service
    - source: salt://sae-prometheus/exporter/files/blackbox_exporter.service.jinja
    - template: jinja
    - defaults:
        blackbox_exporter_environment_file: {{ exporter_config.blackbox_exporter_environment_file }}
        blackbox_exporter_version: {{ exporter_config.blackbox_exporter_version }}
    - watch_in:
      - service: sae|prometheus|exporter|blackbox-exporter-service-running

sae|prometheus|exporter|blackbox-exporter-service-running:
  service.running:
    - name: blackbox_exporter
    - enable: True
    - require:
      - file: sae|prometheus|exporter|blackbox-exporter-service
    - watch:
      - file: sae|prometheus|exporter|blackbox-exporter-service
      - archive: sae|prometheus|exporter|blackbox-exporter-archive

sae|prometheus|exporter|blackbox-exporter-service-reload:
  module.run:
    - name: service.systemctl_reload
    - onchanges:
      - file: /etc/systemd/system/blackbox_exporter.service

sae|prometheus|exporter|blackbox-exporter-default:
  file.managed:
    - name: /etc/default/blackbox_exporter
    - source: salt://sae-prometheus/exporter/files/blackbox_exporter_options.jinja
    - template: jinja
    - require:
      - archive: sae|prometheus|exporter|blackbox-exporter-archive
