{% from "sae-prometheus/exporter/map.jinja" import exporter_config with context %}

sae|prometheus|exporter|netdata-copy-archive:
  file.managed:
    - name: /usr/local/src/netdata-{{ exporter_config.netdata_version }}.gz.run
    - source: http://images.llnw.net/netdata/netdata-{{ exporter_config.netdata_version }}.gz.run
    - source_hash: http://images.llnw.net/netdata/netdata-{{ exporter_config.netdata_version }}.gz.run.md5
    - user: root
    - group: root
    - mode: 700
    - replace: False

sae|prometheus|exporter|netdata-install:
  cmd.run:
    - name: /usr/local/src/netdata-{{ exporter_config.netdata_version }}.gz.run --quiet --accept --noprogress --nox11 -- --dont-start-it
    - unless: grep {{ exporter_config.netdata_version }} /opt/netdata/netdata.version

sae|prometheus|exporter|netdata-touch-version:
  file.managed:
    - name: /opt/netdata/netdata.version
    - contents: {{ exporter_config.netdata_version }}

sae|prometheus|exporter|netdata-config:
  file.managed:
    - name: /opt/netdata/etc/netdata/netdata.conf
    - source: salt://sae-prometheus/exporter/files/netdata.conf.jinja
    - template: jinja
    - user: netdata
    - group: netdata
    - mode: 644
    - defaults:
      netdata_version: {{ exporter_config.netdata_version }}
    - require:
      - cmd: sae|prometheus|exporter|netdata-install

sae|prometheus|exporter|netdata-service-running:
  service.running:
    - name: netdata
    - enable: True
    - watch:
      - file: sae|prometheus|exporter|netdata-config

sae|prometheus|exporter|service-reload:
  module.run:
    - name: service.systemctl_reload
    - onchanges:
      - file: sae|prometheus|exporter|netdata-config

sae|prometheus|exporter|netdata-ssl-dir:
  file.directory:
    - name: /opt/netdata/etc/ssl
    - user: netdata
    - group: netdata
    - mode: 755

sae|prometheus|exporter|netdata-ssl-cert:
  file.managed:
    - name: /opt/netdata/etc/ssl/cert.pem
    - mkdirs: true
    - user: netdata
    - group: netdata
    - mode: 400
    - contents_pillar: secrets:exporterssl:exportercrt
    - require:
      - file: sae|prometheus|exporter|netdata-ssl-dir
      - cmd: sae|prometheus|exporter|netdata-install


sae|prometheus|exporter|netdata-ssl-key:
  file.managed:
    - name: /opt/netdata/etc/ssl/key.pem
    - user: netdata
    - group: netdata
    - mode: 400
    - contents_pillar: secrets:exporterssl:exporterkey
    - require:
      - cmd: sae|prometheus|exporter|netdata-install

