{% from "sae-prometheus/exporter/map.jinja" import exporter_config with context %}

sae|prometheus|exporter|node-exporter-archive:
  archive.extracted:
    - name: /opt
    - source: http://images.llnw.net/prometheus/node_exporter-{{ exporter_config.node_exporter_version }}.linux-amd64.tar.gz
    - source_hash: http://images.llnw.net/prometheus/node_exporter-{{ exporter_config.node_exporter_version }}.linux-amd64.tar.gz.md5
    - if_missing: /opt/node_exporter-{{ exporter_config.node_exporter_version }}.linux-amd64
    - user: node_exporter
    - group: node_exporter
    - require:
      - user: sae|prometheus|exporter|node-exporter-user
      - group: sae|prometheus|exporter|node-exporter-user
      - file: sae|prometheus|exporter|node-exporter-textfile-collector-dir

sae|prometheus|exporter|node-exporter-symlink:
  file.symlink:
    - name: /opt/node_exporter
    - target: /opt/node_exporter-{{ exporter_config.node_exporter_version }}.linux-amd64
    - force: True
    - require:
      - archive: sae|prometheus|exporter|node-exporter-archive

sae|prometheus|exporter|node-exporter-sbin-symlink:
  file.symlink:
    - name: /usr/sbin/node_exporter
    - target: /opt/node_exporter-{{ exporter_config.node_exporter_version }}.linux-amd64/node_exporter
    - force: True
    - require:
      - archive: sae|prometheus|exporter|node-exporter-archive

sae|prometheus|exporter|node-exporter-user:
  group.present:
    - name: node_exporter
  user.present:
    - name: node_exporter
    - shell: /bin/false
    - gid_from_name: True
    - createhome: False
    - system: True

sae|prometheus|exporter|node-exporter-textfile-collector-dir:
  file.directory:
    - name: {{ exporter_config.node_exporter_textfile_collector }}
    - user: node_exporter
    - group: node_exporter
    - makedirs: True
    - require:
      - user: sae|prometheus|exporter|node-exporter-user
      - group: sae|prometheus|exporter|node-exporter-user

sae|prometheus|exporter|node-exporter-service:
  file.managed:
{%- if grains.get('init') == 'systemd' %}
    - name: /etc/systemd/system/node_exporter.service
    - source: salt://sae-prometheus/exporter/files/node_exporter.service.jinja
{%- elif grains.get('init') == 'upstart' %}
    - name: /etc/init.d/node_exporter
    - source: salt://sae-prometheus/exporter/files/node_exporter.init.jinja
    - mode: 755
{%- endif %}
    - template: jinja
    - defaults:
        node_exporter_environment_file: {{ exporter_config.node_exporter_environment_file }}
        node_exporter_version: {{ exporter_config.node_exporter_version }}
    - watch_in:
      - service: sae|prometheus|exporter|node-exporter-service-running

{% if grains.get('init') == 'upstart' %}
sae|prometheus|exporter|daemon-pkg:
  pkg.installed:
    - name: daemon

sae|prometheus|exporter|init-helper:
  file.managed:
    - name: /usr/local/lib/init-d-script
    - source: salt://sae-prometheus/exporter/files/init-d-script
    - require:
      - pkg: sae|prometheus|exporter|daemon-pkg
{%- endif %}

sae|prometheus|exporter|node-exporter-service-running:
  service.running:
    - name: node_exporter
    - enable: True
    - require:
      - file: sae|prometheus|exporter|node-exporter-service
    - watch:
      - file: sae|prometheus|exporter|node-exporter-service
      - archive: sae|prometheus|exporter|node-exporter-archive

{% if grains.get('init') == 'systemd' %}
sae|prometheus|exporter|node-exporter-service-reload:
  module.run:
    - name: service.systemctl_reload
    - onchanges:
      - file: /etc/systemd/system/node_exporter.service
{%- endif %}

sae|prometheus|exporter|node-exporter-default:
  file.managed:
    - name: /etc/default/node_exporter
    - source: salt://sae-prometheus/exporter/files/node_exporter_options.jinja
    - template: jinja
    - defaults:
        node_exporter_textfile_collector: {{ exporter_config.node_exporter_textfile_collector }}
    - require:
      - archive: sae|prometheus|exporter|node-exporter-archive
