{% from "sae-prometheus/exporter/map.jinja" import exporter_config with context %}
{% from "pepper/map.jinja" import netblocks %}

include:
  - firewall.standard

sae|prometheus|exporter|snmp-firewall:
  firewall.accept:
    - tcp:
      - [ {{ exporter_config.snmp_exporter_port }}, {{ netblocks }} ]
    - require_in:
      - firewall: core|firewall|final-reject

sae|prometheus|exporter|snmp-exporter-archive:
  archive.extracted:
    - name: /opt
    - source: http://images.llnw.net/prometheus/snmp_exporter-{{ exporter_config.snmp_exporter_version }}.linux-amd64.tar.gz
    - source_hash: http://images.llnw.net/prometheus/snmp_exporter-{{ exporter_config.snmp_exporter_version }}.linux-amd64.tar.gz.md5
    - if_missing: /opt/snmp_exporter-{{ exporter_config.snmp_exporter_version }}.linux-amd64
    - user: snmp_exporter
    - group: snmp_exporter
    - require:
      - user: sae|prometheus|exporter|snmp-exporter-user
      - group: sae|prometheus|exporter|snmp-exporter-user

sae|prometheus|exporter|snmp-exporter-symlink:
  file.symlink:
    - name: /opt/snmp_exporter
    - target: /opt/snmp_exporter-{{ exporter_config.snmp_exporter_version }}.linux-amd64
    - force: True
    - require:
      - archive: sae|prometheus|exporter|snmp-exporter-archive

sae|prometheus|exporter|snmp-exporter-sbin-symlink:
  file.symlink:
    - name: /usr/sbin/snmp_exporter
    - target: /opt/snmp_exporter-{{ exporter_config.snmp_exporter_version }}.linux-amd64/snmp_exporter
    - force: True
    - require:
      - archive: sae|prometheus|exporter|snmp-exporter-archive

sae|prometheus|exporter|snmp-exporter-user:
  group.present:
    - name: snmp_exporter
  user.present:
    - name: snmp_exporter
    - shell: /bin/false
    - gid_from_name: True
    - createhome: False
    - system: True

sae|prometheus|exporter|snmp-exporter-service:
  file.managed:
    - name: /etc/systemd/system/snmp_exporter.service
    - source: salt://sae-prometheus/exporter/files/snmp_exporter.service.jinja
    - template: jinja
    - defaults:
        snmp_exporter_environment_file: {{ exporter_config.snmp_exporter_environment_file }}
        snmp_exporter_version: {{ exporter_config.snmp_exporter_version }}
    - watch_in:
      - service: sae|prometheus|exporter|snmp-exporter-service-running

sae|prometheus|exporter|snmp-exporter-yml:
  file.managed:
    - name: /etc/snmp_exporter/snmp.yml
    - source: salt://sae-prometheus/exporter/files/snmp_exporter_yml.jinja
    - template: jinja
    - user: snmp_exporter
    - group: snmp_exporter
    - require:
      - file: sae|prometheus|exporter|snmp-exporter-dir
      - user: sae|prometheus|exporter|snmp-exporter-user
      - group: sae|prometheus|exporter|snmp-exporter-user

sae|prometheus|exporter|snmp-exporter-dir:
  file.directory:
    - name: /etc/snmp_exporter

sae|prometheus|exporter|snmp-exporter-service-running:
  service.running:
    - name: snmp_exporter
    - enable: True
    - require:
      - file: sae|prometheus|exporter|snmp-exporter-service
    - watch:
      - file: sae|prometheus|exporter|snmp-exporter-service
      - archive: sae|prometheus|exporter|snmp-exporter-archive

sae|prometheus|exporter|snmp-exporter-service-reload:
  module.run:
    - name: service.systemctl_reload
    - onchanges_any:
      - file: sae|prometheus|exporter|snmp-exporter-service
      - file: sae|prometheus|exporter|snmp-exporter-yml

sae|prometheus|exporter|snmp-exporter-default:
  file.managed:
    - name: /etc/default/snmp_exporter
    - source: salt://sae-prometheus/exporter/files/snmp_exporter_options.jinja
    - template: jinja
    - require:
      - archive: sae|prometheus|exporter|snmp-exporter-archive
