{% from "sae-prometheus/map.jinja" import prometheus_config with context %}
{% from "sae-prometheus/exporter/map.jinja" import exporter_config with context %}
{% from "sae-prometheus/environment.jinja" import environment %}
{% from "pepper/map.jinja" import netblocks %}
{% from "sysctl/map.jinja" import sysctl with context %}

include:
  - .common
  - .target-configure
  - .exporter.node_exporter
  - firewall.standard
{%- if grains['fqdn'] in prometheus_config.prometheus_servers %}
  - .alertmanager
{% endif %}

{{ sysctl('net-ipv6-conf-all-disable_ipv6-1', 'net.ipv6.conf.all.disable_ipv6', 1) }}
{{ sysctl('net-ipv6-conf-default-disable_ipv6-1', 'net.ipv6.conf.default.disable_ipv6', 1) }}
{{ sysctl('net-ipv6-conf-lo-disable_ipv6-1', 'net.ipv6.conf.lo.disable_ipv6', 1) }}
{% if 'production' in environment %}
{{ sysctl('net-ipv6-conf-bond0-disable_ipv6-1', 'net.ipv6.conf.bond0.disable_ipv6', 1) }}
{% endif %}

{% set prom_list = [] %}
{% for host in prometheus_config.prometheus_servers %}
{%   if 'dev' in host or 'stage' in host %}{% continue %}{% endif %}
{%   set prom_host = salt['dnsutil.A'](host) %}
{%   do prom_list.append(prom_host[0]) %}
{% endfor %}

{% set fed_list = [] %}
{% for host in prometheus_config.federation_servers %}
{%   if 'dev' in host or 'stage' in host %}{% continue %}{% endif %}
{%   set fed_host = salt['dnsutil.A'](host) %}
{%   do fed_list.append(fed_host[0]) %}
{% endfor %}

{% set grafana_list = ['69.164.61.157','69.164.61.158'] %}

{% set ip_list = prom_list + fed_list + grafana_list %}

extend:
  sae|prometheus|exporter|node-exporter-default:
    file.managed:
      - source: salt://sae-prometheus/files/node_exporter_options.jinja

sae|prometheus|ui-firewall:
  firewall.accept:
    - tcp:
      {%- if 'dev' in grains['fqdn'] or 'stage' in grains['fqdn'] %}
      - [ {{ prometheus_config.server_port }}, {{ netblocks }} ]
      {%- else %}
      - [ {{ prometheus_config.server_port }}, {{ ip_list }} ]
      {%- endif %}
    - require_in:
      - firewall: core|firewall|final-reject

sae|prometheus|server-archive:
  archive.extracted:
    - name: /usr/local
    - source: http://images.llnw.net/prometheus/prometheus-{{ prometheus_config.server_version }}.linux-amd64.tar.gz
    - source_hash: http://images.llnw.net/prometheus/prometheus-{{ prometheus_config.server_version }}.linux-amd64.tar.gz.md5
    - if_missing: /usr/local/prometheus-{{ prometheus_config.server_version }}.linux-amd64
    - user: prometheus
    - group: prometheus
    - require:
      - user: sae|prometheus|user
      - group: sae|prometheus|user
      - file: sae|prometheus|log-dir

sae|prometheus|symlink:
  file.symlink:
    - name: {{ prometheus_config.install_symlink }}
    - target: /usr/local/prometheus-{{ prometheus_config.server_version }}.linux-amd64
    - force: True
    - require:
      - archive: sae|prometheus|server-archive

{% if salt['mount.is_mounted'](prometheus_config.data_mount) %}
sae|prometheus|data-dir:
  file.directory:
    - name: {{ prometheus_config.data_dir }}
    - user: prometheus
    - group: prometheus
    - require:
      - user: sae|prometheus|user
      - group: sae|prometheus|user
{% endif %}

sae|prometheus|config:
  file.managed:
    - name: /etc/prometheus/prometheus.yml
    - source: salt://sae-prometheus/files/prometheus.yml.jinja
    - template: jinja
    - user: prometheus
    - group: prometheus
    - defaults:
        prometheus_config: {{ prometheus_config }}
    - require:
      - user: sae|prometheus|user
      - group: sae|prometheus|user

sae|prometheus|recording-rules:
  file.managed:
    - name: /etc/prometheus/recording_rules.yml
    - source: salt://sae-prometheus/files/recording_rules.yml.jinja
    - template: jinja
    - user: prometheus
    - group: prometheus
    - require:
      - user: sae|prometheus|user
      - group: sae|prometheus|user

sae|prometheus|service:
  file.managed:
    - name: /etc/systemd/system/prometheus.service
    - source: salt://sae-prometheus/files/prometheus.service.jinja
    - template: jinja
    - defaults:
        prometheus_config: {{ prometheus_config }}
    - require:
      - archive: sae|prometheus|server-archive
      - file: sae|prometheus|config

sae|prometheus|logrotate:
  file.managed:
    - name: /etc/logrotate.d/prometheus
    - source: salt://sae-prometheus/files/prometheus-logrotate.jinja
    - template: jinja
    - user: root
    - group: root
    - mode: 644

sae|prometheus|service-running:
  service.running:
    - name: prometheus
    - enable: True
    - reload: True
    - watch:
      - file: sae|prometheus|config
      - file: sae|prometheus|recording-rules
{%- if grains['fqdn'] in prometheus_config.prometheus_servers %}
      - file: sae|prometheus|alerting-rules
{%- endif %}

sae|prometheus|service-reload:
  module.run:
    - name: service.systemctl_reload
    - onchanges:
      - file: sae|prometheus|service

{%- if grains['fqdn'] in prometheus_config.prometheus_servers %}
sae|prometheus|alerting-rules:
  file.managed:
    - name: /etc/prometheus/alerting_rules.yml
    - source: salt://sae-prometheus/files/alerting_rules.yml.{{ 'dev' if 'dynamic' in environment else environment }}.jinja
    - template: jinja
    - user: prometheus
    - group: prometheus
    - require:
      - user: sae|prometheus|user
      - group: sae|prometheus|user

sae|prometheus|targets-common:
  file.managed:
    - name: /etc/prometheus/targets_common.yml
    - source: salt://sae-prometheus/files/targets_base.yml.jinja
    - template: jinja
    - user: prometheus
    - group: prometheus
    - require:
      - user: sae|prometheus|user
      - group: sae|prometheus|user

sae|prometheus|targets-common-https:
  file.managed:
    - name: /etc/prometheus/targets_common_https.yml
    - source: salt://sae-prometheus/files/targets_base.yml.jinja
    - template: jinja
    - user: prometheus
    - group: prometheus
    - require:
      - user: sae|prometheus|user
      - group: sae|prometheus|user

sae|prometheus|targets-exceptions:
  file.managed:
    - name: /etc/prometheus/targets_exceptions.yml
    - source: salt://sae-prometheus/files/targets_exceptions.yml.jinja
    - template: jinja
    - user: prometheus
    - group: prometheus
    - require:
      - user: sae|prometheus|user
      - group: sae|prometheus|user

sae|prometheus|targets-exceptions-https:
  file.managed:
    - name: /etc/prometheus/targets_exceptions_https.yml
    - source: salt://sae-prometheus/files/targets_exceptions_https.yml.jinja
    - template: jinja
    - user: prometheus
    - group: prometheus
    - require:
      - user: sae|prometheus|user
      - group: sae|prometheus|user

sae|prometheus|targets-netdata:
  file.managed:
    - name: /etc/prometheus/targets_netdata.yml
    - source: salt://sae-prometheus/files/targets_base.yml.jinja
    - template: jinja
    - user: prometheus
    - group: prometheus
    - require:
      - user: sae|prometheus|user
      - group: sae|prometheus|user

sae|prometheus|targets-rtsv2:
  file.managed:
    - name: /etc/prometheus/targets_rtsv2.yml
    - source: salt://sae-prometheus/files/targets_base.yml.jinja
    - template: jinja
    - user: prometheus
    - group: prometheus
    - require:
      - user: sae|prometheus|user
      - group: sae|prometheus|user

sae|prometheus|targets-ltf: 
  file.managed:
    - name: /etc/prometheus/targets_ltf.yml
    - source: salt://sae-prometheus/files/targets_base.yml.jinja
    - template: jinja
    - user: prometheus
    - group: prometheus
    - require: 
      - user: sae|prometheus|user
      - group: sae|prometheus|user

sae|prometheus|targets-snmp-ifmib:
  file.managed:
    - name: /etc/prometheus/targets_snmp_ifmib.yml
    - source: salt://sae-prometheus/files/targets_snmp.yml.jinja
    - template: jinja
    - user: prometheus
    - group: prometheus
    - require:
      - user: sae|prometheus|user
      - group: sae|prometheus|user

sae|prometheus|targets-snmp-arista:
  file.managed:
    - name: /etc/prometheus/targets_snmp_arista.yml
    - source: salt://sae-prometheus/files/targets_snmp.yml.jinja
    - template: jinja 
    - user: prometheus
    - group: prometheus
    - require:
      - user: sae|prometheus|user
      - group: sae|prometheus|user

sae|prometheus|targets-snmp-brocade:
  file.managed:
    - name: /etc/prometheus/targets_snmp_brocade.yml
    - source: salt://sae-prometheus/files/targets_snmp.yml.jinja
    - template: jinja 
    - user: prometheus
    - group: prometheus
    - require:
      - user: sae|prometheus|user
      - group: sae|prometheus|user
{% endif %}
