{% from "sae-prometheus/test/map.jinja" import test_config with context %}
{% from "pepper/map.jinja" import netblocks %}

include:
  - firewall.standard

sae|prometheus|test|bulk-node-exporter-firewall:
  firewall.accept:
    - tcp:
      {% for port in test_config['node_exporter_ports'] %}
      - [ "{{ port }}:{{ port + test_config['nginx_proxied_port_count'] }}", {{ netblocks }} ]
      {% endfor %}
    - require_in:
      - firewall: core|firewall|final-reject

sae|prometheus|test|packages:
  pkg.installed:
    - name: nginx

sae|prometheus|test|bulk-node-exporter-archive:
  archive.extracted:
    - name: /opt
    - source: http://images.llnw.net/prometheus/node_exporter-{{ test_config.node_exporter_version }}.linux-amd64.tar.gz
    - source_hash: http://images.llnw.net/prometheus/node_exporter-{{ test_config.node_exporter_version }}.linux-amd64.tar.gz.md5
    - if_missing: /opt/node_exporter-{{ test_config.node_exporter_version }}.linux-amd64
    - user: node_exporter
    - group: node_exporter
    - require:
      - user: sae|prometheus|test|bulk-node-exporter-user
      - group: sae|prometheus|test|bulk-node-exporter-user
      - file: sae|prometheus|test|bulk-node-exporter-textfile-collector-dir

sae|prometheus|test|bulk-node-exporter-symlink:
  file.symlink:
    - name: /opt/node_exporter
    - target: /opt/node_exporter-{{ test_config.node_exporter_version }}.linux-amd64
    - force: True
    - require:
      - archive: sae|prometheus|test|bulk-node-exporter-archive

sae|prometheus|test|bulk-node-exporter-sbin-symlink:
  file.symlink:
    - name: /usr/sbin/node_exporter
    - target: /opt/node_exporter-{{ test_config.node_exporter_version }}.linux-amd64/node_exporter
    - force: True
    - require:
      - archive: sae|prometheus|test|bulk-node-exporter-archive

sae|prometheus|test|bulk-node-exporter-user:
  group.present:
    - name: node_exporter
  user.present:
    - name: node_exporter
    - shell: /bin/false
    - gid_from_name: True
    - createhome: False
    - system: True

sae|prometheus|test|bulk-node-exporter-textfile-collector-dir:
  file.directory:
    - name: {{ test_config.node_exporter_textfile_collector }}
    - user: node_exporter
    - group: node_exporter
    - makedirs: True
    - require:
      - user: sae|prometheus|test|bulk-node-exporter-user
      - group: sae|prometheus|test|bulk-node-exporter-user

{% for port in test_config['node_exporter_ports'] %}
sae|prometheus|test|bulk-node-exporter-default-{{ port }}:
  file.managed:
    - name: /etc/default/node_exporter_{{ port }}
    - source: salt://sae-prometheus/test/files/node_exporter_options.jinja
    - template: jinja
    - defaults:
        port: {{ port }}
        node_exporter_textfile_collector: {{ test_config.node_exporter_textfile_collector }}
    - require:
      - archive: sae|prometheus|test|bulk-node-exporter-archive

sae|prometheus|test|bulk-node-exporter-service-{{ port }}:
  file.managed:
    - name: /etc/systemd/system/node_exporter_{{ port }}.service
    - source: salt://sae-prometheus/test/files/node_exporter.service.jinja
    - template: jinja
    - defaults:
        node_exporter_environment_file: /etc/default/node_exporter_{{ port }}
        node_exporter_version: {{ test_config.node_exporter_version }}
        port: {{ port }}
    - watch_in:
      - service: sae|prometheus|test|bulk-node-exporter-service-running-{{ port }}

sae|prometheus|test|bulk-node-exporter-service-running-{{ port }}:
  service.running:
    - name: node_exporter_{{ port }}
    - enable: True
    - require:
      - file: sae|prometheus|test|bulk-node-exporter-service-{{ port }}
    - watch:
      - file: sae|prometheus|test|bulk-node-exporter-service-{{ port }}
      - archive: sae|prometheus|test|bulk-node-exporter-archive

sae|prometheus|test|bulk-node-exporter-service-reload-{{ port }}:
  module.run:
    - name: service.systemctl_reload
    - onchanges:
      - file: /etc/systemd/system/node_exporter_{{ port }}.service
{% endfor %}

sae|prometheus|test|nginx-config:
  file.managed:
    - name: /etc/nginx/sites-available/bulk-nginx.conf
    - source: salt://sae-prometheus/test/files/nginx.conf.jinja
    - template: jinja
    - defaults:
        test_config: {{ test_config }}
    - require:
      - pkg: sae|prometheus|test|packages

sae|prometheus|test|nginx-service-running:
  service.running:
    - name: nginx
    - enable: True
    - reload: True
    - require:
      - file: sae|prometheus|test|nginx-config
      - pkg: sae|prometheus|test|packages
    - watch:
      - file: sae|prometheus|test|nginx-config
