{% from "sae-prometheus/uat/map.jinja" import prometheus_config with context %}
{% from "sysctl/map.jinja" import sysctl with context %}

{{ sysctl('net-ipv6-conf-all-disable_ipv6-1', 'net.ipv6.conf.all.disable_ipv6', 1) }}
{{ sysctl('net-ipv6-conf-default-disable_ipv6-1', 'net.ipv6.conf.default.disable_ipv6', 1) }}
{{ sysctl('net-ipv6-conf-lo-disable_ipv6-1', 'net.ipv6.conf.lo.disable_ipv6', 1) }}

sae|prometheus|uat|user:
  group.present:
    - name: prometheus
  user.present:
    - name: prometheus
    - shell: /bin/false
    - gid_from_name: True
    - createhome: False
    - system: True

sae|prometheus|uat|log-dir:
  file.directory:
    - name: /var/log/prometheus
    - user: prometheus
    - group: prometheus
    - require:
      - user: sae|prometheus|uat|user
      - group: sae|prometheus|uat|user

sae|prometheus|uat|etc-dir:
  file.directory:
    - name: /etc/prometheus
    - user: prometheus
    - group: prometheus
    - require:
      - user: sae|prometheus|uat|user
      - group: sae|prometheus|uat|user

sae|prometheus|uat|server-archive:
  archive.extracted:
    - name: /usr/local
    - source: http://images.llnw.net/prometheus/prometheus-{{ prometheus_config.server_version }}.linux-amd64.tar.gz
    - source_hash: http://images.llnw.net/prometheus/prometheus-{{ prometheus_config.server_version }}.linux-amd64.tar.gz.md5
    - if_missing: /usr/local/prometheus-{{ prometheus_config.server_version }}.linux-amd64
    - user: prometheus
    - group: prometheus
    - require:
      - user: sae|prometheus|uat|user
      - group: sae|prometheus|uat|user
      - file: sae|prometheus|uat|log-dir

sae|prometheus|uat|symlink:
  file.symlink:
    - name: {{ prometheus_config.install_symlink }}
    - target: /usr/local/prometheus-{{ prometheus_config.server_version }}.linux-amd64
    - force: True
    - require:
      - archive: sae|prometheus|uat|server-archive

sae|prometheus|uat|data-dir:
  file.directory:
    - name: {{ prometheus_config.data_dir }}
    - user: prometheus
    - group: prometheus
    - makedirs: True
    - require:
      - user: sae|prometheus|uat|user
      - group: sae|prometheus|uat|user

sae|prometheus|uat|config:
  file.managed:
    - name: /etc/prometheus/prometheus.yml
    - source: salt://sae-prometheus/uat/files/prometheus.yml.jinja
    - template: jinja
    - user: prometheus
    - group: prometheus
    - defaults:
        prometheus_config: {{ prometheus_config }}
    - require:
      - user: sae|prometheus|uat|user
      - group: sae|prometheus|uat|user
    - replaceTrue: False

sae|prometheus|uat|targets-common:
  file.managed:
    - name: /etc/prometheus/targets_common.yml
    - source: salt://sae-prometheus/uat/files/targets_common.yml.jinja
    - template: jinja
    - user: prometheus
    - group: prometheus
    - require:
      - user: sae|prometheus|uat|user
      - group: sae|prometheus|uat|user
    - replaceTrue: False

sae|prometheus|uat|targets-common-https:
  file.managed:
    - name: /etc/prometheus/targets_common_https.yml
    - source: salt://sae-prometheus/uat/files/targets_common_https.yml.jinja
    - template: jinja
    - user: prometheus
    - group: prometheus
    - require:
      - user: sae|prometheus|uat|user
      - group: sae|prometheus|uat|user
    - replaceTrue: False

sae|prometheus|uat|targets-netdata:
  file.managed:
    - name: /etc/prometheus/targets_netdata.yml
    - source: salt://sae-prometheus/uat/files/targets_netdata.yml.jinja
    - template: jinja
    - user: prometheus
    - group: prometheus
    - require:
      - user: sae|prometheus|uat|user
      - group: sae|prometheus|uat|user
    - replaceTrue: False

sae|prometheus|uat|service:
  file.managed:
    - name: /etc/systemd/system/prometheus.service
    - source: salt://sae-prometheus/uat/files/prometheus.service.jinja
    - template: jinja
    - defaults:
        prometheus_config: {{ prometheus_config }}
    - require:
      - archive: sae|prometheus|uat|server-archive
      - file: sae|prometheus|uat|config

sae|prometheus|uat|remove-prometheus-script:
  file.managed:
    - name: /usr/local/bin/remove-prometheus.sh
    - source: salt://sae-prometheus/uat/files/remove-prometheus.sh.jinja
    - template: jinja
    - defaults:
        version: {{ prometheus_config.server_version }}
    - user: root
    - group: root
    - mode: 744

sae|prometheus|uat|service-running:
  service.running:
    - name: prometheus
    - enable: True
    - reload: True
    - watch:
      - file: sae|prometheus|uat|config

sae|prometheus|uat|service-reload:
  module.run:
    - name: service.systemctl_reload
    - onchanges:
      - file: sae|prometheus|uat|service
