# vim: sts=2 ts=2 sw=2 et ai

{% from "sae-rancid/map.jinja" import rancid_conf with context %}

include:
  - .packages

sae|rancid|conf:
  file.managed:
    - name: /etc/rancid/rancid.conf
    - user: root
    - group: rancid
    - mode: 640
    - source: salt://sae-rancid/templates/rancid-conf.jinja
    - template: jinja
    - require:
      - pkg: sae|rancid|pkgs

sae|rancid|sync-conf:
  file.managed:
    - name: /etc/cornerstone-rancid-sync.yml
    - user: root
    - group: rancid
    - mode: 640
    - source: salt://sae-rancid/templates/sync-conf.jinja
    - template: jinja
    - require:
      - pkg: sae|rancid|pkgs

sae|rancid|git-config:
  file.managed:
    - name: {{ rancid_conf['home_dir'] }}/.gitconfig
    - user: rancid
    - group: rancid
    - mode: 664
    - source: salt://sae-rancid/templates/gitconfig.jinja
    - template: jinja
    - require:
      - pkg: sae|rancid|pkgs

# Minor gymnastics to deal with the repo dir being the home dir,
# because git will not clone to a dir that already exists.
sae|rancid|git-clone:
  cmd.run:
    - name: |
        mkdir -p `dirname {{ rancid_conf['repo_dir'] }}`
        git clone {{ rancid_conf['git_repo'] }} {{ rancid_conf['home_dir'] }}/rancid_git_clone
        rsync -a {{ rancid_conf['home_dir'] }}/rancid_git_clone/ {{ rancid_conf['repo_dir'] }}
        rm -rf {{ rancid_conf['home_dir'] }}/rancid_git_clone
    - runas: rancid
    - creates: {{ rancid_conf['repo_dir'] }}/README.md
    - require:
      - file: sae|rancid|git-key-private
      - file: sae|rancid|netrc|user
      - file: sae|rancid|git-config

sae|rancid|cloginrc:
  file.managed:
    - name: {{ rancid_conf['home_dir'] }}/.cloginrc
    - user: rancid
    - group: rancid
    - mode: 600
    - source: salt://sae-rancid/templates/cloginrc.jinja
    - template: jinja
    - require:
      - pkg: sae|rancid|pkgs

sae|rancid|ssh-dir:
  file.directory:
    - name: {{ rancid_conf['home_dir'] }}/.ssh
    - user: rancid
    - group: rancid
    - mode: 700
    - require:
      - pkg: sae|rancid|pkgs

sae|rancid|ssh-config:
  file.managed:
    - name: {{ rancid_conf['home_dir'] }}/.ssh/config
    - user: rancid
    - group: rancid
    - mode: 600
    - require:
      - file: sae|rancid|ssh-dir
    - contents: |
        # Allow some old crap that various devices need.
        # Don't bother checking or storing host keys, they change kind of often.
        Host *
            KexAlgorithms +diffie-hellman-group1-sha1
            HostKeyAlgorithms +ssh-dss
            StrictHostKeyChecking no
            UserKnownHostsFile /dev/null

# maybe should put this in .ssh/git_id_rsa and add a config file to use
# this key only for github.llnw.com
sae|rancid|git-key-private:
  file.managed:
    - name: {{ rancid_conf['home_dir'] }}/.ssh/id_rsa
    - user: rancid
    - group: rancid
    - mode: 600
    - contents_pillar: secrets:sae-rancid:git_ssh_key
    - require:
      - file: sae|rancid|ssh-dir

# create .netrc and git deploy token entry
sae|rancid|netrc:
  file.managed:
    - name: {{ rancid_conf.home_dir }}/.netrc
    - user: rancid
    - group: rancid
    - mode: 600
    - require:
      - pkg: sae|rancid|pkgs

sae|rancid|netrc|user:
  file.blockreplace:
    - name: {{ rancid_conf.home_dir }}//.netrc
    - marker_start: '# START {{ rancid_conf.https_user }} access'
    - marker_end: '# END {{ rancid_conf.https_user }} access'
    - append_if_not_found: True
    - show_changes: True
    - content: |
        machine gitlab.com
        login {{ rancid_conf.https_user }}
        password {{ salt['pillar.get']('secrets:sae-rancid:%s'|format(rancid_conf.https_user))|trim }}
    - require:
      - sae|rancid|netrc
