{% from "pepper/map.jinja" import defaults with context %}
{% from 'sae-repoui/map.jinja' import repo %}
{% from "sudoers/map.jinja" import sudo_map with context %}
{% set certname = 'star_hs_llnwd_net-256' %}

{% if salt['grains.get']('fqdn') == 'repoui-dev1.phx7.llnw.net' -%}
{% set environment = 'testing' -%}
{%- else -%}
{% set environment = 'production' -%}
{%- endif -%}

include:
  - firewall.standard
  - firewall.web
  - certs
  - proxy

sae|repoui|sudoers:
  file.managed:
    - name: {{ sudo_map.includedir }}/repoui
    - user: root
    - group: {{ defaults.root_group }}
    - mode: 440
    - contents: '%posix-lxvm-admin   ALL=(ALL:ALL) ALL'
    - require:
      - file: core|sudoers|includedir

sae|repoui|repo:
  pkgrepo.managed:
    - name: deb http://repo.llnw.net/llnw/ubuntu/{{ environment }}/repoui/ {{ salt['grains.get']('oscodename') }}/
    - file: /etc/apt/sources.list.d/repoui.list

sae|repoui|packages:
  pkg.latest:
    - names:
      - aptly
      - gnupg
      - repoui
    - skip_verify: True
    - require:
      - pkgrepo: sae|repoui|repo

sae|repoui|config:
  file.managed:
    - name: /etc/repoui/config.yaml
    - template: jinja
    - source: salt://sae-repoui/templates/config.yaml.jinja
    - require:
      - pkg: sae|repoui|packages
    - context:
        repo: {{ repo }}
    - defaults:
        environment: {{ environment }}
        amqp_pass: {{ salt['pillar.get']('secrets:sae-repoui:' + environment + ':amqp_pass') }}
        cookie_validation_key: {{ salt['pillar.get']('secrets:sae-repoui:' + environment + ':cookie_validation_key') }}
        db_pass: {{ salt['pillar.get']('secrets:sae-repoui:' + environment + ':db_pass') }}
        ldap_secretkey: {{ salt['pillar.get']('secrets:sae-repoui:' + environment + ':ldap_secretkey') }}

sae|repoui|aptlyconf:
  file.managed:
    - name: /etc/aptly.conf
    - mode: 444
    - source: salt://sae-repoui/files/aptly.conf

sae|repoui|aptlydir:
  file.directory:
    - name: /aptly

sae|repoui|uploaddir:
  file.directory:
    - name: /aptly/uploads
    - user: www-data
    - group: www-data
    - require:
      - file: sae|repoui|aptlydir
      - pkg: sae|repoui|packages

sae|repoui|gpg-private:
  file.managed:
    - name: /etc/repoui/gpg-private-key.asc
    - user: root
    - group: root
    - mode: 400
    - contents_pillar: secrets:sae-repoui:gpg_privatekey
    - require:
      - pkg: sae|repoui|packages

sae|repoui|gpg-passphrase:
  file.managed:
    - name: /etc/repoui/gpg-passphrase
    - user: root
    - group: root
    - mode: 400
    - contents_pillar: secrets:sae-repoui:gpg_passphrase
    - require:
      - pkg: sae|repoui|packages

sae|repoui|gpg-public:
  file.managed:
    - name: /etc/repoui/gpg-public-key.asc
    - user: root
    - group: root
    - mode: 444
    - source: salt://sae-repoui/files/gpg-public-key.asc
    - require:
      - pkg: sae|repoui|packages

sae|repoui|gpg-import:
  cmd.run:
    - name: gpg --allow-secret-key-import --import /etc/repoui/gpg-private-key.asc
    - unless: gpg --list-keys | grep {{ repo.gpg_key_id }}
    - require:
      - file: sae|repoui|gpg-private

sae|repoui|apache-ports:
  file.managed:
    - name: /etc/apache2/ports.conf
    - source: salt://sae-repoui/files/ports.conf
    - require:
      - pkg: sae|repoui|packages
    - watch_in:
      - service: sae|repoui|apache2

sae|repoui|apache-repoui:
  file.managed:
    - name: /etc/apache2/sites-available/repoui.conf
    - source: salt://sae-repoui/templates/apache.conf.jinja
    - require:
      - pkg: sae|repoui|packages
    - template: jinja
    - defaults:
        vhost: {{ repo.vhost }}
        cert: {{ cert_path['certdir'] }}/{{ cert_path['certname'] }}.crt
        key: {{ cert_path['keydir'] }}/{{ cert_path['certname'] }}.key
        intermediate: {{ cert_path['certdir'] }}/{{ cert_path['intermediatebundle'] }}
    - watch_in:
      - service: sae|repoui|apache2

sae|repoui|apache-a2dissite-default:
  cmd.run:
    - name: a2dissite 000-default
    - onlyif: test -L /etc/apache2/sites-enabled/000-default.conf
    - require:
      - pkg: sae|repoui|packages
    - watch_in:
      - service: sae|repoui|apache2

{% for mod in ['rewrite', 'ssl', 'headers'] %}
sae|repoui|apache-a2enmod-{{ mod }}:
  cmd.run:
    - name: a2enmod {{ mod }}
    - unless: test -L /etc/apache2/mods-enabled/{{ mod }}.load
    - require:
      - pkg: sae|repoui|packages
    - watch_in:
      - service: sae|repoui|apache2
{% endfor %}

sae|repoui|apache-a2ensite-repoui:
  cmd.run:
    - name: a2ensite repoui
    - unless: test -L /etc/apache2/sites-enabled/repoui.conf
    - watch:
      - file: sae|repoui|apache-repoui
    - watch_in:
      - service: sae|repoui|apache2

sae|repoui|apache-ssl-protocols:
  file.replace:
    - name: /etc/apache2/mods-available/ssl.conf
    - pattern: SSLProtocol all$
    - repl: SSLProtocol all -SSLv2 -SSLv3
    - watch_in:
      - service: sae|repoui|apache2

sae|repoui|apache-server-signature:
  file.replace:
    - name: /etc/apache2/conf-available/security.conf
    - pattern: ServerSignature On
    - repl: ServerSignature Off
    - watch_in:
      - service: sae|repoui|apache2

sae|repoui|phpini:
  file.managed:
    - name: /etc/php5/apache2/conf.d/50-repoui.ini
    - source: salt://sae-repoui/files/php.ini
    - watch_in:
      - service: sae|repoui|apache2

sae|repoui|apache2:
  service.running:
    - name: apache2
    - require:
      - cmd: core|certs|update-symlinks
    - watch:
      - file: core|certs|{{ certname }}-key
      - file: core|certs|{{ certname }}
      - file: core|certs|chain-geotrust

sae|repoui|backend-serivce:
  service.running:
    - name: repo-dispatcher
    - require:
      - file: sae|repoui|config

sae|repoui|cron:
  cron.present:
    - name: /usr/share/repoui/console mirror/update > /dev/null 2>&1
    - identifier: repo-mirror-updates
    - user: root
    - minute: 0
    - hour: 4

sae|repoui|root-sshkey:
  file.managed:
    - name: /root/.ssh/id_rsa
    - mode: 400
    - contents_pillar: secrets:sae-repoui:ssh_key
