{% import_yaml "sae-rtapp/map.yaml" as rtapp_map %}


{% if 'salt_states_vb' in grains and grains['salt_states_vb'] == True %}
  {% set environment='dev' %}
{% else %}
  {% if 'team_env' in  grains -%}
    {% set environment = grains['team_env'] -%}
  {%- else -%}
    {% set environment = 'dev' -%}
  {%- endif -%}
{% endif %}

{% if 'dev' in environment %}
  {% set repo_env = 'testing' %}
{% else %}
  {% set repo_env = grains['team_env'] %}
{% endif %}

{% set rt3_env = rtapp_map[environment] %}

sae|rtapp|rt3-apache-conf:
  apache.configfile:
    - name: /etc/apache2/sites-available/rt3.conf
    - config:
      - VirtualHost:
          this: '*:80'
          ServerName:
            - rt.llnw.com
          ServerAdmin:
            - webmaster@localhost
          DocumentRoot: /opt/rt3/share/html
          Directory:
            this: /opt/rt3/share/html/
            Require:
              - all
              - granted
          ReplaceMe:
            this: /opt/rt3/bin/
            Require:
              - all
              - granted
            Options: +ExecCGI
            SetHandler: fcgid-script
          ScriptAlias:
            - /
            - /opt/rt3/bin/mason_handler.fcgi/
          LogLevel: warn
          CustomLog: ${APACHE_LOG_DIR}/rt-access.log combined
          ErrorLog: ${APACHE_LOG_DIR}/rt-error.log

sae|rtapp|rt3-apache-fix:
  file.replace:
    - name: /etc/apache2/sites-available/rt3.conf
    - pattern: ReplaceMe
    - repl: Directory
    - backup: False

sae|rtapp|rt3-apache-symlink:
  file.symlink:
    - name: /etc/apache2/sites-enabled/rt3.conf
    - target: /etc/apache2/sites-available/rt3.conf

sae|rtapp|zabbix-repo:
  pkgrepo.managed:
    - name: deb http://repo.llnw.net/llnw/ubuntu/{{ repo_env }}/zabbix/ precise/
    - file: /etc/apt/sources.list.d/zabbix.list

sae|rtapp|rt-repo:
  pkgrepo.managed:
    - name: deb http://repo.llnw.net/llnw/ubuntu/{{ repo_env }}/request-tracker/ trusty/
    - file: /etc/apt/sources.list.d/request-tracker.list

sae|rtapp|rt3-package:
  pkg.installed:
    - name: rt3-llnw

sae|rtapp|liblog-package:
  pkg.installed:
    - name: liblog-dispatch-file-stamped-perl

sae|rtapp|rt3-dir-perm:
  file.directory:
    - name: /opt/rt3
    - user: www-data
    - recurse:
      - user
    - require:
      - pkg: sae|rtapp|rt3-package

sae|rtap|rt3-siteconfig:
  file.managed:
    - name: /opt/rt3/etc/RT_SiteConfig.pm
    - source: salt://sae-rtapp/rt3/RT_SiteConfig.pm
    - template: jinja
    - defaults:
        rt_web_base_url:  {{ rt3_env['rt_web_base_url'] }}
        rt_db_type: {{ rt3_env['rt_db_type'] }}
        rt_db_host: {{ rt3_env['rt_db_host'] }}
        rt_db_user: {{ rt3_env['rt_db_user'] }}
        rt_db_password: "{{ salt['pillar.get']('secrets:sae-rtapp:rt_db_password') }}"
        rt_db_name: {{ rt3_env['rt_db_name'] }}
        rt_company_src_db_host: {{ rt3_env['rt_company_src_db_host'] }}
        rt_company_src_db_user: {{ rt3_env['rt_company_src_db_user'] }}
        rt_company_src_db_pass: "{{ salt['pillar.get']('secrets:sae-rtapp:rt_company_src_db_pass') }}"
        rt_company_src_db_name: {{ rt3_env['rt_company_src_db_name'] }}
        rt_company_src_db_table: {{ rt3_env['rt_company_src_db_table'] }}
        rt_contacts_src_db_host: {{ rt3_env['rt_contacts_src_db_host'] }}
        rt_contacts_src_db_user: {{ rt3_env['rt_contacts_src_db_user'] }}
        rt_contacts_src_db_pass: "{{ salt['pillar.get']('secrets:sae-rtapp:rt_contacts_src_db_pass') }}"
        rt_contacts_src_db_name: {{ rt3_env['rt_contacts_src_db_name'] }}
        rt_contacts_src_db_table: {{ rt3_env['rt_contacts_src_db_table'] }}
        rt_company_dest_db_host: {{ rt3_env['rt_company_dest_db_host'] }}
        rt_company_dest_db_user: {{ rt3_env['rt_company_dest_db_user'] }}
        rt_company_dest_db_pass: "{{ salt['pillar.get']('secrets:sae-rtapp:rt_company_dest_db_pass') }}"
        rt_company_dest_db_name: {{ rt3_env['rt_company_dest_db_name'] }}
        rt_company_dest_db_table: {{ rt3_env['rt_company_dest_db_table'] }}
        rt_contacts_dest_db_host: {{ rt3_env['rt_contacts_dest_db_host'] }}
        rt_contacts_dest_db_user: {{ rt3_env['rt_contacts_dest_db_user'] }}
        rt_contacts_dest_db_pass: "{{ salt['pillar.get']('secrets:sae-rtapp:rt_contacts_dest_db_pass') }}"
        rt_contacts_dest_db_name: {{ rt3_env['rt_contacts_dest_db_name'] }}
        rt_contacts_dest_db_table: {{ rt3_env['rt_contacts_dest_db_table'] }}

    - require:
      - pkg: sae|rtapp|rt3-package
