# Any configuration directives you include  here will override 
# RT's default configuration file, RT_Config.pm
#
# To include a directive here, just copy the equivalent statement
# from RT_Config.pm and change the value. We've included a single
# sample value below.
#
# This file is actually a perl module, so you can include valid
# perl code, as well.
#
# The converse is also true, if this file isn't valid perl, you're
# going to run into trouble. To check your SiteConfig file, use
# this comamnd:
#
#   perl -c /path/to/your/etc/RT_SiteConfig.pm
no warnings qw(once);

Set( $rtname, 'llnw');

# You should set this to your organization's DNS domain. For example,
# fsck.com or asylum.arkham.ma.us. It's used by the linking interface to
# guarantee that ticket URIs are unique and easy to construct.

Set($Organization , "llnw.com");

Set($WebBaseURL, '{{ rt_web_base_url }}');

# $Timezone is used to convert times entered by users into GMT and back again
# It should be set to a timezone recognized by your local unix box.
Set($Timezone , 'US/Arizona');

# OwnerEmail is the address of a human who manages RT. RT will send
# errors generated by the mail gateway to this address.  This address
# should _not_ be an address that's managed by your RT instance.

Set($OwnerEmail , 'noc-leads@llnw.com');

# If $ParseNewMessageForTicketCcs is true, RT will attempt to divine
# Ticket 'Cc' watchers from the To and Cc lines of incoming messages
# Be forewarned that if you have _any_ addresses which forward mail to
# RT automatically and you enable this option without modifying
# "RTAddressRegexp" below, you will get yourself into a heap of trouble.

# TODO: add CC'ed people as "CC watchers" in ticket?
Set($ParseNewMessageForTicketCcs , 1);

# RTAddressRegexp is used to make sure RT doesn't add itself as a ticket CC if
# the setting above is enabled.

# TODO: if CC'ed people are added to ticket, need regexp to match all RT/support email (e.g.  <whatever>.support@limelightnetworks.com)
my $local_addr = join('|', qw(
    abuse2
    abuseq
    announce
    bgp
    change
    contentrequests
    ctu
    custbillserviceapproval
    custcancellationapproval
    custcannpapproval
    custpaidtrialapproval
    custrenewalapproval
    custtest
    custtrialapproval
    custturndownapproval
    custturnupapproval
    dcops
    dnsreq
    engprojects
    ipreq
    is
    llnwsupport
    maint4
    mrvnms
    msecn-support
    netops-support
    networkbilltest
    network4
    network5
    network-hostissue
    noc
    opseng-rt
    outage
    peering-queue
    proserv
    provq
    qwest-dsl
    rtbounce
    rtcomment
    rtdev
    rtpo
    se
    slaguarantee
    striptest
    supportpri4
));
Set($RTAddressRegexp , sprintf('^(%s)\@l.*n.*w.*.com$', $local_addr));

#Set($RTAddressRegexp , '^(custcannpapproval|custrenewalapproval|custbillserviceapproval|custpaidtrialapproval|custcancellationapproval|announce|msecn-support|rtdev|outage|llnwsupport|opseng-rt|supportpri4|proserv|rtbounce|maint4|networkbilltest|network4|network5|network-hostissue|peering-queue|mrvnms|qwest-dsl|bgp|ipreq|dnsreq|striptest|is|abuse2|abuseq|provq|ctu|custturnupapproval|custtest|custtrialapproval|custturndownapproval|se|rtpo|engprojects|slaguarantee|rtcomment)\@l.*n.*w.*.com$');

# Automated emails are sent from these addresses
Set($LLNWAutomatedEmailFrom, '(netsaint|circuit-threshold-checker|nobody|donotreply)\@l.*n.*w.*.com$'); 

# TODO: set default correspond address to: support@limelightnetworks.com
#Set($CorrespondAddress , 'support@limelightnetworks.com');
#Set($CorrespondAddress , 'support@rtmail.llnw.com');
Set($CorrespondAddress , 'llnwsupport@llnw.com');

# TODO: set default comment address to: support.comment@limelightnetworks.com
Set($CommentAddress , 'rtcomment@limelightnetworks.com');

# sprintf() format of the friendly 'From:' header; its arguments
# are SenderName and SenderEmailAddress.
Set($FriendlyFromLineFormat , "\"%s\" <%s>");

#  Mail loops will generate a critical log message.
# TODO: log to syslog, text file or both?
# TODO: determine min log level for PRODUCTION; leave at "debug" during testing
Set($LogToSyslog, 'error');
Set($LogToScreen, 'error');
#Set($LogToFile, 'error');
#Set($LogDir, '/var/www/rt/3.6.6/hostroot/rt-3.6.6/var/log');
#Set($LogToFileNamed, "rt.log");    #log to rt.log

Set($LogoLinkURL, $WebURL);
Set($LogoImageURL , $WebImagesURL . "llnw_logo.gif");
Set($LogoAltText, "Limelight Networks, Inc. - Request Tracker");
Set($LogoWidth, '173');
Set($LogoHeight, '70');

# For message boxes, set the entry box width and what type of wrapping
# to use.
#
# Default width: 72
Set($MessageBoxWidth , 90);

# Default wrapping: "HARD"  (choices "SOFT", "HARD")
Set($MessageBoxWrap, "SOFT");

# TODO: largest attachment (jpeg, gif, etc.) we want to view in-line (as part of ticket text)
Set($MaxInlineBody, 1000000);

# $DefaultSummaryRows is default number of rows displayed in for search
# results on the frontpage.

Set($DefaultSummaryRows, 10);

# By default, RT shows newest transactions at the bottom of the ticket
# history page, if you want see them at the top set this to '0'.

Set($OldestTransactionsFirst, '0');

Set($HomepageComponents, [qw(QuickCreate Quicksearch MyAdminQueues MySupportQueues MyReminders RefreshHomepage Ownertickets DueDateCalendar TicketPreview Dashboards)]);

# If $DontSearchFileAttachments is set to a true value, then uploaded
# files (attachments with file names) are not searched during full-content
# ticket searches.

Set($DontSearchFileAttachments, 1);

# Set this to 1 if your local date convention looks like "dd/mm/yy"
# instead of "mm/dd/yy".

Set($DateDayBeforeMonth , 0);

# Should "Tuesday" default to meaning "Next Tuesday" or "Last Tuesday"?
# Set to 0 for "Next" or 1 for "Last".

Set($AmbiguousDayInPast , 1);

# Backward compatability setting. Add/Delete Link used to record one
# transaction and run one scrip. Set this value to 0 if you want
# both link transactions to have a scrip run.
Set($LinkTransactionsRun1Scrip , 1);

# temporary directory
Set($TmpDir, '/tmp');

Set($SendmailPath , "/usr/sbin/sendmail");

Set($DatabaseType, "{{ rt_db_type }}");
Set($DatabaseHost   , '{{ rt_db_host }}' );
Set($DatabasePort , '');
Set($DatabaseUser , '{{ rt_db_user }}');

Set($DatabasePassword , '{{ rt_db_password }}');
Set($DatabaseName , '{{ rt_db_name }}');


Set(@Plugins, qw(RT::Site::Limelight::Reports
		 RT::Site::Limelight
		 RT::Extension::TicketPreview
		 RT::Extension::SaltedPasswords
));

Set($CompanySourceDBHost,     '{{ rt_company_src_db_host }}');
Set($CompanySourceDBUser,     '{{ rt_company_src_db_user }}');
Set($CompanySourceDBPassword, '{{ rt_company_src_db_pass }}');
Set($CompanySourceDBName,     '{{ rt_company_src_db_name }}');
Set($CompanySourceDBTable,    '{{ rt_company_src_db_table }}');

Set($ContactsSourceDBHost,     '{{ rt_contacts_src_db_host }}');
Set($ContactsSourceDBUser,     '{{ rt_contacts_src_db_user }}');
Set($ContactsSourceDBPassword, '{{ rt_contacts_src_db_pass }}');
Set($ContactsSourceDBName,     '{{ rt_contacts_src_db_name }}t');
Set($ContactsSourceDBTable,    '{{ rt_contacts_src_db_table }}');

Set($CompanyDestDBHost,     '{{ rt_company_dest_db_host }}');
Set($CompanyDestDBUser,     '{{ rt_company_dest_db_user }}');
Set($CompanyDestDBPassword, '{{ rt_company_dest_db_pass }}');
Set($CompanyDestDBName,     '{{ rt_company_dest_db_name }}');
Set($CompanyDestDBTable,    '{{ rt_company_dest_db_table }}');

Set($ContactsDestDBHost,     '{{ rt_contacts_dest_db_host }}');
Set($ContactsDestDBUser,     '{{ rt_contacts_dest_db_user }}');
Set($ContactsDestDBPassword, '{{ rt_contacts_dest_db_pass }}');
Set($ContactsDestDBName,     '{{ rt_contacts_dest_db_name }}');
Set($ContactsDestDBTable,    '{{ rt_contacts_dest_db_table }}');

Set( %GnuPG, ( Enable => 0 ) );

Set(@Active_MakeClicky, qw(httpurl_overwrite));

1;

