include:
  - jenkins.slave
  - proxy

{% set proxy = 'http://proxy.llnw.net:3128' %}
{% set ghe_key = pillar['secrets']['sae']['github_key'] %}

sae|singel|jenkins-ssh-dir:
  file.directory:
    - name: /home/jenkins/.ssh
    - user: jenkins
    - group: jenkins-group
    - mode: 700
    - makedirs: True

sae|singel|id_ecdsa:
  file.managed:
    - name: /home/jenkins/.ssh/id_ecdsa
    - user: jenkins
    - group: jenkins-group
    - mode: 400
    - contents_pillar: secrets:sae-singel:id_ecdsa

# Deploy the public key, in case some one needs it
sae|singel|id_ecdsa.pub:
  file.managed:
    - name: /home/jenkins/.ssh/id_ecdsa.pub
    - user: jenkins
    - group: jenkins-group
    - mode: 444
    - contents: 'ecdsa-sha2-nistp256 AAAAE2VjZHNhLXNoYTItbmlzdHAyNTYAAAAIbmlzdHAyNTYAAABBBAi0dCETKEVP3rNr8ETJNgxXwtZ5dCr8bvKf09qqS2ZCfxwBr90ClmksC0vS8f7DS3AughTKDsQrZv5a3/j2OYo= jenkins@singel-01.phx2.llnw.net'

{% for file in 'wget', 'net' %}
sae|singel|jenkins-{{ file }}rc-file:
  file.managed:
    - name: /home/jenkins/.{{ file }}rc
    - contents: |
        use_proxy=yes
        ftp_proxy={{ proxy }}
        http_proxy={{ proxy }}
        https_proxy={{ proxy }}
{% endfor %}

sae|singel|packages:
  pkg.latest:
    - names:
      - libvirt-bin
      - qemu-kvm
      - lftp
      - vagrant
      - virtualbox-5.1
    - require:
      - pkgrepo: sae|singel|vbox-repo

# needed by the scripts borrowed from lxvm to spin up a testing vm
sae|singel|lxvm-dirs:
  file.directory:
    - names:
      - /srv/kvm/configs
      - /srv/kvm/images
      - /srv/kvm/kernels
    - user: libvirt-qemu
    - group: kvm
    - mode: 755
    - makedirs: True
    - require:
      - pkg: sae|singel|packages

sae|singel|scratch-dirs:
  file.directory:
    - names:
      - /opt/packer_cache
      - /opt/singel_output_files
      - /opt/singel_tmp
      - /opt/workspace
    - user: jenkins
    - group: jenkins-group
    - mode: 755
    - makedirs: True
    - require:
      - pkg: sae|singel|packages

sae|singel|vbox-repo:
  pkgrepo.managed:
    - name: deb http://download.virtualbox.org/virtualbox/debian {{ salt['grains.get']('oscodename') }} contrib
    - file: /etc/apt/sources.list.d/virtualbox.list
    - require:
      - cmd: sae|singel|vbox-repo-key

sae|singel|vbox-repo-key:
  cmd.run:
    - name: wget -q -O - http://download.virtualbox.org/virtualbox/debian/oracle_vbox.asc | apt-key add -
    - env:
      - ftp_proxy: {{ proxy }}
      - http_proxy: {{ proxy }}
      - https_proxy: {{ proxy }}
    - unless: apt-key list | grep 'VirtualBox archive signing key'

sae|singel|singel-repo:
  pkgrepo.managed:
    - name: deb http://repo.llnw.net/llnw/ubuntu/production/singel/ {{ salt['grains.get']('oscodename') }}/
    - file: /etc/apt/sources.list.d/singel.list

sae|singel|pkg-packer:
  pkg.latest:
    - names:
      - packer
    - skip_verify: True
    - require:
      - pkgrepo: sae|singel|singel-repo

sae|singel|groups:
  group.present:
    - names:
      - vboxusers
      - kvm
    - addusers:
      - jenkins
    - require:
      - pkg: sae|singel|packages

sae|singel|jenkins-config-file:
  file.managed:
    - name: /etc/VagrantTests/config.ini
    - template: jinja
    - backup: False
    - mode: 664
    - source: salt://sae-singel/templates/config.jinja
    - makedirs: True
    - defaults:
        github_key: {{ ghe_key }}

sae|singel|repo-github3:
  pkgrepo.managed:
    - names:
      - deb http://llnwsae.vo.llnwd.net/v1/packages/llnw/github3/ubuntu/{{ grains['osrelease'] }} ./
    - file:  /etc/apt/sources.list.d/github3.xenial.list

sae|singel|github3:
  pkg.installed:
    - name: python-github3.py
    - require:
      - pkgrepo: sae|singel|repo-github3

sae|singel|uritemplate-ppa:
  pkgrepo.managed:
    - name: deb http://ppa.launchpad.net/dennis/python/ubuntu xenial main
    - file: /etc/apt/sources.list.d/dennis-ppa.list

sae|singel|python-pkgs:
  pkg.installed:
    - pkgs:
      - python-psutil
      - python-uritemplate.py
      - python-pathlib
      - python-yaml
    - require:
      - pkgrepo: sae|singel|uritemplate-ppa
