{% set nginxvhost = {'path': '/etc/nginx', 'pkg': 'nginx-full'} %}

{% from slspath ~ "/slb_tools_map.jinja" import slb_tools_api_conf with context %}
{% from slspath ~ "/map.jinja" import slb_conf, is_lab with context %}

{% set mgmt_ip = slb_conf.get('address', '127.0.0.1').split('/')[0] %}

{# use eth0 for lab devices that are configured with a command and control interface #}
{% if is_lab %}
{%   set _eth0 =  salt['network.interfaces']().get('eth0', {}).get('inet', []) %}
{%   set mgmt_ip = _eth0[0].get('address', mgmt_ip) if _eth0 else mgmt_ip %}
{% endif %}


sae|slb|nginx|create_self_signed_cert:
  module.run:
    - name: tls.create_self_signed_cert
    - CN: {{ salt['grains.get']('fqdn') }}

sae|slb|nginx|repo:
  pkgrepo.managed:
    - humanname: PPA Nginx
    - architectures: amd64
    - name: deb http://llnwsae.vo.llnwd.net/v1/packages/mirrors/daily-update/debian/ppa.launchpad.net/nginx/stable/ubuntu {{ salt['grains.get']('oscodename') }} main
    - dist: {{ salt['grains.get']('oscodename') }}
    - key_url: http://llnwsae.vo.llnwd.net/v1/packages/mirrors/daily-update/debian/ppa.launchpad.net/nginx/stable/0x00A6F0A3C300EE8C.key
    - file: /etc/apt/sources.list.d/nginx.list
    - require_in:
      - pkg: sae|slb|nginx|pkg

sae|slb|nginx|pkg:
  pkg.installed:
    - name: {{nginxvhost.pkg}}
    - require_in:
      - file: sae|slb|nginx|timeout-fix
    - watch_in:
      - service: sae|slb|nginx|service_restart

sae|slb|nginx|timeout-fix:
  file.comment:
    - name: {{nginxvhost.path}}/nginx.conf
    - regex: ^\s*keepalive_timeout.*
    - onlyif:
      - grep -q '^[[:space:]]*keepalive_timeout.*' {{nginxvhost.path}}/nginx.conf


sae|slb|nginx|site-config:
  file.managed:
    - name: {{ nginxvhost.path }}/sites-available/slb_tools_api
    - template: jinja
    - source: salt://{{ slspath }}/templates/slb_tools_api_nginx.conf.jinja
    - user: root
    - group: root
    - mode: '0644'
    - defaults:
        names: [{{ salt['grains.get']('fqdn') }}]
        app_port: 8081
        allowed_networks: {{ slb_tools_api_conf.allowed_networks }}
        bind_ip: {{ mgmt_ip }}
    - require:
      - module: sae|slb|nginx|create_self_signed_cert 
    - watch_in:
      - service: sae|slb|nginx|service_restart

sae|slb|nginx|site-enable:
  file.symlink:
    - target: {{ nginxvhost.path }}/sites-available/slb_tools_api
    - name: {{ nginxvhost.path }}/sites-enabled/slb_tools_api
    - require:
      - file: sae|slb|nginx|site-config
    - watch_in:
      - service: sae|slb|nginx|service_restart

sae|slb|nginx|service_restart:
  service.running:
    - name: nginx
    - enable: True
    - reload: True

