# vim: sts=2 ts=2 sw=2 et ai

{% from "pepper/map.jinja" import defaults with context %}
{% from slspath ~ "/slb_tools_map.jinja" import slb_tools_api_conf with context %}
{% from slspath ~ "/map.jinja" import keepalived_version, production as kernel_version with context %}
{% from "sudoers/map.jinja" import sudo_map with context %}

include:
  - sudoers.setup

# remove specified files
{% for fn in slb_tools_api_conf.remove_files %}
sae|slb_tools|remove-files|{{ fn }}:
  file.absent:
    - name: {{ fn }}
{% endfor %}

# create local slb_tools user 
sae|slb_tools|user:
  user.present:
    - name: slb_tools
    - fullname: slb tools
    - shell: /bin/bash
    - home: /home/slb_tools
    - uid: 997
    - gid: slb_tools
    - require:
      - group: sae|slb_tools|group

# create slb_tools group
sae|slb_tools|group:
  group.present:
    - name: slb_tools
    - system: True
    - gid: 997

# add entry to /etc/pam.d/sudo to silence messages for slb_tools
sae|slb_tools|pam_sudo:
  file.replace:
    - name: /etc/pam.d/sudo
    - pattern: '^#%PAM-1.0'
    - repl: |
        #%PAM-1.0

        # silence syslog opened/closed messages for user slb_tools
        session [success=done default=ignore] pam_succeed_if.so quiet uid = 0 user = root ruser = slb_tools
    - unless:
      - grep -q 'ruser[[:space:]]*=[[:space:]]*slb_tools' /etc/pam.d/sudo

# create sudo entry for user slb_tools -- this will ensure slb_tools can perform
# the various SLB functions which require root access
sae|slb_tools|sudo:
  file.managed:
    - name: {{ sudo_map.includedir }}/slb-tools
    - user: root
    - group: {{ defaults.root_group }}
    - mode: 440
    - contents: |
        # silence syslog output for user slb_tools
        Defaults:slb_tools !syslog, !logfile

        slb_tools ALL=(root) NOPASSWD: /sbin/ipvsadm, /usr/bin/vtysh, /bin/cat, /bin/sed, /bin/systemctl

    - require:
      - user: sae|slb_tools|user 
      - file: sae|slb_tools|pam_sudo
      - file: core|sudoers|includedir


sae|slb_tools|pkgs:
  pkg.installed:
    - pkgs:
      - dh-virtualenv: 1.0-1
      - python3.7
      - python3-pip
      - python3.7-venv
      - supervisor
      # required for pycurl
      - libcurl4-openssl-dev
      - libssl-dev


# install slb_tools pkg
sae|slb_tools|slb_tools_pkg:
  pkg.installed:
    - name: slb-tools={{ slb_tools_api_conf.slb_tools_pkg_version }}
    - require:
      - pkg: sae|slb_tools|pkgs

# create a folder for legacy scripts
sae|slb_tools|legacy_folder:
  file.directory:
    - name: /etc/keepalived/scripts/.legacy
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755
    - makedirs: True

# create links from virtual env
{% for tool in slb_tools_api_conf.tools %}
sae|slb_tools|link|{{ tool.name }}:
  file.symlink:
    - name: {{tool.path }}/{{ tool.name }}
    - target: {{ slb_tools_api_conf.bin_path }}/{{ tool.name }} 
    - force: True
    - require:
      - pkg: sae|slb_tools|slb_tools_pkg

{# if specified, add required_in entries #}
{%  if 'required_in' in tool %}
    - required_in:
{%    for state_name in tool.required_in %} 
      - {{ state_name }}
{%    endfor %}
{%  endif %}

{% if 'legacy_name' in tool %}
{#
sae|slb_tools|link-remove-legacy|{{ tool.legacy_name }}:
  file.absent:
    - name: {{ tool.path }}/{{ tool.legacy_name }}
#}

{%   if 'link' in tool and tool.link %}
{#- note that this will remove the legacy tool if it exists then create a new symlink -#}
sae|slb_tools|link-legacy|{{ tool.legacy_name }}:
  file.symlink:
    - name: {{tool.path }}/{{ tool.legacy_name }}
    - target: {{ tool.path }}/{{ tool.name }} 
    - force: True
    - backupname: /etc/keepalived/scripts/.legacy/{{ tool.legacy_name }}
    - require:
      - pkg: sae|slb_tools|slb_tools_pkg
      - file: sae|slb_tools|legacy_folder
      #- file: sae|slb_tools|link-remove-legacy|{{ tool.legacy_name }}
{%   else %}
{#- note this will remove the legacy tool -#}
sae|slb_tools|remove-legacy|{{ tool.legacy_name }}:   
  file.absent:
    - name: {{ tool.path }}/{{ tool.legacy_name }}
{%   endif %}
{% endif %}
{% endfor %}

# build slb_tools config/env conf file
sae|slb_tools|config:
  file.managed:
    - name: /etc/keepalived/slb_tools.conf
    - template: jinja
    - source: salt://{{ slspath }}/templates/slb_tools.conf.jinja
    - user: slb_tools 
    - group: slb_tools
    - mode: 755
    - context:
      kernel_version: {{ kernel_version }}
      keepalived_version: {{ keepalived_version }}
    - require:
      - user: sae|slb_tools|user

# build slb_tools config/env conf file
sae|slb_tools|api_config:
  file.managed:
    - name: /etc/keepalived/slb_tools_api.conf
    - template: jinja
    - source: salt://{{ slspath }}/templates/slb_tools_api.conf.jinja
    - user: root
    - group: slb_tools
    - mode: 755
    - context:
      config: {{ slb_tools_api_conf }}
    - require:
      - file: sae|slb_tools|config
      

# build slb_tools API log config file
sae|slb_tools|log_config:
  file.managed:
    - name: /etc/keepalived/slb_tools_api_logging.conf
    - template: jinja
    - source: salt://{{ slspath }}/templates/slb_tools_api_logging.conf.jinja
    - user: root
    - group: slb_tools 
    - mode: 755
    - context:
      app_name: slb_tools
      keepalived_version: {{ keepalived_version }}
    - require:
      - file: sae|slb_tools|config

# create logging directory
sae|slb_tools|log_dir:
  file.directory:
    - name: /var/log/llnw
    - user: root
    - group: slb_tools
    - create: True
    - replace: False
    - mode: 775
    - require:
      - group: sae|slb_tools|group

# create supervisor conf
sae|slb_tools|supervisor:
  file.managed:
    - name: /etc/supervisor/conf.d/{{ slb_tools_api_conf.name }}.conf
    - template: jinja
    - source: salt://{{ slspath }}/templates/slb_tools_api_supervisor.conf.jinja
    - context:
      config: {{ slb_tools_api_conf }}
    - require:
      - file: sae|slb_tools|log_dir  
  supervisord.running:
    - name: {{ slb_tools_api_conf.name }}
    - update: True
    - watch:
      - file: sae|slb_tools|config
      - file: sae|slb_tools|api_config
      - file: sae|slb_tools|log_config
      - file: sae|slb_tools|supervisor 
      - pkg: sae|slb_tools|slb_tools_pkg
