# vim: sts=2 ts=2 sw=2 et ai

{% from "pepper/map.jinja" import defaults with context %}
{% set city = salt['grains.get']('cornerstone:building_group_name') %}
{% from slspath ~ "/map.jinja" import kernel, keepalived_version with context %}

include:
  - salt.minion
  - crontab

#Install Keepalived pkg and health scripts
sae|slb|keepalived-pkg:
  pkg.installed:
    - name: keepalived
    - version: {{ keepalived_version }}

sae|slb|slb_reconfig:
  file.managed:
    - name: /etc/keepalived/scripts/slb_reconfig.sh
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755
    - makedirs: True
    - source: salt://{{ slspath }}/scripts/slb_reconfig.sh
    - require:
      - pkg: sae|slb|keepalived-pkg

sae|slb|slb_reconfig|crontab:
  file.accumulated:
    - filename: /etc/crontab
    - text: |
        */5 * * * * root /etc/keepalived/scripts/slb_reconfig.sh -s
    - require:
      - file: sae|slb|slb_reconfig
    - require_in:
      - file: core|crontab|base

sae|slb|gen_network_configs:
  file.managed:
    - name: /etc/keepalived/scripts/gen_network_configs.pl
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755
    - makedirs: True
    - source: salt://{{ slspath }}/scripts/gen_network_configs.pl
    - require:
      - pkg: sae|slb|keepalived-pkg

sae|slb|gen_slb_configs:
  file.managed:
    - name: /etc/keepalived/scripts/gen_slb_configs.pl
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755
    - makedirs: True
    - source: salt://{{ slspath }}/scripts/gen_slb_configs.pl
    - require:
      - pkg: sae|slb|keepalived-pkg

sae|slb|check_vips:
  file.managed:
    - name: /etc/keepalived/scripts/check_vips.sh
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755
    - makedirs: True
    - source: salt://{{ slspath }}/scripts/check_vips.sh
    - require:
      - pkg: sae|slb|keepalived-pkg

sae|slb|http_check:
  file.managed:
    - name: /etc/keepalived/scripts/http_check.sh
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755
    - makedirs: True
{% if 'slb-macping-daemon-debug' in salt['grains.get']('cornerstone:tags', {}) %}
    - source: salt://{{ slspath }}/scripts/http_check.sh.debug
{% else %}
    - source: salt://{{ slspath }}/scripts/http_check.sh
{% endif %}
    - require:
      - pkg: sae|slb|keepalived-pkg

sae|slb|bgp_check:
  file.managed:
    - name: /etc/keepalived/scripts/bgp_check.sh
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755
    - makedirs: True
    - source: salt://{{ slspath }}/scripts/bgp_check.sh
    - require:
      - pkg: sae|slb|keepalived-pkg

sae|slb|parse_ips:
  file.managed:
    - name: /etc/keepalived/scripts/parse_ips.sh
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755
    - makedirs: True
    - source: salt://{{ slspath }}/scripts/parse_ips.sh
    - require:
      - pkg: sae|slb|keepalived-pkg

sae|slb|macping:
  file.managed:
    - name: /etc/keepalived/scripts/macping
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755
    - makedirs: True
    - source: http://images.llnw.net/bins/macping.daemon-xenial
    - source_hash: md5=3a7393bc46b81f8ba19696afba78e16d
    - require:
      - pkg: sae|slb|keepalived-pkg

sae|slb|keepalived_global_defs:
  file.managed:
    - name: /etc/keepalived/config_containers/global_defs.conf
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755
    - makedirs: True
    - source: salt://{{ slspath }}/templates/keepalived-global_defs.conf.jinja
    - template: jinja
    - require:
      - pkg: sae|slb|keepalived-pkg

sae|slb|keepalived_conf:
  file.managed:
    - name: /etc/keepalived/keepalived.conf
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755
    - makedirs: True
    - source: salt://{{ slspath }}/files/keepalived.conf
    - require:
      - pkg: sae|slb|keepalived-pkg

sae|slb|server_state:
  file.directory:
    - name: /etc/keepalived/server_states
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755
    - makedirs: True
    - require:
      - pkg: sae|slb|keepalived-pkg

sae|slb|config-pull:
  schedule.present:
    - function: state.sls
    - job_args:
      - sae-slb.conf_update
    - seconds: 300
    - splay: 30
    - require:
      - pkg: sae|slb|keepalived-pkg
    - service: core|salt|minion-service
