# vim: sts=2 ts=2 sw=2 et ai

{% from "pepper/map.jinja" import defaults with context %}
{% from slspath ~ "/map.jinja" import conf_vars with context %}
{% set city = salt['grains.get']('cornerstone:building_group_name') %}

{% set edge_conf_cdn = 'http://test.vo.llnwd.net/cdn-edge-config/econfigs' %}
{% set edge_conf_secret = salt['pillar.get']('secrets:sae:edge_conf_cdn_mediavault_secret') %}

sae|slb|update_config_files:
  file.managed:
    - name: /etc/keepalived/scripts/update_config_files.sh
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755
    - source: salt://{{ slspath }}/scripts/update_config_files.sh

sae|slb|slb_conf_yml:
  file.managed:
    - name: /etc/keepalived/slb_conf.yml
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755
    - source: salt://sae-slb/files/{{ city }}-slb_conf.yml

sae|slb|global_conf:
  file.managed:
    - name: /etc/keepalived/global_conf.yml
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 644
    - source: salt://sae-slb/files/global_conf.yml
    - require:
      - file: sae|slb|global_conf_get

sae|slb|run_config_update:
  cmd.run:
    - name: /etc/keepalived/scripts/gen_slb_configs.pl; echo $? > /tmp/gen_slb_configs.status
    - onchanges_any:
      - file: sae|slb|slb_conf_yml
      - file: sae|slb|global_conf

{% for edge_conf, v in conf_vars.remote_config_files.items() %}
{%   set edge_conf_mediavault_url = salt['mediavault.buildurl'](
         edge_conf_secret,
         '%s/%s'|format(edge_conf_cdn, edge_conf), 0)
%}
{%   set edge_conf_csum_mediavault_url = salt['mediavault.buildurl'](
         edge_conf_secret,
         '%s/%s.md5'|format(edge_conf_cdn, edge_conf), 0)
%}

sae|slb|slb-config-{{ edge_conf }}:
  cmd.run:
    - name: /etc/keepalived/scripts/update_config_files.sh "{{ edge_conf_mediavault_url }}" /etc/keepalived/{{ edge_conf }} "{{ edge_conf_csum_mediavault_url }}" "{{ v.get('required', 0) }}"
    - require: 
      - file: sae|slb|update_config_files
    - stateful: True
    - onchanges_in:
      - cmd: sae|slb|run_config_update

{% endfor %}
