#!/usr/bin/env bash

#This maps both physical core and ht core to an irq associated
#with the ethernet queues before proceeding to the next cpu.
#ie irq 89 = cpu 1 , irq 90 = cpu 15, where cpu 1 is physical
#and cpu 15 is the HT core of cpu 1

build_cpu_map(){
  #Use all cores except 0 for smp_affinity
  num_cpus=`grep -ic processor /proc/cpuinfo`
  num_queues=`egrep -ic "eth[0-9]+-[RT]" /proc/interrupts`
  pps_cpu=1
  start_cpu=$pps_cpu
  end_cpu=$(( num_cpus - 2 ))
  offset=$(( (num_cpus / 2) ))
  counter=1

  while [ $counter -lt $offset ]; do
    ht_cpu=$(( counter + offset ))
    cpu_map+=( "${counter}" "${ht_cpu}" )
    (( counter++ ))
  done
}

set_smp_affinity(){
  for i in $(egrep "eth[0-9]-[RT]" /proc/interrupts | awk '{printf "%d\n",$1}' ) ; do
    irq_map+=( "$i" )
  done

  counter=0

  for irq in ${irq_map[@]}; do
    echo "mapping $irq to ${cpu_map[$counter]}"
    echo "${cpu_map[$counter]}" > /proc/irq/${irq}/smp_affinity_list
    (( counter++ ))
    if [ $counter -ge $end_cpu ]; then
      counter=0
    fi
  done
}

build_cpu_map
set_smp_affinity
