#!/usr/bin/env bash

#This maps both physical core and ht core to an irq associated
#with the ethernet queues before proceeding to the next cpu.
#ie irq 89 = cpu 1 , irq 90 = cpu 15, where cpu 1 is physical
#and cpu 15 is the HT core of cpu 1

# Check what module we have
cxgb4_module=`modinfo cxgb4 | grep ^version | awk '{print $2}'`

build_cpu_map(){
  #Use all cores except 0 for smp_affinity
  num_cpus=`grep -ic processor /proc/cpuinfo`
  pps_cpu=1
  start_cpu=$pps_cpu
  end_cpu=$(( num_cpus - 2 ))
  offset=$(( (num_cpus / 2) ))
  counter=1

  while [ $counter -lt $offset ]; do
    ht_cpu=$(( counter + offset ))
    cpu_map+=( "${counter}" "${ht_cpu}" )
    (( counter++ ))
  done
}

set_smp_affinity(){
  for i in $(egrep "eth[0-9]-[RT]" /proc/interrupts | awk '{printf "%d\n",$1}' ) ; do
    irq_map+=( "$i" )
  done

  counter=0

  for irq in ${irq_map[@]}; do
    echo "mapping $irq to ${cpu_map[$counter]}"
    echo "${cpu_map[$counter]}" > /proc/irq/${irq}/smp_affinity_list
    (( counter++ ))
    if [ $counter -ge $end_cpu ]; then
      counter=0
    fi
  done
}

#
# Set cpu affinity for chelsio 3.13 universal wire driver
#
# The SLB relies on the chelsio RSS (receive side scaling) hashing to spread the load of received traffic
# over the available cores. The RSS hash table is fixed at 32 buckets. With selecting 28 queues to spread
# each ports traffic over there will be 4 queues that carry more traffic. (32 - 28 = 4) The driver will
# fill the last 4 hash buckes with queus 0, 1, 2, 3. So when spreading the queues over the set of cpu's,
# we shift 4 cpus over for each port so that cpu 0, 1, 2, 3 dont get all of the hot queues from all ports.
# (if you want to see the hash table: ethtool -x eth2)
# 
set_cxgb4uw_affinity(){
    ports=4
    num=0
    startcpu=0
    totalcpus=`grep -ic processor /proc/cpuinfo`
    irqs=$(cat /proc/interrupts |grep "queue " |awk '{split($1,a,":"); print a[1]}' )
    totalqueus=$( echo $irqs |wc |awk '{print $2}' )
    let q_per_port="$totalqueus/$ports"

    echo "== cxgb4uw driver found =="
    echo "total cpus: $totalcpus | Chelsio ports: $ports | queues per port: $q_per_port | total queues: $totalqueus"

    cpu=$startcpu
    for i in $irqs; do

	echo "Mapping IRQ ${i} to ${cpu}"
	echo $cpu > /proc/irq/$i/smp_affinity_list
	(( cpu++ ))
	(( num++ ))

	# Make sure the cpu number wraps
	if [ $cpu -eq  $totalcpus ]; then
	    cpu=0
	fi
	
	# need to shift over 4 cores for the next nic to prevent all hot queues
	# on all nics from landing on the same cores.
	if [ $num -eq $q_per_port ]; then
            startcpu=$(( $startcpu + 4 ))
            cpu=$startcpu
            num=0
	fi

    done;

    # Set the congestion mode for each queue
    let q=$q_per_port-1
    for e in eth2 eth3 eth4 eth5; do
	for i in `seq 0 $q`; do cxgbtool $e qset $i congmode 1; done
    done

}

if [ $cxgb4_module == '3.13.0.1' ]; then
    set_cxgb4uw_affinity
else
    build_cpu_map
    set_smp_affinity 
fi
