This folder contains various scripts required for SLB deployment.

# Table of Contents
1. [Scripts](#scripts)
2. [Health Checks](#health-checks)
    1. [Health Check Scripts](#health-check-script-requirements)

## Scripts

|script|deployed by|used by|notes|
|--- |--- |--- |--- |
|bgp_check.sh|keepalived.sls|gen_slb_config.pl|Checks for process (quagga) running on TCP port 179|
|check_vips.sh|keepalived.sls|gen_slb_config.pl|Checks if real servers are bound under a vip, if so then the real server is healthy and so is the vip. healthy return 0unhealthy return 1|
|cli|tools.sls| |Command line tool which is similar in syntax to IOS|
|gen_network_configs.pl|keepalived.sls|rclocal.sls|Command line tool used to generate the following:/etc/network/interfaces/etc/network/interfaces/<cdn vlan>/etc/rclocal – default route commands|
|gen_slb_configs.pl|keepalived.sls|<ul><li>http_check.sh</li><li>conf_update.sls</li><li>cli</li></ul>|Generates keepalived virtual and real server config files.  Config files are generated with .new extension. Note that slb_reconfig.sh is responsible for processing .new files and apply changes to keepalived.|
|global_conf_get.pl|conf_update.sls|gen_slb_config.sh|Processes global_conf.yml.  Is used by gen_slb_conf.sh to handle yaml processing since bash doesn't support yaml.|
|http_check.sh|keepalived.sls|real server config|http_check.sh is health check used to determine the health of real servers (CDS servers).|
|http_check|TBD|TBD|http_check is a python port of http_check.sh.|
|rts_check|TBD|TBD|rts_check is python health check used to determine the health of real servers (RTS servers).|
|slb_utils.py|TBD|rts_check|Various python utilities in support of python health checks|
|mk_bgp_conf.pl|quagga.sls|slb_reconfig.sh|Processes slb_conf.yml BGP and VIP sections to generate and apply BGP configuration to Quagga.|
|parse_ips.sh|keepalived.sls|gen_slb_configs.sh|Script to read the vrrp and virtual server files for keepalived and bind the necessary ip addresses to the dummy interface. This keeps keepalived from sending out massive amounts of gratuitous arp entries which overflow the netlink buffers|
|set-cpu-affinity.sh|cxgb4.sls|rclocal.sls|This maps both physical core and ht core to an irq associated with the ethernet queues before proceeding to the next cpu. ie irq 89 = cpu 1 , irq 90 = cpu 15, where cpu 1 is physical and cpu 15 is the HT core of cpu 1|
|slb_interface_collector.py|tools.sls|/etc/crontab|Used to collect SLB interface statistics such as egress/ingress for specific bonded vlan interfaces|
|slb_reconfig.sh|keepalived.sls|/etc/crontab|Script to look for .new configs in /etc/keepalived/config_containers and reconfigure the keepalived process.Will also run some simple tests and roll back configs if health checks fail, to help mitigating bad configs.|
|slb_scan.sh|tools.sls|<ul><li>SLB admins</li><li>/etc/crontab</li></ul>|Validates the current SLB status and health.<br><br>This script provides administrators a quick view into the health of the SLB.<br><br>Additionally this script is executed by a cron entry every 300 seconds to detect any potential health issues. <br><br> Errors are logged to syslog.  Note that there is a limon syslog rule which processes SLB error log messages into Zabbix items.|
|softnet.sh|tools.sls| |Provides a user-friendly output of softirqs.  Note that we are not sure of this script's history.  It doesn't appear to be used other than a nice-to-have script.|
|tsdb_collector.sh|tools.sls|<ul><li>vip_traffic.pl</li><li>/etc/crontab</li></ul>|Collects various system stats such as CPU util and ingest these values into TSDB|
|update_config_files.sh|conf_update.sls| |Used to retrieve various config files from a media server.  This script is meant to handshake with salt.  It is meant to be called by salt state cmd and returns a specific result and state.   Please reference the comments at the top of the script for greater detail.|
|vip_quorum.sh|keepalived.sls|<ul><li>gen_slb_configs.pl</li><li>virtual server configs</li></ul>|This script is called by a virtual server config file when quorum changes in a vip group to add or remove VIP IPs and to add or remove VIP nets from the BGP interface.|
|vip_traffic.pl|tools.ls|/etc/crontab|This script calculates the PPS rate per VIP, VIP range and port and sends it to OpenTSDB.|


## Health Checks

The SLB solution supports the use of keepalived's MISC_CHECK. MISC_CHECK calls a script.
  

### Health Check script Requirements

_Note that legacy health script `http_check.sh` is an exception to the following requirements._
* Health checks are defined in site SLB config in section vips.<name of vip>.vip_healthck. For example:
```vips:
  ssl_range2:
    vip_addr: ...
    vip_port: ...
    vip_range: ...
    vip_sticky: false
    vip_healthck: ['443', 'http']
```
* Script name must match the health check name. For example if the health check name is 'rts' the script must be named 'rts_check' 
* Script should not have an extension
* The first line of the script must include a hash-bang with a path to the script's interpreter. Example:
```#!/usr/bin/python```
* Health scripts should perform health checks at Layers 3-7 but should also ensure DSR functionality. Commonly, mac_ping is used to perform DSR checks.
* Health scripts are called from MISC_CHECK with the following command line positional arguments:
    * Real IP
    * VIP 
   