#!/usr/bin/env perl
use strict;
use warnings;
use Sys::Hostname;
use POSIX;
use YAML qw(LoadFile);

# For local testing
#my $config_file = "../files/global_conf.yml";

# For production and lab
my $config_file = "/etc/keepalived/global_conf.yml";

main();

sub main {
  my $argc = $#ARGV + 1;
  if ( $argc < 1 || $argc > 2 ) {
    usage();
  }
  my $option = $ARGV[0];
  my $hostname = get_hostname();

  print get_value($option, $hostname);
}

sub usage {
  print STDERR "Usage: global_conf_get.pl <option> [<hostname or pop>]\n";
  print STDERR "Examples:\n";
  print STDERR "    global_conf_get.pl loadfactors (use current hostname)\n";
  print STDERR "    global_conf_get.pl loadfactors slb01.nrt1.llnw.net (for testing)\n";
  print STDERR "    global_conf_get.pl loadfactors nrt1 (for testing)\n";
  exit(1);
}

sub get_hostname {
  if ($#ARGV + 1 == 1) {
    return hostname;
  }
  return $ARGV[1];
}

sub get_pop {
  my $hostname = shift || die "Missing hostname arg $!";
  my $pop = (split '\.',$hostname)[1];
  if ($pop) {
    return $pop;
  }
  print STDERR "ERROR: Failed to extract POP from hostname ${hostname}\n";
  exit(1);
}

sub get_value {
  my $option = shift || die "Missing key arg $!";
  my $hostname = shift || die "Missing hostname arg $!";

  my $yml = LoadFile($config_file);
  my $yml_config = $yml->{$option} or die "No entry for option $option found in ${config_file} $!";

  # First try FQDN.
  if ($yml_config->{$hostname}) {
    return $yml_config->{$hostname};
  }

  # FQDN failed, try POP.
  if ($yml_config->{get_pop($hostname)}) {
    return $yml_config->{get_pop($hostname)};
  }

  # POP also failed, return the default value.
  if ($yml_config->{"default"}) {
    return $yml_config->{"default"};
  }

  print STDERR "ERROR: A default value is missing for option \"${option}\"\n";
  exit(1);
}
