# vim: sts=2 ts=2 sw=2 et ai

{% from "pepper/map.jinja" import defaults with context %}
{% from slspath ~ "/map.jinja" import production, keepalived_version with context %}
{% from slspath ~ "/slb_tools_map.jinja" import slb_tools_api_conf with context %}
{% from "sudoers/map.jinja" import sudo_map with context %}

include:
  - sudoers.setup

# create local slb_tools user 
sae|slb|slb_tools|user:
  user.present:
    - name: slb_tools
    - fullname: slb tools
    - shell: /bin/bash
    - home: /home/slb_tools
    - uid: 997
    - gid: slb_tools
    - require:
      - group: sae|slb|slb_tools|group

# create slb_tools group
sae|slb|slb_tools|group:
  group.present:
    - name: slb_tools
    - system: True
    - gid: 997

# create sudo entry for user slb_tools -- this will ensure slb_tools can perform
# the various SLB functions which require root access
sae|slb|slb_tools|sudo:
  file.managed:
    - name: {{ sudo_map.includedir }}/slb-tools
    - user: root
    - group: {{ defaults.root_group }}
    - mode: 440
    - contents: 'slb_tools ALL=(root) NOPASSWD: /sbin/ipvsadm, /usr/bin/vtysh, /bin/cat'
    - require:
      - user: sae|slb|slb_tools|user 
      - file: core|sudoers|includedir


sae|slb|slb_tools|pkgs:
  pkg.installed:
    - pkgs:
      - dh-virtualenv: 1.0-1
      - python3.7
      - python3-pip
      - python3.7-venv
      - supervisor


# install slb_tools pkg
sae|slb|slb_tools|slb_tools_pkg:
  pkg.installed:
    - name: slb-tools=1.0-1
    - require:
      - pkg: sae|slb|slb_tools|pkgs

# create links from virtual env
sae|slb|slb_tools|slb_cli2:
  file.symlink:
    - name: /usr/local/bin/slb_cli2
    - target: {{ slb_tools_api_conf.bin_path }}/slb_cli2
    - require:
      - pkg: sae|slb|slb_tools|slb_tools_pkg


# build slb_tools config/env conf file
sae|slb|slb_tools|config:
  file.managed:
    - name: /etc/keepalived/slb_tools.conf
    - template: jinja
    - source: salt://{{ slspath }}/templates/slb_tools.conf.jinja
    - user: slb_tools 
    - group: slb_tools
    - mode: 755
    - context:
      kernel_version: {{ production }}
      keepalived_version: {{ keepalived_version }}
    - require:
      - user: sae|slb|slb_tools|user

# build slb_tools config/env conf file
sae|slb|slb_tools|api_config:
  file.managed:
    - name: /etc/keepalived/slb_tools_api.conf
    - template: jinja
    - source: salt://{{ slspath }}/templates/slb_tools_api.conf.jinja
    - user: root
    - group: slb_tools
    - mode: 755
    - context:
      config: {{ slb_tools_api_conf }}
    - require:
      - file: sae|slb|slb_tools|config
      

# build slb_tools API log config file
sae|slb|slb_tools|log_config:
  file.managed:
    - name: /etc/keepalived/slb_tools_api_logging.conf
    - template: jinja
    - source: salt://{{ slspath }}/templates/slb_tools_api_logging.conf.jinja
    - user: root
    - group: slb_tools 
    - mode: 755
    - context:
      app_name: slb_tools
      keepalived_version: {{ keepalived_version }}
    - require:
      - file: sae|slb|slb_tools|config

# create logging directory
sae|slb|slb_tools|log_dir:
  file.directory:
    - name: /var/log/llnw
    - user: root
    - group: slb_tools
    - create: True
    - replace: False
    - mode: 775
    - require:
      - group: sae|slb|slb_tools|group

# create supervisor conf
sae|slb|slb_tools|supervisor:
  file.managed:
    - name: /etc/supervisor/conf.d/{{ slb_tools_api_conf.name }}.conf
    - template: jinja
    - source: salt://{{ slspath }}/templates/slb_tools_api_supervisor.conf.jinja
    - context:
      config: {{ slb_tools_api_conf }}
    - require:
      - file: sae|slb|slb_tools|log_dir  
  supervisord.running:
    - name: {{ slb_tools_api_conf.name }}
    - update: True
    - watch:
      - file: sae|slb|slb_tools|config
      - file: sae|slb|slb_tools|api_config
      - file: sae|slb|slb_tools|log_config
      - file: sae|slb|slb_tools|supervisor 
      - pkg: sae|slb|slb_tools|slb_tools_pkg


