# vim: sts=2 ts=2 sw=2 et ai

{% from "pepper/map.jinja" import defaults with context %}
{% from slspath ~ "/map.jinja" import conf_vars, hostname, city, building_type, slb_conf, is_lab with context %}

{% set edge_conf_cdn = 'http://test.vo.llnwd.net/cdn-edge-config/econfigs' %}
{% set edge_conf_secret = salt['pillar.get']('secrets:sae:edge_conf_cdn_mediavault_secret') %}

{#- include tools.sls which contains requisite sae|slb|global_conf_get #}
include:
  - .tools
  - .keepalived
  - .slb_tools

sae|slb|update_config_files:
  file.managed:
    - name: /etc/keepalived/scripts/update_config_files.sh
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755
    - source: salt://{{ slspath }}/scripts/update_config_files.sh

sae|slb|slb_conf_yml:
  file.managed:
    - name: /etc/keepalived/slb_conf.yml
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755
{%- if is_lab %}
    {# SLB lab only: if tagged 'slb-lab' and a local config file exists -- use it otherwise use slb config file #}
    - source: 
      - file:///etc/keepalived/local_slb_conf.yml
      - salt://sae-slb/files/{{ city }}-slb_conf.yml
{%- else %}
    - source: salt://sae-slb/files/{{ city }}-slb_conf.yml
{%- endif %}

sae|slb|running_vars:
  file.managed:
    - name: /etc/keepalived/scripts/.running_vars.inc
    - template: jinja
    - source: salt://{{ slspath }}/templates/set_running_env.jinja
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 755
    - context:
        hostname: {{ hostname }}
        city: {{ city }}
        building_type: {{ building_type }}
        slb_conf: {{ slb_conf }}
    - require:
      - file: sae|slb|slb_conf_yml 

sae|slb|global_conf:
  file.managed:
    - name: /etc/keepalived/global_conf.yml
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 644
{%- if is_lab %}
    {# SLB lab only: if tagged 'slb-lab' and a local config file exists -- use it #}
    - source:
      - file:///etc/keepalived/local_global_conf.yml
      - salt://sae-slb/files/global_conf.yml
{%- else %}
    - source: salt://sae-slb/files/global_conf.yml
{%- endif %}
    - require:
      - file: sae|slb|global_conf_get

sae|slb|server_load_affinity_conf:
  file.managed:
    - name: /etc/keepalived/server_load_affinity.yml
    - user: root
    - group: {{ defaults['root_group'] }}
    - mode: 644
{%- if is_lab %}
    {# SLB lab only: if tagged 'slb-lab' and a local config file exists -- use it #}
    - source:
      - file:///etc/keepalived/local_server_load_affinity.yml
      - salt://sae-slb/files/server_load_affinity.yml
{%- else %}
    - source: salt://sae-slb/files/server_load_affinity.yml
{%- endif %}


sae|slb|run_config_update:
  cmd.run:
    - name: /etc/keepalived/scripts/gen_slb_configs; echo $? > /tmp/gen_slb_configs.status
    - onchanges:
      - file: sae|slb|slb_conf_yml
      - file: sae|slb|gen_slb_configs
      - file: sae|slb|global_conf 
      - file: sae|slb|server_load_affinity_conf 

{% for edge_conf, v in conf_vars.remote_config_files.items() %}
{%   if is_lab and salt['file.file_exists']('/etc/keepalived/local_%s'|format(edge_conf)) %}
{%     set edge_conf_mediavault_url = '/etc/keepalived/local_%s'|format(edge_conf) %}
{%     set edge_conf_csum_mediavault_url = "" %}
{%   else %}
{%     set edge_conf_mediavault_url = salt['mediavault.buildurl'](
         edge_conf_secret,
         '%s/%s'|format(edge_conf_cdn, edge_conf), 0)
%}
{%     set edge_conf_csum_mediavault_url = salt['mediavault.buildurl'](
         edge_conf_secret,
         '%s/%s.md5'|format(edge_conf_cdn, edge_conf), 0)
%}
{%   endif %}

sae|slb|slb-config-{{ edge_conf }}:
  cmd.run:
    - name: /etc/keepalived/scripts/update_config_files.sh "{{ edge_conf_mediavault_url }}" /etc/keepalived/{{ edge_conf }} "{{ edge_conf_csum_mediavault_url }}" "{{ v.get('required', 0) }}"
    - require: 
      - file: sae|slb|update_config_files
    - stateful: True
    - onchanges_in:
      - cmd: sae|slb|run_config_update

{% endfor %}
