# vim: sts=2 ts=2 sw=2 et ai

{% from "pepper/map.jinja" import netblocks with context %}
{% from "pepper/map.jinja" import egblocks %}
{%- from "sae-splunk/envs.jinja" import splunk_envs with context %}

include:
  - .init
  - firewall.standard
  - firewall.web

sae|splunk|authorized-key-splunk-deploy:
  file.managed:
    - name: /opt/splunk/.ssh/id_dsa
    - contents_pillar: secrets:sae-splunk:splunk_github_ssh_key
    - user: splunk
    - group: splunk
    - mode: 600

sae|splunk|sshdir:
  file.directory:
    - name: /opt/splunk/.ssh
    - user: splunk
    - group: splunk
    - dir_mode: 700
    - require:
      - pkg: sae|splunk|splunk-pkg
    - recurse:
      - user
      - group
    - require_in:
      - cmd: sae|splunk|enable

sae|splunk|deployment-apps-dir:
  file.directory:
    - name: /splunk-shared/
    - user: splunk
    - group: splunk
    - dir_mode: 755
    - require:
      - pkg: sae|splunk|splunk-pkg
    - require_in:
      - cmd: sae|splunk|enable
    - recurse:
      - user
      - group

# Get deployment apps from git
sae|splunk|git-repo-checkout:
  git.latest:
    - name: git@github.llnw.net:Splunk/splunk-deployment-apps.git
    - user: splunk
    - rev: {{ splunk_envs['prodstatus'] }}
    - target: /splunk-shared/deploy/
    - identity: /opt/splunk/.ssh/id_dsa
    - force_checkout: True
    - force_fetch: True
    - force_reset: True
    - require:
      - file: sae|splunk|authorized-key-splunk-deploy
      - file: sae|splunk|deployment-apps-dir
    - require_in:
      - cmd: sae|splunk|enable

sae|splunk|git-post-merge-hook:
  file.managed:
    - name: /splunk-shared/deploy/.git/hooks/post-merge
    - user: splunk
    - group: splunk
    - mode: 755
    - source: salt://sae-splunk/files/git-post-merge-hook
    - require:
      - git: sae|splunk|git-repo-checkout

sae|msops|git-splunk-deployment:
  cron.present:
    - name: 'cd /splunk-shared/deploy && git checkout -q {{ splunk_envs['prodstatus'] }} && git reset --hard -q && git pull -q'
    - identifier: git-splunk-deployment
    - minute: '*/5'
    - user: splunk
    - require:
      - file: sae|splunk|git-post-merge-hook

# We symlink this so it can live in the Git repo
sae|splunk|serverclass-symlink:
  file.symlink:
    - name: /opt/splunk/etc/system/local/serverclass.conf
    - target: /splunk-shared/deploy/serverclass.conf
    - mode: 755
    - require:
      - git: sae|splunk|git-repo-checkout
    - require_in:
      - cmd: sae|splunk|enable
    - watch_in:
      - service: sae|splunk|service

sae|splunk|firewall-splunk-search-ports:
  firewall.accept:
    - tcp:
      - [8000, {{ netblocks + egblocks }}] # Web port
      - [8089, {{ netblocks + egblocks }}] # Splunk control port
    - require_in:
      - firewall: core|firewall|final-reject
