# vim: sts=2 ts=2 sw=2 et ai

{% from "pepper/map.jinja" import defaults with context %}
{%- from "sae-splunk/envs.jinja" import splunk_envs with context %}

include:
  - sae-sudoers.splunk-admin
  - base_repos
  - apache2
  - apache2.acl
  - certs.star
  - sysctl.ipv6_disable
  - pepper.nobluekey

sae|splunk|repo:
  pkgrepo.managed:
    - name: deb [trusted=yes] http://repo.llnw.net/llnw/ubuntu/{{ splunk_envs['prodstatus'] }}/splunk/ {{ grains['oscodename'] }}/
    - file: /etc/apt/sources.list.d/llnw.splunk.{{ grains['oscodename'] }}.list
    - refresh_db: true
    - watch_in:
      - module: core|base_repos|apt-refresh-db

sae|splunk|other-pkgs:
  pkg.latest:
    - names:
      - iftop
      - iotop
      - nmap
      - git

sae|splunk|splunk-pkg:
  pkg.installed:
    - name: splunk
    - version: {{ splunk_envs['splunk_ver'] }}

sae|splunk|group:
  group.present:
    - names: 
      - adm
      - ssl-cert
    - addusers:
      - splunk

sae|splunk|chown:
  cmd.run:
    - name: /bin/chown -R splunk:splunk /opt/splunk/ 2>/dev/null
    - require:
      - pkg: sae|splunk|splunk-pkg

sae|splunk|splunk-secret:
  file.managed:
    - name: /opt/splunk/etc/auth/splunk.secret
    - user: splunk
    - group: splunk
    - mode: 600
    - source: salt://sae-splunk/templates/splunk.secret
    - template: jinja
    - backup: True
    - require: 
      - file: sae|splunk|dir

sae|splunk|splunk-user-seed:
  file.managed:
    - name: /opt/splunk/etc/system/default/user-seed.conf
    - user: splunk
    - group: splunk
    - mode: 600
    - source: salt://sae-splunk/templates/user-seed.conf
    - template: jinja
    - backup: True
    - require: 
      - file: sae|splunk|dir

sae|splunk|splunk-web-conf:
  file.managed:
    - name: /opt/splunk/etc/system/local/web.conf
    - user: splunk
    - group: splunk
    - mode: 600
    - source: salt://sae-splunk/templates/web.conf
    - template: jinja
    - backup: True
    - require: 
      - file: sae|splunk|dir

sae|splunk|splunk-authorize-conf:
  file.managed:
    - name: /opt/splunk/etc/system/local/authorize.conf
    - user: splunk
    - group: splunk
    - mode: 600
    - source: salt://sae-splunk/files/authorize.conf
    - template: jinja
    - backup: True
    - require: 
      - file: sae|splunk|dir

sae|splunk|splunk-authentication-conf:
  file.managed:
    - name: /opt/splunk/etc/system/local/authentication.conf
    - user: splunk
    - group: splunk
    - mode: 600
    - source: salt://sae-splunk/files/authentication.conf
    - template: jinja
    - backup: True
    - require: 
      - file: sae|splunk|dir

sae|splunk|enable:
  cmd.run:
    - name: /opt/splunk/bin/splunk start --accept-license ; /opt/splunk/bin/splunk enable boot-start --answer-yes --no-prompt -user splunk --accept-license
    - creates: /etc/init.d/splunk
    - require:
      - pkg: sae|splunk|splunk-pkg
      - file: sae|splunk|splunk-secret
      - file: sae|splunk|splunk-user-seed

sae|splunk|service:
  service.running:
    - name: splunk
    - enable: True
    - full_restart: True
    - watch:
      - pkg: sae|splunk|splunk-pkg
      - group: sae|splunk|group
      - file: sae|splunk|splunk-web-conf
      - file: sae|splunk|splunk-authorize-conf
      - file: sae|splunk|splunk-authentication-conf

sae|splunk|apache-config:
  file.managed:
    - name: /etc/apache2/sites-available/splunk-redirect-apache2.conf
    - source: salt://sae-splunk/files/splunk-redirect-apache2.conf
    - mode: '0644'
    - user: splunk
    - group: splunk
    - require:
      - pkg: sae|splunk|splunk-pkg

sae|splunk|apache-rewrite:
  apache_module.enabled:
    - name: rewrite

sae|splunk|dir:
  file.directory:
    - name: /opt/splunk
    - user: splunk
    - group: splunk
    - require:
      - pkg: sae|splunk|splunk-pkg

sae|splunk|apache-config-enable:
  apache_site.enabled:
    - name: splunk-redirect-apache2
    - require:
      - file: sae|splunk|apache-config
      - apache_module: sae|splunk|apache-rewrite

sae|splunk|link-logs:
  file.symlink:
    - name: /opt/splunk/var/log/splunk/
    - target: /var/log/splunk
    - user: splunk
    - group: splunk
    - require:
      - pkg: sae|splunk|splunk-pkg
