{% import_yaml slspath ~ '/cdnvpn.yml' as cdnvpn %}

# {{ cdnvpn|json }}

{% set route_ips = {} %}
{% for key, ip_list in cdnvpn.iteritems() %}
{%   if key not in route_ips %}
{%     do route_ips.update({key: []}) %}
{%   endif %}
{%   for ip in ip_list %}
{%     if "/" not in ip %}
{%       set ip = ip ~ '/32' %}
{%     endif %}
{%     do route_ips[key].append(ip) %}
{%   endfor %}
{% endfor %}

# route_ips = {{route_ips|json}}

{% set device_class_name = salt['grains.get']('cornerstone:device_class_name', {}) %}
{% set building_type = salt['grains.get']('cornerstone:building_type_name', 'unknown') %}
{% set building_short_name = salt['grains.get']('cornerstone:building_name_short', 'unknown') %}
{% set os_family = salt['grains.get']('os_family', 'unknown') %}
{% set gateway_host = 'mor01.' ~ building_short_name|lower ~ '.llnw.net' %}
{% set gateway_ip = salt['llnetwork.get_hostbyname'](gateway_host) %}

{% set virtual = salt['grains.get']('virtual', 'unknown') %}
{% if 'physical' in virtual %}
{%   set management_iface = 'eth0' %}
{% elif 'kvm' in virtual %}
{%   set management_iface = 'eth1' %}
{% elif 'VirtualBox' in virtual %}
{%   set management_iface = 'eth1' %}
{% else %}
{%   set management_iface = 'error' %}
{% endif %}

# gateway_ip = {{gateway_ip}}
# os_family = {{os_family}}

{% if building_type == 'SPS' and gateway_ip is not none %}

{%   if os_family == 'FreeBSD' %}

{%     set route_info = {'static_routes': ''} %}
{%     for key, ip_list in route_ips.iteritems() %}
{%       for ip in ip_list %}
{%         set counter = loop.index %}
{%         set route_name = key ~ '_' ~ counter  %}
{%         set route =  '-net ' ~ ip ~ ' ' ~ gateway_ip %}
{%         do route_info.update({route_name: route}) %}
{%         set static_routes = route_info['static_routes'] %}
{%         do route_info.update({'static_routes': static_routes ~ route_name ~ ' '}) %}
{%       endfor %}
{%     endfor %}

salt-sae|sae-sps|route|make|rc_conf_local:
  file.touch:
    - name: /etc/rc.conf.local

salt-sae|sae-sps|route|update|rc_conf_local:
  file.blockreplace:
    - name: /etc/rc.conf.local
    - marker_start: "# { static routes"
    - marker_end: "# } static routes"
    - append_if_not_found: true
    - content: |
         static_routes="{{route_info['static_routes']}}"
{# the use of {%- on the following lines is necessary for proper rendering #} 
{%-    for route_name, route in route_info.iteritems() %}
{%-      if 'static_routes' not in route_name %}
         route_{{route_name}}="{{route}}"
{%-      endif %}
{%-    endfor %}
    - require:
      - salt-sae|sae-sps|route|make|rc_conf_local

salt-sae|sae-sps|route|run|netstart:
  cmd.run:
    - name: /etc/netstart
    - onchanges:
      - file: salt-sae|sae-sps|route|update|rc_conf_local

{%   elif os_family == 'Debian' %}

salt-sae|sae-sps|route|update|iproute2|rt_tables:
  file.blockreplace:
    - name: /etc/iproute2/rt_tables
    - marker_start: "# { vlan10"
    - marker_end: "# } vlan10"
    - append_if_not_found: true
    - content: |
         10  vlan10

{%     if 'error' in management_iface %}

salt-sae|sae-sps|route|fail|set-routes:
  test.fail_without_changes:
    - name: "Error: could not detect physical or virtual host type. 'virtual' grain is not set"
salt-sae|sae-sps|route|delete|set-routes:
  file.absent:
    - name: /etc/network/if-up.d/set-routes

{%     else %}

{%     if 'software-load-balancer' not in device_class_name %}
{#       no special routing, except on SLB's #}
{%       set route_ips = {} %}
{%     endif %}

salt-sae|sae-sps|route|make|set-routes:
  file.managed:
    - name: /etc/network/if-up.d/set-routes
    - source: salt://{{slspath}}/files/set-routes
    - makedirs: true
    - owner: root
    - group: root
    - mode: 755
    - template: jinja
    - context:
      management_iface: {{management_iface}}
      gateway_ip: {{gateway_ip}}
      route_ips: {{route_ips|json}}
    - requires:
      - salt-sae|sae-sps|route|update|iproute2|rt_tables

salt-sae|sae-sps|route|run|set-routes:
  cmd.run:
    - name: /etc/network/if-up.d/set-routes
    - stateful: true
    - requires:
      - salt-sae|sae-sps|route|make|set-routes
{%     endif %}

{%   else %}

salt-sae|sae-sps|route|fail|set-routes|unsupported-os:
  test.fail_without_changes:
    - name: "Error: '{{os_family}}' OS family not supported"

{%   endif %}

{% endif %}

salt-sae|sae-sps|route|always-works:
  test.succeed_without_changes:
    - name: salt-sae|sae-sps|route|always-works

