{% import_yaml slspath ~ '/cdnvpn.yml' as cdnvpn %}

# {{ cdnvpn|json }}

{% set route_ips = {} %}
{% for key, ip_list in cdnvpn.iteritems() %}
{%   if key not in route_ips %}
{%     do route_ips.update({key: []}) %}
{%   endif %}
{%   for ip in ip_list %}
{%     if "/" not in ip %}
{%       set ip = ip ~ '/32' %}
{%     endif %}
{%     do route_ips[key].append(ip) %}
{%   endfor %}
{% endfor %}

# route_ips = {{route_ips|json}}

{% set building_type = salt['grains.get']('cornerstone:building_type_name', 'unknown') %}
{% set building_short_name = salt['grains.get']('cornerstone:building_name_short', 'unknown') %}
{% set os_family = salt['grains.get']('os_family', 'unknown') %}
{% set gateway_host = 'mor01.' ~ building_short_name|lower ~ '.llnw.net' %}
{% set gateway_ip = salt['llnetwork.get_hostbyname'](gateway_host) %}

# gateway_ip = {{gateway_ip}}
# os_family = {{os_family}}

{% if building_type == 'SPS' and gateway_ip is not none %}

{%   if os_family == 'FreeBSD' %}

{%     set route_info = {'static_routes': ''} %}
{%     for key, ip_list in route_ips.iteritems() %}
{%       for ip in ip_list %}
{%         set counter = loop.index %}
{%         set route_name = key ~ '_' ~ counter  %}
{%         set route =  '-net ' ~ ip ~ ' ' ~ gateway_ip %}
{%         do route_info.update({route_name: route}) %}
{%         set static_routes = route_info['static_routes'] %}
{%         do route_info.update({'static_routes': static_routes ~ route_name ~ ' '}) %}
{%       endfor %}
{%     endfor %}

salt-sae|sae-sps|route|make|rc_conf_local:
  file.touch:
    - name: /etc/rc.conf.local

salt-sae|sae-sps|route|update|rc_conf_local:
  file.blockreplace:
    - name: /etc/rc.conf.local
    - marker_start: "# { static routes"
    - marker_end: "# } static routes"
    - append_if_not_found: true
    - content: |
         static_routes="{{route_info['static_routes']}}"
{# the use of {%- on the following lines is necessary for proper rendering #} 
{%-    for route_name, route in route_info.iteritems() %}
{%-      if 'static_routes' not in route_name %}
         route_{{route_name}}="{{route}}"
{%-      endif %}
{%-    endfor %}
    - require:
      - salt-sae|sae-sps|route|make|rc_conf_local

salt-sae|sae-sps|route|run|netstart:
  cmd.run:
    - name: /etc/netstart
    - onchanges:
      - file: salt-sae|sae-sps|route|update|rc_conf_local

{%   else %}
{#     os_family = Debian #}

salt-sae|sae-sps|route|update|iproute2|rt_tables:
  file.blockreplace:
    - name: /etc/iproute2/rt_tables
    - marker_start: "# { vlan10"
    - marker_end: "# } vlan10"
    - append_if_not_found: true
    - content: |
         10  vlan10

salt-sae|sae-sps|route|make|set-routes:
  file.managed:
    - name: /tmp/set-routes.sh
    - mode: 775
    - contents: |
        #!/usr/bin/env bash
        changed="false"
        result=$(ip route add 10.0.0.0/8 via {{gateway_ip}} 2>&1)
        echo $result
        if [[ ! $result =~ "File exists" ]]; then
          changed="true"
        fi
        result=$(ip route add 172.16.0.0/12 via {{gateway_ip}} 2>&1)
        echo $result
        if [[ ! $result =~ "File exists" ]]; then
          changed="true"
        fi
        result=$(ip route add 192.168.0.0/16 via {{gateway_ip}} 2>&1)
        echo $result
        if [[ ! $result =~ "File exists" ]]; then
          changed="true"
        fi
        result=$(ip route add default via {{gateway_ip}} table vlan10 2>&1)
        echo $result
        if [[ ! $result =~ "File exists" ]]; then
          changed="true"
        fi
        host_ip=$(ifconfig eth1|grep 'inet '|awk '{print $2}'|tr -d 'addr:')
        result=$(ip rule add from ${host_ip} table vlan10 2>&1)
        echo $result
        if [[ ! $result =~ "File exists" ]]; then
          changed="true"
        fi

        if [ "$change" == "true" ]; then
          echo 'changed=true comment="Routes set"'
        else
          echo 'changed=false comment="Routes already set"'
        fi

salt-sae|sae-sps|route|run|set-routes:
  cmd.run:
    - name: /tmp/set-routes.sh
    - stateful: true
    - requires:
      - salt-sae|sae-sps|route|make|set-routes

{%   endif %}

{% endif %}

salt-sae|sae-sps|route|always-works:
  test.succeed_without_changes:
    - name: salt-sae|sae-sps|route|always-works

