{% from slspath ~ "/map.jinja" import defaults with context %}

{% set building_type = salt['grains.get']('cornerstone:building_type_name', 'unknown') %}
{% set os_family = salt['grains.get']('os_family', 'unknown') %}

{% if building_type == 'SPS' %}

{%   if os_family == 'FreeBSD' %}

salt-sae|sae-sps|make|rc_conf_local:
  file.touch:
    - name: /etc/rc.conf.local

salt-sae|sae-sps|update|rc_conf_local:
  file.blockreplace:
    - name: /etc/rc.conf.local
    - marker_start: "# { fake tun0 for SPS"
    - marker_end: "# } fake tun0 for SPS"
    - append_if_not_found: true
    - content: |
        cloned_interfaces="${cloned_interfaces} tun0" 
        ifconfig_tun0="up"
    - require:
      - salt-sae|sae-sps|make|rc_conf_local

salt-sae|sae-sps|mktun0_sh:
  file.managed:
    - name: /tmp/mktun0.sh
    - mode: 775
    - contents: |
        exists=$(ifconfig | grep -c "tun0:")
        if [ $exists -eq 0 ]; then
          /etc/netstart 
          echo 'changed=true comment="Turned on tun0"'
        else
          echo 'changed=false comment="tun0 already exists"'
        fi

salt-sae|sae-sps|run|mktun0_sh:
  cmd.run:
    - name: /tmp/mktun0.sh
    - stateful: true
    - requires:
      - salt-sae|sae-sps|mktun0_sh

{%   else %}

salt-sae|sae-sps|mktun0_sh:
  file.managed:
    - name: /tmp/mktun0.sh
    - mode: 775
    - contents: |
        exists=$(ip link show | grep -c "tun0:")
        if [ $exists -eq 0 ]; then
          ip link add tun0 type dummy
          ip link set tun0 up
          echo 'changed=true comment="Turned on tun0"'
        else
          echo 'changed=false comment="tun0 already exists"'
        fi

salt-sae|sae-sps|run|mktun0_sh:
  cmd.run:
    - name: /tmp/mktun0.sh
    - stateful: true
    - requires:
      - salt-sae|sae-sps|mktun0_sh

{%   endif %}

{% else %}

{# needed in case this is not an SPS site ...                      #}
{# otherwise, this sls would be empty, resulting in a failed state #}
salt-sae|sae-sps|fake_tunnel|always-works:
  test.succeed_without_changes:
    - name: salt-sae|sae-sps|fake_tunnel|always-works

{% endif %}

