{% from slspath ~ "/map.jinja" import defaults with context %}

{%   set building_type = salt['grains.get']('cornerstone:building_type_name', 'unknown') %}
{%   set building_group_name = salt['grains.get']('cornerstone:building_group_name', 'unknown')|lower %}
{%   set building_short_name = salt['grains.get']('cornerstone:building_name_short', 'unknown') %}

{% if building_type == 'SPS' %}

{%   set os_family = salt['grains.get']('os_family', 'unknown') %}
{%   set os_release =  salt['grains.get']('osrelease', 'unknown') %}

{%   set gateway_host = 'mor01.' ~ building_short_name|lower ~ '.llnw.net' %}
{%   set gateway_ip = salt['llnetwork.get_hostbyname'](gateway_host) %}

{%   set fqdn = salt['grains.get']('fqdn', 'unknown') %}
{%   set fqdn_search = '.' ~ building_group_name %}
{%   set fqdn_replace = '-vpn.' ~ building_group_name %}
{%   set fqdn_vpn = fqdn|replace(fqdn_search, fqdn_replace)  %}
{%   set fqdn_vpn_ip = salt['llnetwork.get_hostbyname'](fqdn_vpn) %}

{#   SPS sites always use a /24 for the VPN IP space #}
{%   set netmask = '255.255.255.0' %}
{%   set cidr_netmask = '/24' %}

{#   OpenNebula hypervisors running Ubuntu 18.04 use netplan #}
{%   if os_release == '18.04' and 'onhv' in fqdn_vpn %}
{%     set use_netplan = true %}
{%   else %}
{%     set use_netplan = false %}
{%   endif %}

{%   if os_family == 'FreeBSD' %}

{%     if fqdn_vpn_ip is not none %}

salt-sae|sae-sps|private_ip|make|rc_conf_local:
  file.touch:
    - name: /etc/rc.conf.local

salt-sae|sae-sps|private_ip|bge0:
  file.blockreplace:
    - name: /etc/rc.conf.local
    - marker_start: "# { bge0"
    - marker_end: "# } bge0"
    - append_if_not_found: true
    - content: |
        ifconfig_bge0="inet {{fqdn_vpn_ip}}{{cidr_netmask}} -lro mtu 1400"
    - require:
      - salt-sae|sae-sps|private_ip|make|rc_conf_local

salt-sae|sae-sps|private_ip|run|netstart:
  cmd.run:
    - name: /etc/netstart
    - onchanges:
      - file: salt-sae|sae-sps|private_ip|bge0

{%    endif %}

{# zabbix proxies already have a private IP assigned #}
{%   elif 'zabbix-proxy' not in fqdn_vpn %}

{%     if use_netplan == true %}

salt-sae|sae-sps|private_ip|eth1:
  file.managed:
    - name: /etc/netplan/02-llnw-vpn.yaml
    - create: true
    - mode: 644
    - user: root
    - contents: |
        network:
          version: 2
          renderer: networkd
          ethernets:
            eth1:
              dhcp4: no
              dhcp6: no
              addresses: [{{fqdn_vpn_ip}}{{cidr_netmask}}] 
              gateway4: {{gateway_ip}}

{%     else %}

{%       if fqdn_vpn_ip is not none %}

salt-sae|sae-sps|private_ip|eth1:
  file.blockreplace:
    - name: /etc/network/interfaces
    - marker_start: "# { vpn"
    - marker_end: "# } vpn"
    - append_if_not_found: true
    - content: |
        auto eth1
        iface eth1 inet static
            address {{fqdn_vpn_ip}}
            netmask {{netmask}}
            gateway {{gateway_ip}}

salt-sae|sae-sps|private_ip|run|ifconfig:
  cmd.run:
    - name: ifconfig eth1 up
    - onchanges:
      - file: salt-sae|sae-sps|private_ip|eth1

{%        endif %}

{%      endif %}

{%   endif %}

{% endif %}

{# needed in case this is not an SPS site ...                      #}
{# otherwise, this sls would be empty, resulting in a failed state #}
salt-sae|sae-sps|private_ip|always-works:
  test.succeed_without_changes:
    - name: salt-sae|sae-sps|fake_tunnel|always-works


