# vim: sts=2 ts=2 sw=2 et ai
{% set zabbix_audit_db_pass = salt['pillar.get'] ("secrets:zabbix:zabbix_audit_db_pass") %}
{% from "beats/map.jinja" import extend_filebeats with context %}

include:
  - beats.filebeat

{{ extend_filebeats('/var/log/zabbix-audit/zabbix-audit.log', 'log', { "service": "zabbix-audit" }) }}

sae-zabbix-infra|audit|packages:
  pkg.installed:
    - pkgs:
      - python-mysql.connector
    - skip_verify: True
    - refresh: True

sae-zabbix-infra|audit|script:
  file.managed:
    - name: /opt/monitoring/zabbix-audit.py
    - source: salt://sae-zabbix-infra/audit/files/zabbix-audit.py
    - makedirs: True
    - user: root
    - group: root
    - mode: 755

sae-zabbix-infra|audit|cron:
  file.managed:
    - name: /etc/cron.d/zabbix-audit
    - source: salt://sae-zabbix-infra/audit/files/zabbix-audit-cron.jinja
    - template: jinja
    - user: root
    - group: root
    - mode: 644

sae-zabbix-infra|audit|logdir:
  file.directory:
    - name: /var/log/zabbix-audit
    - user: root
    - group: root
    - mode: 755

sae-zabbix-infra|audit|logrotate:
  file.managed:
    - name: /etc/logrotate.d/zabbix-audit
    - source: salt://sae-zabbix-infra/audit/files/zabbix-audit-logrotate.jinja
    - template: jinja
    - user: root
    - group: root
    - mode: 644

sae-zabbix-infra|audit|conf:
  file.managed:
    - name: /etc/zabbix/zabbix-audit.conf
    - mode: 644
    - source: salt://sae-zabbix-infra/audit/files/zabbix-audit.conf.jinja
    - template: jinja
    - makedirs: True
    - defaults:
        dbhost: cdn-zabbix-db-ro-slave.llnw.com
        dbname: zabbix
        dbuser: zabbix_audit
        dbpass: {{ zabbix_audit_db_pass }}
