{% from "sae-zabbix-infra/map.jinja" import zabbix with context %}
{% set environment = salt['grains.get']('team_env', '') %}

include:
  - sae-zabbix-infra.sudo
  - firewall.standard
  - firewall.web
  - apache2
  - apache2.ssl
  - certs
  - sysctl.ipv6_disable

sae|zabbix-infra|command|apt-config:
  pkgrepo.managed:
    - name: {{ zabbix.repo.Link }}/ {{ grains['oscodename'] }}/
    - file: /etc/apt/sources.list.d/llnw.zabbix.{{ grains['oscodename'] }}.list
    - require_in:
      - pkg: sae|zabbix-infra|command|pkgs

sae|zabbix-infra|command|pkgs:
  pkg.installed:
    - pkgs: 
        {% if environment == 'production' %}
        - zabbix-frontend-php: 80:3.0.29-80+xenial+llnw.1
        - php7.0-common: 7.0.33-0ubuntu0.16.04.12
        - php7.0-curl: 7.0.33-0ubuntu0.16.04.12
        - php7.0-ldap: 7.0.33-0ubuntu0.16.04.12
        - php7.0-fpm: 7.0.33-0ubuntu0.16.04.12
        - libapache2-mod-fastcgi: 2.4.7~0910052141-1.2
        - librt-client-rest-perl: 1:0.50-1
        - llnw-zabbixapi-perl: 1.0.0
        - iptables-persistent: 1.0.4
        {% elif environment == 'dev' %}
        - zabbix-frontend-php: 80:3.0.29-80+xenial+llnw.1
        - php7.0-common: 7.0.33-0ubuntu0.16.04.12
        - php7.0-curl: 7.0.33-0ubuntu0.16.04.12
        - php7.0-ldap: 7.0.33-0ubuntu0.16.04.12
        - php7.0-fpm: 7.0.33-0ubuntu0.16.04.12
        - libapache2-mod-fastcgi: 2.4.7~0910052141-1.2
        - librt-client-rest-perl: 1:0.50-1
        - llnw-zabbixapi-perl: 1.0.0
        - iptables-persistent: 1.0.4
        {% else %}
        - zabbix-frontend-php: 80:3.0.29-80+xenial+llnw.1
        - php7.0-common: 7.0.33-0ubuntu0.16.04.12
        - php7.0-curl: 7.0.33-0ubuntu0.16.04.12
        - php7.0-ldap: 7.0.33-0ubuntu0.16.04.12
        - php7.0-fpm: 7.0.33-0ubuntu0.16.04.12
        - libapache2-mod-fastcgi: 2.4.7~0910052141-1.2
        - librt-client-rest-perl: 1:0.50-1
        - llnw-zabbixapi-perl: 1.0.0
        - iptables-persistent: 1.0.4
        {% endif %}
    - skip_verify: True
    - refresh: True

sae|zabbix-infra|command|web-conf:
  file.managed:
    - name: /etc/zabbix/web/zabbix.conf.php
    - source: salt://sae-zabbix-infra/command/files/zabbix.conf.php
    - template: jinja 
    - mode: 644
    - user: www-data
    - group: root
    - makedirs: True
    - require: 
      - pkg: sae|zabbix-infra|command|pkgs

sae|zabbix-infra|command|web-api-conf:
  file.managed:
    - name: /usr/share/zabbix/llnw/config.php
    - source: salt://sae-zabbix-infra/command/files/config.php
    - template: jinja 
    - mode: 644
    - user: www-data
    - group: root
    - makedirs: True
    - require: 
      - pkg: sae|zabbix-infra|command|pkgs

sae|zabbix-infra|command|apache-conf:
  file.managed:
    - name: /etc/apache2/apache2.conf
    - source: salt://sae-zabbix-infra/command/files/apache/apache2.conf
    - mode: 644
    - user: root
    - group: root
    - require:
      - pkg: sae|zabbix-infra|command|pkgs

sae|zabbix-infra|command|fastcgi-conf:
  file.managed:
    - name: /etc/apache2/mods-available/fastcgi.conf
    - source: salt://sae-zabbix-infra/command/files/apache/mods-available/fastcgi.conf
    - mode: 644
    - user: root
    - group: root
    - require:
      - pkg: sae|zabbix-infra|command|pkgs

sae|zabbix-infra|command|mpm-worker:
  file.managed:
    - name: /etc/apache2/mods-available/mpm_worker.conf
    - source: salt://sae-zabbix-infra/command/files/apache/mods-available/mpm_worker.conf
    - mode: 644
    - user: root
    - group: root
    - require:
      - pkg: sae|zabbix-infra|command|pkgs

sae|zabbix-infra|command|apache-php-ini:
  file.managed:
    - name: /etc/php/7.0/apache2/php.ini
    - source: salt://sae-zabbix-infra/command/files/php/7.0/apache2/php.ini
    - mode: 644
    - user: root
    - group: root
    - require:
      - pkg: sae|zabbix-infra|command|pkgs


sae|zabbix-infra|command|cli-php-ini:
  file.managed:
    - name: /etc/php/7.0/cli/php.ini
    - source: salt://sae-zabbix-infra/command/files/php/7.0/cli/php.ini
    - mode: 644
    - user: root
    - group: root
    - require:
      - pkg: sae|zabbix-infra|command|pkgs

sae|zabbix-infra|command|fpm-php-ini:
  file.managed:
    - name: /etc/php/7.0/fpm/php.ini
    - source: salt://sae-zabbix-infra/command/files/php/7.0/fpm/php.ini
    - mode: 644
    - user: root
    - group: root
    - require:
      - pkg: sae|zabbix-infra|command|pkgs


sae|zabbix-infra|command|dashboard-override:
  file.managed:
    - name: /usr/share/zabbix/app/controllers/CControllerDashboardView.php
    - source: salt://sae-zabbix-infra/command/files/CControllerDashboardView.php
    - mode: 644
    - user: root
    - group: root
    - makedirs: True
    - require:
      - pkg: sae|zabbix-infra|command|pkgs

sae|zabbix-infra|command|proxymap-conf:
  file.managed:
    - name: /usr/share/zabbix/llnw/proxymap.json
    - source: salt://sae-zabbix-infra/command/files/proxymap.json
    - template: jinja 
    - mode: 644
    - user: www-data
    - group: root
    - makedirs: True
    - require: 
      - pkg: sae|zabbix-infra|command|pkgs

sae|zabbix-infra|command|zabbix-conf:
  file.managed:
    - name: /etc/apache2/conf/zabbix.conf
    - source: salt://sae-zabbix-infra/command/files/apache/zabbix.conf
    - template: jinja
    - mode: 640
    - user: root
    - group: root
    - makedirs: True
    - require:
      - pkg: sae|zabbix-infra|command|pkgs

sae|zabbix-infra|command|zabbix-sites-conf:
  file.managed:
    - name: /etc/apache2/sites-available/zabbix.conf
    - source: salt://sae-zabbix-infra/command/files/apache/sites-available/zabbix.conf
    - template: jinja
    - mode: 640
    - user: root
    - group: root
    - makedirs: True
    - require:
      - pkg: sae|zabbix-infra|command|pkgs

sae|zabbix-infra|command|zabbix-acls:
  file.managed:
    - name: /etc/apache2/acls/ms-ops-boxes.conf
    - source: salt://sae-zabbix-infra/command/files/apache/acls/ms-ops-boxes.conf
    - template: jinja
    - mode: 644
    - user: root
    - group: root
    - makedirs: True
    - require:
      - pkg: sae|zabbix-infra|command|pkgs

sae|zabbix-infra|command|disable-default:
  apache_site.disabled:
    - name: 000-default.conf

sae|zabbix-infra|command|apache-configuration:
  apache_site.enabled:
    - name: zabbix.conf
  apache_module.enabled:
    - name: ssl
    - name: mpm_worker
    - name: status
    - name: rewrite
    - name: actions
    - name: cgid
  service.running:
    - name: apache2
    - enable: True
    - reload: True
    - watch:
      - apache_site: sae|zabbix-infra|command|apache-configuration
      - apache_module: sae|zabbix-infra|command|apache-configuration
      - file: sae|zabbix-infra|command|web-conf
    - require:
      - pkg: sae|zabbix-infra|command|pkgs
