{% from "sae-zabbix-infra/map.jinja" import zabbix, zabbix_ips, frontend_tools_ips with context %}
{% from "zabbix/map.jinja" import zabbix_proxy_ips, zabbix_proxy_ranges %}
{% set environment = salt['grains.get']('team_env', '') %}

include:
  - resolver
  - sae-zabbix-infra.sudo
  - sae-zabbix-infra.main.external
  - firewall.standard
  - splunkforwarder

sae|zabbix-infra|main|proxy-fw:
  firewall.accept:
    - tcp:
      {% for zbx_ip in zabbix_proxy_ips %}
      - [10051, {{ zbx_ip }}]
      {% endfor %}
      {% for zbx_range in zabbix_proxy_ranges %}
      - [10051, {{ zbx_range }}]
      {% endfor %}
      {% for frontend_ip in frontend_tools_ips %}
      - [10051, {{ frontend_ip }}]
      {% endfor %}
    - require_in:
      - firewall: core|firewall|final-reject

sae|zabbix-infra|main|corosync-fw:
  firewall.accept:
    - udp:
      - ['5404:5407', {{ zabbix_ips }}]
    - require_in:
      - firewall: core|firewall|final-reject

sae|zabbix-infra|main|apt-config:
  pkgrepo.managed:
    - name: {{ zabbix.repo.Link }}/ {{ grains['oscodename'] }}/
    - file: /etc/apt/sources.list.d/llnw.zabbix.{{ grains['oscodename'] }}.list
    - require_in:
      - pkg: sae|zabbix-infra|main|pkgs

sae|zabbix-infra|main|pkgs:
  pkg.installed:
    - pkgs:
        {% if environment == 'production' %}
        - zabbix-server-mysql: 80:3.0.29-80+xenial+llnw.1
        - llnw-rest-client-perl: 1.0.0
        - llnw-rundeck-client-perl: 1.0.0
        - llnw-zabbixapi-perl: 1.0.0
        - llnw-zbxrundeck-perl: 1.0.2
        - zabbix-rt-tkt: 1.1.2
        - zabbix-get: 80:3.0.29-80+xenial+llnw.1
        - zabbix-sender: 80:3.0.29-80+xenial+llnw.1
        - zabbix-java-gateway: 80:3.0.29-80+xenial+llnw.1
        - zabbix-alert-scripts: 1.0
        - corosync: 2.3.5-3ubuntu1
        - pacemaker: 1.1.14-2ubuntu1.1
        {% elif environment == 'dev' %}
        - zabbix-server-mysql: 80:3.0.29-80+xenial+llnw.1
        - llnw-rest-client-perl: 1.0.0
        - llnw-rundeck-client-perl: 1.0.0
        - llnw-zabbixapi-perl: 1.0.0
        - llnw-zbxrundeck-perl: 1.0.2
        - zabbix-rt-tkt: 1.1.2
        - zabbix-get: 80:3.0.29-80+xenial+llnw.1
        - zabbix-sender: 80:3.0.29-80+xenial+llnw.1
        - zabbix-java-gateway: 80:3.0.29-80+xenial+llnw.1
        - zabbix-alert-scripts: 1.0
        - corosync: 2.3.5-3ubuntu1
        - pacemaker: 1.1.14-2ubuntu1.1
        {% else %}
        - zabbix-server-mysql: 80:3.0.29-80+xenial+llnw.1
        - llnw-rest-client-perl: 1.0.0
        - llnw-rundeck-client-perl: 1.0.0
        - llnw-zabbixapi-perl: 1.0.0
        - llnw-zbxrundeck-perl: 1.0.2
        - zabbix-rt-tkt: 1.1.2
        - zabbix-get: 80:3.0.29-80+xenial+llnw.1
        - zabbix-sender: 80:3.0.29-80+xenial+llnw.1
        - zabbix-java-gateway: 80:3.0.29-80+xenial+llnw.1
        - zabbix-alert-scripts: 1.0
        - corosync: 2.3.5-3ubuntu1
        - pacemaker: 1.1.14-2ubuntu1.1
        {% endif %}       
    - skip_verify: True
    - refresh: True

sae|zabbix-infra|main|share-mem-conf:
  file.managed:
    - name: /etc/sysctl.conf
    - source: salt://sae-zabbix-infra/main/files/sysctl.conf
    - template: jinja 
    - mode: 644
    - user: root
    - group: root
    - makedirs: True
    - require: 
      - pkg: sae|zabbix-infra|main|pkgs

sae|zabbix-infra|main|server-conf:
  file.managed:
    - name: /etc/zabbix/zabbix_server.conf
    - source: salt://sae-zabbix-infra/main/files/zabbix_server.conf
    - template: jinja 
    - mode: 640
    - user: zabbix
    - group: zabbix
    - makedirs: True
    - require: 
      - pkg: sae|zabbix-infra|main|pkgs

sae|zabbix-infra|main|alert-scripts:
  file.directory:
    - name: /usr/local/zabbix/alert_scripts
    - makedirs: True
    - user: zabbix
    - group: zabbix
    - dir_mode: 750
    - file_mode: 750
    - recurse: 
        - user
        - group
        - mode
    - require: 
      - pkg: sae|zabbix-infra|main|pkgs

sae|zabbix-infra|main|external-scripts:
  file.directory:
    - name: /usr/local/zabbix/external_scripts
    - makedirs: True
    - user: zabbix
    - group: zabbix
    - dir_mode: 750
    - file_mode: 750
    - recurse: 
        - user
        - group
        - mode
    - require: 
      - pkg: sae|zabbix-infra|main|pkgs

sae|zabbix-infra|main|bin-scripts:
  file.directory:
    - name: /usr/local/zabbix/bin
    - makedirs: True
    - user: zabbix
    - group: zabbix
    - dir_mode: 750
    - file_mode: 750
    - recurse: 
        - user
        - group
        - mode
    - require: 
      - pkg: sae|zabbix-infra|main|pkgs

sae|zabbix-infra|main|footprint-response-logrotate:
  file.managed:
    - name: /etc/logrotate.d/footprint-response
    - mode: 644
    - user: root
    - group: root
    - source: salt://sae-zabbix-infra/main/files/footprint-response

sae|zabbix-infra|main|java-gateway|service:
  service.running:
    - name: zabbix-java-gateway
    - enable: True
    - reload: True
    - require:
      - pkg: sae|zabbix-infra|main|pkgs

{% if grains.virtual == 'VirtualBox' %}
sae|zabbix-infra|main|vbox-my-cnf:
  file.managed:
    - name: /etc/mysql/my.cnf
    - source: salt://sae-zabbix-infra/main/files/my.cnf
    - template: jinja 
    - mode: 644
    - user: root
    - group: root
    - makedirs: True
    - require: 
      - pkg: sae|zabbix-infra|main|pkgs

sae|zabbix-infra|main|vbox-mysql-grant:
  mysql_grants.present:
    - grant: all privileges
    - database: '*.*'
    - user: root
    - host: '%'
    - require:
      - file: sae|zabbix-infra|main|vbox-my-cnf
    - watch_in:
      - service: sae|zabbix-infra|main|zabbix-service
{% endif %}

