# vim: sts=2 ts=2 sw=2 et ai

{% from "pepper/map.jinja" import defaults with context %}
{% from "sae-zabbix-infra/map.jinja" import zbx_proxy_map, zbx_proxy_component with context %}

{% set images_cdn_secret = salt['pillar.get']('secrets:sae:images_cdn_mediavault_secret') %}
{% set tmp_dir = '/tmp/zbx-proxy' %}
{% set zbx_proxy_tar = 'zbx_conf_proxy.tar.gz' %}
{% set zabbix_cdn = 'http://images.llnw.net/zabbix/' %}

{% set component_mediavault_url = salt['mediavault.buildurl'](
     images_cdn_secret,
     '%s/%s'|format(zabbix_cdn, zbx_proxy_tar))
%}
{% set component_csum_mediavault_url = salt['mediavault.buildurl'](
     images_cdn_secret,
     '%s/%s.md5'|format(zabbix_cdn, zbx_proxy_tar))
%}

{% set vip_wget_version = '0.1' %}

sae|zabbix-infra|arch-tmpdir:
  file.directory:
    - name: {{ tmp_dir }}
    - user: root
    - group: root

sae|zabbix-infra|zbx_conf_proxy-extract:
  file.managed:
    - name: {{ tmp_dir }}/{{ zbx_proxy_tar }}
    - source: {{ component_mediavault_url }}
    - source_hash: {{ component_csum_mediavault_url }}
  cmd.run:
    - name: tar -zxf {{ tmp_dir }}/{{ zbx_proxy_tar }} -C {{ tmp_dir }} && rsync -av --exclude=README.md --exclude=.gitignore {{ tmp_dir }}/zbx-proxy/ {{ zbx_proxy_map.basedir }}/ && rm -rf {{ tmp_dir }}

sae|zabbix-infra|proxy|vip-wget-archive:
  archive.extracted:
    - name: /
    - source: http://images.llnw.net/zabbix/vip-wget-{{ vip_wget_version }}.tar.gz
    - source_hash: http://images.llnw.net/zabbix/vip-wget-{{ vip_wget_version }}.tar.gz.md5
    - if_missing: /opt/vip-wget-{{ vip_wget_version }}

sae|zabbix-infra|proxy|vip-wget-symlink:
  file.symlink:
    - name: /usr/bin/vip-wget
    - target: /opt/vip-wget-{{ vip_wget_version }}/bin/wget
    - mode: 755
    - force: True
    - require:
      - archive: sae|zabbix-infra|proxy|vip-wget-archive

{% for component, attr in zbx_proxy_component.iteritems() %}
sae|zabbix-infra|proxy|zbx_conf_proxy-{{ component }}-permissions:
  file.directory:
    - name: {{ zbx_proxy_map.basedir }}/{{ component }}
    - user: zabbix
    - group: zabbix
    - file_mode: '{{ attr.mode }}'
    - dir_mode: '0755'
    - recurse:
      - user
      - group
      - mode
    - require:
      - sae|zabbix-infra|zbx_conf_proxy-extract
{% endfor %}