{% from "pepper/map.jinja" import defaults with context %}
{% import_yaml "sae-zabbix-infra/proxy/proxy_override.yaml" as proxy_override %}
{% from "sae-zabbix-infra/map.jinja" import zabbix, zbx_proxy_map, ipv6_enable, firewall_standard_enable with context %}
{% set environment = salt['grains.get']('team_env', '') %}

include:
  - resolver
  - pepper.nobluekey
  - sae-zabbix-infra.proxy.configs
  - sae-zabbix-infra.sudo
{% if grains['fqdn'] in ipv6_enable %}
  - sysctl.ipv6_enable
{% else %}
  - sysctl.ipv6_disable
{% endif %}
{% if grains['fqdn'] in firewall_standard_enable %}
  - firewall.standard
{% endif %}

{% if grains['os_family'] == 'Debian' %}
sae|zabbix-infra|proxy|debconf:
  debconf.set_file:
    - source: salt://sae-zabbix-infra/proxy/files/debconf
    - require_in:
      - pkg: sae|zabbix-infra|proxy|packages

sae|zabbix-infra|proxy|apt-config:
  pkgrepo.managed:
    - name: {{ zabbix.repo.Link }}/ {{ grains['oscodename'] }}/
    - file: /etc/apt/sources.list.d/llnw.zabbix.{{ grains['oscodename'] }}.list
    - require_in:
      - pkg: sae|zabbix-infra|proxy|dep-packages
      - pkg: sae|zabbix-infra|proxy|packages

sae|zabbix-infra|proxy|apt-config-lama:
  pkgrepo.managed:
    - name: deb http://repo.llnw.net/lama/prod/ubuntu/{{ grains['oscodename'] }} binary/
    - file: /etc/apt/sources.list.d/llnw.zabbix.lama.{{ grains['oscodename'] }}.list

sae|zabbix-infra|proxy|sqlite-dir:
  file.directory:
    - name: {{ zbx_proxy_map.dbdir }}
    - user: zabbix
    - group: zabbix
    - dir_mode: 755
    - makedirs: True
    - require_in:
      - service: sae|zabbix-infra|proxy|service

sae|zabbix-infra|proxy|log-dir:
  file.directory:
    - name: {{ zbx_proxy_map.logdir }}
    - user: zabbix
    - group: zabbix
    - dir_mode: 755
    - makedirs: True
{% endif %}

{% macro sysctl(name, sysctl, value) %}
sae|zabbix-infra|proxy|sysctl-{{ name }}:
  sysctl.present:
    - name: {{ sysctl }}
    - value: {{ value }}
    - config: /etc/sysctl.conf
{%- endmacro %}

{% if grains['kernel'] == 'Linux' %}
# shmall is approx 90% of the phy mem divided by 4 KB (the base page size).
# Example 24G * 0.90 * 1024 * 1024 / 4 = 5662310
{{ sysctl('shmall', 'kernel.shmall', '5662310') }}
# shmmax is maximum size (in bytes) for a shared memory segment. Recommended
# setting is 2GB (max is 4GB).  minimum for 64-bit systems is 1GB.
{{ sysctl('shmmax', 'kernel.shmmax', '2147483648') }}
{{ sysctl('shmni', 'kernel.shmni', '4096') }}
# semaphores: semmsl, semmns, semopm, semmni
{{ sysctl('sem', 'kernel.sem', '250 32000 100 128') }}
# Account for mis-announced mtu size and resulting blackhole
{{ sysctl('mtu', 'net.ipv4.tcp_mtu_probing', '1') }}
{% endif %}

sae|zabbix-infra|proxy|dep-packages:
  pkg.installed:
    - pkgs:
      {% if environment == 'production' %}
      - lamactl-7-5-0: 7.5.0-186-g97237b7
      - lamactl-8-4-0: 8.4.0-10-g4d77235
      - libcache-memcached-perl: 1.30-1
      - libconfig-properties-perl: 1.75-1
      - libdate-manip-perl: 6.52-1
      - libdbd-mysql-perl: 4.033-1ubuntu0.1
      - libdbi-perl: 1.634-1build1
      - libiodbc2: 3.52.9-2
      - liblwp-useragent-determined-perl: 1.07-1
      - libmysqlclient20: 5.7.18-0ubuntu0.16.04.1
      - libnet-daemon-perl: 0.48-1
      - libnet-dns-perl: 0.81-2build1
      - librtsp-lite-perl: 0.1-1
      - libsys-sigaction-perl: 0.20-1
      - libxml-simple-perl: 2.22-1
      - libyaml-syck-perl: 1.29-1build1
      - python-beautifulsoup: 3.2.1-1
      - python-jsonrpclib: 0.1.3-1build1
      - python-mysqldb: 1.3.7-1build2
      - python-requests: 2.9.1-3
      - python-suds: 0.7~git20150727.94664dd-3
      - pyzabbix: 0.7.4-llnw1
      - libsnmp30: 5.7.3+dfsg-1ubuntu4.4
      - snmp: 5.7.3+dfsg-1ubuntu4.4
      {% elif environment == 'dev' %}
      - lamactl-7-5-0: 7.5.0-186-g97237b7
      - lamactl-8-4-0: 8.4.0-10-g4d77235
      - libcache-memcached-perl: 1.30-1
      - libconfig-properties-perl: 1.75-1
      - libdate-manip-perl: 6.52-1
      - libdbd-mysql-perl: 4.033-1ubuntu0.1
      - libdbi-perl: 1.634-1build1
      - libiodbc2: 3.52.9-2
      - liblwp-useragent-determined-perl: 1.07-1
      - libmysqlclient20: 5.7.18-0ubuntu0.16.04.1
      - libnet-daemon-perl: 0.48-1
      - libnet-dns-perl: 0.81-2build1
      - librtsp-lite-perl: 0.1-1
      - libsys-sigaction-perl: 0.20-1
      - libxml-simple-perl: 2.22-1
      - libyaml-syck-perl: 1.29-1build1
      - python-beautifulsoup: 3.2.1-1
      - python-jsonrpclib: 0.1.3-1build1
      - python-mysqldb: 1.3.7-1build2
      - python-requests: 2.9.1-3
      - python-suds: 0.7~git20150727.94664dd-3
      - pyzabbix: 0.7.4-llnw1
      - libsnmp30: 5.7.3+dfsg-1ubuntu4.4
      - snmp: 5.7.3+dfsg-1ubuntu4.4
      {% else %}
      - lamactl-7-5-0: 7.5.0-186-g97237b7
      - lamactl-8-4-0: 8.4.0-10-g4d77235
      - libcache-memcached-perl: 1.30-1
      - libconfig-properties-perl: 1.75-1
      - libdate-manip-perl: 6.52-1
      - libdbd-mysql-perl: 4.033-1ubuntu0.1
      - libdbi-perl: 1.634-1build1
      - libiodbc2: 3.52.9-2
      - liblwp-useragent-determined-perl: 1.07-1
      - libmysqlclient20: 5.7.18-0ubuntu0.16.04.1
      - libnet-daemon-perl: 0.48-1
      - libnet-dns-perl: 0.81-2build1
      - librtsp-lite-perl: 0.1-1
      - libsys-sigaction-perl: 0.20-1
      - libxml-simple-perl: 2.22-1
      - libyaml-syck-perl: 1.29-1build1
      - python-beautifulsoup: 3.2.1-1
      - python-jsonrpclib: 0.1.3-1build1
      - python-mysqldb: 1.3.7-1build2
      - python-requests: 2.9.1-3
      - python-suds: 0.7~git20150727.94664dd-3
      - pyzabbix: 0.7.4-llnw1
      - libsnmp30: 5.7.3+dfsg-1ubuntu4.4
      - snmp: 5.7.3+dfsg-1ubuntu4.4
      {% endif %}
    - skip_verify: True
    - refresh: True

sae|zabbix-infra|proxy|packages:
  pkg.installed:
    - pkgs:
      {% if environment == 'production' %}
      - zabbix-get: 80:3.0.29-80+xenial+llnw.1
      - zabbix-java-gateway: 80:3.0.29-80+xenial+llnw.1
      - zabbix-proxy-sqlite3: 80:3.0.29-80+xenial+llnw.1
      - zabbix-sender: 80:3.0.29-80+xenial+llnw.1
      {% elif environment == 'dev' %}
      - zabbix-get: 80:3.0.29-80+xenial+llnw.1
      - zabbix-java-gateway: 80:3.0.29-80+xenial+llnw.1
      - zabbix-proxy-sqlite3: 80:3.0.29-80+xenial+llnw.1
      - zabbix-sender: 80:3.0.29-80+xenial+llnw.1
      {% else %}
      - zabbix-get: 80:3.0.29-80+xenial+llnw.1
      - zabbix-java-gateway: 80:3.0.29-80+xenial+llnw.1
      - zabbix-proxy-sqlite3: 80:3.0.29-80+xenial+llnw.1
      - zabbix-sender: 80:3.0.29-80+xenial+llnw.1
      {% endif %}
    - skip_verify: True
    - watch_in:
      - service: sae|zabbix-infra|proxy|service

sae|zabbix-infra|proxy|config:
{% set proxy_config = proxy_override.get(grains['fqdn']) %}
{% if not proxy_config %}
{%   set proxy_config = proxy_override.get('default') %}
{%   set proxy_server = proxy_config['server'] %}
{%   set proxy_num = grains['host'][-2:] %}
{%   set proxy_host = "%s%s"|format(salt['grains.get']('cornerstone:building_group_name'), proxy_num) %}
{% else %}
{%   set proxy_host = proxy_config['hostname'] %}
{%   set proxy_server = proxy_config['server'] %}
{% endif %}
  file.managed:
    - name: /etc/zabbix/zabbix_proxy.conf
    - template: jinja
    - backup: False
    - mode: 640
    - user: zabbix
    - source: salt://sae-zabbix-infra/proxy/files/zabbix_proxy.conf.jinja
    - makedirs: True
    - defaults:
        Server: {{ proxy_server }}
        Hostname: {{ proxy_host }}
        DBName: {{ zbx_proxy_map.dbdir }}/zabbix_proxy.db
        CacheSize: 256M
        HistoryCacheSize: 24M
        StartDBSyncers: 2
        StartDiscoverers: 15
        StartPingers: 20
        StartPollers: 48
        StartPollersUnreachable: 40
        StartTrappers: 10
        UnavailableDelay: 60
        UnreachableDelay: 60
        UnreachablePeriod: 10
    - watch_in:
      - service: sae|zabbix-infra|proxy|service

sae|zabbix-infra|proxy|external-config:
  file.managed:
    - name: /etc/zabbix/zabbix_scripts.yaml
    - template: jinja
    - backup: False
    - mode: 640
    - user: zabbix
    - group: root
    - source: salt://sae-zabbix-infra/proxy/files/zabbix_scripts.yaml.jinja
    - makedirs: True
    - defaults:
        ExternalUserReadOnly: {{ zabbix.proxy.ExternalUserReadOnly }}
        ExternalPassReadOnly: {{ zabbix.proxy.ExternalPassReadOnly }}
    - watch_in:
      - service: sae|zabbix-infra|proxy|service

sae|zabbix-infra|proxy|java-gateway|service:
  service.running:
    - name: zabbix-java-gateway
    - enable: True
    - reload: True
    - require:
      - pkg: sae|zabbix-infra|proxy|packages

sae|zabbix-infra|proxy|service:
  service.running:
    - name: zabbix-proxy
    - enable: True
    - sig: /usr/sbin/zabbix_proxy
    - require:
      - pkg: sae|zabbix-infra|proxy|dep-packages
      - pkg: sae|zabbix-infra|proxy|packages
      - file: sae|zabbix-infra|proxy|config

sae-zabbix-infra|proxy|divert-init-script:
  cmd.run:
    - names:
      - dpkg-divert --add --local --divert /etc/init.d/zabbix-proxy.orig /etc/init.d/zabbix-proxy

sae|zabbix-infra|proxy|init-script:
  file.managed:
    - name: /etc/init.d/zabbix-proxy
    - mode: 755
    - user: root
    - group: root
    - source: salt://sae-zabbix-infra/proxy/files/zabbix-proxy

sae|zabbix-infra|proxy|proxy-logrotate:
  file.managed:
    - name: /etc/logrotate.d/zabbix-proxy-sqlite3
    - mode: 644
    - user: root
    - group: root
    - source: salt://sae-zabbix-infra/proxy/files/zabbix-proxy-sqlite3

sae|zabbix-infra|proxy|footprint-response-logrotate:
  file.managed:
    - name: /etc/logrotate.d/footprint-response
    - mode: 644
    - user: root
    - group: root
    - source: salt://sae-zabbix-infra/proxy/files/footprint-response

sae|zabbix-infra|proxy|large_customer:
  file.managed:
    - name: /usr/local/llnw/zabbix/json/LargeCustomer.json
    - mode: 644
    - user: root
    - group: root
    - source: salt://sae-zabbix-infra/proxy/files/LargeCustomer.json

sae|zabbix-infra|proxy|cron:
  cron.present:
    - name: /usr/local/llnw/zabbix-proxy/bin/get_vip_confs.sh
    - identifier: zabbix-infra-proxy-cron
    - user: root
    - minute: random

sae|zabbix-infra|proxy|vip_discovery:
  cron.present:
    - name: /usr/local/llnw/zabbix-proxy/external/vip-discovery-cron.pl
    - identifier: zabbix-infra-proxy-vip-discovery
    - user: root
    - minute: '*/30'

sae|zabbix-infra|proxy|proxy-db-health-sender:
  cron.present:
    - name: /usr/local/llnw/zabbix/bin/proxy-db-health-sender.py
    - identifier: proxy-db-health-sender
    - user: root
    - minute: '*/15'