{% from "sae-zabbix-infra/map.jinja" import zabbix with context %}
{% from "zabbix/map.jinja" import zabbix_proxy_ips, zabbix_proxy_ranges %}

include:
  - sae-zabbix-infra.sudo
  - sae-zabbix-infra.stage.external
  - firewall.standard
  - firewall.web
  - apache2
  - apache2.ssl
  - certs
  - resolver

sae|zabbix-infra|stage|devnet-firewall:
  firewall.accept:
    - tcp:
      - [ 10051, 69.28.130.113 ]
    - require_in:
      - firewall: core|firewall|final-reject

sae|zabbix-infra|stage|apt-config:
  pkgrepo.managed:
    - name: {{ zabbix.repo.Link }}/ {{ grains['oscodename'] }}/
    - file: /etc/apt/sources.list.d/llnw.zabbix.{{ grains['oscodename'] }}.list
    - require_in:
      - pkg: sae|zabbix-infra|stage|pkgs

sae|zabbix-infra|stage|pkgs:
  pkg.installed:
    - pkgs:
        - zabbix-server-mysql: 80:3.0.29-80+xenial+llnw.1
        - llnw-rest-client-perl: 1.0.0
        - llnw-rundeck-client-perl: 1.0.0
        - llnw-zabbixapi-perl: 1.0.0
        - llnw-zbxrundeck-perl: 1.0.2
        - zabbix-rt-tkt: 1.1.2
        - zabbix-get: 80:3.0.29-80+xenial+llnw.1
        - zabbix-sender:  80:3.0.29-80+xenial+llnw.1
        - zabbix-java-gateway: 80:3.0.29-80+xenial+llnw.1
        - zabbix-alert-scripts: 1.0
        - zabbix-frontend-php: 80:3.0.29-80+xenial+llnw.1
        - php7.0-curl: 7.0.33-0ubuntu0.16.04.9
        - php7.0-ldap: 7.0.33-0ubuntu0.16.04.9
        - php7.0-fpm: 7.0.33-0ubuntu0.16.04.9
        - libapache2-mod-fastcgi: 2.4.7~0910052141-1.2
        - librt-client-rest-perl: 1:0.50-1
        - llnw-zabbixapi-perl: 1.0.0
        - iptables-persistent: 1.0.4
    - skip_verify: True
    - refresh: True

sae|zabbix-infra|stage|proxy-fw:
  firewall.accept:
    - tcp:
      {% for zbx_ip in zabbix_proxy_ips %}
      - [10051, {{ zbx_ip }}]
      {% endfor %}
      {% for zbx_range in zabbix_proxy_ranges %}
      - [10051, {{ zbx_range }}]
      {% endfor %}
    - require_in:
      - firewall: core|firewall|final-reject

sae|zabbix-infra|stage|share-mem-conf:
  file.managed:
    - name: /etc/sysctl.conf
    - source: salt://sae-zabbix-infra/stage/files/sysctl.conf
    - template: jinja
    - mode: 644
    - user: root
    - group: root
    - makedirs: True
    - require:
      - pkg: sae|zabbix-infra|stage|pkgs

sae|zabbix-infra|stage|server-conf:
  file.managed:
    - name: /etc/zabbix/zabbix_server.conf
    - source: salt://sae-zabbix-infra/stage/files/zabbix_server.conf
    - template: jinja
    - mode: 640
    - user: zabbix
    - group: zabbix
    - makedirs: True
    - require:
      - pkg: sae|zabbix-infra|stage|pkgs

sae|zabbix-infra|stage|alert-scripts:
  file.directory:
    - name: /usr/local/zabbix/alert_scripts
    - makedirs: True
    - user: zabbix
    - group: zabbix
    - dir_mode: 750
    - file_mode: 750
    - recurse:
        - user
        - group
        - mode
    - require:
      - pkg: sae|zabbix-infra|stage|pkgs

sae|zabbix-infra|stage|external-scripts:
  file.directory:
    - name: /usr/local/zabbix/external_scripts
    - makedirs: True
    - user: zabbix
    - group: zabbix
    - dir_mode: 750
    - file_mode: 750
    - recurse:
        - user
        - group
        - mode
    - require:
      - pkg: sae|zabbix-infra|stage|pkgs

sae|zabbix-infra|stage|bin-scripts:
  file.directory:
    - name: /usr/local/zabbix/bin
    - makedirs: True
    - user: zabbix
    - group: zabbix
    - dir_mode: 750
    - file_mode: 750
    - recurse:
        - user
        - group
        - mode
    - require:
      - pkg: sae|zabbix-infra|stage|pkgs

sae|zabbix-infra|stage|java-gateway|service:
  service.running:
    - name: zabbix-java-gateway
    - enable: True
    - reload: True
    - require:
      - pkg: sae|zabbix-infra|stage|pkgs

sae|zabbix-infra|stage|web-conf:
  file.managed:
    - name: /etc/zabbix/web/zabbix.conf.php
    - source: salt://sae-zabbix-infra/stage/files/zabbix.conf.php
    - template: jinja
    - mode: 644
    - user: www-data
    - group: root
    - makedirs: True
    - require:
      - pkg: sae|zabbix-infra|stage|pkgs

sae|zabbix-infra|stage|web-api-conf:
  file.managed:
    - name: /usr/share/zabbix/llnw/config.php
    - source: salt://sae-zabbix-infra/stage/files/config.php
    - template: jinja
    - mode: 644
    - user: www-data
    - group: root
    - makedirs: True
    - require:
      - pkg: sae|zabbix-infra|stage|pkgs

sae|zabbix-infra|stage|dashboard-override:
  file.managed:
    - name: /usr/share/zabbix/app/controllers/CControllerDashboardView.php
    - source: salt://sae-zabbix-infra/stage/files/CControllerDashboardView.php
    - mode: 644
    - user: root
    - group: root
    - makedirs: True
    - require:
      - pkg: sae|zabbix-infra|stage|pkgs

sae|zabbix-infra|stage|zabbix-conf:
  file.managed:
    - name: /etc/apache2/conf/zabbix.conf
    - source: salt://sae-zabbix-infra/stage/files/apache/zabbix.conf
    - template: jinja
    - mode: 640
    - user: root
    - group: root
    - makedirs: True
    - require:
      - pkg: sae|zabbix-infra|stage|pkgs

sae|zabbix-infra|stage|zabbix-sites-conf:
  file.managed:
    - name: /etc/apache2/sites-available/zabbix.conf
    - source: salt://sae-zabbix-infra/stage/files/apache/sites-available/zabbix.conf
    - template: jinja
    - mode: 640
    - user: root
    - group: root
    - makedirs: True
    - require:
      - pkg: sae|zabbix-infra|stage|pkgs

sae|zabbix-infra|stage|disable-default:
  apache_site.disabled:
    - name: 000-default.conf

sae|zabbix-infra|stage|apache-configuration:
  apache_site.enabled:
    - name: zabbix.conf
  apache_module.enabled:
    - name: ssl
  service.running:
    - name: apache2
    - enable: True
    - reload: True
    - watch:
      - apache_site: sae|zabbix-infra|stage|apache-configuration
      - apache_module: sae|zabbix-infra|stage|apache-configuration
      - file: sae|zabbix-infra|stage|web-conf
    - require:
      - pkg: sae|zabbix-infra|stage|pkgs
