{% set environment = salt['grains.get']('team_env', 'production') %}

{% if ('salt_states_vb' in grains and grains['salt_states_vb'] == True) or grains['singel'] is defined or environment == 'lab' %}
  {% set repo_env='testing' %}
{% else %}
  {% if environment == 'production' %}
    {% set repo_env='production' %}
  {% else %}
    {% set repo_env='staging' %}
  {% endif %}
{% endif %}

include:
  - firewall.standard
  - certs


sae|znc|pkg-repo:
  pkgrepo.managed:
    - names:
      - deb http://repo.llnw.net/llnw/ubuntu/{{ repo_env }}/znc {{ grains['oscodename'] }}/
    - file: /etc/apt/sources.list.d/znc.list
    - refresh_db: false
    - watch_in:
      - module: core|base_repos|apt-refresh-db

sae|znc|pkgs:
  pkg.latest:
   - pkgs:
     - znc-llnw
     - sasl2-bin
   - require:
     - pkgrepo: sae|znc|pkg-repo

sae|znc|user:
  user.present:
    - name: znc
    - gid_from_name: True
    - home: /var/lib/znc
    - shell: /bin/false
    - system: True
    - createhome: False
    - groups:
      - sasl
      - ssl-cert
    - require:
      - pkg: sae|znc|pkgs
      - group: sae|znc|group

sae|znc|group:
  group.present:
    - name: znc
    - system: True
    - require:
      - pkg: sae|znc|pkgs

sae|znc|data-dir:
  file.directory:
    - name: /var/lib/znc
    - user: znc
    - group: znc
    - require:
      - pkg: sae|znc|pkgs
      - group: sae|znc|group
      - user: sae|znc|user

sae|znc|systemd-init:
  file.managed:
    - name: /lib/systemd/system/znc.service
    - source: salt://sae-znc/files/znc.service
    - template: jinja
    - require:
      - pkg: sae|znc|pkgs

sae|znc|init-reload:
  module.run:
    - name: service.systemctl_reload
    - onchanges:
      - file: sae|znc|systemd-init

sae|znc|sasl-config:
  file.managed:
    - name: /etc/default/saslauthd
    - source: salt://sae-znc/files/saslauthd
    - template: jinja
    - require:
      - pkg: sae|znc|pkgs

sae|znc|znc-service:
  service.enabled:
    - name: znc
    - require:
      - file: sae|znc|systemd-init
      - pkg: sae|znc|pkgs

sae|znc|sasl-service:
  service.running:
    - name: saslauthd
    - enable: true
    - require:
      - file: sae|znc|systemd-init
      - pkg: sae|znc|pkgs

sae|znc|znc-port-firewall:
  firewall.accept:
    - tcp:
      - 8388
    - require_in:
      - firewall: core|firewall|final-reject

sae|znc|disable_ipv6_all:
  sysctl.present:
    - name: net.ipv6.conf.all.disable_ipv6
    - value: 1

sae|znc|disable_ipv6_default:
  sysctl.present:
    - name: net.ipv6.conf.default.disable_ipv6
    - value: 1

sae|znc|disable_ipv6_lo:
  sysctl.present:
    - name: net.ipv6.conf.lo.disable_ipv6
    - value: 1
